@@ -25,10 +25,9 @@
 
 /* Methods file for Barrel */
 
-#if defined(USE_RPLAY) || defined(USE_NAS) || defined(USE_VMSPLAY) || defined(USE_ESOUND) || defined(WINVER) || defined(DEF_PLAY)
-#define USE_SOUND
-extern void playSound(char * filename);
-#endif
+#include "file.h"
+#include "rngs.h"
+#include "sound.h"
 #include "BarrelP.h"
 
 #ifndef PICTURE
@@ -220,8 +219,11 @@ static XtActionsRec actionsListBarrel[] =
 static XtResource resourcesBarrel[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(BarrelWidget, barrel.username),
-	 XtRString, (caddr_t) "guest"},
+	 XtOffset(BarrelWidget, barrel.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(BarrelWidget, barrel.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(BarrelWidget, barrel.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
@@ -312,6 +314,12 @@ static XtResource resourcesBarrel[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(BarrelWidget, barrel.cheat),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(BarrelWidget, barrel.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(BarrelWidget, barrel.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(BarrelWidget, barrel.menu),
 	 XtRString, (caddr_t) "-1"},
@@ -363,78 +371,6 @@ BarrelClassRec barrelClassRec =
 
 WidgetClass barrelWidgetClass = (WidgetClass) & barrelClassRec;
 
-#ifndef HAVE_USLEEP
-#if !defined( VMS ) || defined( XVMSUTILS ) || ( __VMS_VER >= 70000000 )
-#ifdef USE_XVMSUTILS
-#include <X11/unix_time.h>
-#endif
-#if HAVE_SYS_TIME_H
-#include <sys/time.h>
-#else
-#if HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#endif
-#endif
-#endif
-#if defined(SYSV) || defined(SVR4)
-#ifdef LESS_THAN_AIX3_2
-#include <sys/poll.h>
-#else /* !LESS_THAN_AIX3_2 */
-#include <poll.h>
-#endif /* !LESS_THAN_AIX3_2 */
-#endif /* defined(SYSV) || defined(SVR4) */
-
-/* not static in case usleep found in system include */
-int
-usleep(unsigned int usec)
-{
-#if (defined (SYSV) || defined(SVR4)) && !defined(__hpux)
-#if defined(HAVE_NANOSLEEP)
-	{
-		struct timespec rqt;
-
-		rqt.tv_nsec = 1000 * (usec % (unsigned int) 1000000);
-		rqt.tv_sec = usec / (unsigned int) 1000000;
-		return nanosleep(&rqt, NULL);
-	}
-#else
-	(void) poll(
-#if defined(__cplusplus) || defined(c_plusplus)
-		(pollfd *) /* guess */
-#else
-		(void *)
-#endif
-		0, (int) 0, usec / 1000);	/* ms resolution */
-#endif
-#else
-#ifdef VMS
-	long timadr[2];
-
-	if (usec != 0) {
-		timadr[0] = -usec * 10;
-		timadr[1] = -1;
-
-		sys$setimr(4, &timadr, 0, 0, 0);
-		sys$waitfr(4);
-	}
-#else
-	struct timeval time_out;
-
-#if 0
-	/* (!defined(AIXV3) && !defined(__hpux)) */
-	extern int select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
-
-#endif
-
-	time_out.tv_usec = usec % (unsigned int) 1000000;
-	time_out.tv_sec = usec / (unsigned int) 1000000;
-	(void) select(0, (void *) 0, (void *) 0, (void *) 0, &time_out);
-#endif
-#endif
-	return 0;
-}
-#endif
-
 void
 SetBarrel(BarrelWidget w, int reason)
 {
@@ -460,13 +396,13 @@ loadFont(BarrelWidget w)
 	if ((w->barrel.fontInfo = XLoadQueryFont(display,
 			w->barrel.font)) == NULL) {
 		(void) sprintf(buf,
-			"Cannot open %s font.\nAttempting %s font as alternate\n",
+			"Can not open %s font.\nAttempting %s font as alternate\n",
 			w->barrel.font, altfontname);
 		DISPLAY_WARNING(buf);
 		if ((w->barrel.fontInfo = XLoadQueryFont(display,
 				altfontname)) == NULL) {
 			(void) sprintf(buf,
-				"Cannot open %s alternate font.\nUse the -font option to specify a font to use.\n",
+				"Can not open %s alternate font.\nUse the -font option to specify a font to use.\n",
 				altfontname);
 			DISPLAY_WARNING(buf);
 		}
@@ -488,77 +424,6 @@ loadFont(BarrelWidget w)
 #define LOGFILE "barrel.log"
 #endif
 
-#if (!defined(WINVER) || (WINVER <= 0x030a)) /* if X or WINDOWS 3.1 or less */
-static void
-Sleep(unsigned int cMilliseconds)
-{
-#if (defined(WINVER) && (WINVER <= 0x030a))
-	unsigned long time_out = GetTickCount() + cMilliseconds;
-
-	while (time_out > GetTickCount());
-#else
-	(void) usleep(cMilliseconds * 1000);
-#endif
-}
-#endif
-
-static void
-initTimer(BarrelWidget w)
-{
-#ifdef WINVER
-	w->barrel.oldTime = GetTickCount();
-#else
-	XFlush(XtDisplay(w));
-	(void) X_GETTIMEOFDAY(&(w->barrel.oldTime));
-#endif
-}
-
-
-static void
-useTimer(BarrelWidget w, int delay)
-{
-	int sleepTime;
-#ifdef WINVER
-	long tv = GetTickCount();
-
-	sleepTime = delay - (tv - w->barrel.oldTime);
-	w->barrel.oldTime = tv;
-	if (sleepTime > 0) {
-		Sleep((unsigned int) sleepTime);
-	}
-#else
-	struct timeval tv;
-
-	XFlush(XtDisplay(w));
-	(void) X_GETTIMEOFDAY(&tv);
-	sleepTime = delay * 1000 - ((tv.tv_sec - w->barrel.oldTime.tv_sec) *
-		1000000 + tv.tv_usec - w->barrel.oldTime.tv_usec);
-	w->barrel.oldTime.tv_sec = tv.tv_sec;
-	w->barrel.oldTime.tv_usec = tv.tv_usec;
-	if (sleepTime > 0) {
-		(void) usleep((unsigned int) sleepTime);
-	}
-#endif
-}
-
-void
-intCat(char ** string, const char * var1, const int var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + 21))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%d", var1, var2);
-}
-
-void
-stringCat(char ** string, const char * var1, const char * var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + strlen(var2) + 1))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%s", var1, var2);
-}
-
 static void
 CheckTiles(BarrelWidget w)
 {
@@ -873,15 +738,15 @@ DrawTile(BarrelWidget w, int pos, Boolean blank, Boolean erase,
 		return;
 	}
 #ifdef WINVER
-	w->barrel.hOldBitmap = (HBITMAP) SelectObject(w->barrel.memDC,
+	w->core.hOldBitmap = (HBITMAP) SelectObject(w->core.memDC,
 		w->barrel.bufferTiles[pressedOffset]);
 	BitBlt(w->core.hDC,
 		dx, dy,
 		w->barrel.tileSize.x, w->barrel.tileSize.y,
-		w->barrel.memDC,
+		w->core.memDC,
 		sx, sy,
 		SRCCOPY);
-	SelectObject(w->barrel.memDC, w->barrel.hOldBitmap);
+	(void) SelectObject(w->core.memDC, w->core.hOldBitmap);
 #else
 	XSetGraphicsExposures(XtDisplay(w), w->barrel.tileGC, False);
 	XCopyArea(XtDisplay(w),
@@ -1029,7 +894,8 @@ AnimateSlide(BarrelWidget w, int numTiles, int dir, int fast)
 	  gapI++;
 	if (numTiles < 0)
 	  numTiles = -numTiles;
-	initTimer(w);
+	FLUSH(w);
+	initTimer(w->barrel.oldTime);
 	for (inc = 0; inc < moveI + gapI; inc += gapI) {
 	  if (inc > moveI)
 	    inc = moveI;
@@ -1076,7 +942,8 @@ AnimateSlide(BarrelWidget w, int numTiles, int dir, int fast)
 		}
 	      }
 	    }
-	    useTimer(w, w->barrel.delay / fast);
+	    FLUSH(w);
+	    useTimer(&(w->barrel.oldTime), w->barrel.delay / fast);
 	  }
 	}
 	for (plunger = 0; plunger < NUMPLUNGERS; plunger++) {
@@ -1114,7 +981,7 @@ AnimateRotate(BarrelWidget w, int start, int finish, int direction, int fast)
 {
 #ifdef WINVER
 	HDC memDC;
-	HBITMAP hBit;
+	HBITMAP hBitmap, hOldBitmap;
 #else
 	Pixmap bufferBox;
 	XWindowAttributes xgwa;
@@ -1130,9 +997,9 @@ AnimateRotate(BarrelWidget w, int start, int finish, int direction, int fast)
 
 #ifdef WINVER
 	memDC = CreateCompatibleDC(w->core.hDC);
-	hBit = CreateCompatibleBitmap(w->core.hDC, size * moveI + 1,
+	hBitmap = CreateCompatibleBitmap(w->core.hDC, size * moveI + 1,
 		w->barrel.puzzleSize.y);
-	SelectObject(memDC, hBit);
+	hOldBitmap = SelectObject(memDC, hBitmap);
 	BitBlt(memDC, 0, 0,
 		size * moveI,
 		w->barrel.puzzleSize.y,
@@ -1140,6 +1007,7 @@ AnimateRotate(BarrelWidget w, int start, int finish, int direction, int fast)
 		start * moveI + w->barrel.puzzleOffset.x + 1,
 		w->barrel.puzzleOffset.y,
 		SRCCOPY);
+	(void) SelectObject(memDC, hOldBitmap);
 #else
 	(void) XGetWindowAttributes(XtDisplay(w), XtWindow(w), &xgwa);
 
@@ -1158,7 +1026,8 @@ AnimateRotate(BarrelWidget w, int start, int finish, int direction, int fast)
 		0, 0);
 	XSetGraphicsExposures(XtDisplay(w), w->barrel.frameGC, False);
 #endif
-	initTimer(w);
+	FLUSH(w);
+	initTimer(w->barrel.oldTime);
 	for (inc = 0; inc < moveJ + gapJ; inc += gapJ) {
 		if (inc > moveJ)
 			inc = moveJ;
@@ -1167,7 +1036,7 @@ AnimateRotate(BarrelWidget w, int start, int finish, int direction, int fast)
 		else
 			i = w->barrel.puzzleSize.y - inc + 1;
 #ifdef WINVER
-		SelectObject(memDC, hBit);
+		hOldBitmap = SelectObject(memDC, hBitmap);
 		BitBlt(w->core.hDC,
 			start * moveI + w->barrel.puzzleOffset.x + 1,
 			w->barrel.puzzleOffset.y + 1,
@@ -1185,6 +1054,7 @@ AnimateRotate(BarrelWidget w, int start, int finish, int direction, int fast)
 			memDC,
 			0, 0,
 			SRCCOPY);
+		(void) SelectObject(memDC, hOldBitmap);
 #else
 
 		XCopyArea(XtDisplay(w), bufferBox, XtWindow(w),
@@ -1203,10 +1073,11 @@ AnimateRotate(BarrelWidget w, int start, int finish, int direction, int fast)
 			w->barrel.puzzleSize.y - i + w->barrel.puzzleOffset.y -
 			w->barrel.delta.y + 1);
 #endif
-		useTimer(w, w->barrel.delay / fast);
+		FLUSH(w);
+		useTimer(&(w->barrel.oldTime), w->barrel.delay / fast);
 	}
 #ifdef WINVER
-	DeleteObject(hBit);
+	DeleteObject(hBitmap);
 	DeleteDC(memDC);
 #else
 	XFreePixmap(XtDisplay(w), bufferBox);
@@ -2126,10 +1997,14 @@ SetValuesBarrel(BarrelWidget w)
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) strcpy(w->barrel.moveSound, szBuf);
 	w->barrel.moveSound[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "name", "Guest",
+	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
 			szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->barrel.username, szBuf);
-	w->barrel.username[80] = 0;
+	(void) strcpy(w->barrel.userName, szBuf);
+	w->barrel.userName[80] = 0;
+	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
+			szBuf, sizeof (szBuf), INIFILE);
+	(void) strcpy(w->barrel.scoreFile, szBuf);
+	w->barrel.scoreFile[80] = 0;
 }
 
 void
@@ -2429,8 +2304,8 @@ QuitBarrel(BarrelWidget w
 		if (w->barrel.bufferTiles != NULL) {
 			DeleteObject(w->barrel.bufferTiles);
 		}
-		DeleteDC(w->barrel.memDC);
-		w->barrel.memDC = NULL;
+		DeleteDC(w->core.memDC);
+		w->core.memDC = NULL;
 	}
 #else
 	Display *display = XtDisplay(w);
@@ -2476,9 +2351,9 @@ ResizeTiles(BarrelWidget w)
 	int sel;
 
 #ifdef WINVER
-	if (w->barrel.memDC == NULL) {
-		w->barrel.memDC = CreateCompatibleDC(w->core.hDC);
-		if (w->barrel.memDC == NULL) {
+	if (w->core.memDC == NULL) {
+		w->core.memDC = CreateCompatibleDC(w->core.hDC);
+		if (w->core.memDC == NULL) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
