@@ -37,6 +37,7 @@
 #ifndef WINVER
 #define XtNselectCallback ((char *) "selectCallback")
 #define XtNuserName ((char *) "userName")
+#define XtNscoreFile ((char *) "scoreFile")
 #define XtNtiles ((char *) "tiles")
 #define XtNfaces ((char *) "faces")
 #define XtNorient ((char *) "orient")
@@ -63,7 +64,10 @@
 #define XtNfaceColor3 ((char *) "faceColor3")
 #define XtNfaceColor4 ((char *) "faceColor4")
 #define XtNfaceColor5 ((char *) "faceColor5")
+#define XtNscoreOnly ((char *) "scoreOnly")
+#define XtNversionOnly ((char *) "versionOnly")
 #define XtCUserName ((char *) "UserName")
+#define XtCScoreFile ((char *) "ScoreFile")
 #define XtCTiles ((char *) "Tiles")
 #define XtCFaces ((char *) "Faces")
 #define XtCOrient ((char *) "Orient")
@@ -114,23 +118,6 @@ typedef struct {
 #define BARREL_UNDO 12
 #define BARREL_SPEED 13
 
-#ifdef WINVER
-#ifdef UNIXDELIM
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#else
-#define CURRENTDELIM ".\\"
-#define FINALDELIM "\\"
-#endif
-#else
-#ifdef VMS
-#define CURRENTDELIM "[]"
-#define FINALDELIM ""
-#else
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#endif
-#endif
 #define MINFACES 5
 #define MAXFACES 5
 #define MINTILES 6
@@ -153,8 +140,5 @@ typedef struct {
 
 typedef struct _BarrelRec *BarrelWidget;
 
-extern void intCat(char ** string, const char * var1, const int var2);
-extern void stringCat(char ** string, const char * var1, const char * var2);
-
 #endif /* _XtBarrel_h */
 /* DON'T ADD STUFF AFTER THIS #endif */
