@@ -27,38 +27,25 @@
   Version 7: 03/11/15 X/Windows
 */
 
+#include "file.h"
 #ifdef WINVER
 #include "BarrelP.h"
 #include "wbarrel.h"
 #define TITLE "wbarrel"
 
 static BarrelRec widget;
-static HWND Wnd;
 
 #ifndef SCOREPATH
-#define SCOREPATH "c:\\Windows"
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
 #endif
-#define PRINT_MESSAGE(b) (void) MessageBox(Wnd, (LPCSTR) b, "Warning", MB_OK);
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
 #define SET_STARTED(w,b) w->barrel.started = b
 #else
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
-#ifdef VMS
-#include <unixlib.h>
-#define getlogin() cuserid(NULL)
-#else
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif
-#if HAVE_FCNTL_H
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#endif
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
+#include "xwin.h"
 #include <X11/Shell.h>
 #include <X11/cursorfont.h>
 #ifdef HAVE_MOTIF
@@ -79,7 +66,7 @@ static HWND Wnd;
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
-#define SET_STARTED(w,b) XtSetArg(arg[0], XtNstart, b); XtSetValues(w, arg, 1)
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
 #include "Barrel.h"
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
@@ -87,29 +74,36 @@ static HWND Wnd;
 #endif
 #include "icons/barrel.xbm"
 #ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
 #define SCOREPATH "/var/games/xpuzzles"
 #endif
 #endif
+#endif
 
-#ifdef HAVE_MOTIF
+#ifndef WINVER
 static const char aboutHelp[] = {
-	"Version 7.1.3\n"
+	"Barrel Version 7.1.5\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
 	"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
+
 static const char optionsHelp[] = {
-	"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]] "
-	"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"[-{foreground|fg} {color}] [-{background|bg} {color}] "
-	"[-{border|bd} {color}] [-tile {color}]\n"
-	"[-face{0|1|2|3|4|5} {color}] [-[no]orient] [-[no]pairs] "
-	"[-[no]install] [-picture {filename}] [-delay msecs]\n"
-	"[-[no]sound] [-bumpsound {filename}] [-movesound {filename}] "
-	"[-base {int}] [-{font|fn} {fontname}] [-username {string}]\n"
+	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+	"\t[-{border|bd} {color}] [-tile {color}]\n"
+	"\t[-face{0|1|2|3|4|5} {color}] [-[no]orient] [-[no]pairs]\n"
+	"\t[-[no]install] [-picture {filename}] [-delay msecs]\n"
+	"\t[-[no]sound] [-bumpSound {filename}] [-moveSound {filename}]\n"
+	"\t[-base {int}] [-{font|fn} {fontname}] [-userName {string}]\n"
+	"\t[-scoreFile {filename}] [-scores] [-version]\n"
 };
 #endif
+
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
 	"The Barrel, the Billion Barrel, or Wonderful Barrel also "
@@ -122,6 +116,7 @@ static const char descriptionHelp[] = {
 	"separate from the other two.  There are 2 separate wheels or\n"
 	"disks that rotate about the center axis.\n"
 };
+
 static const char featuresHelp[] = {
 	"Press \"mouse-left\" button to move a tile. Release "
 	"\"mouse-left\" button in the same row would move the tile towards\n"
@@ -152,6 +147,8 @@ static const char featuresHelp[] = {
 	"\n"
 	"Press \"W\" or \"w\" keys to save a puzzle.\n"
 	"\n"
+	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+	"\n"
 	"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
 	"\n"
 	"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
@@ -174,6 +171,7 @@ static const char featuresHelp[] = {
 	"Use the shift key and the up or down arrow keys to rotate "
 	"all the tiles.\n"
 };
+
 static const char referencesHelp[] = {
 	"L. E. Horden, Sliding Piece Puzzles (Recreations in "
 	"Mathematics Series), Oxford University\n"
@@ -185,6 +183,7 @@ static const char referencesHelp[] = {
 	"New York, 1982, pp 50-54?\n"
 };
 #endif
+
 static const char solveHelp[] = {
 	"Auto-solver: sorry, not implemented.\n"
 };
@@ -193,7 +192,7 @@ static const char solveHelp[] = {
 #define SCOREFILE "barrel.scores"
 #endif
 
-#define NEVER -1
+#define NEVER (-1)
 #define FILENAMELEN 1024
 #define USERNAMELEN 120
 #define MESSAGELEN (USERNAMELEN+64)
@@ -224,20 +223,21 @@ static char buff[21];
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
+static Arg arg[3];
 #else
 static char titleDsp[TITLELEN] = "";
 #endif
+static char scoreFileName[FILENAMELEN] = SCOREFILE;
+static char fileName[FILENAMELEN];
 #ifdef WINVER
 #define MAXPROGNAME 80
 static char progDsp[MAXPROGNAME] = TITLE;
-static char usernameDsp[USERNAMELEN] = "Guest";
+static char userNameDsp[USERNAMELEN] = "Guest";
 #else
 static Pixmap barrelIcon = None;
 static Widget topLevel, barrel;
-static Arg arg[3];
 static char *progDsp;
-static char usernameDsp[USERNAMELEN] = "";
-#endif
+static char userNameDsp[USERNAMELEN] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -248,29 +248,25 @@ PrintState(Widget w, char *msg)
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
 		XtError("PrintState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
-	XtSetArg(arg[0], XmNlabelString, xmstr);
-	XtSetValues(w, arg, 1);
+	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
-#else
+#endif
+
 static void
-PrintState(
-#ifndef WINVER
-Widget w,
-#endif
-Boolean pairs, int moves, char *msg)
+PrintRecords(void)
 {
-	if (pairs)
-		(void) sprintf(titleDsp, "%s: norm@ (%d/%s) - %s",
-			progDsp, moves, recordDsp, msg);
-	else
-		(void) sprintf(titleDsp, "%s: ind@ (%d/%s) - %s",
-			progDsp, moves, recordDsp, msg);
-#ifdef WINVER
-	SetWindowText(Wnd, (LPSTR) titleDsp);
-#else
-	XtSetArg(arg[0], XtNtitle, titleDsp);
-	XtSetValues(w, arg, 1);
-#endif
+	int k, l;
+
+	(void) printf("        BARREL  HALL OF FAME\n\n");
+	(void) printf("PAIR ORIENT USER            MOVES\n");
+	for (l = 0; l < 2; l++)
+		for (k = 0; k < 2; k++) {
+			if (barrelRecord[l][k].score > 0)
+				(void) printf("%4d%7d %-12s%9d\n",
+					l, k,
+					barrelRecord[l][k].name,
+					barrelRecord[l][k].score);
+		}
 }
 #endif
 
@@ -292,21 +288,21 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int k, l, n;
-	char username[USERNAMELEN];
+	char userName[USERNAMELEN];
 	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *fname, *lname;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
+	stringCat(&buf1, CURRENTDELIM, scoreFileName);
 	lname = buf1;
 	stringCat(&buf1, SCOREPATH, FINALDELIM);
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "r")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "r")) == NULL) {
+	(void) strncpy(fileName, lname, USERNAMELEN);
+	if ((fp = fopen(fileName, "r")) == NULL) {
+		(void) strncpy(fileName, fname, USERNAMELEN);
+		/* Try installed directory. */
+		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
@@ -335,12 +331,12 @@ ReadRecords(void)
 	free(fname);
 	for (l = 0; l < 2; l++)
 		for (k = 0; k < 2; k++) {
-			(void) fscanf(fp, "%d %s\n", &n, username);
+			(void) fscanf(fp, "%d %s\n", &n, userName);
 			if (n <= barrelRecord[l][k].score ||
 					barrelRecord[l][k].score <= NEVER) {
 				barrelRecord[l][k].score = n;
 				(void) strncpy(barrelRecord[l][k].name,
-					username, USERNAMELEN);
+					userName, USERNAMELEN);
 			}
 		}
 	(void) fclose(fp);
@@ -351,61 +347,31 @@ WriteRecords(void)
 {
 	FILE *fp;
 	int k, l;
-	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *buf1 = NULL;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
-	lname = buf1;
-	stringCat(&buf1, SCOREPATH, FINALDELIM);
-	stringCat(&buf2, buf1, SCOREFILE);
-	free(buf1);
-	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "w")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "w")) == NULL) {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, " or ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-			free(lname);
-			free(fname);
-			return;
-		}
-/* Probably annoying */
-#if 0
-		else {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, ", falling back to ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-		}
-#endif
+	if ((fp = fopen(fileName, "w")) == NULL) {
+		stringCat(&buf1, "Can not write to ", fileName);
+		PRINT_MESSAGE(buf1);
+		free(buf1);
+		return;
 	}
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockfile[FILENAMELEN];
+		char lockFile[FILENAMELEN];
 
-		(void) strncpy(lockfile, name, FILENAMELEN - 6);
-		(void) strcat(lockfile, ".lock");
-		while (((lfd = open(lockfile, O_CREAT | O_EXCL, 0644)) < 0) &&
+		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strcat(lockFile, ".lock");
+		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
 			(void) sleep(1);
 		if (lfd < 0) {
 #if 1
 			(void) fprintf(stderr,
-			  "Lock file exists... guessing its an old one.\n");
+				"Lock file exists... guessing its an old one.\n");
 #else
 			(void) fprintf(stderr,
-			  "Lock file exists... score not recorded - sorry.\n");
+				"Lock file exists... score not recorded - sorry.\n");
 			return;
 #endif
 		}
@@ -420,12 +386,10 @@ WriteRecords(void)
 		}
 #if HAVE_FCNTL_H
 		(void) close(lfd);
-		(void) unlink(lockfile);
+		(void) unlink(lockFile);
 #endif
 		(void) fclose(fp);
 	}
-	free(lname);
-	free(fname);
 }
 
 static void
@@ -433,14 +397,13 @@ PrintRecord(Boolean orient, Boolean pairs, Boolean practice)
 {
 	int k = (orient) ? 1 : 0, l = (pairs) ? 1 : 0;
 
-	if (practice)
+	if (practice) {
 		(void) strncpy(recordDsp, "practice", MESSAGELEN);
 #if 0
-	else if (tiles > MAXTILES) {
+	} else if (tiles > MAXTILES) {
 		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
-	}
 #endif
-	else if (barrelRecord[l][k].score <= NEVER) {
+	} else if (barrelRecord[l][k].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
 		(void) sprintf(recordDsp, "%d %s",
@@ -452,6 +415,32 @@ PrintRecord(Boolean orient, Boolean pairs, Boolean practice)
 #endif
 }
 
+static void
+PrintStatus(char *msg, int nMoves
+#ifndef HAVE_MOTIF
+		, Boolean pairs
+#endif
+		)
+{
+#ifdef HAVE_MOTIF
+	PrintState(message, msg);
+	(void) sprintf(buff, "%d", nMoves);
+	PrintState(moves, buff);
+#else
+	if (pairs)
+		(void) sprintf(titleDsp, "%s: norm@ (%d/%s) - %s",
+			progDsp, nMoves, recordDsp, msg);
+	else
+		(void) sprintf(titleDsp, "%s: ind@ (%d/%s) - %s",
+			progDsp, nMoves, recordDsp, msg);
+#ifdef WINVER
+	SetWindowText(widget.core.hWnd, (LPSTR) titleDsp);
+#else
+	XtVaSetValues(XtParent(barrel), XtNtitle, titleDsp, NULL);
+#endif
+#endif
+}
+
 static Boolean
 HandleSolved(int counter, Boolean orient, Boolean pairs)
 {
@@ -461,7 +450,7 @@ HandleSolved(int counter, Boolean orient, Boolean pairs)
 			 barrelRecord[l][k].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		barrelRecord[l][k].score = counter;
-		(void) strncpy(barrelRecord[l][k].name, usernameDsp,
+		(void) strncpy(barrelRecord[l][k].name, userNameDsp,
 			USERNAMELEN);
 		WriteRecords();
 		PrintRecord(orient, pairs, False);
@@ -480,7 +469,7 @@ Widget w
 )
 {
 	Boolean orient, pairs, practice;
-	char *username;
+	char *userName, *scoreFile;
 
 #ifdef WINVER
 	InitializeBarrel(w, brush);
@@ -489,13 +478,33 @@ Widget w
 	orient = w->barrel.orient;
 	pairs = w->barrel.pairs;
 	practice = w->barrel.practice;
-	username = w->barrel.username;
+	userName = w->barrel.userName;
+	scoreFile = w->barrel.scoreFile;
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
 #else
+	Boolean scoreOnly, versionOnly;
+
 	XtVaGetValues(w,
-		XtNuserName, &username,
+		XtNuserName, &userName,
+		XtNscoreFile, &scoreFile,
 		XtNorient, &orient,
 		XtNpairs, &pairs,
-		XtNpractice, &practice, NULL);
+		XtNpractice, &practice,
+		XtNscoreOnly, &scoreOnly,
+		XtNversionOnly, &versionOnly, NULL);
+	if (versionOnly) {
+		(void) printf(aboutHelp);
+		exit(0);
+	}
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+	if (scoreOnly) {
+		InitRecords();
+		ReadRecords();
+		PrintRecords();
+		exit(0);
+	}
 #ifdef HAVE_MOTIF
 #if 0
 	if (tiles > MAXTILES)
@@ -518,31 +527,29 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(usernameDsp, username, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #endif
-	if (!strcmp(username, "") || !strcmp(username, "(null)") ||
-	    !strcmp(username, NOACCESS) || !strcmp(username, NOBODY)) {
-		/* The NOACCESS is not necessary, but it may stop silliness. */
+	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
+			!strcmp(userName, NOACCESS) ||
+			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(usernameDsp, username, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(usernameDsp, "%s", getlogin());
-		if (!strcmp(usernameDsp, "") ||
-				!strcmp(usernameDsp, "(null)") ||
-				!strcmp(usernameDsp, NOACCESS) ||
-				!strcmp(usernameDsp, NOBODY))
+		(void) sprintf(userNameDsp, "%s", getlogin());
+		if (!strcmp(userNameDsp, "") ||
+				!strcmp(userNameDsp, "(null)") ||
+				!strcmp(userNameDsp, NOACCESS) ||
+				!strcmp(userNameDsp, NOBODY))
 			/* It really IS nobody */
-			(void) sprintf(usernameDsp, "%s", "guest");
+			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
 	PrintRecord(orient, pairs, practice);
+	PrintStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
-#endif
-		pairs, movesDsp, messageDsp);
+		, pairs
 #endif
+		);
 }
 
 #ifdef WINVER
@@ -586,16 +593,16 @@ CallbackBarrel(Widget w, caddr_t clientData, barrelCallbackStruct * callData)
 #ifdef HAVE_MOTIF
 			XtManageChild(practiceDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 9); /* menu choice */
-			XtSetValues(barrel, arg, 1);
+			XtVaSetValues(barrel,
+				XtNmenu, 9, NULL); /* menu choice */
 #endif
 			break;
 		case BARREL_RANDOMIZE_QUERY:
 #ifdef HAVE_MOTIF
 			XtManageChild(randomizeDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-			XtSetValues(barrel, arg, 1);
+			XtVaSetValues(barrel,
+				XtNmenu, 5, NULL); /* menu choice */
 #endif
 			break;
 #endif
@@ -604,7 +611,6 @@ CallbackBarrel(Widget w, caddr_t clientData, barrelCallbackStruct * callData)
 			(void) MessageBox(w->core.hWnd, solveHelp,
 				"Auto-Solve", MB_OK);
 #else
-
 #ifdef HAVE_MOTIF
 			XtManageChild(solveDialog);
 #else
@@ -649,10 +655,10 @@ CallbackBarrel(Widget w, caddr_t clientData, barrelCallbackStruct * callData)
 				movesDsp = 0;
 			else if (cheat)
 				(void) sprintf(messageDsp,
-					"No cheating %s!!", usernameDsp);
+					"No cheating %s!!", userNameDsp);
 			else if (HandleSolved(movesDsp, orient, pairs))
 				(void) sprintf(messageDsp,
-					"Congratulations %s!!", usernameDsp);
+					"Congratulations %s!!", userNameDsp);
 			else
 				(void) strncpy(messageDsp, "Solved!",
 					MESSAGELEN);
@@ -669,9 +675,9 @@ CallbackBarrel(Widget w, caddr_t clientData, barrelCallbackStruct * callData)
 			w->barrel.practice = practice;
 			w->barrel.started = False;
 #else
-			XtSetArg(arg[0], XtNpractice, practice);
-			XtSetArg(arg[1], XtNstart, False);
-			XtSetValues(w, arg, 2);
+			XtVaSetValues(w,
+				XtNpractice, practice,
+				XtNstart, False, NULL);
 #endif
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(practiceSwitch, practice, True);
@@ -680,12 +686,12 @@ CallbackBarrel(Widget w, caddr_t clientData, barrelCallbackStruct * callData)
 		case BARREL_RANDOMIZE:
 			movesDsp = 0;
 #ifdef WINVER
-			w->barrel.practice = practice;
+			w->barrel.practice = False;
 			w->barrel.started = False;
 #else
-			XtSetArg(arg[0], XtNpractice, practice);
-			XtSetArg(arg[1], XtNstart, False);
-			XtSetValues(w, arg, 2);
+			XtVaSetValues(w,
+				XtNpractice, False,
+				XtNstart, False, NULL);
 #endif
 			break;
 		case BARREL_ORIENT:
@@ -695,8 +701,7 @@ CallbackBarrel(Widget w, caddr_t clientData, barrelCallbackStruct * callData)
 #ifdef WINVER
 			w->barrel.orient = orient;
 #else
-			XtSetArg(arg[0], XtNorient, orient);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNorient, orient, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(orientSwitch, orient, True);
 #endif
@@ -709,8 +714,7 @@ CallbackBarrel(Widget w, caddr_t clientData, barrelCallbackStruct * callData)
 #ifdef WINVER
 			w->barrel.pairs = pairs;
 #else
-			XtSetArg(arg[0], XtNpairs, pairs);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNpairs, pairs, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(pairsSwitch, pairs, True);
 #endif
@@ -724,8 +728,7 @@ CallbackBarrel(Widget w, caddr_t clientData, barrelCallbackStruct * callData)
 #ifdef WINVER
 			w->barrel.tiles = tiles;
 #else
-			XtSetArg(arg[0], XtNtiles, tiles);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(tile, tiles);
 			if (tiles >= MAXTILES)
@@ -740,8 +743,7 @@ CallbackBarrel(Widget w, caddr_t clientData, barrelCallbackStruct * callData)
 #ifdef WINVER
 			w->barrel.tiles = tiles;
 #else
-			XtSetArg(arg[0], XtNtiles, tiles);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
 			if (tiles > MAXTILES)
 				XtVaSetValues(tile, XmNmaximum, tiles, NULL);
@@ -756,8 +758,7 @@ CallbackBarrel(Widget w, caddr_t clientData, barrelCallbackStruct * callData)
 #ifdef WINVER
 			w->barrel.faces = faces;
 #else
-			XtSetArg(arg[0], XtNfaces, faces);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNfaces, faces, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(face, faces);
 #endif
@@ -770,8 +771,7 @@ CallbackBarrel(Widget w, caddr_t clientData, barrelCallbackStruct * callData)
 #ifdef WINVER
 			w->barrel.faces = faces;
 #else
-			XtSetArg(arg[0], XtNfaces, faces);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNfaces, faces, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(face, faces);
 #endif
@@ -797,8 +797,8 @@ CallbackBarrel(Widget w, caddr_t clientData, barrelCallbackStruct * callData)
 				if (delay < 0)
 					delay = 0;
 				if (delay != oldDelay) {
-					XtSetArg(arg[0], XtNdelay, delay);
-					XtSetValues(w, arg, 1);
+					XtVaSetValues(w,
+						XtNdelay, delay, NULL);
 				}
 				XmScaleSetValue(speed,
 					MAXSPEED + MINSPEED - delay - 1);
@@ -806,17 +806,11 @@ CallbackBarrel(Widget w, caddr_t clientData, barrelCallbackStruct * callData)
 			return;
 #endif
 	}
-#ifdef HAVE_MOTIF
-	PrintState(message, messageDsp);
-	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-#else
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
-#endif
-		pairs, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp
+#ifndef HAVE_MOTIF
+		, pairs
 #endif
+		);
 }
 
 #ifdef WINVER
@@ -841,7 +835,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	PAINTSTRUCT paint;
 	static Boolean mousePressed = False;
 
-	Wnd = widget.core.hWnd = hWnd;
+	widget.core.hWnd = hWnd;
 	if (GetFocus()) {
 		if (!widget.barrel.focus) {
 			widget.core.hDC = GetDC(hWnd);
@@ -1107,28 +1101,7 @@ static void
 Usage(char * programName)
 {
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr,
-		"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n");
-	(void) fprintf(stderr,
-		"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n");
-	(void) fprintf(stderr,
-		"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{border|bd} {color}] [-tile {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-face{0|1|2|3|4|5} {color}]\n");
-#if 0
-	(void) fprintf(stderr,
-		"\t[-tiles {int}] [-faces {int}]\n");
-#endif
-	(void) fprintf(stderr,
-		"\t[-[no]orient] [-[no]pairs]\n");
-	(void) fprintf(stderr,
-		"\t[-[no]install] [-picture {filename}] [-delay msecs] [-[no]sound]\n");
-	(void) fprintf(stderr,
-		"\t[-bumpsound {filename}] [-movesound {filename}]\n");
-	(void) fprintf(stderr,
-		"\t[-base {int}] [-{font|fn} {fontname}] [-username {string}]\n");
+	(void) fprintf(stderr, optionsHelp);
 	exit(1);
 }
 
@@ -1167,12 +1140,15 @@ static XrmOptionDescRec options[] =
 	{(char *) "-delay", (char *) "*barrel.delay", XrmoptionSepArg, NULL},
 	{(char *) "-sound", (char *) "*barrel.sound", XrmoptionNoArg, (char *) "TRUE"},
 	{(char *) "-nosound", (char *) "*barrel.sound", XrmoptionNoArg, (char *) "FALSE"},
-	{(char *) "-bumpsound", (char *) "*barrel.bumpSound", XrmoptionSepArg, NULL},
-	{(char *) "-movesound", (char *) "*barrel.moveSound", XrmoptionSepArg, NULL},
+	{(char *) "-bumpSound", (char *) "*barrel.bumpSound", XrmoptionSepArg, NULL},
+	{(char *) "-moveSound", (char *) "*barrel.moveSound", XrmoptionSepArg, NULL},
 	{(char *) "-base", (char *) "*barrel.base", XrmoptionSepArg, NULL},
 	{(char *) "-fn", (char *) "*barrel.font", XrmoptionSepArg, NULL},
 	{(char *) "-font", (char *) "*barrel.font", XrmoptionSepArg, NULL},
-	{(char *) "-username", (char *) "*barrel.userName", XrmoptionSepArg, NULL}
+	{(char *) "-userName", (char *) "*barrel.userName", XrmoptionSepArg, NULL},
+	{(char *) "-scoreFile", (char *) "*barrel.scoreFile", XrmoptionSepArg, NULL},
+	{(char *) "-scores", (char *) "*barrel.scoreOnly", XrmoptionNoArg, (char *) "TRUE"},
+	{(char *) "-version", (char *) "*barrel.versionOnly", XrmoptionNoArg, (char *) "TRUE"}
 };
 
 #ifdef HAVE_MOTIF
@@ -1181,8 +1157,7 @@ CallbackBarrelPractice(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 9); /* menu choice */
-		XtSetValues(barrel, arg, 1);
+		XtVaSetValues(barrel, XtNmenu, 9, NULL); /* menu choice */
 	}
 }
 
@@ -1191,8 +1166,7 @@ CallbackBarrelRandomize(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-		XtSetValues(barrel, arg, 1);
+		XtVaSetValues(barrel, XtNmenu, 5, NULL); /* menu choice */
 	}
 }
 
@@ -1339,16 +1313,15 @@ fileCB(Widget w, void *value, void *clientData)
 
 	if (val == 2)
 		exit(0);
-	XtSetArg(arg[0], XtNmenu, val);
-	XtSetValues(barrel, arg, 1);
+	XtVaSetValues(barrel, XtNmenu, val, NULL);
 }
 
 static void
 playCB(Widget w, void *value, void *clientData)
 {
 	int val = (int) value;
-	XtSetArg(arg[0], XtNmenu, val + 3); /* GWQ */
-	XtSetValues(barrel, arg, 1);
+
+	XtVaSetValues(barrel, XtNmenu, val + 3, NULL); /* GWQ */
 }
 
 static Widget
@@ -1482,11 +1455,10 @@ main(int argc, char **argv)
 			RootWindowOfScreen(XtScreen(topLevel)),
 			(char *) barrel_bits,
 			barrel_width, barrel_height);
-	XtSetArg(arg[0], XtNiconPixmap, barrelIcon);
 #ifdef HAVE_MOTIF
-	/* not XmEXPLICIT */
-	XtSetArg(arg[1], XmNkeyboardFocusPolicy, XmPOINTER);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, barrelIcon,
+		XmNkeyboardFocusPolicy, XmPOINTER, NULL); /* not XmEXPLICIT */
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
 		xmPanedWindowWidgetClass, topLevel,
 		XmNseparatorOn, False,
@@ -1725,8 +1697,9 @@ main(int argc, char **argv)
 	barrel = XtCreateManagedWidget("barrel",
 		barrelWidgetClass, mainPanel, NULL, 0);
 #else
-	XtSetArg(arg[1], XtNinput, True);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, barrelIcon,
+		XtNinput, True, NULL);
 	barrel = XtCreateManagedWidget("barrel",
 		barrelWidgetClass, topLevel, NULL, 0);
 #endif
