@@ -25,10 +25,9 @@
 
 /* Methods file for Cubes */
 
-#if defined(USE_RPLAY) || defined(USE_NAS) || defined(USE_VMSPLAY) || defined(USE_ESOUND) || defined(WINVER) || defined(DEF_PLAY)
-#define USE_SOUND
-extern void playSound(char * filename);
-#endif
+#include "file.h"
+#include "rngs.h"
+#include "sound.h"
 #include "CubesP.h"
 
 #ifndef PICTURE
@@ -182,8 +181,11 @@ static XtActionsRec actionsListCubes[] =
 static XtResource resourcesCubes[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(CubesWidget, cubes.username),
-	 XtRString, (caddr_t) "guest"},
+	 XtOffset(CubesWidget, cubes.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(CubesWidget, cubes.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(CubesWidget, cubes.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
@@ -250,6 +252,12 @@ static XtResource resourcesCubes[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(CubesWidget, cubes.cheat),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(CubesWidget, cubes.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(CubesWidget, cubes.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(CubesWidget, cubes.menu),
 	 XtRString, (caddr_t) "-1"},
@@ -301,78 +309,6 @@ CubesClassRec cubesClassRec =
 
 WidgetClass cubesWidgetClass = (WidgetClass) & cubesClassRec;
 
-#ifndef HAVE_USLEEP
-#if !defined( VMS ) || defined( XVMSUTILS ) || ( __VMS_VER >= 70000000 )
-#ifdef USE_XVMSUTILS
-#include <X11/unix_time.h>
-#endif
-#if HAVE_SYS_TIME_H
-#include <sys/time.h>
-#else
-#if HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#endif
-#endif
-#endif
-#if defined(SYSV) || defined(SVR4)
-#ifdef LESS_THAN_AIX3_2
-#include <sys/poll.h>
-#else /* !LESS_THAN_AIX3_2 */
-#include <poll.h>
-#endif /* !LESS_THAN_AIX3_2 */
-#endif /* defined(SYSV) || defined(SVR4) */
-
-/* not static in case usleep found in system include */
-int
-usleep(unsigned int usec)
-{
-#if (defined (SYSV) || defined(SVR4)) && !defined(__hpux)
-#if defined(HAVE_NANOSLEEP)
-	{
-		struct timespec rqt;
-
-		rqt.tv_nsec = 1000 * (usec % (unsigned int) 1000000);
-		rqt.tv_sec = usec / (unsigned int) 1000000;
-		return nanosleep(&rqt, NULL);
-	}
-#else
-	(void) poll(
-#if defined(__cplusplus) || defined(c_plusplus)
-		(pollfd *) /* guess */
-#else
-		(void *)
-#endif
-		0, (int) 0, usec / 1000);	/* ms resolution */
-#endif
-#else
-#ifdef VMS
-	long timadr[2];
-
-	if (usec != 0) {
-		timadr[0] = -usec * 10;
-		timadr[1] = -1;
-
-		sys$setimr(4, &timadr, 0, 0, 0);
-		sys$waitfr(4);
-	}
-#else
-	struct timeval time_out;
-
-#if 0
-	/* (!defined(AIXV3) && !defined(__hpux)) */
-	extern int select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
-
-#endif
-
-	time_out.tv_usec = usec % (unsigned int) 1000000;
-	time_out.tv_sec = usec / (unsigned int) 1000000;
-	(void) select(0, (void *) 0, (void *) 0, (void *) 0, &time_out);
-#endif
-#endif
-	return 0;
-}
-#endif
-
 void
 SetCubes(CubesWidget w, int reason)
 {
@@ -398,13 +334,13 @@ loadFont(CubesWidget w)
 	if ((w->cubes.fontInfo = XLoadQueryFont(display,
 			w->cubes.font)) == NULL) {
 		(void) sprintf(buf,
-			"Cannot open %s font.\nAttempting %s font as alternate\n",
+			"Can not open %s font.\nAttempting %s font as alternate\n",
 			w->cubes.font, altfontname);
 		DISPLAY_WARNING(buf);
 		if ((w->cubes.fontInfo = XLoadQueryFont(display,
 				altfontname)) == NULL) {
 			(void) sprintf(buf,
-				"Cannot open %s alternate font.\nUse the -font option to specify a font to use.\n",
+				"Can not open %s alternate font.\nUse the -font option to specify a font to use.\n",
 				altfontname);
 			DISPLAY_WARNING(buf);
 		}
@@ -426,77 +362,6 @@ loadFont(CubesWidget w)
 #define LOGFILE "cubes.log"
 #endif
 
-#if (!defined(WINVER) || (WINVER <= 0x030a)) /* if X or WINDOWS 3.1 or less */
-static void
-Sleep(unsigned int cMilliseconds)
-{
-#if (defined(WINVER) && (WINVER <= 0x030a))
-	unsigned long time_out = GetTickCount() + cMilliseconds;
-
-	while (time_out > GetTickCount());
-#else
-	(void) usleep(cMilliseconds * 1000);
-#endif
-}
-#endif
-
-static void
-initTimer(CubesWidget w)
-{
-#ifdef WINVER
-	w->cubes.oldTime = GetTickCount();
-#else
-	XFlush(XtDisplay(w));
-	(void) X_GETTIMEOFDAY(&(w->cubes.oldTime));
-#endif
-}
-
-
-static void
-useTimer(CubesWidget w, int delay)
-{
-	int sleepTime;
-#ifdef WINVER
-	long tv = GetTickCount();
-
-	sleepTime = delay - (tv - w->cubes.oldTime);
-	w->cubes.oldTime = tv;
-	if (sleepTime > 0) {
-		Sleep((unsigned int) sleepTime);
-	}
-#else
-	struct timeval tv;
-
-	XFlush(XtDisplay(w));
-	(void) X_GETTIMEOFDAY(&tv);
-	sleepTime = delay * 1000 - ((tv.tv_sec - w->cubes.oldTime.tv_sec) *
-		1000000 + tv.tv_usec - w->cubes.oldTime.tv_usec);
-	w->cubes.oldTime.tv_sec = tv.tv_sec;
-	w->cubes.oldTime.tv_usec = tv.tv_usec;
-	if (sleepTime > 0) {
-		(void) usleep((unsigned int) sleepTime);
-	}
-#endif
-}
-
-void
-intCat(char ** string, const char * var1, const int var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + 21))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%d", var1, var2);
-}
-
-void
-stringCat(char ** string, const char * var1, const char * var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + strlen(var2) + 1))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%s", var1, var2);
-}
-
 static void
 CheckBlocks(CubesWidget w)
 {
@@ -760,15 +625,15 @@ DrawBlock(CubesWidget w, int pos, Boolean blank, Boolean erase,
 		return;
 	}
 #ifdef WINVER
-	w->cubes.hOldBitmap = (HBITMAP) SelectObject(w->cubes.memDC,
+	w->core.hOldBitmap = (HBITMAP) SelectObject(w->core.memDC,
 		w->cubes.bufferBlocks[pressedOffset]);
 	BitBlt(w->core.hDC,
 		dx, dy,
 		w->cubes.blockSize.x, w->cubes.blockSize.y,
-		w->cubes.memDC,
+		w->core.memDC,
 		sx, sy,
 		SRCCOPY);
-	SelectObject(w->cubes.memDC, w->cubes.hOldBitmap);
+	(void) SelectObject(w->core.memDC, w->core.hOldBitmap);
 #else
 	XSetGraphicsExposures(XtDisplay(w), w->cubes.blockGC, False);
 	XCopyArea(XtDisplay(w),
@@ -803,15 +668,15 @@ DrawBlockPiece(CubesWidget w, int pos, Boolean blank, Boolean erase,
 		return;
 	}
 #ifdef WINVER
-	w->cubes.hOldBitmap = (HBITMAP) SelectObject(w->cubes.memDC,
+	w->core.hOldBitmap = (HBITMAP) SelectObject(w->core.memDC,
 		w->cubes.bufferBlocks[pressedOffset]);
 	BitBlt(w->core.hDC,
 		dx + lox, dy + loy,
 		lsx, lsy,
-		w->cubes.memDC,
+		w->core.memDC,
 		sx + lox, sy + loy,
 		SRCCOPY);
-	SelectObject(w->cubes.memDC, w->cubes.hOldBitmap);
+	(void) SelectObject(w->core.memDC, w->core.hOldBitmap);
 #else
 	XSetGraphicsExposures(XtDisplay(w), w->cubes.blockGC, False);
 	XCopyArea(XtDisplay(w),
@@ -925,7 +790,8 @@ AnimateSlide(CubesWidget w, int numBlocks, int dir, int fast, Boolean logMoves)
 		gapI++;
 	if (numBlocks < 0)
 	  numBlocks = -numBlocks;
-	initTimer(w);
+	FLUSH(w);
+	initTimer(w->cubes.oldTime);
 	for (inc = 0; inc < moveI + gapI; inc += gapI) {
 	  if (inc > moveI)
 	    inc = moveI;
@@ -1004,8 +870,9 @@ AnimateSlide(CubesWidget w, int numBlocks, int dir, int fast, Boolean logMoves)
 		break;
 	      }
 	    }
-	  }
-	  useTimer(w, w->cubes.delay);
+	  }	
+	  FLUSH(w);
+	  useTimer(&(w->cubes.oldTime), w->cubes.delay);
 	}
 	pos = w->cubes.spacePosition;
 	for (aBlock = 0; aBlock < numBlocks; aBlock++) {
@@ -1050,7 +917,8 @@ AnimateMove(CubesWidget w, int fromPos, int fast)
 		w->cubes.inverseGC,
 		fx, fy + w->cubes.blockSize.y - incAt,
 		w->cubes.blockSize.x, incAt);
-	initTimer(w);
+	FLUSH(w);
+	initTimer(w->cubes.oldTime);
 	for (inc = incAt; inc < incTo; inc += incAt) {
 		int xR = fx + inc, yR = fy + inc;
 		int wR = w->cubes.blockSize.x - 2 * inc;
@@ -1127,13 +995,12 @@ AnimateMove(CubesWidget w, int fromPos, int fast)
 			    True);
 #endif
 		}
-		useTimer(w, w->cubes.delay);
+		FLUSH(w);
+		useTimer(&(w->cubes.oldTime), w->cubes.delay);
 	}
 	DrawBlock(w, fromPos, True, True, FALSE, 0, 0);
 	DrawBlock(w, pos, False, False, FALSE, 0, 0);
-#ifndef WINVER
-	XFlush(XtDisplay(w));
-#endif
+	FLUSH(w);
 	w->cubes.spacePosition = fromPos;
 }
 
@@ -1587,14 +1454,14 @@ ResetBlocks(CubesWidget w)
 	w->cubes.sizeRect = w->cubes.sizeX * w->cubes.sizeY;
 	w->cubes.sizeBlock = w->cubes.sizeRect * w->cubes.sizeZ;
 	if (w->cubes.blockOfPosition)
-		free((void *) w->cubes.blockOfPosition);
+		free(w->cubes.blockOfPosition);
 	if (!(w->cubes.blockOfPosition = (int *)
 			malloc(sizeof (int) * w->cubes.sizeBlock))) {
 		DISPLAY_ERROR("Not enough memory, exiting.");
 	}
 
 	if (startPosition)
-		free((void *) startPosition);
+		free(startPosition);
 	if (!(startPosition = (int *)
 			malloc(sizeof (int) * w->cubes.sizeBlock))) {
 		DISPLAY_ERROR("Not enough memory, exiting.");
@@ -1852,9 +1719,7 @@ RandomizeBlocks(CubesWidget w)
 			DISPLAY_WARNING("RandomizeBlocks: should not get here");
 		}
 		DrawAllBlocks(w);
-#ifndef WINVER
-		XFlush(XtDisplay(w));
-#endif
+		FLUSH(w);
 	}
 	/* randomly position space */
 	/* Idea for this came from "puzzle" by Don Bennett, HP Labs */
@@ -2044,10 +1909,14 @@ SetValuesCubes(CubesWidget w)
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) strcpy(w->cubes.dripSound, szBuf);
 	w->cubes.dripSound[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "name", "Guest",
+	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
 		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->cubes.username, szBuf);
-	w->cubes.username[80] = 0;
+	(void) strcpy(w->cubes.userName, szBuf);
+	w->cubes.userName[80] = 0;
+	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
+		szBuf, sizeof (szBuf), INIFILE);
+	(void) strcpy(w->cubes.scoreFile, szBuf);
+	w->cubes.scoreFile[80] = 0;
 }
 
 void
@@ -2276,8 +2145,8 @@ QuitCubes(CubesWidget w
 		if (w->cubes.bufferBlocks != NULL) {
 			DeleteObject(w->cubes.bufferBlocks);
 		}
-		DeleteDC(w->cubes.memDC);
-		w->cubes.memDC = NULL;
+		DeleteDC(w->core.memDC);
+		w->core.memDC = NULL;
 	}
 #else
 	Display *display = XtDisplay(w);
@@ -2320,9 +2189,9 @@ ResizeBlocks(CubesWidget w)
 	int sel;
 
 #ifdef WINVER
-	if (w->cubes.memDC == NULL) {
-		w->cubes.memDC = CreateCompatibleDC(w->core.hDC);
-		if (w->cubes.memDC == NULL) {
+	if (w->core.memDC == NULL) {
+		w->core.memDC = CreateCompatibleDC(w->core.hDC);
+		if (w->core.memDC == NULL) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
@@ -2584,9 +2453,7 @@ SelectCubes(CubesWidget w
 		if (rowType < 0) {
 			DrawBlock(w, w->cubes.currentPosition,
 				rowType == CUBES_SPACE, False, TRUE, 0, 0);
-#ifndef WINVER
-			XFlush(XtDisplay(w));
-#endif
+			FLUSH(w);
 			Sleep(100);
 			DrawBlock(w, w->cubes.currentPosition,
 				True, True, TRUE, 0, 0);
