@@ -37,6 +37,7 @@
 #ifndef WINVER
 #define XtNselectCallback ((char *) "selectCallback")
 #define XtNuserName ((char *) "userName")
+#define XtNscoreFile ((char *) "scoreFile")
 #define XtNsizeX ((char *) "sizeX")
 #define XtNsizeY ((char *) "sizeY")
 #define XtNsizeZ ((char *) "sizeZ")
@@ -55,7 +56,10 @@
 #define XtNframeColor ((char *) "frameColor")
 #define XtNblockColor ((char *) "blockColor")
 #define XtNblockBorder ((char *) "blockBorder")
+#define XtNscoreOnly ((char *) "scoreOnly")
+#define XtNversionOnly ((char *) "versionOnly")
 #define XtCUserName ((char *) "UserName")
+#define XtCScoreFile ((char *) "ScoreFile")
 #define XtCSizeX ((char *) "SizeX")
 #define XtCSizeY ((char *) "SizeY")
 #define XtCSizeZ ((char *) "SizeZ")
@@ -102,23 +106,6 @@ typedef struct {
 #define CUBES_UNDO 11
 #define CUBES_SPEED 12
 
-#ifdef WINVER
-#ifdef UNIXDELIM
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#else
-#define CURRENTDELIM ".\\"
-#define FINALDELIM "\\"
-#endif
-#else
-#ifdef VMS
-#define CURRENTDELIM "[]"
-#define FINALDELIM ""
-#else
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#endif
-#endif
 #define MINCUBES 1
 #define DEFAULTCUBESX 4
 #define DEFAULTCUBESY 4
@@ -136,8 +123,5 @@ typedef struct {
 
 typedef struct _CubesRec *CubesWidget;
 
-extern void intCat(char ** string, const char * var1, const int var2);
-extern void stringCat(char ** string, const char * var1, const char * var2);
-
 #endif /* _XtCubes_h */
 /* DON'T ADD STUFF AFTER THIS #endif */
