@@ -32,38 +32,25 @@
   Version 1: 91/03/19 SunView
 */
 
+#include "file.h"
 #ifdef WINVER
 #include "CubesP.h"
 #include "wcubes.h"
 #define TITLE "wcubes"
 
 static CubesRec widget;
-static HWND Wnd;
 
 #ifndef SCOREPATH
-#define SCOREPATH "c:\\Windows"
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
 #endif
-#define PRINT_MESSAGE(b) (void) MessageBox(Wnd, (LPCSTR) b, "Warning", MB_OK);
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
 #define SET_STARTED(w,b) w->cubes.started = b
 #else
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
-#ifdef VMS
-#include <unixlib.h>
-#define getlogin() cuserid(NULL)
-#else
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif
-#if HAVE_FCNTL_H
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#endif
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
+#include "xwin.h"
 #include <X11/Shell.h>
 #include <X11/cursorfont.h>
 #ifdef HAVE_MOTIF
@@ -83,7 +70,7 @@ static HWND Wnd;
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
-#define SET_STARTED(w,b) XtSetArg(arg[0], XtNstart, b); XtSetValues(w, arg, 1)
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
 #include "Cubes.h"
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
@@ -91,28 +78,35 @@ static HWND Wnd;
 #endif
 #include "icons/cubes.xbm"
 #ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
 #define SCOREPATH "/var/games/xpuzzles"
 #endif
 #endif
+#endif
 
-#ifdef HAVE_MOTIF
+#ifndef WINVER
 static const char aboutHelp[] = {
-	"Version 7.1.3\n"
+	"Cubes Version 7.1.5\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
 	"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
+
 static const char optionsHelp[] = {
-	"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]] "
-	"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"[-{foreground|fg} {color}] [-{background|bg} {color}] "
-	"[-{border|bd} {color}] [-block {color}] [-size{x|y|z} {int}] \n"
-	"[-[no]install] [-picture {filename}] [-delay msecs] "
-	"[-[no]sound] [-bumpsound {filename}] [-dripsound {filename}]\n"
-	"[-base {int}] [-{font|fn} {fontname}] [-username {string}]\n"
+	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+	"\t[-{border|bd} {color}] [-block {color}] [-size{x|y|z} {int}] \n"
+	"\t[-[no]install] [-picture {filename}] [-delay msecs]\n"
+	"\t[-[no]sound] [-bumpSound {filename}] [-dripSound {filename}]\n"
+	"\t[-base {int}] [-{font|fn} {fontname}] [-userName {string}]\n"
+	"\t[-scoreFile {filename}] [-scores] [-version]\n"
 };
 #endif
+
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
 	"A 3D  sliding block puzzle.  The cubes represented are  "
@@ -126,6 +120,7 @@ static const char descriptionHelp[] = {
 	"Box 'L (3x3x3) (Hungary) and Mad Marbles (3x3x3) by "
 	"Toys & Games International USA.\n"
 };
+
 static const char featuresHelp[] = {
 	"Click \"mouse-left\" button to move a block.  Clicks on "
 	"a space, or clicks blocks that are not in line with\n"
@@ -178,6 +173,7 @@ static const char featuresHelp[] = {
 	"xcubes.  Hold down control key and use the keypad\n"
 	"or arrow keys to reduce or enlarge puzzle complexity.\n"
 };
+
 static const char referencesHelp[] = {
 	"L. E. Horden, Sliding Piece Puzzles  (Recreations in "
 	"Mathematics Series), Oxford University Press  1986,\n"
@@ -187,6 +183,7 @@ static const char referencesHelp[] = {
 	"Press, Seattle 1987, p 126, 127.\n"
 };
 #endif
+
 static const char solveHelp[] = {
 	"Auto-solver: sorry, only implemented for lxmx1 where "
 	"l > 3 and m > 3.\n"
@@ -197,7 +194,7 @@ static const char solveHelp[] = {
 #endif
 
 #define MAXCUBES 8
-#define NEVER -1
+#define NEVER (-1)
 #define FILENAMELEN 1024
 #define USERNAMELEN 120
 #define MESSAGELEN (USERNAMELEN+64)
@@ -224,20 +221,21 @@ static char buff[21];
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, randomizeDialog;
+static Arg arg[3];
 #else
 static char titleDsp[TITLELEN] = "";
 #endif
+static char scoreFileName[FILENAMELEN] = SCOREFILE;
+static char fileName[FILENAMELEN];
 #ifdef WINVER
 #define MAXPROGNAME 80
 static char progDsp[MAXPROGNAME] = TITLE;
-static char usernameDsp[USERNAMELEN] = "Guest";
+static char userNameDsp[USERNAMELEN] = "Guest";
 #else
 static Pixmap cubesIcon = None;
 static Widget topLevel, cubes;
-static Arg arg[3];
 static char *progDsp;
-static char usernameDsp[USERNAMELEN] = "";
-#endif
+static char userNameDsp[USERNAMELEN] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -248,25 +246,26 @@ PrintState(Widget w, char *msg)
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
 		XtError("PrintState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
-	XtSetArg(arg[0], XmNlabelString, xmstr);
-	XtSetValues(w, arg, 1);
+	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
-#else
+#endif
+
 static void
-PrintState(
-#ifndef WINVER
-Widget w,
-#endif
-int sizeX, int sizeY, int sizeZ, int moves, char *msg)
+PrintRecords(void)
 {
-	(void) sprintf(titleDsp, "%s: %dx%dx%d@ (%d/%s) - %s",
-		progDsp, sizeX, sizeY, sizeZ, moves, recordDsp, msg);
-#ifdef WINVER
-	SetWindowText(Wnd, (LPSTR) titleDsp);
-#else
-	XtSetArg(arg[0], XtNtitle, titleDsp);
-	XtSetValues(w, arg, 1);
-#endif
+	int i, j, k;
+
+	(void) printf("          CUBES  HALL OF FAME\n\n");
+	(void) printf("   Z   Y   X USER             MOVES\n");
+	for (i = 0; i < MAXCUBES - MINCUBES + 1; i++)
+		for (j = i; j < MAXCUBES - MINCUBES + 1; j++)
+			for (k = j; k < MAXCUBES - MINCUBES + 1; k++) {
+				if (cubesRecord[k][j][i].score > 0)
+					(void) printf("%4d%4d%4d %-12s%9d\n",
+						i + 1, j + 1, k + 1,
+						cubesRecord[k][j][i].name,
+						cubesRecord[k][j][i].score);
+			}
 }
 #endif
 
@@ -301,21 +300,21 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, j, k, n;
-	char username[USERNAMELEN];
+	char userName[USERNAMELEN];
 	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *fname, *lname;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
+	stringCat(&buf1, CURRENTDELIM, scoreFileName);
 	lname = buf1;
 	stringCat(&buf1, SCOREPATH, FINALDELIM);
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "r")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "r")) == NULL) {
+	(void) strncpy(fileName, lname, USERNAMELEN);
+	if ((fp = fopen(fileName, "r")) == NULL) {
+		(void) strncpy(fileName, fname, USERNAMELEN);
+		/* Try installed directory. */
+		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
@@ -345,25 +344,24 @@ ReadRecords(void)
 	for (i = 0; i < MAXCUBES - MINCUBES + 1; i++)
 		for (j = i; j < MAXCUBES - MINCUBES + 1; j++)
 			for (k = j; k < MAXCUBES - MINCUBES + 1; k++) {
-				(void) fscanf(fp, "%d %s\n", &n, username);
+				(void) fscanf(fp, "%d %s", &n, userName);
 				if (n <= cubesRecord[i][j][k].score ||
 				    cubesRecord[i][j][k].score <= NEVER) {
-					(void) fscanf(fp, "%d %s\n", &n, username);
 					cubesRecord[k][j][i].score = cubesRecord[k][i][j].score =
 						cubesRecord[j][k][i].score = cubesRecord[j][i][k].score =
 						cubesRecord[i][k][j].score = cubesRecord[i][j][k].score = n;
 					(void) strncpy(cubesRecord[k][j][i].name,
-						username, USERNAMELEN);
+						userName, USERNAMELEN);
 					(void) strncpy(cubesRecord[k][i][j].name,
-						username, USERNAMELEN);
+						userName, USERNAMELEN);
 					(void) strncpy(cubesRecord[j][k][i].name,
-						username, USERNAMELEN);
+						userName, USERNAMELEN);
 					(void) strncpy(cubesRecord[j][i][k].name,
-						username, USERNAMELEN);
+						userName, USERNAMELEN);
 					(void) strncpy(cubesRecord[i][k][j].name,
-						username, USERNAMELEN);
+						userName, USERNAMELEN);
 					(void) strncpy(cubesRecord[i][j][k].name,
-						username, USERNAMELEN);
+						userName, USERNAMELEN);
 				}
 			}
 	(void) fclose(fp);
@@ -374,61 +372,31 @@ WriteRecords(void)
 {
 	FILE *fp;
 	int i, j, k;
-	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *buf1 = NULL;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
-	lname = buf1;
-	stringCat(&buf1, SCOREPATH, FINALDELIM);
-	stringCat(&buf2, buf1, SCOREFILE);
-	free(buf1);
-	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "w")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "w")) == NULL) {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, " or ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-			free(lname);
-			free(fname);
-			return;
-		}
-/* Probably annoying */
-#if 0
-		else {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, ", falling back to ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-		}
-#endif
+	if ((fp = fopen(fileName, "w")) == NULL) {
+		stringCat(&buf1, "Can not write to ", fileName);
+		PRINT_MESSAGE(buf1);
+		free(buf1);
+		return;
 	}
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockfile[FILENAMELEN];
+		char lockFile[FILENAMELEN];
 
-		(void) strncpy(lockfile, name, FILENAMELEN - 6);
-		(void) strcat(lockfile, ".lock");
-		while (((lfd = open(lockfile, O_CREAT | O_EXCL, 0644)) < 0) &&
+		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strcat(lockFile, ".lock");
+		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
 			(void) sleep(1);
 		if (lfd < 0) {
 #if 1
 			(void) fprintf(stderr,
-			  "Lock file exists... guessing its an old one.\n");
+				"Lock file exists... guessing its an old one.\n");
 #else
 			(void) fprintf(stderr,
-			  "Lock file exists... score not recorded - sorry.\n");
+				"Lock file exists... score not recorded - sorry.\n");
 			return;
 #endif
 		}
@@ -445,12 +413,10 @@ WriteRecords(void)
 		}
 #if HAVE_FCNTL_H
 		(void) close(lfd);
-		(void) unlink(lockfile);
+		(void) unlink(lockFile);
 #endif
 		(void) fclose(fp);
 	}
-	free(lname);
-	free(fname);
 }
 
 static void
@@ -471,14 +437,36 @@ PrintRecord(int sizeX, int sizeY, int sizeZ)
 #endif
 }
 
+static void
+PrintStatus(char *msg, int nMoves
+#ifndef HAVE_MOTIF
+		, int sizeX, int sizeY, int sizeZ
+#endif
+		)
+{
+#ifdef HAVE_MOTIF
+	PrintState(message, msg);
+	(void) sprintf(buff, "%d", nMoves);
+	PrintState(moves, buff);
+#else
+	(void) sprintf(titleDsp, "%s: %dx%dx%d@ (%d/%s) - %s",
+		progDsp, sizeX, sizeY, sizeZ, nMoves, recordDsp, msg);
+#ifdef WINVER
+	SetWindowText(widget.core.hWnd, (LPSTR) titleDsp);
+#else
+	XtVaSetValues(XtParent(cubes), XtNtitle, titleDsp, NULL);
+#endif
+#endif
+}
+
 static Boolean
 HandleSolved(int counter, int sizeX, int sizeY, int sizeZ)
 {
 	int i = sizeX - MINCUBES, j = sizeY - MINCUBES, k = sizeZ - MINCUBES;
 
 	if (sizeX <= MAXCUBES && sizeY <= MAXCUBES && sizeZ <= MAXCUBES &&
-	    (counter < cubesRecord[i][j][k].score ||
-	    cubesRecord[i][j][k].score <= NEVER)) {
+			(counter < cubesRecord[i][j][k].score ||
+			cubesRecord[i][j][k].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 
 		cubesRecord[i][j][k].score = cubesRecord[i][k][j].score =
@@ -487,17 +475,17 @@ HandleSolved(int counter, int sizeX, int sizeY, int sizeZ)
 			cubesRecord[k][i][j].score =
 			cubesRecord[k][j][i].score =
 			counter;
-		(void) strncpy(cubesRecord[i][j][k].name, usernameDsp,
+		(void) strncpy(cubesRecord[i][j][k].name, userNameDsp,
 			USERNAMELEN);
-		(void) strncpy(cubesRecord[i][k][j].name, usernameDsp,
+		(void) strncpy(cubesRecord[i][k][j].name, userNameDsp,
 			USERNAMELEN);
-		(void) strncpy(cubesRecord[j][i][k].name, usernameDsp,
+		(void) strncpy(cubesRecord[j][i][k].name, userNameDsp,
 			USERNAMELEN);
-		(void) strncpy(cubesRecord[j][k][i].name, usernameDsp,
+		(void) strncpy(cubesRecord[j][k][i].name, userNameDsp,
 			USERNAMELEN);
-		(void) strncpy(cubesRecord[k][i][j].name, usernameDsp,
+		(void) strncpy(cubesRecord[k][i][j].name, userNameDsp,
 			USERNAMELEN);
-		(void) strncpy(cubesRecord[k][j][i].name, usernameDsp,
+		(void) strncpy(cubesRecord[k][j][i].name, userNameDsp,
 			USERNAMELEN);
 		WriteRecords();
 		PrintRecord(sizeX, sizeY, sizeZ);
@@ -516,7 +504,7 @@ Widget w
 )
 {
 	int sizeX, sizeY, sizeZ;
-	char *username;
+	char *userName, *scoreFile;
 
 #ifdef WINVER
 	InitializeCubes(w, brush);
@@ -524,13 +512,33 @@ Widget w
 	sizeX = w->cubes.sizeX;
 	sizeY = w->cubes.sizeY;
 	sizeZ = w->cubes.sizeZ;
-	username = w->cubes.username;
+	userName = w->cubes.userName;
+	scoreFile = w->cubes.scoreFile;
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
 #else
+	Boolean scoreOnly, versionOnly;
+
 	XtVaGetValues(w,
-		XtNuserName, &username,
+		XtNuserName, &userName,
+		XtNscoreFile, &scoreFile,
 		XtNsizeX, &sizeX,
 		XtNsizeY, &sizeY,
-		XtNsizeZ, &sizeZ, NULL);
+		XtNsizeZ, &sizeZ,
+		XtNscoreOnly, &scoreOnly,
+		XtNversionOnly, &versionOnly, NULL);
+	if (versionOnly) {
+		(void) printf(aboutHelp);
+		exit(0);
+	}
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+	if (scoreOnly) {
+		InitRecords();
+		ReadRecords();
+		PrintRecords();
+		exit(0);
+	}
 #ifdef HAVE_MOTIF
 	if (sizeX > MAXCUBES)
 		XtVaSetValues(blockX, XmNmaximum, sizeX, NULL);
@@ -544,7 +552,7 @@ Widget w
 	{
 		int delay;
 
-		XtVaGetValues(cubes, XtNdelay, &delay, NULL);
+		XtVaGetValues(w, XtNdelay, &delay, NULL);
 		XmScaleSetValue(speed, MAXSPEED + MINSPEED - delay - 1);
 	}
 #endif
@@ -553,31 +561,29 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(usernameDsp, username, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #endif
-	if (!strcmp(username, "") || !strcmp(username, "(null)") ||
-	    !strcmp(username, NOACCESS) || !strcmp(username, NOBODY)) {
-		/* The NOACCESS is not necessary, but it may stop silliness. */
+	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
+			!strcmp(userName, NOACCESS) ||
+			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(usernameDsp, username, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(usernameDsp, "%s", getlogin());
-		if (!strcmp(usernameDsp, "") ||
-				!strcmp(usernameDsp, "(null)") ||
-				!strcmp(usernameDsp, NOACCESS) ||
-				!strcmp(usernameDsp, NOBODY))
+		(void) sprintf(userNameDsp, "%s", getlogin());
+		if (!strcmp(userNameDsp, "") ||
+				!strcmp(userNameDsp, "(null)") ||
+				!strcmp(userNameDsp, NOACCESS) ||
+				!strcmp(userNameDsp, NOBODY))
 			/* It really IS nobody */
-			(void) sprintf(usernameDsp, "%s", "guest");
+			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
 	PrintRecord(sizeX, sizeY, sizeZ);
+	PrintStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
-#endif
-		sizeX, sizeY, sizeZ, movesDsp, messageDsp);
+		, sizeX, sizeY, sizeZ
 #endif
+		);
 }
 
 #ifdef WINVER
@@ -622,8 +628,8 @@ CallbackCubes(Widget w, caddr_t clientData, cubesCallbackStruct * callData)
 #ifdef HAVE_MOTIF
 			XtManageChild(randomizeDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-			XtSetValues(cubes, arg, 1);
+			XtVaSetValues(cubes,
+				XtNmenu, 5, NULL); /* menu choice */
 #endif
 			break;
 #endif
@@ -665,10 +671,10 @@ CallbackCubes(Widget w, caddr_t clientData, cubesCallbackStruct * callData)
 		case CUBES_SOLVED:
 			if (cheat)
 				(void) sprintf(messageDsp,
-					"No cheating %s!!", usernameDsp);
+					"No cheating %s!!", userNameDsp);
 			else if (HandleSolved(movesDsp, sizeX, sizeY, sizeZ))
 				(void) sprintf(messageDsp,
-					"Congratulations %s!!", usernameDsp);
+					"Congratulations %s!!", userNameDsp);
 			else
 				(void) strncpy(messageDsp, "Solved!",
 					MESSAGELEN);
@@ -685,8 +691,7 @@ CallbackCubes(Widget w, caddr_t clientData, cubesCallbackStruct * callData)
 #ifdef WINVER
 			w->cubes.sizeX = sizeX;
 #else
-			XtSetArg(arg[0], XtNsizeX, sizeX);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNsizeX, sizeX, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(blockX, sizeX);
 			if (sizeX >= MAXCUBES)
@@ -701,8 +706,7 @@ CallbackCubes(Widget w, caddr_t clientData, cubesCallbackStruct * callData)
 #ifdef WINVER
 			w->cubes.sizeX = sizeX;
 #else
-			XtSetArg(arg[0], XtNsizeX, sizeX);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNsizeX, sizeX, NULL);
 #ifdef HAVE_MOTIF
 			if (sizeX > MAXCUBES)
 				XtVaSetValues(blockX, XmNmaximum, sizeX, NULL);
@@ -717,8 +721,7 @@ CallbackCubes(Widget w, caddr_t clientData, cubesCallbackStruct * callData)
 #ifdef WINVER
 			w->cubes.sizeY = sizeY;
 #else
-			XtSetArg(arg[0], XtNsizeY, sizeY);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNsizeY, sizeY, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(blockY, sizeY);
 			if (sizeY >= MAXCUBES)
@@ -733,8 +736,7 @@ CallbackCubes(Widget w, caddr_t clientData, cubesCallbackStruct * callData)
 #ifdef WINVER
 			w->cubes.sizeY = sizeY;
 #else
-			XtSetArg(arg[0], XtNsizeY, sizeY);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNsizeY, sizeY, NULL);
 #ifdef HAVE_MOTIF
 			if (sizeY > MAXCUBES)
 				XtVaSetValues(blockY, XmNmaximum, sizeY, NULL);
@@ -749,8 +751,7 @@ CallbackCubes(Widget w, caddr_t clientData, cubesCallbackStruct * callData)
 #ifdef WINVER
 			w->cubes.sizeZ = sizeZ;
 #else
-			XtSetArg(arg[0], XtNsizeZ, sizeZ);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNsizeZ, sizeZ, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(blockZ, sizeZ);
 			if (sizeZ >= MAXCUBES)
@@ -765,8 +766,7 @@ CallbackCubes(Widget w, caddr_t clientData, cubesCallbackStruct * callData)
 #ifdef WINVER
 			w->cubes.sizeZ = sizeZ;
 #else
-			XtSetArg(arg[0], XtNsizeZ, sizeZ);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNsizeZ, sizeZ, NULL);
 #ifdef HAVE_MOTIF
 			if (sizeZ > MAXCUBES)
 				XtVaSetValues(blockZ, XmNmaximum, sizeZ, NULL);
@@ -793,8 +793,8 @@ CallbackCubes(Widget w, caddr_t clientData, cubesCallbackStruct * callData)
 				if (delay < 0)
 					delay = 0;
 				if (delay != oldDelay) {
-					XtSetArg(arg[0], XtNdelay, delay);
-					XtSetValues(w, arg, 1);
+					XtVaSetValues(w,
+						XtNdelay, delay, NULL);
 				}
 				XmScaleSetValue(speed,
 					MAXSPEED + MINSPEED - delay - 1);
@@ -802,17 +802,11 @@ CallbackCubes(Widget w, caddr_t clientData, cubesCallbackStruct * callData)
 			return;
 #endif
 	}
-#ifdef HAVE_MOTIF
-	PrintState(message, messageDsp);
-	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-#else
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
-#endif
-		sizeX, sizeY, sizeZ, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp
+#ifndef HAVE_MOTIF
+		, sizeX, sizeY, sizeZ
 #endif
+		);
 }
 
 #ifdef WINVER
@@ -836,7 +830,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	HBRUSH brush = (HBRUSH) NULL;
 	PAINTSTRUCT paint;
 
-	Wnd = widget.core.hWnd = hWnd;
+	widget.core.hWnd = hWnd;
 	if (GetFocus()) {
 		if (!widget.cubes.focus) {
 			widget.core.hDC = GetDC(hWnd);
@@ -1070,20 +1064,7 @@ static void
 Usage(char * programName)
 {
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr,
-		"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n");
-	(void) fprintf(stderr,
-		"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n");
-	(void) fprintf(stderr,
-		"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{border|bd} {color}] [-block {color}] [-size{x|y|z} {int}]\n");
-	(void) fprintf(stderr,
-		"\t[-[no]install] [-picture {filename}] [-delay msecs] [-[no]sound]\n");
-	(void) fprintf(stderr,
-		"\t[-bumpsound {filename}] [-dripsound {filename}]\n");
-	(void) fprintf(stderr,
-		"\t[-base {int}] [-{font|fn} {fontname}] [-username {string}]\n");
+	(void) fprintf(stderr, optionsHelp);
 	exit(1);
 }
 
@@ -1112,12 +1093,15 @@ static XrmOptionDescRec options[] =
 	{(char *) "-delay", (char *) "*cubes.delay", XrmoptionSepArg, NULL},
 	{(char *) "-sound", (char *) "*cubes.sound", XrmoptionNoArg, (char *) "TRUE"},
 	{(char *) "-nosound", (char *) "*cubes.sound", XrmoptionNoArg, (char *) "FALSE"},
-	{(char *) "-bumpsound", (char *) "*cubes.bumpSound", XrmoptionSepArg, NULL},
-	{(char *) "-dripsound", (char *) "*cubes.dripSound", XrmoptionSepArg, NULL},
+	{(char *) "-bumpSound", (char *) "*cubes.bumpSound", XrmoptionSepArg, NULL},
+	{(char *) "-dripSound", (char *) "*cubes.dripSound", XrmoptionSepArg, NULL},
 	{(char *) "-base", (char *) "*cubes.base", XrmoptionSepArg, NULL},
 	{(char *) "-fn", (char *) "*cubes.font", XrmoptionSepArg, NULL},
 	{(char *) "-font", (char *) "*cubes.font", XrmoptionSepArg, NULL},
-	{(char *) "-username", (char *) "*cubes.userName", XrmoptionSepArg, NULL}
+	{(char *) "-userName", (char *) "*cubes.userName", XrmoptionSepArg, NULL},
+	{(char *) "-scoreFile", (char *) "*cubes.scoreFile", XrmoptionSepArg, NULL},
+	{(char *) "-scores", (char *) "*cubes.scoreOnly", XrmoptionNoArg, (char *) "TRUE"},
+	{(char *) "-version", (char *) "*cubes.versionOnly", XrmoptionNoArg, (char *) "TRUE"}
 };
 
 #ifdef HAVE_MOTIF
@@ -1125,8 +1109,7 @@ static void
 CallbackCubesRandomize(Widget w, XtPointer clientData, XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-		XtSetValues(cubes, arg, 1);
+		XtVaSetValues(cubes, XtNmenu, 5, NULL); /* menu choice */
 	}
 }
 
@@ -1212,16 +1195,15 @@ fileCB(Widget w, void *value, void *clientData)
 
 	if (val == 2)
 		exit(0);
-	XtSetArg(arg[0], XtNmenu, val);
-	XtSetValues(cubes, arg, 1);
+	XtVaSetValues(cubes, XtNmenu, val, NULL);
 }
 
 static void
 playCB(Widget w, void *value, void *clientData)
 {
 	int val = (int) value;
-	XtSetArg(arg[0], XtNmenu, val + 3); /* GWQ */
-	XtSetValues(cubes, arg, 1);
+
+	XtVaSetValues(cubes, XtNmenu, val + 3, NULL); /* GWQ */
 }
 
 static Widget
@@ -1354,11 +1336,10 @@ main(int argc, char **argv)
 			RootWindowOfScreen(XtScreen(topLevel)),
 			(char *) cubes_bits,
 			cubes_width, cubes_height);
-	XtSetArg(arg[0], XtNiconPixmap, cubesIcon);
 #ifdef HAVE_MOTIF
-	/* not XmEXPLICIT */
-	XtSetArg(arg[1], XmNkeyboardFocusPolicy, XmPOINTER);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, cubesIcon,
+		XmNkeyboardFocusPolicy, XmPOINTER, NULL); /* not XmEXPLICIT */
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
 		xmPanedWindowWidgetClass, topLevel,
 		XmNseparatorOn, False,
@@ -1571,8 +1552,9 @@ main(int argc, char **argv)
 	cubes = XtCreateManagedWidget("cubes",
 		cubesWidgetClass, mainPanel, NULL, 0);
 #else
-	XtSetArg(arg[1], XtNinput, True);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, cubesIcon,
+		XtNinput, True, NULL);
 	cubes = XtCreateManagedWidget("cubes",
 		cubesWidgetClass, topLevel, NULL, 0);
 #endif
