@@ -46,7 +46,6 @@ static void CallbackDial(Widget w, caddr_t clientData,
 static void PrintState(Widget w, int n);
 
 static Widget dial, dialsq;
-static Arg arg[1];
 static char prog[] = "TAC: ";
 static char title[TITLELEN] = "";
 
@@ -113,9 +112,8 @@ static void CallbackDial(Widget w, caddr_t clientData,
 		otherw = dialsq;
 	else /* (w == dialsq) */
 		otherw = dial;
-	XtSetArg(arg[0], XtNval, callData->val);
-	XtSetValues(w, arg, 1);
-	XtSetValues(otherw, arg, 1);
+	XtVaSetValues(w, XtNval, callData->val, NULL);
+	XtVaSetValues(otherw, XtNval, callData->val, NULL);
 	PrintState(XtParent(w), callData->val);
 	PrintState(XtParent(otherw), callData->val);
 }
@@ -123,6 +121,5 @@ static void CallbackDial(Widget w, caddr_t clientData,
 static void PrintState(Widget w, int n)
 {
 	(void) sprintf(title, "%s%d", prog, n);
-	XtSetArg(arg[0], XtNtitle, title);
-	XtSetValues(w, arg, 1);
+	XtVaSetValues(w, XtNtitle, title, NULL);
 }
