@@ -25,6 +25,8 @@
 
 /* Methods file for Dino */
 
+#include "file.h"
+#include "rngs.h"
 #include "DinoP.h"
 #include "Dino2dP.h"
 #include "Dino3dP.h"
@@ -147,13 +149,13 @@ loadFont(DinoWidget w)
 	if ((w->dino.fontInfo = XLoadQueryFont(display,
 			w->dino.font)) == NULL) {
 		(void) sprintf(buf,
-			"Cannot open %s font.\nAttempting %s font as alternate\n",
+			"Can not open %s font.\nAttempting %s font as alternate\n",
 			w->dino.font, altfontname);
 		DISPLAY_WARNING(buf);
 		if ((w->dino.fontInfo = XLoadQueryFont(display,
 				altfontname)) == NULL) {
 			(void) sprintf(buf,
-				"Cannot open %s alternate font.\nUse the -font option to specify a font to use.\n",
+				"Can not open %s alternate font.\nUse the -font option to specify a font to use.\n",
 				altfontname);
 			DISPLAY_WARNING(buf);
 		}
@@ -380,24 +382,6 @@ static int  faceToRotate[MAXFACES][MAXORIENT] =
 	{3, 0, 1, 4}
 };
 
-void
-intCat(char ** string, const char * var1, const int var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + 21))) {
-        	DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%d", var1, var2);
-}
-
-void
-stringCat(char ** string, const char * var1, const char * var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + strlen(var2) + 1))) {
-        	DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%s", var1, var2);
-}
-
 static void
 CheckPieces(DinoWidget w)
 {
@@ -478,68 +462,6 @@ PrintCube(DinoWidget w)
 }
 #endif
 
-#ifdef WINVER
-void
-POLYGON(DinoWidget w, GC color, GC lineColor, const POINT * poly, int n,
-		Boolean origin)
-{
-	/* CoordModePrevious -> CoordModeOrigin */
-	POINT      *temp = NULL;
-	int         pt;
-
-	if (!origin) {
-		if (!(temp = (POINT *) malloc(sizeof (POINT) * n))) {
-			DISPLAY_ERROR("Not enough memory, exiting.");
-		}
-		temp[0] = poly[0];
-		for (pt = 1; pt < n; pt++) {
-			temp[pt].x = temp[pt - 1].x + poly[pt].x,
-			temp[pt].y = temp[pt - 1].y + poly[pt].y;
-		}
-	}
-	w->dino.hPen = CreatePen(PS_SOLID, 1, lineColor);
-	w->dino.hOldPen = (HPEN) SelectObject(w->core.hDC, w->dino.hPen);
-	w->dino.hBrush = CreateSolidBrush(color);
-	w->dino.hOldBrush = (HBRUSH) SelectObject(w->core.hDC, w->dino.hBrush);
-	(void) Polygon(w->core.hDC, (origin) ? poly : temp, n);
-	(void) SelectObject(w->core.hDC, w->dino.hOldBrush);
-	(void) DeleteObject(w->dino.hBrush);
-	(void) SelectObject(w->core.hDC, w->dino.hOldPen);
-        (void) DeleteObject(w->dino.hPen);
-	if (!origin) {
-		free(temp);
-	}
-}
-
-void
-POLYLINE(DinoWidget w, GC color, const POINT * poly, int n,
-		Boolean origin)
-{
-	/* CoordModePrevious -> CoordModeOrigin */
-	POINT      *temp = NULL;
-	int         pt;
-
-	if (!origin) {
-		if (!(temp = (POINT *) malloc(sizeof (POINT) * n))) {
-			DISPLAY_ERROR("Not enough memory, exiting.");
-		}
-		temp[0] = poly[0];
-		for (pt = 1; pt < n; pt++) {
-			temp[pt].x = temp[pt - 1].x + poly[pt].x,
-			temp[pt].y = temp[pt - 1].y + poly[pt].y;
-		}
-	}
-	w->dino.hPen = CreatePen(PS_SOLID, 1, color);
-	w->dino.hOldPen = (HPEN) SelectObject(w->core.hDC, w->dino.hPen);
-	(void) Polygon(w->core.hDC, (origin) ? poly : temp, n);
-	(void) SelectObject(w->core.hDC, w->dino.hOldPen);
-        (void) DeleteObject(w->dino.hPen);
-	if (!origin) {
-		free(temp);
-	}
-}
-#endif
-
 static void
 DrawTriangle(DinoWidget w, int face, int position, int offset)
 {
@@ -1204,11 +1126,14 @@ SetValuesDino(DinoWidget w)
 			szBuf, sizeof (szBuf), INIFILE);
 		w->dino.faceChar[face] = szBuf[0];
 	}
-	(void) GetPrivateProfileString(SECTION, "name", "Guest",
+	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
 		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->dino.username, szBuf);
-		w->dino.username[80] = 0;
-
+	(void) strcpy(w->dino.userName, szBuf);
+		w->dino.userName[80] = 0;
+	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
+		szBuf, sizeof (szBuf), INIFILE);
+	(void) strcpy(w->dino.scoreFile, szBuf);
+		w->dino.scoreFile[80] = 0;
 }
 
 void
