@@ -37,6 +37,7 @@
 #ifndef WINVER
 #define XtNselectCallback ((char *) "selectCallback")
 #define XtNuserName ((char *) "userName")
+#define XtNscoreFile ((char *) "scoreFile")
 #define XtNmode ((char *) "mode")
 #define XtNorient ((char *) "orient")
 #define XtNmono ((char *) "mono")
@@ -57,7 +58,10 @@
 #define XtNfaceColor3 ((char *) "faceColor3")
 #define XtNfaceColor4 ((char *) "faceColor4")
 #define XtNfaceColor5 ((char *) "faceColor5")
+#define XtNscoreOnly ((char *) "scoreOnly")
+#define XtNversionOnly ((char *) "versionOnly")
 #define XtCUserName ((char *) "UserName")
+#define XtCScoreFile ((char *) "ScoreFile")
 #define XtCMode ((char *) "Mode")
 #define XtCOrient ((char *) "Orient")
 #define XtCMono ((char *) "Mono")
@@ -103,23 +107,6 @@ typedef struct {
 #define DINO_UNDO 12
 #define DINO_DIM 13
 
-#ifdef WINVER
-#ifdef UNIXDELIM
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#else
-#define CURRENTDELIM ".\\"
-#define FINALDELIM "\\"
-#endif
-#else
-#ifdef VMS
-#define CURRENTDELIM "[]"
-#define FINALDELIM ""
-#else
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#endif
-#endif
 #define PERIOD2 2
 #define PERIOD3 3
 #define BOTH 4
@@ -137,8 +124,5 @@ typedef struct {
 
 typedef struct _DinoRec *DinoWidget;
 
-extern void intCat(char ** string, const char * var1, const int var2);
-extern void stringCat(char ** string, const char * var1, const char * var2);
-
 #endif /* _XtDino_h */
 /* DON'T ADD STUFF AFTER THIS #endif */
