@@ -140,15 +140,18 @@ static XtActionsRec actionsListDino2D[] =
 static XtResource resourcesDino2D[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(DinoWidget, dino.username),
-	 XtRString, (caddr_t) "nobody"},
+	 XtOffset(DinoWidget, dino.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(DinoWidget, dino.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.background),
 	 XtRString, (caddr_t) XtDefaultBackground},
-	{XtNframeColor, XtCForeground, XtRPixel, sizeof (Pixel),
+	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
 	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
@@ -214,6 +217,12 @@ static XtResource resourcesDino2D[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(DinoWidget, dino.cheat),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(DinoWidget, dino.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(DinoWidget, dino.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(DinoWidget, dino.menu),
 	 XtRString, (caddr_t) "-1"},
@@ -304,33 +313,35 @@ static Point triangleUnit[MAXORIENT][4] =
 static Point triangleList[MAXORIENT][4], letterList[MAXORIENT];
 static Point offsetList[MAXORIENT];
 
+static Pixmap dr = 0; /* dummy for future double buffering */
+
 static void
 DrawOrientLine(Dino2DWidget w, int orient, int dx, int dy, GC borderGC)
 {
 	switch (orient) {
 		case TOP:
-			DRAWLINE(w, borderGC,
+			DRAWLINE(w, dr, borderGC,
 				  dx,
 				  dy - w->dino.delta,
 				  dx,
 			  dy - w->dino.delta - w->dino.orientLineLength / 2);
 			return;
 		case RIGHT:
-			DRAWLINE(w, borderGC,
+			DRAWLINE(w, dr, borderGC,
 				  dx + w->dino.delta,
 				  dy,
 			   dx + w->dino.delta + w->dino.orientLineLength / 2,
 				  dy);
 			return;
 		case BOTTOM:
-			DRAWLINE(w, borderGC,
+			DRAWLINE(w, dr, borderGC,
 				  dx,
 				  dy + w->dino.delta,
 				  dx,
 			  dy + w->dino.delta + w->dino.orientLineLength / 2);
 			return;
 		case LEFT:
-			DRAWLINE(w, borderGC,
+			DRAWLINE(w, dr, borderGC,
 				  dx - w->dino.delta,
 				  dy,
 			   dx - w->dino.delta - w->dino.orientLineLength / 2,
@@ -382,8 +393,8 @@ DrawTriangle2D(Dino2DWidget w, int face, int position, int offset)
 		faceGC = w->dino.faceGC[(int) w->dino.cubeLoc[face][position].face];
 		borderGC = w->dino.borderGC;
 	}
-	POLYGON((DinoWidget) w, faceGC, borderGC,
-		triangleList[newSide], 3, False);
+	POLYGON((DinoWidget) w, dr, faceGC, borderGC,
+		triangleList[newSide], 3, True, False);
 	if (w->dino.mono) {
 		char        buf[2];
 
@@ -400,7 +411,7 @@ DrawTriangle2D(Dino2DWidget w, int face, int position, int offset)
 		} else {
 			borderGC = w->dino.inverseGC;
 		}
-		DRAWTEXT(w, borderGC, letterX, letterY, buf, 1);
+		DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, 1);
 	}
 	if (w->dino.orient)
 		DrawOrientLine(w, orient + 2 * MAXORIENT,
@@ -419,32 +430,32 @@ DrawFrame2D(Dino2DWidget w, Boolean focus)
 		pos[i].x = i * w->dino2d.viewLength + w->dino.puzzleOffset.x;
 		pos[i].y = i * w->dino2d.viewLength + w->dino.puzzleOffset.y;
 	}
-	DRAWLINE(w, gc, pos[1].x, pos[0].y, pos[2].x, pos[0].y);
-	DRAWLINE(w, gc, pos[3].x, pos[1].y, pos[3].x, pos[2].y);
-	DRAWLINE(w, gc, pos[1].x, pos[3].y, pos[2].x, pos[3].y);
-	DRAWLINE(w, gc, pos[0].x, pos[1].y, pos[0].x, pos[2].y);
+	DRAWLINE(w, dr, gc, pos[1].x, pos[0].y, pos[2].x, pos[0].y);
+	DRAWLINE(w, dr, gc, pos[3].x, pos[1].y, pos[3].x, pos[2].y);
+	DRAWLINE(w, dr, gc, pos[1].x, pos[3].y, pos[2].x, pos[3].y);
+	DRAWLINE(w, dr, gc, pos[0].x, pos[1].y, pos[0].x, pos[2].y);
 	letters.x = pos[0].x + w->dino2d.viewLength / 2 - w->dino.delta;
 	letters.y = pos[0].y + w->dino2d.viewLength / 2;
-	DRAWTEXT(w, w->dino.borderGC,
+	DRAWTEXT(w, dr, w->dino.borderGC,
 		    (int) (letters.x + 5 * w->dino.letterOffset.x),
 		    (int) (letters.y + w->dino.letterOffset.y), "Front", 5);
 	letters.x = pos[2].x + w->dino2d.viewLength / 2 - w->dino.delta;
 	letters.y = pos[2].y + w->dino2d.viewLength / 2;
-	DRAWTEXT(w, w->dino.borderGC,
+	DRAWTEXT(w, dr, w->dino.borderGC,
 		    (int) (letters.x + 4 * w->dino.letterOffset.x),
 		    (int) (letters.y + w->dino.letterOffset.y), "Back", 4);
 	if (w->dino.vertical) {
-		DRAWLINE(w, gc, pos[1].x, pos[0].y, pos[1].x, pos[4].y);
-		DRAWLINE(w, gc, pos[2].x, pos[0].y, pos[2].x, pos[4].y);
-		DRAWLINE(w, gc, pos[0].x, pos[1].y, pos[3].x, pos[1].y);
-		DRAWLINE(w, gc, pos[0].x, pos[2].y, pos[3].x, pos[2].y);
-		DRAWLINE(w, gc, pos[1].x, pos[4].y, pos[2].x, pos[4].y);
+		DRAWLINE(w, dr, gc, pos[1].x, pos[0].y, pos[1].x, pos[4].y);
+		DRAWLINE(w, dr, gc, pos[2].x, pos[0].y, pos[2].x, pos[4].y);
+		DRAWLINE(w, dr, gc, pos[0].x, pos[1].y, pos[3].x, pos[1].y);
+		DRAWLINE(w, dr, gc, pos[0].x, pos[2].y, pos[3].x, pos[2].y);
+		DRAWLINE(w, dr, gc, pos[1].x, pos[4].y, pos[2].x, pos[4].y);
 	} else {
-		DRAWLINE(w, gc, pos[0].x, pos[1].y, pos[4].x, pos[1].y);
-		DRAWLINE(w, gc, pos[0].x, pos[2].y, pos[4].x, pos[2].y);
-		DRAWLINE(w, gc, pos[1].x, pos[0].y, pos[1].x, pos[3].y);
-		DRAWLINE(w, gc, pos[2].x, pos[0].y, pos[2].x, pos[3].y);
-		DRAWLINE(w, gc, pos[4].x, pos[1].y, pos[4].x, pos[2].y);
+		DRAWLINE(w, dr, gc, pos[0].x, pos[1].y, pos[4].x, pos[1].y);
+		DRAWLINE(w, dr, gc, pos[0].x, pos[2].y, pos[4].x, pos[2].y);
+		DRAWLINE(w, dr, gc, pos[1].x, pos[0].y, pos[1].x, pos[3].y);
+		DRAWLINE(w, dr, gc, pos[2].x, pos[0].y, pos[2].x, pos[3].y);
+		DRAWLINE(w, dr, gc, pos[4].x, pos[1].y, pos[4].x, pos[2].y);
 	}
 }
 
@@ -644,7 +655,7 @@ Widget renew, XEvent * event, Region region
 	if (!w->core.visible)
 		return;
 #endif
-	FILLRECTANGLE(w, w->dino.inverseGC,
+	FILLRECTANGLE(w, dr, w->dino.inverseGC,
 		0, 0, w->core.width, w->core.height);
 	DrawFrame2D(w, w->dino.focus);
 	DrawAllPieces((DinoWidget) w);
