@@ -149,15 +149,18 @@ static XtActionsRec actionsListDino3D[] =
 static XtResource resourcesDino3D[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(DinoWidget, dino.username),
-	 XtRString, (caddr_t) "nobody"},
+	 XtOffset(DinoWidget, dino.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(DinoWidget, dino.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.background),
 	 XtRString, (caddr_t) XtDefaultBackground},
-	{XtNframeColor, XtCForeground, XtRPixel, sizeof (Pixel),
+	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
 	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
@@ -223,6 +226,12 @@ static XtResource resourcesDino3D[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(DinoWidget, dino.cheat),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(DinoWidget, dino.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(DinoWidget, dino.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(DinoWidget, dino.menu),
 	 XtRString, (caddr_t) "-1"},
@@ -286,6 +295,8 @@ static Point triangleLoc3D[MAXFACES][MAXORIENT][4];
 static Point letter3DList[MAXFACES][MAXORIENT];
 static Point orientTriangle[MAXFACES][MAXORIENT][2];
 
+static Pixmap dr = 0; /* dummy for future double buffering */
+
 static void
 DiamondOffset3D(Dino3DWidget w, int face, int *dx, int *dy)
 {
@@ -468,8 +479,8 @@ DrawTriangle3D(Dino3DWidget w, int face, int position, int offset)
 		faceGC = w->dino.faceGC[(int) w->dino.cubeLoc[face][position].face];
 		borderGC = w->dino.borderGC;
 	}
-	POLYGON((DinoWidget) w, faceGC, borderGC,
-		triangleLoc3D[face][corner], 3, False);
+	POLYGON((DinoWidget) w, dr, faceGC, borderGC,
+		triangleLoc3D[face][corner], 3, True, False);
 	if (w->dino.mono) {
 		char        buf[2];
 
@@ -487,12 +498,12 @@ DrawTriangle3D(Dino3DWidget w, int face, int position, int offset)
 		} else {
 			borderGC = w->dino.inverseGC;
 		}
-		DRAWTEXT(w, borderGC,
+		DRAWTEXT(w, dr, borderGC,
 			    letterX + w->dino.letterOffset.x, letterY + w->dino.letterOffset.y,
 			    buf, 1);
 	}
 	if (w->dino.orient) {
-		DRAWLINE(w, borderGC,
+		DRAWLINE(w, dr, borderGC,
 			  letterX +
 			  orientTriangle[face][w->dino.cubeLoc[face][position].rotation][0].x,
 			  letterY +
@@ -513,31 +524,32 @@ DrawFrame3D(Dino3DWidget w, Boolean focus)
 	dx = w->dino3d.viewSize.x + w->dino.puzzleOffset.x;
 	dy = w->dino3d.viewSize.y + w->dino.puzzleOffset.y;
 	if (w->dino.vertical) {
-		DRAWLINE(w, w->dino.frameGC,
+		DRAWLINE(w, dr, w->dino.frameGC,
 			  0, dy, dx + w->dino.puzzleOffset.x + 1, dy);
-		DRAWTEXT(w, w->dino.borderGC,
+		DRAWTEXT(w, dr, w->dino.borderGC,
 			    (int) (2 * w->dino.delta),
 			  (int) (3 * w->dino.delta + w->dino.letterOffset.y),
 			    "Front", 5);
-		DRAWTEXT(w, w->dino.borderGC, (int)
+		DRAWTEXT(w, dr, w->dino.borderGC, (int)
 			    (-4 * w->dino.delta + 2 * 6 * w->dino.letterOffset.x + w->core.width),
 			    (int) (-w->dino.delta - 2 * w->dino.letterOffset.y + w->core.height),
 			    "Back", 4);
 	} else {
-		DRAWLINE(w, w->dino.frameGC,
+		DRAWLINE(w, dr, w->dino.frameGC,
 			  dx, 0, dx, dy + w->dino.puzzleOffset.y + 1);
-		DRAWTEXT(w, w->dino.borderGC,
+		DRAWTEXT(w, dr, w->dino.borderGC,
 			    (int) (2 * w->dino.delta),
 			  (int) (3 * w->dino.delta + w->dino.letterOffset.y),
 			    "Front", 5);
-		DRAWTEXT(w, w->dino.borderGC, (int)
+		DRAWTEXT(w, dr, w->dino.borderGC, (int)
 			    (-4 * w->dino.delta + 2 * 6 * w->dino.letterOffset.x + w->core.width),
 			    (int) (-w->dino.delta - 2 * w->dino.letterOffset.y + w->core.height),
 			    "Back", 4);
 	}
-	for (face = 0; face < MAXFACES; face++)
-		POLYLINE((DinoWidget) w, gc,
+	for (face = 0; face < MAXFACES; face++) {
+		POLYLINE((DinoWidget) w, dr, gc,
 			faceLoc3D[face], MAXORIENT, False);
+	}
 }
 
 static void
@@ -1053,7 +1065,7 @@ Widget renew, XEvent * event, Region region
 	if (!w->core.visible)
 		return;
 #endif
-	FILLRECTANGLE(w, w->dino.inverseGC,
+	FILLRECTANGLE(w, dr, w->dino.inverseGC,
 			0, 0, w->core.width, w->core.height);
 	DrawFrame3D(w, w->dino.focus);
 	DrawAllPieces((DinoWidget) w);
