@@ -29,38 +29,25 @@
   Version 4: 94/05/30 Xt
 */
 
+#include "file.h"
 #ifdef WINVER
 #include "DinoP.h"
 #include "wdino.h"
 #define TITLE "wdino"
 
 static DinoRec widget;
-static HWND Wnd;
 
 #ifndef SCOREPATH
-#define SCOREPATH "c:\\Windows"
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
 #endif
-#define PRINT_MESSAGE(b) (void) MessageBox(Wnd, (LPCSTR) b, "Warning", MB_OK);
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
 #define SET_STARTED(w,b) w->dino.started = b
 #else
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
-#ifdef VMS
-#include <unixlib.h>
-#define getlogin() cuserid(NULL)
-#else
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif
-#if HAVE_FCNTL_H
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#endif
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
+#include "xwin.h"
 #include <X11/Shell.h>
 #include <X11/cursorfont.h>
 #ifdef HAVE_MOTIF
@@ -81,7 +68,7 @@ static HWND Wnd;
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
-#define SET_STARTED(w,b) XtSetArg(arg[0], XtNstart, b); XtSetValues(w, arg, 1)
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
 #include "Dino.h"
 #include "Dino2d.h"
 #include "Dino3d.h"
@@ -91,27 +78,34 @@ static HWND Wnd;
 #endif
 #include "icons/dino.xbm"
 #ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
 #define SCOREPATH "/var/games/xpuzzles"
 #endif
 #endif
+#endif
 
-#ifdef HAVE_MOTIF
+#ifndef WINVER
 static const char aboutHelp[] = {
-	"Version 7.1.3\n"
+	"Dino Version 7.1.5\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
 	"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
+
 static const char optionsHelp[] = {
-	"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]] "
-	"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"[-{foreground|fg} {color}] [-{background|bg} {color}] "
-	"[-{border|bd} {color}] [-face{0|1|2|3|4|5} {color}] \n"
-	"[-{mode {int} | both}] [-[no]orient] [-[no]practice] "
-	"[-{font|fn} {fontname}] [-username {string}]\n"
+	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+	"\t[-{border|bd} {color}] [-face{0|1|2|3|4|5} {color}] \n"
+	"\t[-{mode {int} | both}] [-[no]orient] [-[no]practice]\n"
+	"\t[-{font|fn} {fontname}] [-userName {string}]\n"
+	"\t[-scoreFile {filename}] [-scores] [-version]\n"
 };
 #endif
+
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
 	"The period 2 turning (i.e. the edges turn with 180 "
@@ -125,18 +119,22 @@ static const char descriptionHelp[] = {
 	"manufactured by The International Puzzle & Games "
 	"(Great Animation International Corporation).\n"
 };
+
 static const char featuresHelp[] = {
 	"Press \"mouse-left\" button to move a piece.  Release "
 	"\"mouse-left\" button on a piece on the same face.\n"
-	"in the same row.  The pieces will then turn towards "
-	"where the mouse button was released.\n"
+	"The pieces will then turn towards where the mouse "
+	"button was released.\n"
+	"\n"
 	"Click \"mouse-center\" button, or press \"P\" or \"p\" "
 	"keys, to toggle the practice mode (in practice mode the\n"
 	"record should say \"practice\").  This is good for learning "
 	"moves and experimenting.\n"
+	"\n"
 	"Click \"mouse-right\" button, or press \"R\" or \"r\" "
 	"keys, to randomize the puzzle (this must be done first\n"
 	"to set a new record).\n"
+	"\n"
 	"Press \"O\" or \"o\" keys to toggle the orient mode.  One "
 	"has to orient the faces in orient mode, besides\n"
 	"getting all the faces to be the same color.  To do this "
@@ -144,15 +142,25 @@ static const char featuresHelp[] = {
 	"the same direction.  This does add complexity (ever so "
 	"slightly, there are only 2 possibilities) so there\n"
 	"are 2 sets of records.\n"
+	"\n"
 	"Press \"2\", \"3\", \"B\", or \"b\" keys (not the keypad "
 	"2, 3) to change modes to Period 2, Period 3, or Both.\n"
+	"\n"
 	"\"S\" or \"s\" keys reserved for the auto-solver "
 	"(not implemented).\n"
+	"\n"
 	"Press \"U\" or \"u\" keys to undo a move.\n"
+	"\n"
 	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+	"\n"
 	"Press \"W\" or \"w\" keys to save a puzzle.\n"
+	"\n"
+	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+	"\n"
 	"Press \"Esc\" key to hide program.\n"
+	"\n"
 	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+	"\n"
 	"Use the key pad, \"R\" keys, or arrow keys to move without "
 	"clicks.\n"
 	"Key pad is defined for Dino2d as:\n"
@@ -165,25 +173,30 @@ static const char featuresHelp[] = {
 	"control key is pressed and there is no analog for\n"
 	"Dino3d.\n"
 	"Key pad for Dino3d, use must use your intuition (is this "
-        "a cop out or what?).  The key pad is defined\n"
-        "differently depending on which side of the cube your mouse "
-        "is pointing at.\n"
+	"a cop out or what?).  The key pad is defined\n"
+	"differently depending on which side of the cube your mouse "
+	"is pointing at.\n"
+	"\n"
 	"Use the alt key and the left mouse button, keypad, or arrow "
 	"keys to move the center of the cube.  The 2 opposite\n"
 	"corners do not move.\n"
+	"\n"
 	"Use the shift keys and the left mouse button, keypad, "
 	"or arrow key to access \"Period 2\" turns from \"Both\" mode,\n"
 	"otherwise it assumes \"Period 3\" turning.  Edges turn in "
 	"\"Period 2\" and corners turn in \"Period 3\".  The\n"
 	"\"Period 2\" mode has extra cuts around the faces.\n"
-        "Use the control key and the left mouse button, keypad, or "
-        "arrow keys to move the whole cube.  This is\n"
-        "not recorded as a turn.\n"
+	"\n"
+	"Use the control key and the left mouse button, keypad, or "
+	"arrow keys to move the whole cube.  This is\n"
+	"not recorded as a turn.\n"
 };
+
 static const char referencesHelp[] = {
 	"International Puzzles & Games Catalog.\n"
 };
 #endif
+
 static const char solveHelp[] = {
 	"Auto-solver: sorry, not implemented.\n"
 };
@@ -192,7 +205,7 @@ static const char solveHelp[] = {
 #define SCOREFILE "dino.scores"
 #endif
 
-#define NEVER -1
+#define NEVER (-1)
 #define FILENAMELEN 1024
 #define USERNAMELEN 120
 #define MESSAGELEN (USERNAMELEN+64)
@@ -212,14 +225,16 @@ static char recordDsp[MESSAGELEN] = "NOT RECORDED";
 #ifndef HAVE_MOTIF
 static char titleDsp[TITLELEN] = "";
 #endif
+static char scoreFileName[FILENAMELEN] = SCOREFILE;
+static char fileName[FILENAMELEN];
 #ifdef WINVER
 #define MAXPROGNAME 80
 static char progDsp[MAXPROGNAME] = TITLE;
-static char usernameDsp[USERNAMELEN] = "Guest";
+static char userNameDsp[USERNAMELEN] = "Guest";
 #else
 #ifdef HAVE_MOTIF
-static Widget moves, record, message, modes[MAXMODES],
-	orientSwitch, practiceSwitch;
+static Widget moves, record, message, modes[MAXMODES];
+static Widget orientSwitch, practiceSwitch;
 static char buff[21];
 static const char *modeString[] =
 {
@@ -228,63 +243,14 @@ static const char *modeString[] =
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
+static Arg arg[3];
 #else
-Widget shell;
+static Widget shell;
 #endif
 static Pixmap dinoIcon = None;
 static Widget topLevel, dino2d, dino3d;
-static Arg arg[5];
 static char *progDsp;
-static char usernameDsp[USERNAMELEN] = "";
-
-/* There's probably a better way to assure that they are the same but I don't
-   know it off hand. */
-static void
-MakeEquivalent(String * username, int *mode, Boolean * orient, Boolean * practice)
-{
-	Boolean mono, reverse;
-	Pixel foreground, background, pieceBorder;
-	String faceColor[MAXFACES];
-
-	XtVaGetValues(dino2d,
-		XtNuserName, username,
-		XtNmode, mode,
-		XtNorient, orient,
-		XtNpractice, practice,
-		XtNmono, &mono,
-		XtNreverse, &reverse,
-		XtNforeground, &foreground,
-		XtNbackground, &background,
-		XtNpieceBorder, &pieceBorder,
-		XtNfaceColor0, &(faceColor[0]),
-		XtNfaceColor1, &(faceColor[1]),
-		XtNfaceColor2, &(faceColor[2]),
-		XtNfaceColor3, &(faceColor[3]),
-		XtNfaceColor4, &(faceColor[4]),
-		XtNfaceColor5, &(faceColor[5]), NULL);
-	XtVaSetValues(dino2d,
-		XtNdirection, DINO_IGNORE,
-		XtNstart, False, NULL);
-	XtVaSetValues(dino3d,
-		XtNuserName, *username,
-		XtNmode, *mode,
-		XtNorient, *orient,
-		XtNpractice, *practice,
-		XtNmono, mono,
-		XtNreverse, reverse,
-		XtNdirection, DINO_IGNORE,
-		XtNstart, False,
-		XtNforeground, foreground,
-		XtNbackground, background,
-		XtNpieceBorder, pieceBorder,
-		XtNfaceColor0, faceColor[0],
-		XtNfaceColor1, faceColor[1],
-		XtNfaceColor2, faceColor[2],
-		XtNfaceColor3, faceColor[3],
-		XtNfaceColor4, faceColor[4],
-		XtNfaceColor5, faceColor[5], NULL);
-}
-#endif
+static char userNameDsp[USERNAMELEN] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -295,31 +261,25 @@ PrintState(Widget w, char *msg)
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
 		XtError("PrintState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
-	XtSetArg(arg[0], XmNlabelString, xmstr);
-	XtSetValues(w, arg, 1);
+	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
-#else
-static void
-PrintState(
-#ifndef WINVER
-Widget w,
 #endif
-int dim, int mode, int moves, char *msg)
-{
-	char mb[10];
 
-	if (mode == BOTH)
-		(void) strcpy(mb, "both");
-	else
-		(void) sprintf(mb, "%d", mode);
-	(void) sprintf(titleDsp, "%s%dd.%s: (%d/%s) - %s",
-		progDsp, dim, mb, moves, recordDsp, msg);
-#ifdef WINVER
-	SetWindowText(Wnd, (LPSTR) titleDsp);
-#else
-	XtSetArg(arg[0], XtNtitle, titleDsp);
-	XtSetValues(w, arg, 1);
-#endif
+static void
+PrintRecords(void)
+{
+	int mode, orient;
+
+	(void) printf("          DINO  HALL OF FAME\n\n");
+	(void) printf("MODE ORIENT USER            MOVES\n");
+	for (mode = 0; mode < MAXMODES; mode++)
+		for (orient = 0; orient < 2; orient++) {
+			if (dinoRecord[mode][orient].score > 0)
+				(void) printf("%4d%7d %-12s%9d\n",
+					mode + 2, orient,
+					dinoRecord[mode][orient].name,
+					dinoRecord[mode][orient].score);
+		}
 }
 #endif
 
@@ -341,21 +301,21 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int n, mode, orient;
-	char username[USERNAMELEN];
+	char userName[USERNAMELEN];
 	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *fname, *lname;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
+	stringCat(&buf1, CURRENTDELIM, scoreFileName);
 	lname = buf1;
 	stringCat(&buf1, SCOREPATH, FINALDELIM);
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "r")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "r")) == NULL) {
+	(void) strncpy(fileName, lname, USERNAMELEN);
+	if ((fp = fopen(fileName, "r")) == NULL) {
+		(void) strncpy(fileName, fname, USERNAMELEN);
+		/* Try installed directory. */
+		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
@@ -384,12 +344,12 @@ ReadRecords(void)
 	free(fname);
 	for (mode = 0; mode < MAXMODES; mode++)
 		for (orient = 0; orient < 2; orient++) {
-			(void) fscanf(fp, "%d %s\n", &n, username);
+			(void) fscanf(fp, "%d %s\n", &n, userName);
 			if (n <= dinoRecord[mode][orient].score ||
-			    dinoRecord[mode][orient].score <= NEVER) {
+					dinoRecord[mode][orient].score <= NEVER) {
 				dinoRecord[mode][orient].score = n;
 				(void) strncpy(dinoRecord[mode][orient].name,
-					username, USERNAMELEN);
+					userName, USERNAMELEN);
 			}
 		}
 	(void) fclose(fp);
@@ -400,61 +360,31 @@ WriteRecords(void)
 {
 	FILE *fp;
 	int mode, orient;
-	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *buf1 = NULL;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
-	lname = buf1;
-	stringCat(&buf1, SCOREPATH, FINALDELIM);
-	stringCat(&buf2, buf1, SCOREFILE);
-	free(buf1);
-	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "w")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "w")) == NULL) {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, " or ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-			free(lname);
-			free(fname);
-			return;
-		}
-/* Probably annoying */
-#if 0
-		else {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, ", falling back to ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-		}
-#endif
+	if ((fp = fopen(fileName, "w")) == NULL) {
+		stringCat(&buf1, "Can not write to ", fileName);
+		PRINT_MESSAGE(buf1);
+		free(buf1);
+		return;
 	}
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockfile[FILENAMELEN];
+		char lockFile[FILENAMELEN];
 
-		(void) strncpy(lockfile, name, FILENAMELEN - 6);
-		(void) strcat(lockfile, ".lock");
-		while (((lfd = open(lockfile, O_CREAT | O_EXCL, 0644)) < 0) &&
+		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strcat(lockFile, ".lock");
+		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
 			(void) sleep(1);
 		if (lfd < 0) {
 #if 1
 			(void) fprintf(stderr,
-			  "Lock file exists... guessing its an old one.\n");
+				"Lock file exists... guessing its an old one.\n");
 #else
 			(void) fprintf(stderr,
-			  "Lock file exists... score not recorded - sorry.\n");
+				"Lock file exists... score not recorded - sorry.\n");
 			return;
 #endif
 		}
@@ -468,12 +398,10 @@ WriteRecords(void)
 		}
 #if HAVE_FCNTL_H
 		(void) close(lfd);
-		(void) unlink(lockfile);
+		(void) unlink(lockFile);
 #endif
 		(void) fclose(fp);
 	}
-	free(lname);
-	free(fname);
 }
 
 static void
@@ -482,9 +410,9 @@ PrintRecord(int mode, Boolean orient, Boolean practice)
 	int i = mode - PERIOD2;
 	int j = (orient) ? 1 : 0;
 
-	if (practice)
+	if (practice) {
 		(void) strncpy(recordDsp, "practice", MESSAGELEN);
-	else if (dinoRecord[i][j].score <= NEVER) {
+	} else if (dinoRecord[i][j].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
 		(void) sprintf(recordDsp, "%d %s",
@@ -495,6 +423,102 @@ PrintRecord(int mode, Boolean orient, Boolean practice)
 #endif
 }
 
+#ifndef WINVER
+/* There's probably a better way to assure that they are the same but I don't
+   know it off hand. */
+static void
+MakeEquivalent(String *userName, String *scoreFile, int *mode,
+		Boolean *orient, Boolean *practice)
+{
+	Boolean mono, reverse;
+	Boolean scoreOnly, versionOnly;
+	Pixel foreground, background, pieceBorder;
+	String faceColor[MAXFACES];
+
+	XtVaGetValues(dino2d,
+		XtNuserName, userName,
+		XtNscoreFile, scoreFile,
+		XtNmode, mode,
+		XtNorient, orient,
+		XtNpractice, practice,
+		XtNmono, &mono,
+		XtNreverse, &reverse,
+		XtNforeground, &foreground,
+		XtNbackground, &background,
+		XtNpieceBorder, &pieceBorder,
+		XtNfaceColor0, &(faceColor[0]),
+		XtNfaceColor1, &(faceColor[1]),
+		XtNfaceColor2, &(faceColor[2]),
+		XtNfaceColor3, &(faceColor[3]),
+		XtNfaceColor4, &(faceColor[4]),
+		XtNfaceColor5, &(faceColor[5]),
+		XtNscoreOnly, &scoreOnly,
+		XtNversionOnly, &versionOnly, NULL);
+	if (versionOnly) {
+		(void) printf(aboutHelp);
+		exit(0);
+	}
+	if (strcmp(*scoreFile, ""))
+		(void) strncpy(scoreFileName, *scoreFile, FILENAMELEN);
+	if (scoreOnly) {
+		InitRecords();
+		ReadRecords();
+		PrintRecords();
+		exit(0);
+	}
+	XtVaSetValues(dino2d,
+		XtNdirection, DINO_IGNORE,
+		XtNstart, False, NULL);
+	XtVaSetValues(dino3d,
+		XtNuserName, *userName,
+		XtNmode, *mode,
+		XtNorient, *orient,
+		XtNpractice, *practice,
+		XtNmono, mono,
+		XtNreverse, reverse,
+		XtNdirection, DINO_IGNORE,
+		XtNstart, False,
+		XtNforeground, foreground,
+		XtNbackground, background,
+		XtNpieceBorder, pieceBorder,
+		XtNfaceColor0, faceColor[0],
+		XtNfaceColor1, faceColor[1],
+		XtNfaceColor2, faceColor[2],
+		XtNfaceColor3, faceColor[3],
+		XtNfaceColor4, faceColor[4],
+		XtNfaceColor5, faceColor[5], NULL);
+}
+#endif
+
+static void
+PrintStatus(char *msg, int nMoves
+#ifndef HAVE_MOTIF
+		, int dim, int mode
+#endif
+		)
+{
+#ifdef HAVE_MOTIF
+	PrintState(message, msg);
+	(void) sprintf(buff, "%d", nMoves);
+	PrintState(moves, buff);
+#else
+	char mb[10];
+
+	if (mode == BOTH)
+		(void) strcpy(mb, "both");
+	else
+		(void) sprintf(mb, "%d", mode);
+	(void) sprintf(titleDsp, "%s%dd.%s: (%d/%s) - %s",
+		progDsp, dim, mb, nMoves, recordDsp, msg);
+#ifdef WINVER
+	SetWindowText(widget.core.hWnd, (LPSTR) titleDsp);
+#else
+	XtVaSetValues(XtParent((dim == 2) ? dino2d : dino3d),
+		XtNtitle, titleDsp, NULL);
+#endif
+#endif
+}
+
 static Boolean
 HandleSolved(int counter, int mode, Boolean orient)
 {
@@ -502,14 +526,15 @@ HandleSolved(int counter, int mode, Boolean orient)
 	int j = (orient) ? 1 : 0;
 
 	if (counter < dinoRecord[i][j].score ||
-	    dinoRecord[i][j].score <= NEVER) {
+			dinoRecord[i][j].score <= NEVER) {
 		ReadRecords();	/* Maybe its been updated by another */
 		dinoRecord[i][j].score = counter;
-		(void) strncpy(dinoRecord[i][j].name, usernameDsp, USERNAMELEN);
+		(void) strncpy(dinoRecord[i][j].name, userNameDsp,
+			USERNAMELEN);
 		if (orient && (counter < dinoRecord[!i][j].score ||
-		    dinoRecord[!i][j].score <= NEVER)) {
+				dinoRecord[!i][j].score <= NEVER)) {
 			dinoRecord[!i][j].score = counter;
-			(void) strncpy(dinoRecord[!i][j].name, usernameDsp,
+			(void) strncpy(dinoRecord[!i][j].name, userNameDsp,
 				USERNAMELEN);
 		}
 		WriteRecords();
@@ -530,7 +555,7 @@ void
 {
 	int mode;
 	Boolean orient, practice;
-	char *username;
+	char *userName, *scoreFile;
 #ifdef WINVER
 	int dim;
 
@@ -539,11 +564,14 @@ void
 	mode = w->dino.mode;
 	orient = w->dino.orient;
 	practice = w->dino.practice;
-	username = w->dino.username;
+	userName = w->dino.userName;
+	scoreFile = w->dino.scoreFile;
 	dim = w->dino.dim;
 	SET_STARTED(w, False);
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
 #else
-	MakeEquivalent(&username, &mode, &orient, &practice);
+	MakeEquivalent(&userName, &scoreFile, &mode, &orient, &practice);
 #ifdef HAVE_MOTIF
 	XmToggleButtonSetState(modes[mode - PERIOD2], True, False);
 	XmToggleButtonSetState(orientSwitch, orient, True);
@@ -553,30 +581,32 @@ void
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(usernameDsp, username, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #endif
-	if (!strcmp(username, "") || !strcmp(username, "(null)") ||
-	    !strcmp(username, NOACCESS) || !strcmp(username, NOBODY)) {
+	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
+			!strcmp(userName, NOACCESS) ||
+			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(usernameDsp, username, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		/* The NOACCESS is not necessary, but it may stop silliness. */
-		(void) sprintf(usernameDsp, "%s", getlogin());
-		if (!strcmp(usernameDsp, "") ||
-				!strcmp(usernameDsp, "(null)") ||
-				!strcmp(usernameDsp, NOACCESS) ||
-				!strcmp(usernameDsp, NOBODY))
+		(void) sprintf(userNameDsp, "%s", getlogin());
+		if (!strcmp(userNameDsp, "") ||
+				!strcmp(userNameDsp, "(null)") ||
+				!strcmp(userNameDsp, NOACCESS) ||
+				!strcmp(userNameDsp, NOBODY))
 			/* It really IS nobody */
-			(void) sprintf(usernameDsp, "%s", NOBODY);
+			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
 	PrintRecord(mode, orient, practice);
 #ifdef WINVER
-	PrintState(dim, mode, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp, dim, mode);
 #else
-#ifndef HAVE_MOTIF
-	PrintState(XtParent(dino2d), 2, mode, movesDsp, messageDsp);
-	PrintState(XtParent(dino3d), 3, mode, movesDsp, messageDsp);
+#ifdef HAVE_MOTIF
+	PrintStatus(messageDsp, movesDsp);
+#else
+	PrintStatus(messageDsp, movesDsp, 2, mode);
+	PrintStatus(messageDsp, movesDsp, 3, mode);
 #endif
 #endif
 }
@@ -648,16 +678,16 @@ CallbackDino(Widget w, caddr_t clientData, dinoCallbackStruct * callData)
 #ifdef HAVE_MOTIF
 			XtManageChild(practiceDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 8); /* menu choice */
-			XtSetValues(dino2d, arg, 1);
+			XtVaSetValues(dino2d,
+				XtNmenu, 8, NULL); /* menu choice */
 #endif
 			break;
 		case DINO_RANDOMIZE_QUERY:
 #ifdef HAVE_MOTIF
 			XtManageChild(randomizeDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-			XtSetValues(dino2d, arg, 1);
+			XtVaSetValues(dino2d,
+				XtNmenu, 5, NULL); /* menu choice */
 #endif
 			break;
 #endif
@@ -675,24 +705,25 @@ CallbackDino(Widget w, caddr_t clientData, dinoCallbackStruct * callData)
 			break;
 		case DINO_RESTORE:
 			if (practice) {
-				(void) strncpy(recordDsp, "practice", MESSAGELEN);
+				(void) strncpy(recordDsp, "practice",
+					MESSAGELEN);
 #ifdef HAVE_MOTIF
 				PrintState(record, recordDsp);
 #endif
 			}
 			movesDsp = 0;
 #ifndef WINVER
-			XtSetArg(arg[0], XtNdirection, DINO_RESTORE);
-			XtSetValues(otherw, arg, 1);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(otherw,
+				XtNdirection, DINO_RESTORE, NULL);
+			XtVaSetValues(w,
+				XtNdirection, DINO_RESTORE, NULL);
 #endif
 			break;
 		case DINO_CLEAR:
 			movesDsp = 0;
 #ifndef WINVER
-			XtSetArg(arg[0], XtNdirection, DINO_CLEAR);
-			XtSetValues(otherw, arg, 1);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(otherw, XtNdirection, DINO_CLEAR, NULL);
+			XtVaSetValues(w, XtNdirection, DINO_CLEAR, NULL);
 #endif
 			break;
 		case DINO_RESET:
@@ -709,20 +740,20 @@ CallbackDino(Widget w, caddr_t clientData, dinoCallbackStruct * callData)
 #ifndef WINVER
 		case DINO_MOVED:
 			movesDsp++;
-			XtSetArg(arg[0], XtNstart, True);
-			XtSetArg(arg[1], XtNface, callData->face);
-			XtSetArg(arg[2], XtNpos, callData->position);
-			XtSetArg(arg[3], XtNdirection, callData->direction);
-			XtSetArg(arg[4], XtNstyle, callData->style);
-			XtSetValues(otherw, arg, 5);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(otherw,
+				XtNstart, True,
+				XtNface, callData->face,
+				XtNpos, callData->position,
+				XtNdirection, callData->direction,
+				XtNstyle, callData->style, NULL);
+			SET_STARTED(w, False);
 			break;
 		case DINO_CONTROL:
-			XtSetArg(arg[0], XtNface, callData->face);
-			XtSetArg(arg[1], XtNpos, callData->position);
-			XtSetArg(arg[2], XtNdirection, callData->direction);
-			XtSetArg(arg[3], XtNstyle, callData->style);
-			XtSetValues(otherw, arg, 4);
+			XtVaSetValues(otherw,
+				XtNface, callData->face,
+				XtNpos, callData->position,
+				XtNdirection, callData->direction,
+				XtNstyle, callData->style, NULL);
 			return;
 #endif
 		case DINO_SOLVED:
@@ -730,19 +761,16 @@ CallbackDino(Widget w, caddr_t clientData, dinoCallbackStruct * callData)
 				movesDsp = 0;
 			else if (cheat)
 				(void) sprintf(messageDsp,
-					"No cheating %s!!", usernameDsp);
+					"No cheating %s!!", userNameDsp);
 			else if (HandleSolved(movesDsp, mode, orient))
 				(void) sprintf(messageDsp,
-					"Congratulations %s!!", usernameDsp);
+					"Congratulations %s!!", userNameDsp);
 			else
-				(void) strncpy(messageDsp, "Solved!", MESSAGELEN);
-#ifdef WINVER
+				(void) strncpy(messageDsp, "Solved!",
+					MESSAGELEN);
 			SET_STARTED(w, False);
-#else
-
-			XtSetArg(arg[0], XtNstart, False);
-			XtSetValues(w, arg, 1);
-			XtSetValues(otherw, arg, 1);
+#ifndef WINVER
+			SET_STARTED(otherw, False);
 #endif
 			break;
 		case DINO_PRACTICE:
@@ -756,10 +784,12 @@ CallbackDino(Widget w, caddr_t clientData, dinoCallbackStruct * callData)
 			w->dino.practice = practice;
 			w->dino.started = False;
 #else
-			XtSetArg(arg[0], XtNpractice, practice);
-			XtSetArg(arg[1], XtNstart, False);
-			XtSetValues(w, arg, 2);
-			XtSetValues(otherw, arg, 2);
+			XtVaSetValues(w,
+				XtNpractice, practice,
+				XtNstart, False, NULL);
+			XtVaSetValues(otherw,
+				XtNpractice, practice,
+				XtNstart, False, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(practiceSwitch, practice, True);
 #endif
@@ -768,13 +798,15 @@ CallbackDino(Widget w, caddr_t clientData, dinoCallbackStruct * callData)
 		case DINO_RANDOMIZE:
 			movesDsp = 0;
 #ifdef WINVER
-			w->dino.practice = practice;
+			w->dino.practice = False;
 			w->dino.started = False;
 #else
-			XtSetArg(arg[0], XtNpractice, False);
-			XtSetArg(arg[1], XtNstart, False);
-			XtSetValues(w, arg, 2);
-			XtSetValues(otherw, arg, 2);
+			XtVaSetValues(w,
+				XtNpractice, False,
+				XtNstart, False, NULL);
+			XtVaSetValues(otherw,
+				XtNpractice, False,
+				XtNstart, False, NULL);
 #endif
 			break;
 		case DINO_ORIENT:
@@ -784,9 +816,10 @@ CallbackDino(Widget w, caddr_t clientData, dinoCallbackStruct * callData)
 #ifdef WINVER
 			w->dino.orient = orient;
 #else
-			XtSetArg(arg[0], XtNorient, orient);
-			XtSetValues(w, arg, 1);
-			XtSetValues(otherw, arg, 1);
+			XtVaSetValues(w,
+				XtNorient, orient, NULL);
+			XtVaSetValues(otherw,
+				XtNorient, orient, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(orientSwitch, orient, True);
 #endif
@@ -801,33 +834,31 @@ CallbackDino(Widget w, caddr_t clientData, dinoCallbackStruct * callData)
 #ifdef WINVER
 			w->dino.mode = mode;
 #else
-			XtSetArg(arg[0], XtNmode, mode);
-			XtSetValues(w, arg, 1);
-			XtSetValues(otherw, arg, 1);
+			XtVaSetValues(w,
+				XtNmode, mode, NULL);
+			XtVaSetValues(otherw,
+				XtNmode, mode, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(modes[mode - PERIOD2], True, True);
 #endif
 #endif
 			break;
 		case DINO_COMPUTED:
-#ifdef WINVER
 			SET_STARTED(w, False);
-#else
-			XtSetArg(arg[0], XtNstart, False);
-			XtSetValues(w, arg, 1);
-			XtSetValues(otherw, arg, 1);
+#ifndef WINVER
+			SET_STARTED(otherw, False);
 #endif
 			break;
 #ifndef WINVER
 		case DINO_UNDO:
 			movesDsp--;
-			XtSetArg(arg[0], XtNstart, True);
-			XtSetArg(arg[1], XtNface, callData->face);
-			XtSetArg(arg[2], XtNpos, callData->position);
-			XtSetArg(arg[3], XtNdirection, callData->direction);
-			XtSetArg(arg[4], XtNstyle, callData->style);
-			XtSetValues(otherw, arg, 5);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(otherw,
+				XtNstart, True,
+				XtNface, callData->face,
+				XtNpos, callData->position,
+				XtNdirection, callData->direction,
+				XtNstyle, callData->style, NULL);
+			SET_STARTED(w, False);
 			break;
 #endif
 #ifdef WINVER
@@ -840,15 +871,13 @@ CallbackDino(Widget w, caddr_t clientData, dinoCallbackStruct * callData)
 #endif
 	}
 #ifdef WINVER
-	PrintState(dim, mode, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp, dim, mode);
 #else
 #ifdef HAVE_MOTIF
-	PrintState(message, messageDsp);
-	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
+	PrintStatus(messageDsp, movesDsp);
 #else
-	PrintState(XtParent(w), dim, mode, movesDsp, messageDsp);
-	PrintState(XtParent(otherw), otherdim, mode, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp, dim, mode);
+	PrintStatus(messageDsp, movesDsp, otherdim, mode);
 #endif
 #endif
 }
@@ -882,7 +911,7 @@ SetDinoMove(DinoWidget w, int reason, int face, int position, int direction,
 			SET_STARTED(w, True);
 			break;
 	}
-	PrintState(dim, mode, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp, dim, mode);
 }
 
 static LRESULT CALLBACK
@@ -906,7 +935,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	PAINTSTRUCT paint;
 	int shift = 0;
 
-	Wnd = widget.core.hWnd = hWnd;
+	widget.core.hWnd = hWnd;
 	if (GetFocus()) {
 		if (!widget.dino.focus) {
 			widget.core.hDC = GetDC(hWnd);
@@ -1238,18 +1267,7 @@ static void
 Usage(char * programName)
 {
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr,
-		"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n");
-	(void) fprintf(stderr,
-		"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n");
-	(void) fprintf(stderr,
-		"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{border|bd} {color}] [-face{0|1|2|3|4|5} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{mode {int} | both}] [-[no]orient] [-[no]practice]\n");
-	(void) fprintf(stderr,
-		"\t[-{font|fn} {fontname}] [-username {string}]\n");
+	(void) fprintf(stderr, optionsHelp);
 	exit(1);
 }
 
@@ -1281,7 +1299,10 @@ static XrmOptionDescRec options[] =
 	{(char *) "-nopractice", (char *) "*dino.practice", XrmoptionNoArg, (char *) "FALSE"},
 	{(char *) "-fn", (char *) "*dino.font", XrmoptionSepArg, NULL},
 	{(char *) "-font", (char *) "*dino.font", XrmoptionSepArg, NULL},
-	{(char *) "-username", (char *) "*dino.userName", XrmoptionSepArg, NULL}
+	{(char *) "-userName", (char *) "*dino.userName", XrmoptionSepArg, NULL},
+	{(char *) "-scoreFile", (char *) "*dino.scoreFile", XrmoptionSepArg, NULL},
+	{(char *) "-scores", (char *) "*dino.scoreOnly", XrmoptionNoArg, (char *) "TRUE"},
+	{(char *) "-version", (char *) "*dino.versionOnly", XrmoptionNoArg, (char *) "TRUE"}
 };
 
 #ifdef HAVE_MOTIF
@@ -1289,8 +1310,7 @@ static void
 CallbackDinoPractice(Widget w, XtPointer clientData, XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 8); /* menu choice */
-		XtSetValues(dino2d, arg, 1);
+		XtVaSetValues(dino2d, XtNmenu, 8, NULL); /* menu choice */
 	}
 }
 
@@ -1298,8 +1318,7 @@ static void
 CallbackDinoRandomize(Widget w, XtPointer clientData, XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-		XtSetValues(dino2d, arg, 1);
+		XtVaSetValues(dino2d, XtNmenu, 5, NULL); /* menu choice */
 	}
 }
 static void
@@ -1378,16 +1397,15 @@ fileCB(Widget w, void *value, void *clientData)
 
 	if (val == 2)
 		exit(0);
-	XtSetArg(arg[0], XtNmenu, val);
-	XtSetValues(dino2d, arg, 1);
+	XtVaSetValues(dino2d, XtNmenu, val, NULL);
 }
 
 static void
 playCB(Widget w, void *value, void *clientData)
 {
 	int val = (int) value;
-	XtSetArg(arg[0], XtNmenu, val + 3); /* GWQ */
-	XtSetValues(dino2d, arg, 1);
+
+	XtVaSetValues(dino2d, XtNmenu, val + 3, NULL); /* GWQ */
 }
 
 static Widget
@@ -1468,7 +1486,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d\n", val);
+			intCat(&buf, "helpCB: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1520,11 +1538,10 @@ main(int argc, char **argv)
 		dinoIcon = XCreateBitmapFromData(XtDisplay(topLevel),
 			RootWindowOfScreen(XtScreen(topLevel)),
 			(char *) dino_bits, dino_width, dino_height);
-	XtSetArg(arg[0], XtNiconPixmap, dinoIcon);
 #ifdef HAVE_MOTIF
-	/* not XmEXPLICIT */
-	XtSetArg(arg[1], XmNkeyboardFocusPolicy, XmPOINTER);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, dinoIcon,
+		XmNkeyboardFocusPolicy, XmPOINTER, NULL); /* not XmEXPLICIT */
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
 		xmPanedWindowWidgetClass, topLevel,
 		XmNseparatorOn, False,
@@ -1731,11 +1748,14 @@ main(int argc, char **argv)
 	XtVaSetValues(dino3d,
 		XtNheight, 200, NULL);
 #else
-	XtSetArg(arg[1], XtNinput, True);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, dinoIcon,
+		XtNinput, True, NULL);
 	shell = XtCreateApplicationShell(argv[0],
 		topLevelShellWidgetClass, NULL, 0);
-	XtSetValues(shell, arg, 2);
+	XtVaSetValues(shell,
+		XtNiconPixmap, dinoIcon,
+		XtNinput, True, NULL);
 	dino2d = XtCreateManagedWidget("dino",
 		dino2dWidgetClass, topLevel, NULL, 0);
 	XtAddCallback(dino2d, XtNselectCallback,
