@@ -25,10 +25,9 @@
 
 /* Methods file for Hexagons */
 
-#if defined(USE_RPLAY) || defined(USE_NAS) || defined(USE_VMSPLAY) || defined(USE_ESOUND) || defined(WINVER) || defined(DEF_PLAY)
-#define USE_SOUND
-extern void playSound(char * filename);
-#endif
+#include "file.h"
+#include "rngs.h"
+#include "sound.h"
 #include "HexagonsP.h"
 
 #ifndef PICTURE
@@ -153,7 +152,7 @@ static char defaultTranslationsHexagons[] =
  <KeyPress>c: Clear()\n\
  <KeyPress>u: Undo()\n\
  <KeyPress>s: Solve()\n\
- <KeyPress>m: Mode()\n\
+ <KeyPress>o: Mode()\n\
  <KeyPress>0x2E: Speed()\n\
  <KeyPress>0x3E: Speed()\n\
  <KeyPress>0x3C: Slow()\n\
@@ -195,8 +194,11 @@ static XtActionsRec actionsListHexagons[] =
 static XtResource resourcesHexagons[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(HexagonsWidget, hexagons.username),
-	 XtRString, (caddr_t) "guest"},
+	 XtOffset(HexagonsWidget, hexagons.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(HexagonsWidget, hexagons.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(HexagonsWidget, hexagons.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
@@ -260,6 +262,12 @@ static XtResource resourcesHexagons[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(HexagonsWidget, hexagons.cheat),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(HexagonsWidget, hexagons.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(HexagonsWidget, hexagons.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(HexagonsWidget, hexagons.menu),
 	 XtRString, (caddr_t) "-1"},
@@ -311,78 +319,6 @@ HexagonsClassRec hexagonsClassRec =
 
 WidgetClass hexagonsWidgetClass = (WidgetClass) & hexagonsClassRec;
 
-#ifndef HAVE_USLEEP
-#if !defined( VMS ) || defined( XVMSUTILS ) || ( __VMS_VER >= 70000000 )
-#ifdef USE_XVMSUTILS
-#include <X11/unix_time.h>
-#endif
-#if HAVE_SYS_TIME_H
-#include <sys/time.h>
-#else
-#if HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#endif
-#endif
-#endif
-#if defined(SYSV) || defined(SVR4)
-#ifdef LESS_THAN_AIX3_2
-#include <sys/poll.h>
-#else /* !LESS_THAN_AIX3_2 */
-#include <poll.h>
-#endif /* !LESS_THAN_AIX3_2 */
-#endif /* defined(SYSV) || defined(SVR4) */
-
-/* not static in case usleep found in system include */
-int
-usleep(unsigned int usec)
-{
-#if (defined (SYSV) || defined(SVR4)) && !defined(__hpux)
-#if defined(HAVE_NANOSLEEP)
-	{
-		struct timespec rqt;
-
-		rqt.tv_nsec = 1000 * (usec % (unsigned int) 1000000);
-		rqt.tv_sec = usec / (unsigned int) 1000000;
-		return nanosleep(&rqt, NULL);
-	}
-#else
-	(void) poll(
-#if defined(__cplusplus) || defined(c_plusplus)
-		(pollfd *) /* guess */
-#else
-		(void *)
-#endif
-		0, (int) 0, usec / 1000);	/* ms resolution */
-#endif
-#else
-#ifdef VMS
-	long timadr[2];
-
-	if (usec != 0) {
-		timadr[0] = -usec * 10;
-		timadr[1] = -1;
-
-		sys$setimr(4, &timadr, 0, 0, 0);
-		sys$waitfr(4);
-	}
-#else
-	struct timeval time_out;
-
-#if 0
-	/* (!defined(AIXV3) && !defined(__hpux)) */
-	extern int select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
-
-#endif
-
-	time_out.tv_usec = usec % (unsigned int) 1000000;
-	time_out.tv_sec = usec / (unsigned int) 1000000;
-	(void) select(0, (void *) 0, (void *) 0, (void *) 0, &time_out);
-#endif
-#endif
-	return 0;
-}
-#endif
-
 void
 SetHexagons(HexagonsWidget w, int reason)
 {
@@ -408,13 +344,13 @@ loadFont(HexagonsWidget w)
 	if ((w->hexagons.fontInfo = XLoadQueryFont(display,
 			w->hexagons.font)) == NULL) {
 		(void) sprintf(buf,
-			"Cannot open %s font.\nAttempting %s font as alternate\n",
+			"Can not open %s font.\nAttempting %s font as alternate\n",
 			w->hexagons.font, altfontname);
 		DISPLAY_WARNING(buf);
 		if ((w->hexagons.fontInfo = XLoadQueryFont(display,
 				altfontname)) == NULL) {
 			(void) sprintf(buf,
-				"Cannot open %s alternate font.\nUse the -font option to specify a font to use.\n",
+				"Can not open %s alternate font.\nUse the -font option to specify a font to use.\n",
 				altfontname);
 			DISPLAY_WARNING(buf);
 		}
@@ -457,38 +393,6 @@ static Point hexagonUnit[MAXORIENT][7] =
 };
 static Point hexagonList[MAXORIENT][7];
 
-#if (!defined(WINVER) || (WINVER <= 0x030a)) /* if X or WINDOWS 3.1 or less */
-static void
-Sleep(unsigned int cMilliseconds)
-{
-#if (defined(WINVER) && (WINVER <= 0x030a))
-	unsigned long time_out = GetTickCount() + cMilliseconds;
-
-	while (time_out > GetTickCount());
-#else
-	(void) usleep(cMilliseconds * 1000);
-#endif
-}
-#endif
-
-void
-intCat(char ** string, const char * var1, const int var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + 21))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%d", var1, var2);
-}
-
-void
-stringCat(char ** string, const char * var1, const char * var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + strlen(var2) + 1))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%s", var1, var2);
-}
-
 static void
 CheckTiles(HexagonsWidget w)
 {
@@ -798,83 +702,6 @@ int2String(HexagonsWidget w, char *buf, int number, int base, Boolean capital)
 	return last;
 }
 
-#ifdef WINVER
-static void
-POLYGON(HexagonsWidget w, Pixmap dr, GC color, GC lineColor,
-		const POINT * poly, int n, Boolean origin)
-{
-	/* CoordModePrevious -> CoordModeOrigin */
-	POINT *temp = NULL;
-	int pt;
-
-	if (!origin) {
-		if (!(temp = (POINT *) malloc(sizeof (POINT) * n))) {
-			DISPLAY_ERROR("Not enough memory, exiting.");
-		}
-		temp[0] = poly[0];
-		for (pt = 1; pt < n; pt++) {
-			temp[pt].x = temp[pt - 1].x + poly[pt].x,
-			temp[pt].y = temp[pt - 1].y + poly[pt].y;
-		}
-	}
-	if (dr)
-		w->hexagons.hOldBitmap =
-			(HBITMAP) SelectObject(w->hexagons.memDC, dr);
-	w->hexagons.hPen = CreatePen(PS_SOLID, 1, lineColor);
-	w->hexagons.hOldPen = (HPEN) SelectObject(DC(w, dr),
-		w->hexagons.hPen);
-	w->hexagons.hBrush = CreateSolidBrush(color);
-	w->hexagons.hOldBrush = (HBRUSH) SelectObject(DC(w, dr),
-		w->hexagons.hBrush);
-	(void) Polygon(DC(w, dr), (origin) ? poly : temp, n);
-	(void) SelectObject(DC(w, dr), w->hexagons.hOldBrush);
-	(void) DeleteObject(w->hexagons.hBrush);
-	(void) SelectObject(DC(w, dr), w->hexagons.hOldPen);
-	(void) DeleteObject(w->hexagons.hPen);
-	if (dr)
-		(void) SelectObject(w->hexagons.memDC,
-			w->hexagons.hOldBitmap);
-	if (!origin) {
-		free(temp);
-	}
-}
-
-static void
-POLYLINE(HexagonsWidget w, Pixmap dr, GC color, const POINT * poly, int n,
-		Boolean origin)
-{
-	/* CoordModePrevious -> CoordModeOrigin */
-	POINT *temp = NULL;
-	int pt;
-
-	if (!origin) {
-		if (!(temp = (POINT *) malloc(sizeof (POINT) * n))) {
-			DISPLAY_ERROR("Not enough memory, exiting.");
-		}
-		temp[0] = poly[0];
-		for (pt = 1; pt < n; pt++) {
-			temp[pt].x = temp[pt - 1].x + poly[pt].x,
-			temp[pt].y = temp[pt - 1].y + poly[pt].y;
-		}
-	}
-	if (dr)
-		w->hexagons.hOldBitmap =
-			(HBITMAP) SelectObject(w->hexagons.memDC, dr);
-	w->hexagons.hPen = CreatePen(PS_SOLID, 1, color);
-	w->hexagons.hOldPen = (HPEN) SelectObject(DC(w, dr),
-		w->hexagons.hPen);
-	(void) Polygon(DC(w, dr), (origin) ? poly : temp, n);
-	(void) SelectObject(DC(w, dr), w->hexagons.hOldPen);
-	(void) DeleteObject(w->hexagons.hPen);
-	if (dr)
-		(void) SelectObject(w->hexagons.memDC,
-			w->hexagons.hOldBitmap);
-	if (!origin) {
-		free(temp);
-	}
-}
-#endif
-
 static void
 fill3DHexagon(HexagonsWidget w, Pixmap dr, GC gc, GC darkerGC, GC brighterGC,
 	Point * list, Boolean raised, Boolean corners)
@@ -888,7 +715,7 @@ fill3DHexagon(HexagonsWidget w, Pixmap dr, GC gc, GC darkerGC, GC brighterGC,
 		tempList[i].y = ((i == 0) ? 0 : tempList[i - 1].y) + list[i].y;
 	}
 
-	POLYGON(w, dr, currentGC, currentGC, list, 6, False);
+	POLYGON(w, dr, currentGC, currentGC, list, 6, True, False);
 	if (!corners) {
 		DRAWLINE(w, dr, currentGC,
 			tempList[4].x, tempList[4].y,
@@ -1043,7 +870,7 @@ DrawTile(HexagonsWidget w, int pos, Boolean blank, Boolean erase,
 	}
 	if (blank) {
 		POLYGON(w, *dr, tileGC, borderGC,
-			hexagonList[corners], 6, False);
+			hexagonList[corners], 6, True, False);
 	} else {
 		if (pressedOffset != 0) {
 			drawShadow(w, *dr, w->hexagons.tileDarkerGC,
@@ -1414,9 +1241,7 @@ AnimateSlide(HexagonsWidget w, int dir, int fast, Boolean logMoves)
 			for (k = 1; k < numTiles + 1; k++)
 				DrawTile(w, rowPos[k],
 					False, False, FALSE, pixX, pixY);
-#ifndef WINVER
-			XFlush(XtDisplay(w));
-#endif
+			FLUSH(w);
 			if (i % 8 == 0)
 				Sleep((unsigned int) (w->hexagons.delay /
 					fast));
@@ -1548,7 +1373,7 @@ DrawFrame(HexagonsWidget w, Pixmap dr, Boolean all, Boolean focus)
 		tempList[3].x = tempList[0].x;
 		tempList[3].y = tempList[0].y;
 		POLYGON(w, dr, w->hexagons.borderGC, w->hexagons.borderGC,
-			 tempList, 3, True);
+			 tempList, 3, True, True);
 		tempList[0].x = sumX + 1;
 		tempList[0].y = offsetY;
 		tempList[1].x = sumX + 1;
@@ -1560,7 +1385,7 @@ DrawFrame(HexagonsWidget w, Pixmap dr, Boolean all, Boolean focus)
 		tempList[4].x = tempList[0].x;
 		tempList[4].y = tempList[0].y;
 		POLYGON(w, dr, w->hexagons.borderGC, w->hexagons.borderGC,
-			 tempList, 4, True);
+			 tempList, 4, True, True);
 		tempList[0].x = offsetX;
 		tempList[0].y = sumY + 1;
 		tempList[1].x = offsetX;
@@ -1572,7 +1397,7 @@ DrawFrame(HexagonsWidget w, Pixmap dr, Boolean all, Boolean focus)
 		tempList[4].x = tempList[0].x;
 		tempList[4].y = tempList[0].y;
 		POLYGON(w, dr, w->hexagons.borderGC, w->hexagons.borderGC,
-			 tempList, 4, True);
+			 tempList, 4, True, True);
 		tempList[0].x = sumX + 1;
 		tempList[0].y = sumY + 1;
 		tempList[1].x = sum3X4;
@@ -1586,7 +1411,7 @@ DrawFrame(HexagonsWidget w, Pixmap dr, Boolean all, Boolean focus)
 		tempList[5].x = tempList[0].x;
 		tempList[5].y = tempList[0].y;
 		POLYGON(w, dr, w->hexagons.borderGC, w->hexagons.borderGC,
-			 tempList, 5, True);
+			 tempList, 5, True, True);
 	}
 	tempList[0].x = sumX4;
 	tempList[0].y = offsetY;
@@ -1605,7 +1430,8 @@ DrawFrame(HexagonsWidget w, Pixmap dr, Boolean all, Boolean focus)
 	tempList[7].x = tempList[0].x;
 	tempList[7].y = tempList[0].y;
 	if (all) {
-		POLYGON(w, dr, w->hexagons.inverseGC, gc, tempList, 6, True);
+		POLYGON(w, dr, w->hexagons.inverseGC, gc,
+			tempList, 6, True, True);
 	} else {
 		POLYLINE(w, dr, gc, tempList, 7, True);
 	}
@@ -1639,9 +1465,7 @@ MoveCornerTiles(HexagonsWidget w, int from, int posRow, int space, int fast)
 	if (fast == INSTANT) {
 		DrawTile(w, from, True, True, FALSE, 0, 0);
 		DrawTile(w, from, False, False, FALSE, cx, cy);
-#ifndef WINVER
-		XFlush(XtDisplay(w));
-#endif
+		FLUSH(w);
 #ifdef USE_SOUND
 		if (w->hexagons.sound) {
 			playSound((char *) BUMPSOUND);
@@ -1658,9 +1482,7 @@ MoveCornerTiles(HexagonsWidget w, int from, int posRow, int space, int fast)
 			slideDone = bresenhamLine(0, 0, cx, cy,
 				&pixX, &pixY, &pixNo);
 			DrawTile(w, from, False, False, FALSE, pixX, pixY);
-#ifndef WINVER
-			XFlush(XtDisplay(w));
-#endif
+			FLUSH(w);
 			if (i % 8 == 0)
 				Sleep((unsigned int) (w->hexagons.delay /
 					fast));
@@ -1679,9 +1501,7 @@ MoveCornerTiles(HexagonsWidget w, int from, int posRow, int space, int fast)
 			slideDone = bresenhamLine(cx, cy, s0x - dx, s0y - dy,
 				&pixX, &pixY, &pixNo);
 			DrawTile(w, from, False, False, FALSE, pixX, pixY);
-#ifndef WINVER
-			XFlush(XtDisplay(w));
-#endif
+			FLUSH(w);
 			if (i % 8 == 0)
 				Sleep((unsigned int) (w->hexagons.delay /
 					fast));
@@ -1693,9 +1513,7 @@ MoveCornerTiles(HexagonsWidget w, int from, int posRow, int space, int fast)
 	w->hexagons.spacePosition[space] = from;
 	w->hexagons.spaceRow[space] = posRow;
 	w->hexagons.tileOfPosition[nextPos] = fromTile;
-#ifndef WINVER
-	XFlush(XtDisplay(w));
-#endif
+	FLUSH(w);
 #ifdef USE_SOUND
 	if (w->hexagons.sound) {
 		playSound((char *) BUMPSOUND);
@@ -2600,10 +2418,14 @@ SetValuesHexagons(HexagonsWidget w)
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->hexagons.inverseGC = RGB(color.red, color.green, color.blue);
-	(void) GetPrivateProfileString(SECTION, "name", "Guest",
+	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
 		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->hexagons.username, szBuf);
-	w->hexagons.username[80] = 0;
+	(void) strcpy(w->hexagons.userName, szBuf);
+	w->hexagons.userName[80] = 0;
+	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
+		szBuf, sizeof (szBuf), INIFILE);
+	(void) strcpy(w->hexagons.scoreFile, szBuf);
+	w->hexagons.scoreFile[80] = 0;
 }
 
 void
@@ -2827,8 +2649,8 @@ QuitHexagons(HexagonsWidget w
 		if (w->hexagons.bufferTiles != NULL) {
 			DeleteObject(w->hexagons.bufferTiles);
 		}
-		DeleteDC(w->hexagons.memDC);
-		w->hexagons.memDC = NULL;
+		DeleteDC(w->core.memDC);
+		w->core.memDC = NULL;
 	}
 #else
 	Display *display = XtDisplay(w);
@@ -2872,9 +2694,9 @@ ResizeTiles(HexagonsWidget w)
 	int sel;
 
 #ifdef WINVER
-	if (w->hexagons.memDC == NULL) {
-		w->hexagons.memDC = CreateCompatibleDC(w->core.hDC);
-		if (w->hexagons.memDC == NULL) {
+	if (w->core.memDC == NULL) {
+		w->core.memDC = CreateCompatibleDC(w->core.hDC);
+		if (w->core.memDC == NULL) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
@@ -3155,9 +2977,7 @@ SelectHexagons(HexagonsWidget w
 		if (rowType < 0) {
 			DrawTile(w, w->hexagons.currentPosition,
 				rowType == HEXAGONS_SPACE, False, TRUE, 0, 0);
-#ifndef WINVER
-			XFlush(XtDisplay(w));
-#endif
+			FLUSH(w);
 			Sleep(100);
 			DrawTile(w, w->hexagons.currentPosition,
 				True, True, TRUE, 0, 0);
