@@ -38,6 +38,7 @@
 #ifndef WINVER
 #define XtNselectCallback ((char *) "selectCallback")
 #define XtNuserName ((char *) "userName")
+#define XtNscoreFile ((char *) "scoreFile")
 #define XtNsizeX ((char *) "sizeX")
 #define XtNsizeY ((char *) "sizeY")
 #define XtNcorners ((char *) "corners")
@@ -56,7 +57,10 @@
 #define XtNframeColor ((char *) "frameColor")
 #define XtNtileColor ((char *) "tileColor")
 #define XtNtileBorder ((char *) "tileBorder")
+#define XtNscoreOnly ((char *) "scoreOnly")
+#define XtNversionOnly ((char *) "versionOnly")
 #define XtCUserName ((char *) "UserName")
+#define XtCScoreFile ((char *) "ScoreFile")
 #define XtCSizeX ((char *) "SizeX")
 #define XtCSizeY ((char *) "SizeY")
 #define XtCCorners ((char *) "Corners")
@@ -102,23 +106,6 @@ typedef struct {
 #define HEXAGONS_UNDO 10
 #define HEXAGONS_SPEED 11
 
-#ifdef WINVER
-#ifdef UNIXDELIM
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#else
-#define CURRENTDELIM ".\\"
-#define FINALDELIM "\\"
-#endif
-#else
-#ifdef VMS
-#define CURRENTDELIM "[]"
-#define FINALDELIM ""
-#else
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#endif
-#endif
 #define MINTILES 1
 #define DEFAULTTILESX 3
 #define DEFAULTTILESY 3
@@ -139,8 +126,5 @@ typedef struct {
 
 typedef struct _HexagonsRec *HexagonsWidget;
 
-extern void intCat(char ** string, const char * var1, const int var2);
-extern void stringCat(char ** string, const char * var1, const char * var2);
-
 #endif /* _XtHexagons_h */
 /* DON'T ADD STUFF AFTER THIS #endif */
