@@ -32,38 +32,25 @@
   Version 1: 91/09/05 SunView
 */
 
+#include "file.h"
 #ifdef WINVER
 #include "HexagonsP.h"
 #include "whexagons.h"
 #define TITLE "whexagons"
 
 static HexagonsRec widget;
-static HWND Wnd;
 
 #ifndef SCOREPATH
-#define SCOREPATH "c:\\Windows"
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
 #endif
-#define PRINT_MESSAGE(b) (void) MessageBox(Wnd, (LPCSTR) b, "Warning", MB_OK);
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
 #define SET_STARTED(w,b) w->hexagons.started = b
 #else
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
-#ifdef VMS
-#include <unixlib.h>
-#define getlogin() cuserid(NULL)
-#else
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif
-#if HAVE_FCNTL_H
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#endif
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
+#include "xwin.h"
 #include <X11/Shell.h>
 #include <X11/cursorfont.h>
 #ifdef HAVE_MOTIF
@@ -84,7 +71,7 @@ static HWND Wnd;
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
-#define SET_STARTED(w,b) XtSetArg(arg[0], XtNstart, b); XtSetValues(w, arg, 1)
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
 #include "Hexagons.h"
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
@@ -92,28 +79,35 @@ static HWND Wnd;
 #endif
 #include "icons/hexagons.xbm"
 #ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
 #define SCOREPATH "/var/games/xpuzzles"
 #endif
 #endif
+#endif
 
-#ifdef HAVE_MOTIF
+#ifndef WINVER
 static const char aboutHelp[] = {
-	"Version 7.1.3\n"
+	"Hexagons Version 7.1.5\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
 	"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
+
 static const char optionsHelp[] = {
-	"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]] "
-	"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"[-{foreground|fg} {color}] [-{background|bg} {color}] "
-	"[-{border|bd} {color}] [-tile {color}] [-size{x|y} {int}]\n"
-	"[-[no]corners] [-[no]install] [-picture {filename}] "
-	"[-delay msecs] [-[no]sound] [-bumpsound {filename}]\n"
-	"[-base {int}] [-{font|fn} {fontname}] [-username {string}]\n"
+	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+	"\t[-{border|bd} {color}] [-tile {color}] [-size{x|y} {int}]\n"
+	"\t[-[no]corners] [-[no]install] [-picture {filename}]\n"
+	"\t[-delay msecs] [-[no]sound] [-bumpSound {filename}]\n"
+	"\t[-base {int}] [-{font|fn} {fontname}] [-userName {string}]\n"
+	"\t[-scoreFile {filename}] [-scores] [-version]\n"
 };
 #endif
+
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
 	"A sliding tile puzzle.  A hexagonal version of the "
@@ -128,13 +122,13 @@ static const char descriptionHelp[] = {
 	"smaller 11 piece \"Counterfax\" of which 8 were\n"
 	"numbered.\n"
 };
+
 static const char featuresHelp[] = {
 	"If in corners mode: Press \"mouse-left\" button to move "
 	"a tile, then release \"mouse-left\" button on a space.\n"
 	"It will not move if blocked.  One can only move one "
 	"tile at a time. The only tiles that can be moved are\n"
 	"the tile(s) next to both spaces.\n"
-	"\n"
 	"If in nocorners mode: Click \"mouse-left\" button to "
 	"move a tile.  One can move more than one tile at a time\n"
 	"and one is not constrained by parity.\n"
@@ -142,7 +136,7 @@ static const char featuresHelp[] = {
 	"Click \"mouse-right\" button, or press \"R\" or \"r\" "
 	"keys, to randomize the puzzle.\n"
 	"\n"
-	"Press \"M\" or \"m\" keys to toggle corners mode.  "
+	"Press \"O\" or \"o\" keys to toggle corners mode.  "
 	"(Default is on).\n"
 	"\n"
 	"\"S\" or \"s\" keys reserved for the auto-solver "
@@ -154,6 +148,8 @@ static const char featuresHelp[] = {
 	"\n"
 	"Press \"W\" or \"w\" keys to save a puzzle.\n"
 	"\n"
+	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+	"\n"
 	"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
 	"\n"
 	"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
@@ -177,6 +173,7 @@ static const char featuresHelp[] = {
 	"xhexagons.  Hold down control key and use the keypad\n"
 	"or arrow keys to reduce or enlarge puzzle complexity.\n"
 };
+
 static const char referencesHelp[] = {
 	"Dieter Gebhardt, \"From Trilemma to Counterfax\", CFF 53, "
 	"October 2000, pp 8-10.\n"
@@ -188,6 +185,7 @@ static const char referencesHelp[] = {
 	"brochure.\n"
 };
 #endif
+
 static const char solveHelp[] = {
 	"Auto-solver: sorry, not implemented.\n"
 };
@@ -197,7 +195,7 @@ static const char solveHelp[] = {
 #endif
 
 #define MAXTILES 10
-#define NEVER -1
+#define NEVER (-1)
 #define FILENAMELEN 1024
 #define USERNAMELEN 120
 #define MESSAGELEN (USERNAMELEN+64)
@@ -217,7 +215,7 @@ static char recordDsp[MESSAGELEN] = "NOT RECORDED";
 
 #ifdef HAVE_MOTIF
 #define MINSPEED 1
-#define MAXSPEED 50 
+#define MAXSPEED 50
 #ifdef ANIMATE
 static Widget speed;
 #endif
@@ -226,20 +224,21 @@ static char buff[21];
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, randomizeDialog;
+static Arg arg[3];
 #else
 static char titleDsp[TITLELEN] = "";
 #endif
+static char scoreFileName[FILENAMELEN] = SCOREFILE;
+static char fileName[FILENAMELEN];
 #ifdef WINVER
 #define MAXPROGNAME 80
 static char progDsp[MAXPROGNAME] = TITLE;
-static char usernameDsp[USERNAMELEN] = "Guest";
+static char userNameDsp[USERNAMELEN] = "Guest";
 #else
 static Pixmap hexagonsIcon = None;
 static Widget topLevel, hexagons;
-static Arg arg[3];
 static char *progDsp;
-static char usernameDsp[USERNAMELEN] = "";
-#endif
+static char userNameDsp[USERNAMELEN] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -250,25 +249,26 @@ PrintState(Widget w, char *msg)
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
 		XtError("PrintState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
-	XtSetArg(arg[0], XmNlabelString, xmstr);
-	XtSetValues(w, arg, 1);
+	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
-#else
+#endif
+
 static void
-PrintState(
-#ifndef WINVER
-Widget w,
-#endif
-int sizeX, int sizeY, int moves, char *msg)
+PrintRecords(void)
 {
-	(void) sprintf(titleDsp, "%s: %dx%d@ (%d/%s) - %s",
-		progDsp, sizeX, sizeY, moves, recordDsp, msg);
-#ifdef WINVER
-	SetWindowText(Wnd, (LPSTR) titleDsp);
-#else
-	XtSetArg(arg[0], XtNtitle, titleDsp);
-	XtSetValues(w, arg, 1);
-#endif
+	int i, j, k;
+
+	(void) printf("         HEXAGONS  HALL OF FAME\n\n");
+	(void) printf("CORNER   X   Y USER            MOVES\n");
+	for (i = 0; i < MAXORIENT; i++)
+		for (j = 0; j < MAXTILES - MINTILES + 1; j++)
+			for (k = 0; k < MAXTILES - MINTILES + 1; k++) {
+				if (hexagonsRecord[i][j][k].score > 0)
+					(void) printf("%6d%4d%4d %-12s%9d\n",
+						i, j + 1, k + 1,
+						hexagonsRecord[i][j][k].name,
+						hexagonsRecord[i][j][k].score);
+			}
 }
 #endif
 
@@ -291,21 +291,21 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, j, k, n;
-	char username[USERNAMELEN];
+	char userName[USERNAMELEN];
 	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *fname, *lname;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
+	stringCat(&buf1, CURRENTDELIM, scoreFileName);
 	lname = buf1;
 	stringCat(&buf1, SCOREPATH, FINALDELIM);
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "r")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "r")) == NULL) {
+	(void) strncpy(fileName, lname, USERNAMELEN);
+	if ((fp = fopen(fileName, "r")) == NULL) {
+		(void) strncpy(fileName, fname, USERNAMELEN);
+		/* Try installed directory. */
+		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
@@ -335,12 +335,12 @@ ReadRecords(void)
 	for (i = 0; i < MAXORIENT; i++)
 		for (j = 0; j < MAXTILES - MINTILES + 1; j++)
 		  for (k = 0; k < MAXTILES - MINTILES + 1; k++) {
-		    (void) fscanf(fp, "%d %s\n", &n, username);
+		    (void) fscanf(fp, "%d %s\n", &n, userName);
 		    if (n <= hexagonsRecord[i][j][k].score ||
-		        hexagonsRecord[i][j][k].score <= NEVER) {
+		    		hexagonsRecord[i][j][k].score <= NEVER) {
 		      hexagonsRecord[i][j][k].score = n;
 		      (void) strncpy(hexagonsRecord[i][j][k].name,
-		        username, USERNAMELEN);
+		      		userName, USERNAMELEN);
 		    }
 		}
 	(void) fclose(fp);
@@ -351,61 +351,31 @@ WriteRecords(void)
 {
 	FILE *fp;
 	int i, j, k;
-	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *buf1 = NULL;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
-	lname = buf1;
-	stringCat(&buf1, SCOREPATH, FINALDELIM);
-	stringCat(&buf2, buf1, SCOREFILE);
-	free(buf1);
-	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "w")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "w")) == NULL) {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, " or ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-			free(lname);
-			free(fname);
-			return;
-		}
-/* Probably annoying */
-#if 0
-		else {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, ", falling back to ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-		}
-#endif
+	if ((fp = fopen(fileName, "w")) == NULL) {
+		stringCat(&buf1, "Can not write to ", fileName);
+		PRINT_MESSAGE(buf1);
+		free(buf1);
+		return;
 	}
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockfile[FILENAMELEN];
+		char lockFile[FILENAMELEN];
 
-		(void) strncpy(lockfile, name, FILENAMELEN - 6);
-		(void) strcat(lockfile, ".lock");
-		while (((lfd = open(lockfile, O_CREAT | O_EXCL, 0644)) < 0) &&
+		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strcat(lockFile, ".lock");
+		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
 			(void) sleep(1);
 		if (lfd < 0) {
 #if 1
 			(void) fprintf(stderr,
-			  "Lock file exists... guessing its an old one.\n");
+				"Lock file exists... guessing its an old one.\n");
 #else
 			(void) fprintf(stderr,
-			  "Lock file exists... score not recorded - sorry.\n");
+				"Lock file exists... score not recorded - sorry.\n");
 			return;
 #endif
 		}
@@ -420,12 +390,10 @@ WriteRecords(void)
 		}
 #if HAVE_FCNTL_H
 		(void) close(lfd);
-		(void) unlink(lockfile);
+		(void) unlink(lockFile);
 #endif
 		(void) fclose(fp);
 	}
-	free(lname);
-	free(fname);
 }
 
 static void
@@ -434,9 +402,9 @@ PrintRecord(int sizeX, int sizeY, Boolean corners)
 	int i = (corners) ? 1 : 0;
 	int j = sizeX - MINTILES, k = sizeY - MINTILES;
 
-	if (sizeX > MAXTILES || sizeY > MAXTILES)
+	if (sizeX > MAXTILES || sizeY > MAXTILES) {
 		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
-	else if (hexagonsRecord[i][j][k].score <= NEVER) {
+	} else if (hexagonsRecord[i][j][k].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
 		(void) sprintf(recordDsp, "%d %s",
@@ -448,6 +416,28 @@ PrintRecord(int sizeX, int sizeY, Boolean corners)
 #endif
 }
 
+static void
+PrintStatus(char *msg, int nMoves
+#ifndef HAVE_MOTIF
+		, int sizeX, int sizeY
+#endif
+		)
+{
+#ifdef HAVE_MOTIF
+	PrintState(message, msg);
+	(void) sprintf(buff, "%d", nMoves);
+	PrintState(moves, buff);
+#else
+	(void) sprintf(titleDsp, "%s: %dx%d@ (%d/%s) - %s",
+		progDsp, sizeX, sizeY, nMoves, recordDsp, msg);
+#ifdef WINVER
+	SetWindowText(widget.core.hWnd, (LPSTR) titleDsp);
+#else
+	XtVaSetValues(XtParent(hexagons), XtNtitle, titleDsp, NULL);
+#endif
+#endif
+}
+
 static Boolean
 HandleSolved(int counter, int sizeX, int sizeY, int corners)
 {
@@ -455,11 +445,11 @@ HandleSolved(int counter, int sizeX, int sizeY, int corners)
 	int j = sizeX - MINTILES, k = sizeY - MINTILES;
 
 	if (sizeX <= MAXTILES && sizeY <= MAXTILES &&
-	    (counter < hexagonsRecord[i][j][k].score ||
-	    hexagonsRecord[i][j][k].score <= NEVER)) {
+			(counter < hexagonsRecord[i][j][k].score ||
+			hexagonsRecord[i][j][k].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		hexagonsRecord[i][j][k].score = counter;
-		(void) strncpy(hexagonsRecord[i][j][k].name, usernameDsp,
+		(void) strncpy(hexagonsRecord[i][j][k].name, userNameDsp,
 			USERNAMELEN);
 		WriteRecords();
 		PrintRecord(sizeX, sizeY, corners);
@@ -479,7 +469,7 @@ Widget w
 {
 	int sizeX, sizeY;
 	Boolean corners;
-	char *username;
+	char *userName, *scoreFile;
 
 #ifdef WINVER
 	InitializeHexagons(w, brush);
@@ -487,14 +477,33 @@ Widget w
 	sizeX = w->hexagons.sizeX;
 	sizeY = w->hexagons.sizeY;
 	corners = w->hexagons.corners;
-	username = w->hexagons.username;
+	userName = w->hexagons.userName;
+	scoreFile = w->hexagons.scoreFile;
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
 #else
+	Boolean scoreOnly, versionOnly;
 
 	XtVaGetValues(w,
-		XtNuserName, &username,
+		XtNuserName, &userName,
+		XtNscoreFile, &scoreFile,
 		XtNsizeX, &sizeX,
 		XtNsizeY, &sizeY,
-		XtNcorners, &corners, NULL);
+		XtNcorners, &corners,
+		XtNscoreOnly, &scoreOnly,
+		XtNversionOnly, &versionOnly, NULL);
+	if (versionOnly) {
+		(void) printf(aboutHelp);
+		exit(0);
+	}
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+	if (scoreOnly) {
+		InitRecords();
+		ReadRecords();
+		PrintRecords();
+		exit(0);
+	}
 #ifdef HAVE_MOTIF
 	if (sizeX > MAXTILES)
 		XtVaSetValues(tileX, XmNmaximum, sizeX, NULL);
@@ -517,32 +526,29 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(usernameDsp, username, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #endif
-	if (!strcmp(username, "") || !strcmp(username, "(null)") ||
-			!strcmp(username, NOACCESS) ||
-			!strcmp(username, NOBODY)) {
-		/* The NOACCESS is not necessary, but it may stop silliness. */
+	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
+			!strcmp(userName, NOACCESS) ||
+			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(usernameDsp, username, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(usernameDsp, "%s", getlogin());
-		if (!strcmp(usernameDsp, "") ||
-				!strcmp(usernameDsp, "(null)") ||
-				!strcmp(usernameDsp, NOACCESS) ||
-				!strcmp(usernameDsp, NOBODY))
+		(void) sprintf(userNameDsp, "%s", getlogin());
+		if (!strcmp(userNameDsp, "") ||
+				!strcmp(userNameDsp, "(null)") ||
+				!strcmp(userNameDsp, NOACCESS) ||
+				!strcmp(userNameDsp, NOBODY))
 			/* It really IS nobody */
-			(void) sprintf(usernameDsp, "%s", "guest");
+			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
 	PrintRecord(sizeX, sizeY, corners);
+	PrintStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
-#endif
-		sizeX, sizeY, movesDsp, messageDsp);
+		, sizeX, sizeY
 #endif
+		);
 }
 
 #ifdef WINVER
@@ -588,8 +594,8 @@ CallbackHexagons(Widget w, caddr_t clientData,
 #ifdef HAVE_MOTIF
 			XtManageChild(randomizeDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-			XtSetValues(hexagons, arg, 1);
+			XtVaSetValues(hexagons,
+				XtNmenu, 5, NULL); /* menu choice */
 #endif
 			break;
 #endif
@@ -630,10 +636,10 @@ CallbackHexagons(Widget w, caddr_t clientData,
 		case HEXAGONS_SOLVED:
 			if (cheat)
 				(void) sprintf(messageDsp,
-					"No cheating %s!!", usernameDsp);
+					"No cheating %s!!", userNameDsp);
 			else if (HandleSolved(movesDsp, sizeX, sizeY, corners))
 				(void) sprintf(messageDsp,
-					"Congratulations %s!!", usernameDsp);
+					"Congratulations %s!!", userNameDsp);
 			else
 				(void) strncpy(messageDsp, "Solved!",
 					MESSAGELEN);
@@ -650,8 +656,7 @@ CallbackHexagons(Widget w, caddr_t clientData,
 #ifdef WINVER
 			w->hexagons.sizeX = sizeX;
 #else
-			XtSetArg(arg[0], XtNsizeX, sizeX);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNsizeX, sizeX, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(tileX, sizeX);
 			if (sizeX >= MAXTILES)
@@ -666,8 +671,7 @@ CallbackHexagons(Widget w, caddr_t clientData,
 #ifdef WINVER
 			w->hexagons.sizeX = sizeX;
 #else
-			XtSetArg(arg[0], XtNsizeX, sizeX);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNsizeX, sizeX, NULL);
 #ifdef HAVE_MOTIF
 			if (sizeX > MAXTILES)
 				XtVaSetValues(tileX, XmNmaximum, sizeX, NULL);
@@ -682,8 +686,7 @@ CallbackHexagons(Widget w, caddr_t clientData,
 #ifdef WINVER
 			w->hexagons.sizeY = sizeY;
 #else
-			XtSetArg(arg[0], XtNsizeY, sizeY);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNsizeY, sizeY, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(tileY, sizeY);
 			if (sizeY >= MAXTILES)
@@ -698,8 +701,7 @@ CallbackHexagons(Widget w, caddr_t clientData,
 #ifdef WINVER
 			w->hexagons.sizeY = sizeY;
 #else
-			XtSetArg(arg[0], XtNsizeY, sizeY);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNsizeY, sizeY, NULL);
 #ifdef HAVE_MOTIF
 			if (sizeY > MAXTILES)
 				XtVaSetValues(tileY, XmNmaximum, sizeY, NULL);
@@ -714,8 +716,7 @@ CallbackHexagons(Widget w, caddr_t clientData,
 #ifdef WINVER
 			w->hexagons.corners = corners;
 #else
-			XtSetArg(arg[0], XtNcorners, corners);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNcorners, corners, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(cornersSwitch, corners, True);
 #endif
@@ -729,38 +730,32 @@ CallbackHexagons(Widget w, caddr_t clientData,
 			SET_STARTED(w, True);
 			break;
 #if defined(HAVE_MOTIF) && defined(ANIMATE)
-	case HEXAGONS_SPEED:
-		{
-			int oldDelay, delay;
+		case HEXAGONS_SPEED:
+			{
+				int oldDelay, delay;
 
-			XtVaGetValues(hexagons,
-				XtNdelay, &delay, NULL);
-			oldDelay = delay;
-			if (delay > MAXSPEED - MINSPEED)
-				delay = MAXSPEED - MINSPEED;
-			if (delay < 0)
-				delay = 0;
-			if (delay != oldDelay) {
-				XtSetArg(arg[0], XtNdelay, delay);
-				XtSetValues(w, arg, 1);
+				XtVaGetValues(hexagons,
+					XtNdelay, &delay, NULL);
+				oldDelay = delay;
+				if (delay > MAXSPEED - MINSPEED)
+					delay = MAXSPEED - MINSPEED;
+				if (delay < 0)
+					delay = 0;
+				if (delay != oldDelay) {
+					XtVaSetValues(w,
+						XtNdelay, delay, NULL);
+				}
+				XmScaleSetValue(speed,
+					MAXSPEED + MINSPEED - delay - 1);
 			}
-			XmScaleSetValue(speed,
-				MAXSPEED + MINSPEED - delay - 1);
-		}
-		return;
+			return;
 #endif
 	}
-#ifdef HAVE_MOTIF
-	PrintState(message, messageDsp);
-	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-#else
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
-#endif
-		sizeX, sizeY, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp
+#ifndef HAVE_MOTIF
+		, sizeX, sizeY
 #endif
+		);
 }
 
 #ifdef WINVER
@@ -784,7 +779,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	HBRUSH brush = (HBRUSH) NULL;
 	PAINTSTRUCT paint;
 
-	Wnd = widget.core.hWnd = hWnd;
+	widget.core.hWnd = hWnd;
 	if (GetFocus()) {
 		if (!widget.hexagons.focus) {
 			widget.core.hDC = GetDC(hWnd);
@@ -1018,20 +1013,7 @@ static void
 Usage(char * programName)
 {
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr,
-		"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n");
-	(void) fprintf(stderr,
-		"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n");
-	(void) fprintf(stderr,
-		"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{border|bd} {color}] [-tile {color}] [-size{x|y} {int}]\n");
-	(void) fprintf(stderr,
-		"\t[-[no]corners] [-[no]install] [-picture {filename}]\n");
-	(void) fprintf(stderr,
-		"\t[-delay msecs] [-[no]sound] [-bumpsound {filename}]\n");
-	(void) fprintf(stderr,
-       		"\t[-base {int}] [-{font|fn} {fontname}] [-username {string}]\n");
+	(void) fprintf(stderr, optionsHelp);
 	exit(1);
 }
 
@@ -1061,11 +1043,14 @@ static XrmOptionDescRec options[] =
 	{(char *) "-delay", (char *) "*hexagons.delay", XrmoptionSepArg, NULL},
 	{(char *) "-sound", (char *) "*hexagons.sound", XrmoptionNoArg, (char *) "TRUE"},
 	{(char *) "-nosound", (char *) "*hexagons.sound", XrmoptionNoArg, (char *) "FALSE"},
-	{(char *) "-bumpsound", (char *) "*hexagons.bumpSound", XrmoptionSepArg, NULL},
+	{(char *) "-bumpSound", (char *) "*hexagons.bumpSound", XrmoptionSepArg, NULL},
 	{(char *) "-base", (char *) "*hexagons.base", XrmoptionSepArg, NULL},
 	{(char *) "-fn", (char *) "*hexagons.font", XrmoptionSepArg, NULL},
 	{(char *) "-font", (char *) "*hexagons.font", XrmoptionSepArg, NULL},
-	{(char *) "-username", (char *) "*hexagons.userName", XrmoptionSepArg, NULL}
+	{(char *) "-userName", (char *) "*hexagons.userName", XrmoptionSepArg, NULL},
+	{(char *) "-scoreFile", (char *) "*hexagons.scoreFile", XrmoptionSepArg, NULL},
+	{(char *) "-scores", (char *) "*hexagons.scoreOnly", XrmoptionNoArg, (char *) "TRUE"},
+	{(char *) "-version", (char *) "*hexagons.versionOnly", XrmoptionNoArg, (char *) "TRUE"}
 };
 
 #ifdef HAVE_MOTIF
@@ -1074,8 +1059,7 @@ CallbackHexagonsRandomize(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-		XtSetValues(hexagons, arg, 1);
+		XtVaSetValues(hexagons, XtNmenu, 5, NULL); /* menu choice */
 	}
 }
 
@@ -1175,16 +1159,14 @@ fileCB(Widget w, void *value, void *clientData)
 
 	if (val == 2)
 		exit(0);
-	XtSetArg(arg[0], XtNmenu, val);
-	XtSetValues(hexagons, arg, 1);
+	XtVaSetValues(hexagons, XtNmenu, val, NULL);
 }
 
 static void
 playCB(Widget w, void *value, void *clientData)
 {
 	int val = (int) value;
-	XtSetArg(arg[0], XtNmenu, val + 3); /* GWQ */
-	XtSetValues(hexagons, arg, 1);
+	XtVaSetValues(hexagons, XtNmenu, val + 3, NULL); /* GWQ */
 }
 
 static Widget
@@ -1318,11 +1300,10 @@ main(int argc, char **argv)
 			RootWindowOfScreen(XtScreen(topLevel)),
 			(char *) hexagons_bits,
 			hexagons_width, hexagons_height);
-	XtSetArg(arg[0], XtNiconPixmap, hexagonsIcon);
 #ifdef HAVE_MOTIF
-	/* not XmEXPLICIT */
-	XtSetArg(arg[1], XmNkeyboardFocusPolicy, XmPOINTER);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, hexagonsIcon,
+		XmNkeyboardFocusPolicy, XmPOINTER, NULL); /* not XmEXPLICIT */
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
 		xmPanedWindowWidgetClass, topLevel,
 		XmNseparatorOn, False,
@@ -1535,8 +1516,9 @@ main(int argc, char **argv)
 	hexagons = XtCreateManagedWidget("hexagons",
 		hexagonsWidgetClass, mainPanel, NULL, 0);
 #else
-	XtSetArg(arg[1], XtNinput, True);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, hexagonsIcon,
+		XtNinput, True, NULL);
 	hexagons = XtCreateManagedWidget("hexagons",
 		hexagonsWidgetClass, topLevel, NULL, 0);
 #endif
