@@ -25,6 +25,8 @@
 
 /* Methods file for Mball */
 
+#include "file.h"
+#include "rngs.h"
 #include "MballP.h"
 
 #ifdef WINVER
@@ -246,15 +248,18 @@ static XtActionsRec actionsListMball[] =
 static XtResource resourcesMball[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(MballWidget, mball.username),
-	 XtRString, (caddr_t) "nobody"},
+	 XtOffset(MballWidget, mball.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(MballWidget, mball.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(MballWidget, mball.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(MballWidget, mball.background),
 	 XtRString, (caddr_t) XtDefaultBackground},
-	{XtNframeColor, XtCForeground, XtRPixel, sizeof (Pixel),
+	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(MballWidget, mball.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
 	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
@@ -332,6 +337,12 @@ static XtResource resourcesMball[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(MballWidget, mball.cheat),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(MballWidget, mball.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(MballWidget, mball.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(MballWidget, mball.menu),
 	 XtRString, (caddr_t) "-1"},
@@ -408,13 +419,13 @@ loadFont(MballWidget w)
 	if ((w->mball.fontInfo = XLoadQueryFont(display,
 			w->mball.font)) == NULL) {
 		(void) sprintf(buf,
-			"Cannot open %s font.\nAttempting %s font as alternate\n",
+			"Can not open %s font.\nAttempting %s font as alternate\n",
 			w->mball.font, altfontname);
 		DISPLAY_WARNING(buf);
 		if ((w->mball.fontInfo = XLoadQueryFont(display,
 				altfontname)) == NULL) {
 			(void) sprintf(buf,
-				"Cannot open %s alternate font.\nUse the -font option to specify a font to use.\n",
+				"Can not open %s alternate font.\nUse the -font option to specify a font to use.\n",
 				altfontname);
 			DISPLAY_WARNING(buf);
 		}
@@ -480,24 +491,7 @@ static int mapWedgeToDir[(MAXWEDGES - MINWEDGES) / 2 + 1][MAXWEDGES] =
 	}
 };
 
-
-void
-intCat(char ** string, const char * var1, const int var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + 21))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%d", var1, var2);
-}
-
-void
-stringCat(char ** string, const char * var1, const char * var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + strlen(var2) + 1))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%s", var1, var2);
-}
+static Pixmap dr = 0; /* dummy for future double buffering */
 
 static void
 CheckPieces(MballWidget w)
@@ -727,11 +721,11 @@ SECTOR(MballWidget w, const GC pieceGC, const GC borderGC,
 		DRAWPIE(w, pieceGC, xo - d / 2, yo - d / 2, d, d, angle1, angle2);
 	} else {
 		d = MAX(r1 + r2 + 2, 2);
-		DRAWARC2(w, pieceGC, t, xo - d / 2, yo - d / 2, d, d, angle1, angle2);
+		DRAWARC2(w, dr, pieceGC, t, xo - d / 2, yo - d / 2, d, d, angle1, angle2);
 		d = MAX(2 * (r1 + 3), 1);
-		DRAWARC(w, borderGC, 1, xo - d / 2, yo - d / 2, d, d, angle1, angle2);
+		DRAWARC(w, dr, borderGC, 1, xo - d / 2, yo - d / 2, d, d, angle1, angle2);
 	}
-	DRAWARC(w, borderGC, 1, xo - d / 2, yo - d / 2, d, d, angle1, angle2);
+	DRAWARC(w, dr, borderGC, 1, xo - d / 2, yo - d / 2, d, d, angle1, angle2);
 #if 0
 	{
 		double ang, x, y;
@@ -740,13 +734,13 @@ SECTOR(MballWidget w, const GC pieceGC, const GC borderGC,
 	ang = RADIANS((double) angle1);
 	x = cos(ang);
 	y = -sin(ang);
-	DRAWLINE(w, pieceGC,
+	DRAWLINE(w, dr, pieceGC,
 		(int) ((double) r1 * x) + xo, (int) ((double) r1 * y) + yo,
 		(int) ((double) r2 * x) + xo, (int) ((double) r2 * y) + yo);
 	ang = RADIANS((double) angle1+angle2);
 	x = cos(ang);
 	y = -sin(ang);
-	DRAWLINE(w, pieceGC,
+	DRAWLINE(w, dr, pieceGC,
 		(int) ((double) r1 * x) + xo, (int) ((double) r1 * y) + yo,
 		(int) ((double) r2 * x) + xo, (int) ((double) r2 * y) + yo);
 	}
@@ -876,7 +870,7 @@ DrawSector(const MballWidget w,
 				buf[1] = '\0';
 				i = 1;
 			}
-			DRAWTEXT(w, borderGC, letterX, letterY, buf, i);
+			DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, i);
 		}
 		if (ring + 1 > w->mball.rings / 2) {
 			if (w->mball.vertical) {
@@ -917,7 +911,7 @@ DrawSector(const MballWidget w,
 				buf[1] = '\0';
 				i = 1;
 			}
-			DRAWTEXT(w, borderGC, letterX, letterY, buf, i);
+			DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, i);
 		}
 	} else if (w->mball.orient) {
 		int letterX, letterY;
@@ -939,7 +933,7 @@ DrawSector(const MballWidget w,
 				letterX += w->mball.letterOffset.x;
 				i++;
 			}
-			DRAWTEXT(w, borderGC, letterX, letterY, buf, i);
+			DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, i);
 		}
 		if (ring + 1 > w->mball.rings / 2 &&
 				w->mball.mballLoc[wedge][ring].direction) {
@@ -970,7 +964,7 @@ DrawSector(const MballWidget w,
 				letterX += w->mball.letterOffset.x;
 				i++;
 			}
-			DRAWTEXT(w, borderGC, letterX, letterY, buf, i);
+			DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, i);
 		}
 	}
 }
@@ -1201,7 +1195,7 @@ DrawSector(const MballWidget w, const int wedge, const int ring,
 				buf[1] = '\0';
 				i = 1;
 			}
-			DRAWTEXT(w, borderGC, letterX, letterY, buf, i);
+			DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, i);
 		}
 		if (ring + 1 > w->mball.rings / 2) {
 			if (w->mball.vertical) {
@@ -1242,7 +1236,7 @@ DrawSector(const MballWidget w, const int wedge, const int ring,
 				buf[1] = '\0';
 				i = 1;
 			}
-			DRAWTEXT(w, borderGC, letterX, letterY, buf, i);
+			DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, i);
 		}
 	} else if (w->mball.orient) {
 		int letterX, letterY;
@@ -1264,7 +1258,7 @@ DrawSector(const MballWidget w, const int wedge, const int ring,
 				letterX += w->mball.letterOffset.x;
 				i++;
 			}
-			DRAWTEXT(w, borderGC, letterX, letterY, buf, i);
+			DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, i);
 		}
 		if (ring + 1 > w->mball.rings / 2 &&
 				w->mball.mballLoc[wedge][ring].direction) {
@@ -1295,7 +1289,7 @@ DrawSector(const MballWidget w, const int wedge, const int ring,
 				letterX += w->mball.letterOffset.x;
 				i++;
 			}
-			DRAWTEXT(w, borderGC, letterX, letterY, buf, i);
+			DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, i);
 		}
 	}
 }
@@ -1327,13 +1321,13 @@ DrawRadar(const MballWidget w, GC gc, int thick,
 	int r, i, stx, sty, lenx, leny;
 	double angle, increment;
 
-	DRAWARC(w, gc, thick, startx, starty,
+	DRAWARC(w, dr, gc, thick, startx, starty,
 		lengthx, lengthy, 0, FULLCIRCLE);
 	if (w->mball.rings % 2) {
 		stx = startx - lengthx / (2 * w->mball.rings);
 		sty = starty - lengthy / (2 * w->mball.rings);
 		for (r = 1; r < w->mball.rings / 2 + 1; r++) {
-			DRAWARC(w, gc, thick,
+			DRAWARC(w, dr, gc, thick,
 				stx + (w->mball.rings / 2 + 1 - r) * lengthx /
 				w->mball.rings,
 				sty + (w->mball.rings / 2 + 1 - r) * lengthy /
@@ -1344,7 +1338,7 @@ DrawRadar(const MballWidget w, GC gc, int thick,
 		}
 	} else {
 		for (r = 1; r < w->mball.rings / 2; r++) {
-			DRAWARC(w, gc, thick,
+			DRAWARC(w, dr, gc, thick,
 				startx + (w->mball.rings / 2 - r) * lengthx /
 				w->mball.rings,
 				starty + (w->mball.rings / 2 - r) * lengthy /
@@ -1365,7 +1359,7 @@ DrawRadar(const MballWidget w, GC gc, int thick,
 	leny += 2;
 #endif
 	for (i = 0; i < w->mball.wedges; i++) {
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			stx, sty,
 			stx + (int) ((double) (lenx) * cos(angle) / 2.0),
 			sty + (int) ((double) (leny) * sin(angle) / 2.0));
@@ -1376,7 +1370,7 @@ DrawRadar(const MballWidget w, GC gc, int thick,
 static void
 EraseFrame(const MballWidget w)
 {
-	FILLRECTANGLE(w, w->mball.inverseGC,
+	FILLRECTANGLE(w, dr, w->mball.inverseGC,
 		0, 0, w->core.width, w->core.height);
 }
 
@@ -1392,11 +1386,11 @@ DrawFrame(MballWidget w, Boolean focus)
 	lengthy = w->mball.viewLength - w->mball.delta + w->mball.puzzleOffset.y;
 	DrawRadar(w, gc, 0, startx, starty, lengthx - startx, lengthy - starty);
 	if (w->mball.vertical) {
-		DRAWLINE(w, w->mball.frameGC, 0, lengthy + 1,
+		DRAWLINE(w, dr, w->mball.frameGC, 0, lengthy + 1,
 			(int) w->core.width, lengthy + 1);
 		DrawRadar(w, gc, 0, startx, lengthy + 3, lengthx - startx, lengthy - starty);
 	} else {
-		DRAWLINE(w, w->mball.frameGC, lengthx + 1, 0,
+		DRAWLINE(w, dr, w->mball.frameGC, lengthx + 1, 0,
 			lengthx + 1, (int) w->core.height);
 		DrawRadar(w, gc, 0, lengthx + 3, starty, lengthx - startx, lengthy - starty);
 	}
@@ -1601,13 +1595,13 @@ ResetPieces(MballWidget w)
 
 	for (wedge = 0; wedge < MAXWEDGES; wedge++) {
 		if (w->mball.mballLoc[wedge])
-			(void) free((void *) w->mball.mballLoc[wedge]);
+			free(w->mball.mballLoc[wedge]);
 		if (!(w->mball.mballLoc[wedge] = (MballLoc *)
 				malloc(sizeof (MballLoc) * w->mball.rings))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 		if (startLoc[wedge])
-			(void) free((void *) startLoc[wedge]);
+			free(startLoc[wedge]);
 		if (!(startLoc[wedge] = (MballLoc *)
 				malloc(sizeof (MballLoc) * w->mball.rings))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
@@ -1966,10 +1960,14 @@ SetValuesMball(MballWidget w)
 			szBuf, sizeof (szBuf), INIFILE);
 		w->mball.wedgeChar[wedge] = szBuf[0];
 	}
-	(void) GetPrivateProfileString(SECTION, "name", "Guest",
+	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
 		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->mball.username, szBuf);
-	w->mball.username[80] = 0;
+	(void) strcpy(w->mball.userName, szBuf);
+	w->mball.userName[80] = 0;
+	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
+		szBuf, sizeof (szBuf), INIFILE);
+	(void) strcpy(w->mball.scoreFile, szBuf);
+	w->mball.scoreFile[80] = 0;
 }
 
 void
