@@ -37,6 +37,7 @@
 #ifndef WINVER
 #define XtNselectCallback ((char *) "selectCallback")
 #define XtNuserName ((char *) "userName")
+#define XtNscoreFile ((char *) "scoreFile")
 #define XtNbase ((char *) "base")
 #define XtNmono ((char *) "mono")
 #define XtNreverse ((char *) "reverse")
@@ -61,7 +62,10 @@
 #define XtNwedgeColor9 ((char *) "wedgeColor9")
 #define XtNwedgeColor10 ((char *) "wedgeColor10")
 #define XtNwedgeColor11 ((char *) "wedgeColor11")
+#define XtNscoreOnly ((char *) "scoreOnly")
+#define XtNversionOnly ((char *) "versionOnly")
 #define XtCUserName ((char *) "UserName")
+#define XtCScoreFile ((char *) "ScoreFile")
 #define XtCBase ((char *) "Base")
 #define XtCMono ((char *) "Mono")
 #define XtCReverse ((char *) "Reverse")
@@ -106,23 +110,6 @@ typedef struct {
 #define MBALL_COMPUTED 14
 #define MBALL_UNDO 15
 
-#ifdef WINVER
-#ifdef UNIXDELIM
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#else
-#define CURRENTDELIM ".\\"
-#define FINALDELIM "\\"
-#endif
-#else
-#ifdef VMS
-#define CURRENTDELIM "[]"
-#define FINALDELIM ""
-#else
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#endif
-#endif
 #define MINWEDGES 2
 #define MAXWEDGES 12
 #define MINRINGS 1
@@ -142,8 +129,5 @@ typedef struct {
 
 typedef struct _MballRec *MballWidget;
 
-extern void intCat(char ** string, const char * var1, const int var2);
-extern void stringCat(char ** string, const char * var1, const char * var2);
-
 #endif /* _XtMball_h */
 /* DON'T ADD STUFF AFTER THIS #endif */
