@@ -83,7 +83,7 @@ PopStack(MoveRecord * move)
 	currMove = lastMove->previous;
 	lastMove->previous->previous->next = lastMove;
 	lastMove->previous = lastMove->previous->previous;
-	(void) free((void *) currMove);
+	free(currMove);
 	count--;
 }
 
@@ -100,7 +100,7 @@ FlushStack(void)
 		currMove = lastMove->previous;
 		lastMove->previous->previous->next = lastMove;
 		lastMove->previous = lastMove->previous->previous;
-		(void) free((void *) currMove);
+		free(currMove);
 	}
 	count = 0;
 }
