@@ -29,38 +29,25 @@
   Version 4: 94/09/15 Xt
 */
 
+#include "file.h"
 #ifdef WINVER
 #include "MballP.h"
 #include "wmball.h"
 #define TITLE "wmball"
 
 static MballRec widget;
-static HWND Wnd;
 
 #ifndef SCOREPATH
-#define SCOREPATH "c:\\Windows"
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
 #endif
-#define PRINT_MESSAGE(b) (void) MessageBox(Wnd, (LPCSTR) b, "Warning", MB_OK);
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
 #define SET_STARTED(w,b) w->mball.started = b
 #else
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
-#ifdef VMS
-#include <unixlib.h>
-#define getlogin() cuserid(NULL)
-#else
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif
-#if HAVE_FCNTL_H
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#endif
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
+#include "xwin.h"
 #include <X11/Shell.h>
 #include <X11/cursorfont.h>
 #ifdef HAVE_MOTIF
@@ -82,7 +69,7 @@ static HWND Wnd;
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
-#define SET_STARTED(w,b) XtSetArg(arg[0], XtNstart, b); XtSetValues(w, arg, 1)
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
 #include "Mball.h"
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
@@ -90,27 +77,34 @@ static HWND Wnd;
 #endif
 #include "icons/mball.xbm"
 #ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
 #define SCOREPATH "/var/games/xpuzzles"
 #endif
 #endif
+#endif
 
-#ifdef HAVE_MOTIF
+#ifndef WINVER
 static const char aboutHelp[] = {
-	"Version 7.1.3\n"
+	"Mball Version 7.1.5\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
 	"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
+
 static const char optionsHelp[] = {
-	"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]] "
-	"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"[-{foreground|fg} {color}] [-{background|bg} {color}] "
-	"[-{border|bd} {color}] [-wedge{0|1|2|3|4|5|6|7|8|9|10|11} {color}]\n"
-	"[-wedges {int}] [-ring {int}] [-[no]orient] [-[no]practice] "
-	"[-base {int}] [-{font|fn} {fontname}] [-username {string}]\n"
+	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+	"\t[-{border|bd} {color}] [-wedge{0|1|2|3|4|5|6|7|8|9|10|11} {color}]\n"
+	"\t[-wedges {int}] [-ring {int}] [-[no]orient] [-[no]practice]\n"
+	"\t[-base {int}] [-{font|fn} {fontname}] [-userName {string}]\n"
+	"\t[-scoreFile {filename}] [-scores] [-version]\n"
 };
 #endif
+
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
 	"The original puzzle has 8 sectors on a sphere "
@@ -130,38 +124,52 @@ static const char descriptionHelp[] = {
 	"Geza Gyovai Hungarian Engineer, manufactured by Whole "
 	"Systems Design, Inc..\n"
 };
+
 static const char featuresHelp[] = {
 	"Press \"mouse-left\" button to move a piece.  Release "
 	"\"mouse-left\" button on a piece and the pieces will\n"
 	"then turn towards where the mouse button was released.  "
 	"Usually, a click and release on the same wedge is\n"
 	"ambiguous and the puzzle will not turn.\n"
+	"\n"
 	"Click \"mouse-center\" button, or press \"P\" or \"p\" "
 	"keys, to toggle the practice mode (in practice mode the\n"
 	"record should say \"practice\").  This is good for learning "
 	"moves and experimenting.\n"
+	"\n"
 	"Click \"mouse-right\" button, or press \"R\" or \"r\" "
 	"keys, to randomize the puzzle (this must be done first\n"
 	"to set a new record).\n"
+	"\n"
 	"Press \"I\" or \"i\" keys to increase the number of rings.\n"
+	"\n"
 	"Press \"D\" or \"d\" keys to decrease the number of rings.\n"
+	"\n"
 	"Press \"O\" or \"o\" keys to toggle the orient mode.  One "
 	"has to orient the wedges in orient mode, besides\n"
 	"getting all the wedges to be the same color.  To do this "
 	"one has to get the numbers to be on the same side\n"
 	"of the ball in clockwise order.\n"
+	"\n"
 	"Press \"2\", \"4\", \"6\", \"8\", \"0\", or \"=\" keys "
 	"(not the keypad 2, 4, 6, 8, 0) to change to 2, 4, 6, 8, 10,\n"
 	"or 12 wedges, respectively.  Note: if there were odd "
 	"number of wedges, there would be no 180 degree turn and\n"
 	"therefore the puzzle would be inoperable.\n"
+	"\n"
 	"\"S\" or \"s\" keys reserved for the auto-solver "
 	"(not implemented).\n"
-	"1x1x1, 2x2x2, and 3x3x3 pyrmaminxs in Period 3 mode.\n"
+	"\n"
 	"Press \"U\" or \"u\" keys to undo a move.\n"
+	"\n"
 	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+	"\n"
 	"Press \"W\" or \"w\" keys to save a puzzle.\n"
+	"\n"
+	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+	"\n"
 	"Press \"Esc\" key to hide program.\n"
+	"\n"
 	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
 	"Use the key pad, \"R\" keys, or arrow keys to move without "
 	"mouse clicks.\n"
@@ -173,14 +181,17 @@ static const char featuresHelp[] = {
 	"  v\n"
 	"1 2 3  Lower Left, Down, Lower Right\n"
 	" 0  .  Lower Lower Left, Lower Lower Right\n"
+	"\n"
 	"Use the control key and the left mouse button, keypad, or "
 	"arrow keys to move the whole Masterball.  This is not\n"
 	"recorded as a turn.\n"
 };
+
 static const char referencesHelp[] = {
 	"http://wsd.com/masterball\n"
 };
 #endif
+
 static const char solveHelp[] = {
 	"Auto-solver: sorry, not implemented.\n"
 };
@@ -190,7 +201,7 @@ static const char solveHelp[] = {
 #endif
 
 #define MAXRINGS 6
-#define NEVER -1
+#define NEVER (-1)
 #define FILENAMELEN 1024
 #define USERNAMELEN 120
 #define MESSAGELEN (USERNAMELEN+64)
@@ -220,20 +231,21 @@ static const char *wedgeString[] =
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
+static Arg arg[3];
 #else
 static char titleDsp[TITLELEN] = "";
 #endif
+static char scoreFileName[FILENAMELEN] = SCOREFILE;
+static char fileName[FILENAMELEN];
 #ifdef WINVER
 #define MAXPROGNAME 80
 static char progDsp[MAXPROGNAME] = TITLE;
-static char usernameDsp[USERNAMELEN] = "Guest";
+static char userNameDsp[USERNAMELEN] = "Guest";
 #else
 static Pixmap mballIcon = None;
 static Widget topLevel, mball;
-static Arg arg[5];
 static char *progDsp;
-static char usernameDsp[USERNAMELEN] = "";
-#endif
+static char userNameDsp[USERNAMELEN] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -244,25 +256,26 @@ PrintState(Widget w, char *msg)
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
 		XtError("PrintState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
-	XtSetArg(arg[0], XmNlabelString, xmstr);
-	XtSetValues(w, arg, 1);
+	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
-#else
+#endif
+
 static void
-PrintState(
-#ifndef WINVER
-Widget w,
-#endif
-int wedges, int rings, int moves, char *msg)
+PrintRecords(void)
 {
-	(void) sprintf(titleDsp, "%s.%d: %d@ (%d/%s) - %s",
-		progDsp, wedges, rings, moves, recordDsp, msg);
-#ifdef WINVER
-	SetWindowText(Wnd, (LPSTR) titleDsp);
-#else
-	XtSetArg(arg[0], XtNtitle, titleDsp);
-	XtSetValues(w, arg, 1);
-#endif
+	int i, j, orient;
+
+	(void) printf("              MBALL  HALL OF FAME\n\n");
+	(void) printf("ORIENT WEDGE RING USER            MOVES\n");
+	for (orient = 0; orient < 2; orient++)
+		for (i = 0; i < (MAXWEDGES - MINWEDGES) / 2 + 1; i++)
+			for (j = 0; j < MAXRINGS - MINRINGS + 1; j++) {
+				if (mballRecord[orient][i][j].score > 0)
+					(void) printf("%6d%6d%5d %-12s%9d\n",
+						orient, 2 * i + 1, j + 1,
+						mballRecord[orient][i][j].name,
+						mballRecord[orient][i][j].score);
+			}
 }
 #endif
 
@@ -280,27 +293,26 @@ InitRecords(void)
 			}
 }
 
-
 static void
 ReadRecords(void)
 {
 	FILE *fp;
 	int i, j, n, orient;
-	char username[USERNAMELEN];
+	char userName[USERNAMELEN];
 	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *fname, *lname;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
+	stringCat(&buf1, CURRENTDELIM, scoreFileName);
 	lname = buf1;
 	stringCat(&buf1, SCOREPATH, FINALDELIM);
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "r")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "r")) == NULL) {
+	(void) strncpy(fileName, lname, USERNAMELEN);
+	if ((fp = fopen(fileName, "r")) == NULL) {
+		(void) strncpy(fileName, fname, USERNAMELEN);
+		/* Try installed directory. */
+		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
@@ -330,12 +342,12 @@ ReadRecords(void)
 	for (orient = 0; orient < 2; orient++)
 		for (i = 0; i < (MAXWEDGES - MINWEDGES) / 2 + 1; i++)
 			for (j = 0; j < MAXRINGS - MINRINGS + 1; j++) {
-				(void) fscanf(fp, "%d %s\n", &n, username);
+				(void) fscanf(fp, "%d %s\n", &n, userName);
 				if (n <= mballRecord[orient][i][j].score ||
 				    mballRecord[orient][i][j].score <= NEVER) {
 					mballRecord[orient][i][j].score = n;
 					(void) strncpy(mballRecord[orient][i][j].name,
-						username, USERNAMELEN);
+						userName, USERNAMELEN);
 				}
 			}
 	(void) fclose(fp);
@@ -346,61 +358,31 @@ WriteRecords(void)
 {
 	FILE *fp;
 	int i, j, orient;
-	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *buf1 = NULL;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
-	lname = buf1;
-	stringCat(&buf1, SCOREPATH, FINALDELIM);
-	stringCat(&buf2, buf1, SCOREFILE);
-	free(buf1);
-	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "w")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "w")) == NULL) {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, " or ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-			free(lname);
-			free(fname);
-			return;
-		}
-/* Probably annoying */
-#if 0
-		else {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, ", falling back to ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-		}
-#endif
+	if ((fp = fopen(fileName, "w")) == NULL) {
+		stringCat(&buf1, "Can not write to ", fileName);
+		PRINT_MESSAGE(buf1);
+		free(buf1);
+		return;
 	}
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockfile[FILENAMELEN];
+		char lockFile[FILENAMELEN];
 
-		(void) strncpy(lockfile, name, FILENAMELEN - 6);
-		(void) strcat(lockfile, ".lock");
-		while (((lfd = open(lockfile, O_CREAT | O_EXCL, 0644)) < 0) &&
+		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strcat(lockFile, ".lock");
+		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
 			(void) sleep(1);
 		if (lfd < 0) {
 #if 1
 			(void) fprintf(stderr,
-			  "Lock file exists... guessing its an old one.\n");
+				"Lock file exists... guessing its an old one.\n");
 #else
 			(void) fprintf(stderr,
-			  "Lock file exists... score not recorded - sorry.\n");
+				"Lock file exists... score not recorded - sorry.\n");
 			return;
 #endif
 		}
@@ -409,19 +391,18 @@ WriteRecords(void)
 			for (i = 0; i < (MAXWEDGES - MINWEDGES) / 2 + 1; i++) {
 				for (j = 0; j < MAXRINGS - MINRINGS + 1; j++)
 					(void) fprintf(fp, "%d %s\n",
-						mballRecord[orient][i][j].score, mballRecord[orient][i][j].name);
+						mballRecord[orient][i][j].score,
+						mballRecord[orient][i][j].name);
 				(void) fprintf(fp, "\n");
 			}
 			(void) fprintf(fp, "\n");
 		}
 #if HAVE_FCNTL_H
 		(void) close(lfd);
-		(void) unlink(lockfile);
+		(void) unlink(lockFile);
 #endif
 		(void) fclose(fp);
 	}
-	free(lname);
-	free(fname);
 }
 
 static void
@@ -431,11 +412,11 @@ PrintRecord(int wedges, int rings, Boolean orient, Boolean practice)
 	int w = (wedges - MINWEDGES) / 2;
 	int r = rings - MINRINGS;
 
-	if (practice)
+	if (practice) {
 		(void) strncpy(recordDsp, "practice", MESSAGELEN);
-	else if (rings > MAXRINGS)
+	} else if (rings > MAXRINGS) {
 		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
-	else if (mballRecord[i][w][r].score <= NEVER) {
+	} else if (mballRecord[i][w][r].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
 		(void) sprintf(recordDsp, "%d %s",
@@ -446,6 +427,28 @@ PrintRecord(int wedges, int rings, Boolean orient, Boolean practice)
 #endif
 }
 
+static void
+PrintStatus(char *msg, int nMoves
+#ifndef HAVE_MOTIF
+		, int wedges, int rings
+#endif
+		)
+{
+#ifdef HAVE_MOTIF
+	PrintState(message, msg);
+	(void) sprintf(buff, "%d", nMoves);
+	PrintState(moves, buff);
+#else
+	(void) sprintf(titleDsp, "%s.%d: %d@ (%d/%s) - %s",
+		progDsp, wedges, rings, nMoves, recordDsp, msg);
+#ifdef WINVER
+	SetWindowText(widget.core.hWnd, (LPSTR) titleDsp);
+#else
+	XtVaSetValues(XtParent(mball), XtNtitle, titleDsp, NULL);
+#endif
+#endif
+}
+
 static Boolean
 HandleSolved(int counter, int wedges, int rings, Boolean orient)
 {
@@ -457,12 +460,12 @@ HandleSolved(int counter, int wedges, int rings, Boolean orient)
 			mballRecord[i][w][r].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		mballRecord[i][w][r].score = counter;
-		(void) strncpy(mballRecord[i][w][r].name, usernameDsp,
+		(void) strncpy(mballRecord[i][w][r].name, userNameDsp,
 			USERNAMELEN);
 		if (orient && (counter < mballRecord[!i][w][r].score ||
 				mballRecord[!i][w][r].score <= NEVER)) {
 			mballRecord[!i][w][r].score = counter;
-			(void) strncpy(mballRecord[!i][w][r].name, usernameDsp,
+			(void) strncpy(mballRecord[!i][w][r].name, userNameDsp,
 				USERNAMELEN);
 		}
 		WriteRecords();
@@ -483,7 +486,7 @@ Widget w
 {
 	int wedges, rings;
 	Boolean orient, practice;
-	char *username;
+	char *userName, *scoreFile;
 
 #ifdef WINVER
 	InitializeMball(w, brush);
@@ -492,14 +495,34 @@ Widget w
 	rings = w->mball.rings;
 	orient = w->mball.orient;
 	practice = w->mball.practice;
-	username = w->mball.username;
+	userName = w->mball.userName;
+	scoreFile = w->mball.scoreFile;
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
 #else
+	Boolean scoreOnly, versionOnly;
+
 	XtVaGetValues(w,
-		XtNuserName, &username,
+		XtNuserName, &userName,
+		XtNscoreFile, &scoreFile,
 		XtNwedges, &wedges,
 		XtNrings, &rings,
 		XtNorient, &orient,
-		XtNpractice, &practice, NULL);
+		XtNpractice, &practice,
+		XtNscoreOnly, &scoreOnly,
+		XtNversionOnly, &versionOnly, NULL);
+	if (versionOnly) {
+		(void) printf(aboutHelp);
+		exit(0);
+	}
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+	if (scoreOnly) {
+		InitRecords();
+		ReadRecords();
+		PrintRecords();
+		exit(0);
+	}
 #ifdef HAVE_MOTIF
 	XmToggleButtonSetState(wedge[(wedges - MINWEDGES) / 2], True, False);
 	if (rings > MAXRINGS)
@@ -513,31 +536,29 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(usernameDsp, username, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #endif
-	if (!strcmp(username, "") || !strcmp(username, "(null)") ||
-	    !strcmp(username, NOACCESS) || !strcmp(username, NOBODY)) {
+	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
+			!strcmp(userName, NOACCESS) ||
+			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(usernameDsp, username, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		/* The NOACCESS is not necessary, but it may stop silliness. */
-		(void) sprintf(usernameDsp, "%s", getlogin());
-		if (!strcmp(usernameDsp, "") ||
-				!strcmp(usernameDsp, "(null)") ||
-				!strcmp(usernameDsp, NOBODY) ||
-				!strcmp(usernameDsp, NOACCESS))
+		(void) sprintf(userNameDsp, "%s", getlogin());
+		if (!strcmp(userNameDsp, "") ||
+				!strcmp(userNameDsp, "(null)") ||
+				!strcmp(userNameDsp, NOBODY) ||
+				!strcmp(userNameDsp, NOACCESS))
 			/* It really IS nobody */
-			(void) sprintf(usernameDsp, "%s", "guest");
+			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
 	PrintRecord(wedges, rings, orient, practice);
+	PrintStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
-#endif
-		wedges, rings, movesDsp, messageDsp);
+		, wedges, rings
 #endif
+		);
 }
 
 #ifdef WINVER
@@ -586,16 +607,16 @@ CallbackMball(Widget w, caddr_t clientData, mballCallbackStruct * callData)
 #ifdef HAVE_MOTIF
 			XtManageChild(practiceDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 10); /* menu choice */
-			XtSetValues(mball, arg, 1);
+			XtVaSetValues(mball,
+				XtNmenu, 10, NULL); /* menu choice */
 #endif
 			break;
 		case MBALL_RANDOMIZE_QUERY:
 #ifdef HAVE_MOTIF
 			XtManageChild(randomizeDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-			XtSetValues(mball, arg, 1);
+			XtVaSetValues(mball,
+				XtNmenu, 5, NULL); /* menu choice */
 #endif
 			break;
 #endif
@@ -613,7 +634,8 @@ CallbackMball(Widget w, caddr_t clientData, mballCallbackStruct * callData)
 			break;
 		case MBALL_RESTORE:
 			if (practice) {
-				(void) strncpy(recordDsp, "practice", MESSAGELEN);
+				(void) strncpy(recordDsp, "practice",
+					MESSAGELEN);
 #ifdef HAVE_MOTIF
 				PrintState(record, recordDsp);
 #endif
@@ -624,7 +646,8 @@ CallbackMball(Widget w, caddr_t clientData, mballCallbackStruct * callData)
 			movesDsp = 0;
 			break;
 		case MBALL_AMBIGUOUS:
-			(void) strncpy(messageDsp, "Ambiguous move", MESSAGELEN);
+			(void) strncpy(messageDsp, "Ambiguous move",
+				MESSAGELEN);
 			break;
 		case MBALL_ILLEGAL:
 			if (practice || start)
@@ -645,10 +668,10 @@ CallbackMball(Widget w, caddr_t clientData, mballCallbackStruct * callData)
 				movesDsp = 0;
 			else if (cheat)
 				(void) sprintf(messageDsp,
-					"No cheating %s!!", usernameDsp);
+					"No cheating %s!!", userNameDsp);
 			else if (HandleSolved(movesDsp, wedges, rings, orient))
 				(void) sprintf(messageDsp,
-					"Congratulations %s!!", usernameDsp);
+					"Congratulations %s!!", userNameDsp);
 			else
 				(void) strncpy(messageDsp, "Solved!",
 					MESSAGELEN);
@@ -665,9 +688,9 @@ CallbackMball(Widget w, caddr_t clientData, mballCallbackStruct * callData)
 			w->mball.practice = practice;
 			w->mball.started = False;
 #else
-			XtSetArg(arg[0], XtNpractice, practice);
-			XtSetArg(arg[1], XtNstart, False);
-			XtSetValues(w, arg, 2);
+			XtVaSetValues(w,
+				XtNpractice, practice,
+				XtNstart, False, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(practiceSwitch, practice, True);
 #endif
@@ -679,9 +702,9 @@ CallbackMball(Widget w, caddr_t clientData, mballCallbackStruct * callData)
 			w->mball.practice = False;
 			w->mball.started = False;
 #else
-			XtSetArg(arg[0], XtNpractice, False);
-			XtSetArg(arg[1], XtNstart, False);
-			XtSetValues(w, arg, 2);
+			XtVaSetValues(w,
+				XtNpractice, False,
+				XtNstart, False, NULL);
 #endif
 			break;
 		case MBALL_DEC:
@@ -691,8 +714,7 @@ CallbackMball(Widget w, caddr_t clientData, mballCallbackStruct * callData)
 #ifdef WINVER
 			w->mball.rings = rings;
 #else
-			XtSetArg(arg[0], XtNrings, rings);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNrings, rings, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(ring, rings);
 			if (rings >= MAXRINGS)
@@ -707,8 +729,7 @@ CallbackMball(Widget w, caddr_t clientData, mballCallbackStruct * callData)
 #ifdef WINVER
 			w->mball.orient = orient;
 #else
-			XtSetArg(arg[0], XtNorient, orient);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNorient, orient, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(orientSwitch, orient, True);
 #endif
@@ -721,8 +742,7 @@ CallbackMball(Widget w, caddr_t clientData, mballCallbackStruct * callData)
 #ifdef WINVER
 			w->mball.rings = rings;
 #else
-			XtSetArg(arg[0], XtNrings, rings);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNrings, rings, NULL);
 #ifdef HAVE_MOTIF
 			if (rings > MAXRINGS)
 				XtVaSetValues(ring, XmNmaximum, rings, NULL);
@@ -743,8 +763,7 @@ CallbackMball(Widget w, caddr_t clientData, mballCallbackStruct * callData)
 #ifdef WINVER
 			w->mball.wedges = wedges;
 #else
-			XtSetArg(arg[0], XtNwedges, wedges);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNwedges, wedges, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(wedge[(wedges - MINWEDGES) / 2],
 				 True, True);
@@ -759,18 +778,11 @@ CallbackMball(Widget w, caddr_t clientData, mballCallbackStruct * callData)
 			SET_STARTED(w, True);
 			break;
 	}
-#ifdef HAVE_MOTIF
-	PrintState(message, messageDsp);
-	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-#else
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
+	PrintStatus(messageDsp, movesDsp
+#ifndef HAVE_MOTIF
+		, wedges, rings
 #endif
-		wedges, rings, movesDsp, messageDsp);
-#endif
-
+		);
 }
 
 #ifdef WINVER
@@ -794,7 +806,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	HBRUSH brush = (HBRUSH) NULL;
 	PAINTSTRUCT paint;
 
-	Wnd = widget.core.hWnd = hWnd;
+	widget.core.hWnd = hWnd;
 	if (GetFocus()) {
 		if (!widget.mball.focus) {
 			widget.core.hDC = GetDC(hWnd);
@@ -1080,18 +1092,7 @@ static void
 Usage(char * programName)
 {
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr,
-		"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n");
-	(void) fprintf(stderr,
-		"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n");
-	(void) fprintf(stderr,
-		"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{border|bd} {color}] [-wedge{0|1|2|3|4|5|6|7|8|9|10|11} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{wedges {int}}] [-{rings {int}}] [-[no]orient] [-[no]practice]\n");
-	(void) fprintf(stderr,
-		"\t[-base {int}] [-{font|fn} {fontname}] [-username {string}]\n");
+	(void) fprintf(stderr, optionsHelp);
 	exit(1);
 }
 
@@ -1130,7 +1131,10 @@ static XrmOptionDescRec options[] =
 	{(char *) "-base", (char *) "*mball.base", XrmoptionSepArg, NULL},
 	{(char *) "-fn", (char *) "*mball.font", XrmoptionSepArg, NULL},
 	{(char *) "-font", (char *) "*mball.font", XrmoptionSepArg, NULL},
-	{(char *) "-username", (char *) "*mball.userName", XrmoptionSepArg, NULL}
+	{(char *) "-userName", (char *) "*mball.userName", XrmoptionSepArg, NULL},
+	{(char *) "-scoreFile", (char *) "*mball.scoreFile", XrmoptionSepArg, NULL},
+	{(char *) "-scores", (char *) "*mball.scoreOnly", XrmoptionNoArg, (char *) "TRUE"},
+	{(char *) "-version", (char *) "*mball.versionOnly", XrmoptionNoArg, (char *) "TRUE"}
 };
 
 #ifdef HAVE_MOTIF
@@ -1138,8 +1142,7 @@ static void
 CallbackMballPractice(Widget w, XtPointer clientData, XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 10); /* menu choice */
-		XtSetValues(mball, arg, 1);
+		XtVaSetValues(mball, XtNmenu, 10, NULL); /* menu choice */
 	}
 }
 
@@ -1147,8 +1150,7 @@ static void
 CallbackMballRandomize(Widget w, XtPointer clientData, XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-		XtSetValues(mball, arg, 1);
+		XtVaSetValues(mball, XtNmenu, 5, NULL); /* menu choice */
 	}
 }
 
@@ -1255,16 +1257,15 @@ fileCB(Widget w, void *value, void *clientData)
 
 	if (val == 2)
 		exit(0);
-	XtSetArg(arg[0], XtNmenu, val);
-	XtSetValues(mball, arg, 1);
+	XtVaSetValues(mball, XtNmenu, val, NULL);
 }
 
 static void
 playCB(Widget w, void *value, void *clientData)
 {
 	int val = (int) value;
-	XtSetArg(arg[0], XtNmenu, val + 3); /* GWQ */
-	XtSetValues(mball, arg, 1);
+
+	XtVaSetValues(mball, XtNmenu, val + 3, NULL); /* GWQ */
 }
 
 static Widget
@@ -1345,7 +1346,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d\n", val);
+			intCat(&buf, "helpCB: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1399,11 +1400,10 @@ main(int argc, char **argv)
 			RootWindowOfScreen(XtScreen(topLevel)),
 			(char *) mball_bits,
 			mball_width, mball_height);
-	XtSetArg(arg[0], XtNiconPixmap, mballIcon);
 #ifdef HAVE_MOTIF
-	/* not XmEXPLICIT */
-	XtSetArg(arg[1], XmNkeyboardFocusPolicy, XmPOINTER);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, mballIcon,
+		XmNkeyboardFocusPolicy, XmPOINTER, NULL); /* not XmEXPLICIT */
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
 		xmPanedWindowWidgetClass, topLevel,
 		XmNseparatorOn, False,
@@ -1617,8 +1617,9 @@ main(int argc, char **argv)
 	mball = XtCreateManagedWidget("mball",
 		mballWidgetClass, mainPanel, NULL, 0);
 #else
-	XtSetArg(arg[1], XtNinput, True);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, mballIcon,
+		XtNinput, True, NULL);
 	mball = XtCreateManagedWidget("mball",
 		mballWidgetClass, topLevel, NULL, 0);
 #endif
