@@ -25,10 +25,9 @@
 
 /* Methods file for Mlink */
 
-#if defined(USE_RPLAY) || defined(USE_NAS) || defined(USE_VMSPLAY) || defined(USE_ESOUND) || defined(WINVER) || defined(DEF_PLAY)
-#define USE_SOUND
-extern void playSound(char * filename);
-#endif
+#include "file.h"
+#include "rngs.h"
+#include "sound.h"
 #include "MlinkP.h"
 
 #ifndef PICTURE
@@ -213,8 +212,11 @@ static XtActionsRec actionsListMlink[] =
 static XtResource resourcesMlink[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(MlinkWidget, mlink.username),
-	 XtRString, (caddr_t) "guest"},
+	 XtOffset(MlinkWidget, mlink.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(MlinkWidget, mlink.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(MlinkWidget, mlink.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
@@ -311,6 +313,12 @@ static XtResource resourcesMlink[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(MlinkWidget, mlink.cheat),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(MlinkWidget, mlink.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(MlinkWidget, mlink.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(MlinkWidget, mlink.menu),
 	 XtRString, (caddr_t) "-1"},
@@ -362,78 +370,6 @@ MlinkClassRec mlinkClassRec =
 
 WidgetClass mlinkWidgetClass = (WidgetClass) & mlinkClassRec;
 
-#ifndef HAVE_USLEEP
-#if !defined( VMS ) || defined( XVMSUTILS ) || ( __VMS_VER >= 70000000 )
-#ifdef USE_XVMSUTILS
-#include <X11/unix_time.h>
-#endif
-#if HAVE_SYS_TIME_H
-#include <sys/time.h>
-#else
-#if HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#endif
-#endif
-#endif
-#if defined(SYSV) || defined(SVR4)
-#ifdef LESS_THAN_AIX3_2
-#include <sys/poll.h>
-#else /* !LESS_THAN_AIX3_2 */
-#include <poll.h>
-#endif /* !LESS_THAN_AIX3_2 */
-#endif /* defined(SYSV) || defined(SVR4) */
-
-/* not static in case usleep found in system include */
-int
-usleep(unsigned int usec)
-{
-#if (defined (SYSV) || defined(SVR4)) && !defined(__hpux)
-#if defined(HAVE_NANOSLEEP)
-	{
-		struct timespec rqt;
-
-		rqt.tv_nsec = 1000 * (usec % (unsigned int) 1000000);
-		rqt.tv_sec = usec / (unsigned int) 1000000;
-		return nanosleep(&rqt, NULL);
-	}
-#else
-	(void) poll(
-#if defined(__cplusplus) || defined(c_plusplus)
-		(pollfd *) /* guess */
-#else
-		(void *)
-#endif
-		0, (int) 0, usec / 1000);	/* ms resolution */
-#endif
-#else
-#ifdef VMS
-	long timadr[2];
-
-	if (usec != 0) {
-		timadr[0] = -usec * 10;
-		timadr[1] = -1;
-
-		sys$setimr(4, &timadr, 0, 0, 0);
-		sys$waitfr(4);
-	}
-#else
-	struct timeval time_out;
-
-#if 0
-	/* (!defined(AIXV3) && !defined(__hpux)) */
-	extern int select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
-
-#endif
-
-	time_out.tv_usec = usec % (unsigned int) 1000000;
-	time_out.tv_sec = usec / (unsigned int) 1000000;
-	(void) select(0, (void *) 0, (void *) 0, (void *) 0, &time_out);
-#endif
-#endif
-	return 0;
-}
-#endif
-
 void
 SetMlink(MlinkWidget w, int reason)
 {
@@ -459,13 +395,13 @@ loadFont(MlinkWidget w)
 	if ((w->mlink.fontInfo = XLoadQueryFont(display,
 			w->mlink.font)) == NULL) {
 		(void) sprintf(buf,
-			"Cannot open %s font.\nAttempting %s font as alternate\n",
+			"Can not open %s font.\nAttempting %s font as alternate\n",
 			w->mlink.font, altfontname);
 		DISPLAY_WARNING(buf);
 		if ((w->mlink.fontInfo = XLoadQueryFont(display,
 				altfontname)) == NULL) {
 			(void) sprintf(buf,
-				"Cannot open %s alternate font.\nUse the -font option to specify a font to use.\n",
+				"Can not open %s alternate font.\nUse the -font option to specify a font to use.\n",
 				altfontname);
 			DISPLAY_WARNING(buf);
 		}
@@ -487,76 +423,6 @@ loadFont(MlinkWidget w)
 #define LOGFILE "mlink.log"
 #endif
 
-#if (!defined(WINVER) || (WINVER <= 0x030a)) /* if X or WINDOWS 3.1 or less */
-static void
-Sleep(unsigned int cMilliseconds)
-{
-#if (defined(WINVER) && (WINVER <= 0x030a))
-	unsigned long time_out = GetTickCount() + cMilliseconds;
-
-	while (time_out > GetTickCount());
-#else
-	(void) usleep(cMilliseconds * 1000);
-#endif
-}
-#endif
-
-static void
-initTimer(MlinkWidget w)
-{
-#ifdef WINVER
-	w->mlink.oldTime = GetTickCount();
-#else
-	XFlush(XtDisplay(w));
-	(void) X_GETTIMEOFDAY(&(w->mlink.oldTime));
-#endif
-}
-
-static void
-useTimer(MlinkWidget w, int delay)
-{
-	int sleepTime;
-#ifdef WINVER
-	long tv = GetTickCount();
-
-	sleepTime = delay - (tv - w->mlink.oldTime);
-	w->mlink.oldTime = tv;
-	if (sleepTime > 0) {
-		Sleep((unsigned int) sleepTime);
-	}
-#else
-	struct timeval tv;
-
-	XFlush(XtDisplay(w));
-	(void) X_GETTIMEOFDAY(&tv);
-	sleepTime = delay * 1000 - ((tv.tv_sec - w->mlink.oldTime.tv_sec) *
-		1000000 + tv.tv_usec - w->mlink.oldTime.tv_usec);
-	w->mlink.oldTime.tv_sec = tv.tv_sec;
-	w->mlink.oldTime.tv_usec = tv.tv_usec;
-	if (sleepTime > 0) {
-		(void) usleep((unsigned int) sleepTime);
-	}
-#endif
-}
-
-void
-intCat(char ** string, const char * var1, const int var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + 21))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%d", var1, var2);
-}
-
-void
-stringCat(char ** string, const char * var1, const char * var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + strlen(var2) + 1))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%s", var1, var2);
-}
-
 static void
 CheckTiles(MlinkWidget w)
 {
@@ -908,15 +774,15 @@ DrawTile(MlinkWidget w, int pos, Boolean blank, Boolean erase,
 		return;
 	}
 #ifdef WINVER
-	w->mlink.hOldBitmap = (HBITMAP) SelectObject(w->mlink.memDC,
+	w->core.hOldBitmap = (HBITMAP) SelectObject(w->core.memDC,
 		w->mlink.bufferTiles[pressedOffset]);
 	BitBlt(w->core.hDC,
 		dx, dy,
 		w->mlink.tileSize.x, w->mlink.tileSize.y,
-		w->mlink.memDC,
+		w->core.memDC,
 		sx, sy,
 		SRCCOPY);
-	SelectObject(w->mlink.memDC, w->mlink.hOldBitmap);
+	(void) SelectObject(w->core.memDC, w->core.hOldBitmap);
 #else
 	XSetGraphicsExposures(XtDisplay(w), w->mlink.tileGC, False);
 	XCopyArea(XtDisplay(w),
@@ -1056,7 +922,8 @@ AnimateSlide(MlinkWidget w, int numTiles, int dir, int fast, Boolean logMoves)
 	  gapI++;
 	if (numTiles < 0)
 	  numTiles = -numTiles;
-	initTimer(w);
+	FLUSH(w);
+	initTimer(w->mlink.oldTime);
 	for (inc = 0; inc < moveI + gapI; inc += gapI) {
 	  if (inc > moveI)
 	    inc = moveI;
@@ -1106,7 +973,8 @@ AnimateSlide(MlinkWidget w, int numTiles, int dir, int fast, Boolean logMoves)
 	      }
 	    }
 	  }
-	  useTimer(w, w->mlink.delay / fast);
+	  FLUSH(w);
+	  useTimer(&(w->mlink.oldTime), w->mlink.delay / fast);
 	}
 	pos = w->mlink.spacePosition;
 	for (aTile = 0; aTile < numTiles; aTile++) {
@@ -1140,7 +1008,7 @@ AnimateRotate(MlinkWidget w, int start, int finish, int direction, int fast)
 {
 #ifdef WINVER
 	HDC memDC;
-	HBITMAP hBit;
+	HBITMAP hBitmap, hOldBitmap;
 #else
 	Pixmap bufferBox;
 	XWindowAttributes xgwa;
@@ -1156,9 +1024,9 @@ AnimateRotate(MlinkWidget w, int start, int finish, int direction, int fast)
 
 #ifdef WINVER
 	memDC = CreateCompatibleDC(w->core.hDC);
-	hBit = CreateCompatibleBitmap(w->core.hDC, size * moveI + 1,
+	hBitmap = CreateCompatibleBitmap(w->core.hDC, size * moveI + 1,
 			w->mlink.puzzleSize.y);
-	SelectObject(memDC, hBit);
+	hOldBitmap = SelectObject(memDC, hBitmap);
 	BitBlt(memDC, 0, 0,
 		size * moveI,
 		w->mlink.puzzleSize.y,
@@ -1166,6 +1034,7 @@ AnimateRotate(MlinkWidget w, int start, int finish, int direction, int fast)
 		start * moveI + w->mlink.puzzleOffset.x + 1,
 		w->mlink.puzzleOffset.y,
 		SRCCOPY);
+	(void) SelectObject(memDC, hOldBitmap);
 #else
 	(void) XGetWindowAttributes(XtDisplay(w), XtWindow(w), &xgwa);
 	if ((bufferBox = XCreatePixmap(XtDisplay(w), XtWindow(w),
@@ -1183,7 +1052,8 @@ AnimateRotate(MlinkWidget w, int start, int finish, int direction, int fast)
 		0, 0);
 	XSetGraphicsExposures(XtDisplay(w), w->mlink.frameGC, False);
 #endif
-	initTimer(w);
+	FLUSH(w);
+	initTimer(w->mlink.oldTime);
 	for (inc = 0; inc < moveJ + gapJ; inc += gapJ) {
 		if (inc > moveJ)
 			inc = moveJ;
@@ -1192,7 +1062,7 @@ AnimateRotate(MlinkWidget w, int start, int finish, int direction, int fast)
 		else
 			i = w->mlink.puzzleSize.y - inc + 1;
 #ifdef WINVER
-		SelectObject(memDC, hBit);
+		hOldBitmap = SelectObject(memDC, hBitmap);
 		BitBlt(w->core.hDC,
 			start * moveI + w->mlink.puzzleOffset.x + 1,
 			w->mlink.puzzleOffset.y + 1,
@@ -1210,6 +1080,7 @@ AnimateRotate(MlinkWidget w, int start, int finish, int direction, int fast)
 			memDC,
 			0, 0,
 			SRCCOPY);
+		(void) SelectObject(memDC, hOldBitmap);
 #else
 		XCopyArea(XtDisplay(w), bufferBox, XtWindow(w),
 			w->mlink.frameGC,
@@ -1227,10 +1098,11 @@ AnimateRotate(MlinkWidget w, int start, int finish, int direction, int fast)
 			w->mlink.puzzleSize.y - i + w->mlink.puzzleOffset.y -
 			w->mlink.delta.y + 1);
 #endif
-		useTimer(w, w->mlink.delay / fast);
+		FLUSH(w);
+		useTimer(&(w->mlink.oldTime), w->mlink.delay / fast);
 	}
 #ifdef WINVER
-	DeleteObject(hBit);
+	DeleteObject(hBitmap);
 	DeleteDC(memDC);
 #else
 	XFreePixmap(XtDisplay(w), bufferBox);
@@ -1980,9 +1852,7 @@ RandomizeTiles(MlinkWidget w)
 			DISPLAY_WARNING("RandomizeTiles: should not get here");
 		}
 		DrawAllTiles(w);
-#ifndef WINVER
-		XFlush(XtDisplay(w));
-#endif
+		FLUSH(w);
 	}
 	/* randomly position space */
 	/* Idea for this came from "puzzle" by Don Bennett, HP Labs */
@@ -2200,10 +2070,14 @@ SetValuesMlink(MlinkWidget w)
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) strcpy(w->mlink.moveSound, szBuf);
 	w->mlink.moveSound[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "name", "Guest",
+	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
 		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->mlink.username, szBuf);
-	w->mlink.username[80] = 0;
+	(void) strcpy(w->mlink.userName, szBuf);
+	w->mlink.userName[80] = 0;
+	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
+		szBuf, sizeof (szBuf), INIFILE);
+	(void) strcpy(w->mlink.scoreFile, szBuf);
+	w->mlink.scoreFile[80] = 0;
 }
 
 void
@@ -2506,8 +2380,8 @@ QuitMlink(MlinkWidget w
 		if (w->mlink.bufferTiles != NULL) {
 			DeleteObject(w->mlink.bufferTiles);
 		}
-		DeleteDC(w->mlink.memDC);
-		w->mlink.memDC = NULL;
+		DeleteDC(w->core.memDC);
+		w->core.memDC = NULL;
 	}
 #else
 	Display *display = XtDisplay(w);
@@ -2552,9 +2426,9 @@ ResizeTiles(MlinkWidget w)
 {
 	int sel;
 #ifdef WINVER
-	if (w->mlink.memDC == NULL) {
-		w->mlink.memDC = CreateCompatibleDC(w->core.hDC);
-		if (w->mlink.memDC == NULL) {
+	if (w->core.memDC == NULL) {
+		w->core.memDC = CreateCompatibleDC(w->core.hDC);
+		if (w->core.memDC == NULL) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
