@@ -37,6 +37,7 @@
 #ifndef WINVER
 #define XtNselectCallback ((char *) "selectCallback")
 #define XtNuserName ((char *) "userName")
+#define XtNscoreFile ((char *) "scoreFile")
 #define XtNtiles ((char *) "tiles")
 #define XtNfaces ((char *) "faces")
 #define XtNorient ((char *) "orient")
@@ -65,7 +66,10 @@
 #define XtNfaceColor5 ((char *) "faceColor5")
 #define XtNfaceColor6 ((char *) "faceColor6")
 #define XtNfaceColor7 ((char *) "faceColor7")
+#define XtNscoreOnly ((char *) "scoreOnly")
+#define XtNversionOnly ((char *) "versionOnly")
 #define XtCUserName ((char *) "UserName")
+#define XtCScoreFile ((char *) "ScoreFile")
 #define XtCTiles ((char *) "Tiles")
 #define XtCFaces ((char *) "Faces")
 #define XtCOrient ((char *) "Orient")
@@ -116,23 +120,6 @@ typedef struct {
 #define MLINK_UNDO 12
 #define MLINK_SPEED 13
 
-#ifdef WINVER
-#ifdef UNIXDELIM
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#else
-#define CURRENTDELIM ".\\"
-#define FINALDELIM "\\"
-#endif
-#else
-#ifdef VMS
-#define CURRENTDELIM "[]"
-#define FINALDELIM ""
-#else
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#endif
-#endif
 #define MINFACES 1
 #define MAXFACES 8
 #define MINTILES 1
@@ -154,8 +141,5 @@ typedef struct {
 
 typedef struct _MlinkRec *MlinkWidget;
 
-extern void intCat(char ** string, const char * var1, const int var2);
-extern void stringCat(char ** string, const char * var1, const char * var2);
-
 #endif /* _XtMlink_h */
 /* DON'T ADD STUFF AFTER THIS #endif */
