@@ -29,38 +29,25 @@
   Version 4: 94/08/30 Xt
 */
 
+#include "file.h"
 #ifdef WINVER
 #include "MlinkP.h"
 #include "wmlink.h"
 #define TITLE "wmlink"
 
 static MlinkRec widget;
-static HWND Wnd;
 
 #ifndef SCOREPATH
-#define SCOREPATH "c:\\Windows"
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
 #endif
-#define PRINT_MESSAGE(b) (void) MessageBox(Wnd, (LPCSTR) b, "Warning", MB_OK);
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
 #define SET_STARTED(w,b) w->mlink.started = b
 #else
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
-#ifdef VMS
-#include <unixlib.h>
-#define getlogin() cuserid(NULL)
-#else
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif
-#if HAVE_FCNTL_H
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#endif
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
+#include "xwin.h"
 #include <X11/Shell.h>
 #include <X11/cursorfont.h>
 #ifdef HAVE_MOTIF
@@ -81,7 +68,7 @@ static HWND Wnd;
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
-#define SET_STARTED(w,b) XtSetArg(arg[0], XtNstart, b); XtSetValues(w, arg, 1)
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
 #include "Mlink.h"
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
@@ -89,30 +76,37 @@ static HWND Wnd;
 #endif
 #include "icons/mlink.xbm"
 #ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
 #define SCOREPATH "/var/games/xpuzzles"
 #endif
 #endif
+#endif
 
-#ifdef HAVE_MOTIF
+#ifndef WINVER
 static const char aboutHelp[] = {
-	"Version 7.1.3\n"
+	"Mlink Version 7.1.5\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
 	"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
+
 static const char optionsHelp[] = {
-	"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]] "
-	"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"[-{foreground|fg} {color}] [-{background|bg} {color}] "
-	"[-{border|bd} {color}] [-tile {color}]\n"
-	"[-face{0|1|2|3|4|5|6|7} {color}] [-tiles {int}] "
-	"[-faces {int}] [-[no]orient] [-[no]pairs]\n"
-	"[-[no]install] [-picture {filename}] [-delay msecs] "
-	"[-[no]sound] [-bumpsound {filename}] [-movesound {filename}]\n"
-	"[-base {int}] [-{font|fn} {fontname}] [-username {string}]\n"
+	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+	"\t[-{border|bd} {color}] [-tile {color}]\n"
+	"\t[-face{0|1|2|3|4|5|6|7} {color}] [-tiles {int}]\n"
+	"\t[-faces {int}] [-[no]orient] [-[no]pairs]\n"
+	"\t[-[no]install] [-picture {filename}] [-delay msecs]\n"
+	"\t[-[no]sound] [-bumpSound {filename}] [-moveSound {filename}]\n"
+	"\t[-base {int}] [-{font|fn} {fontname}] [-userName {string}]\n"
+	"\t[-scoreFile {filename}] [-scores] [-version]\n"
 };
 #endif
+
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
 	"Ideal's The Missing Link, a 4x4 puzzle,  riding on the wave "
@@ -121,6 +115,7 @@ static const char descriptionHelp[] = {
 	"makes the Missing Link a harder puzzle to solve is that the\n"
 	"2 center positions rotate together.\n"
 };
+
 static const char featuresHelp[] = {
 	"Press \"mouse-left\" button to move a tile. Release "
 	"\"mouse-left\" button in the same row would move the tile towards\n"
@@ -178,6 +173,7 @@ static const char featuresHelp[] = {
 	"Use the control key and the keypad or arrow keys to reduce "
 	"or enlarge the complexity of the puzzle.\n"
 };
+
 static const char referencesHelp[] = {
 	"L. E. Horden, Sliding Piece Puzzles (Recreations in "
 	"Mathematics Series), Oxford University\n"
@@ -186,6 +182,7 @@ static const char referencesHelp[] = {
 	"Ideal Toy Corporation, 1981.\n"
 };
 #endif
+
 static const char solveHelp[] = {
 	"Auto-solver: sorry, only implemented "
 	"for tiles = 4 and faces = 4.\n"
@@ -196,7 +193,7 @@ static const char solveHelp[] = {
 #endif
 
 #define MAXTILES 8
-#define NEVER -1
+#define NEVER (-1)
 #define FILENAMELEN 1024
 #define USERNAMELEN 120
 #define MESSAGELEN (USERNAMELEN+64)
@@ -224,20 +221,21 @@ static char buff[21];
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
+static Arg arg[3];
 #else
 static char titleDsp[TITLELEN] = "";
 #endif
+static char scoreFileName[FILENAMELEN] = SCOREFILE;
+static char fileName[FILENAMELEN];
 #ifdef WINVER
 #define MAXPROGNAME 80
 static char progDsp[MAXPROGNAME] = TITLE;
-static char usernameDsp[USERNAMELEN] = "Guest";
+static char userNameDsp[USERNAMELEN] = "Guest";
 #else
 static Pixmap mlinkIcon = None;
 static Widget topLevel, mlink;
-static Arg arg[3];
 static char *progDsp;
-static char usernameDsp[USERNAMELEN] = "";
-#endif
+static char userNameDsp[USERNAMELEN] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -248,29 +246,27 @@ PrintState(Widget w, char *msg)
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
 		XtError("PrintState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
-	XtSetArg(arg[0], XmNlabelString, xmstr);
-	XtSetValues(w, arg, 1);
+	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
-#else
+#endif
+
 static void
-PrintState(
-#ifndef WINVER
-Widget w,
-#endif
-int tiles, int faces, Boolean middle, int moves, char *msg)
+PrintRecords(void)
 {
-	if (middle)
-		(void) sprintf(titleDsp, "%s: %dx%d norm@ (%d/%s) - %s",
-			progDsp, tiles, faces, moves, recordDsp, msg);
-	else
-		(void) sprintf(titleDsp, "%s: %dx%d ind@ (%d/%s) - %s",
-			progDsp, tiles, faces, moves, recordDsp, msg);
-#ifdef WINVER
-	SetWindowText(Wnd, (LPSTR) titleDsp);
-#else
-	XtSetArg(arg[0], XtNtitle, titleDsp);
-	XtSetValues(w, arg, 1);
-#endif
+	int i, j, k, l;
+
+	(void) printf("                    MLINK  HALL OF FAME\n\n");
+	(void) printf("MIDDLE ORIENT FACE TILE USER            MOVES\n");
+	for (l = 0; l < 2; l++)
+		for (k = 0; k < 2; k++)
+			for (j = 0; j < MAXFACES - MINFACES + 1; j++)
+				for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
+					if (mlinkRecord[l][k][j][i].score > 0)
+						(void) printf("%6d%7d%5d%5d %-12s%9d\n",
+							l, k, j + 1, i + 1,
+							mlinkRecord[l][k][j][i].name,
+							mlinkRecord[l][k][j][i].score);
+				}
 }
 #endif
 
@@ -294,21 +290,21 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, j, k, l, n;
-	char username[USERNAMELEN];
+	char userName[USERNAMELEN];
 	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *fname, *lname;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
+	stringCat(&buf1, CURRENTDELIM, scoreFileName);
 	lname = buf1;
 	stringCat(&buf1, SCOREPATH, FINALDELIM);
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "r")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "r")) == NULL) {
+	(void) strncpy(fileName, lname, USERNAMELEN);
+	if ((fp = fopen(fileName, "r")) == NULL) {
+		(void) strncpy(fileName, fname, USERNAMELEN);
+		/* Try installed directory. */
+		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
@@ -339,12 +335,12 @@ ReadRecords(void)
 		for (k = 0; k < 2; k++)
 			for (j = 0; j < MAXFACES - MINFACES + 1; j++)
 				for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
-					(void) fscanf(fp, "%d %s\n", &n, username);
+					(void) fscanf(fp, "%d %s\n", &n, userName);
 					if (n <= mlinkRecord[l][k][j][i].score ||
 					    mlinkRecord[l][k][j][i].score <= NEVER) {
 						mlinkRecord[l][k][j][i].score = n;
 						(void) strncpy(mlinkRecord[l][k][j][i].name,
-							username, USERNAMELEN);
+							userName, USERNAMELEN);
 					}
 				}
 	(void) fclose(fp);
@@ -355,61 +351,31 @@ WriteRecords(void)
 {
 	FILE *fp;
 	int i, j, k, l;
-	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *buf1 = NULL;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
-	lname = buf1;
-	stringCat(&buf1, SCOREPATH, FINALDELIM);
-	stringCat(&buf2, buf1, SCOREFILE);
-	free(buf1);
-	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "w")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "w")) == NULL) {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, " or ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-			free(lname);
-			free(fname);
-			return;
-		}
-/* Probably annoying */
-#if 0
-		else {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, ", falling back to ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-		}
-#endif
+	if ((fp = fopen(fileName, "w")) == NULL) {
+		stringCat(&buf1, "Can not write to ", fileName);
+		PRINT_MESSAGE(buf1);
+		free(buf1);
+		return;
 	}
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockfile[FILENAMELEN];
+		char lockFile[FILENAMELEN];
 
-		(void) strncpy(lockfile, name, FILENAMELEN - 6);
-		(void) strcat(lockfile, ".lock");
-		while (((lfd = open(lockfile, O_CREAT | O_EXCL, 0644)) < 0) &&
+		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strcat(lockFile, ".lock");
+		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
 			(void) sleep(1);
 		if (lfd < 0) {
 #if 1
 			(void) fprintf(stderr,
-			  "Lock file exists... guessing its an old one.\n");
+				"Lock file exists... guessing its an old one.\n");
 #else
 			(void) fprintf(stderr,
-			  "Lock file exists... score not recorded - sorry.\n");
+				"Lock file exists... score not recorded - sorry.\n");
 			return;
 #endif
 		}
@@ -428,12 +394,10 @@ WriteRecords(void)
 		}
 #if HAVE_FCNTL_H
 		(void) close(lfd);
-		(void) unlink(lockfile);
+		(void) unlink(lockFile);
 #endif
 		(void) fclose(fp);
 	}
-	free(lname);
-	free(fname);
 }
 
 static void
@@ -443,9 +407,9 @@ PrintRecord(int tiles, int faces, Boolean orient, Boolean middle,
 	int i = tiles - MINTILES, j = faces - MINFACES;
 	int k = (orient) ? 1 : 0, l = (middle) ? 1 : 0;
 
-	if (practice)
+	if (practice) {
 		(void) strncpy(recordDsp, "practice", MESSAGELEN);
-	else if (tiles > MAXTILES) {
+	} else if (tiles > MAXTILES) {
 		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
 	} else if (mlinkRecord[l][k][j][i].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
@@ -459,6 +423,32 @@ PrintRecord(int tiles, int faces, Boolean orient, Boolean middle,
 #endif
 }
 
+static void
+PrintStatus(char *msg, int nMoves
+#ifndef HAVE_MOTIF
+		, int tiles, int faces, Boolean middle
+#endif
+		)
+{
+#ifdef HAVE_MOTIF
+	PrintState(message, msg);
+	(void) sprintf(buff, "%d", nMoves);
+	PrintState(moves, buff);
+#else
+	if (middle)
+		(void) sprintf(titleDsp, "%s: %dx%d norm@ (%d/%s) - %s",
+			progDsp, tiles, faces, nMoves, recordDsp, msg);
+	else
+		(void) sprintf(titleDsp, "%s: %dx%d ind@ (%d/%s) - %s",
+			progDsp, tiles, faces, nMoves, recordDsp, msg);
+#ifdef WINVER
+	SetWindowText(widget.core.hWnd, (LPSTR) titleDsp);
+#else
+	XtVaSetValues(XtParent(mlink), XtNtitle, titleDsp, NULL);
+#endif
+#endif
+}
+
 static Boolean
 HandleSolved(int counter, int tiles, int faces, Boolean orient, Boolean middle)
 {
@@ -469,12 +459,12 @@ HandleSolved(int counter, int tiles, int faces, Boolean orient, Boolean middle)
 			 mlinkRecord[l][k][j][i].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		mlinkRecord[l][k][j][i].score = counter;
-		(void) strncpy(mlinkRecord[l][k][j][i].name, usernameDsp,
+		(void) strncpy(mlinkRecord[l][k][j][i].name, userNameDsp,
 			USERNAMELEN);
 		if (tiles < 4 || faces < 2) {
 			mlinkRecord[!l][k][j][i].score = counter;
 			(void) strncpy(mlinkRecord[!l][k][j][i].name,
-				usernameDsp, USERNAMELEN);
+				userNameDsp, USERNAMELEN);
 		}
 		WriteRecords();
 		PrintRecord(tiles, faces, orient, middle, False);
@@ -494,7 +484,7 @@ Widget w
 {
 	int tiles, faces;
 	Boolean orient, middle, practice;
-	char *username;
+	char *userName, *scoreFile;
 
 #ifdef WINVER
 	InitializeMlink(w, brush);
@@ -504,15 +494,35 @@ Widget w
 	orient = w->mlink.orient;
 	middle = w->mlink.middle;
 	practice = w->mlink.practice;
-	username = w->mlink.username;
+	userName = w->mlink.userName;
+	scoreFile = w->mlink.scoreFile;
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
 #else
+	Boolean scoreOnly, versionOnly;
+
 	XtVaGetValues(w,
-		XtNuserName, &username,
+		XtNuserName, &userName,
+		XtNscoreFile, &scoreFile,
 		XtNtiles, &tiles,
 		XtNfaces, &faces,
 		XtNorient, &orient,
 		XtNmiddle, &middle,
-		XtNpractice, &practice, NULL);
+		XtNpractice, &practice,
+		XtNscoreOnly, &scoreOnly,
+		XtNversionOnly, &versionOnly, NULL);
+	if (versionOnly) {
+		(void) printf(aboutHelp);
+		exit(0);
+	}
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+	if (scoreOnly) {
+		InitRecords();
+		ReadRecords();
+		PrintRecords();
+		exit(0);
+	}
 #ifdef HAVE_MOTIF
 	if (tiles > MAXTILES)
 		XtVaSetValues(tile, XmNmaximum, tiles, NULL);
@@ -524,7 +534,7 @@ Widget w
 	{
 		int delay;
 
-		XtVaGetValues(mlink, XtNdelay, &delay, NULL);
+		XtVaGetValues(w, XtNdelay, &delay, NULL);
 		XmScaleSetValue(speed, MAXSPEED + MINSPEED - delay - 1);
 	}
 #endif
@@ -533,31 +543,29 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(usernameDsp, username, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #endif
-	if (!strcmp(username, "") || !strcmp(username, "(null)") ||
-	    !strcmp(username, NOACCESS) || !strcmp(username, NOBODY)) {
-		/* The NOACCESS is not necessary, but it may stop silliness. */
+	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
+			!strcmp(userName, NOACCESS) ||
+			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(usernameDsp, username, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(usernameDsp, "%s", getlogin());
-		if (!strcmp(usernameDsp, "") ||
-				!strcmp(usernameDsp, "(null)") ||
-				!strcmp(usernameDsp, NOACCESS) ||
-				!strcmp(usernameDsp, NOBODY))
+		(void) sprintf(userNameDsp, "%s", getlogin());
+		if (!strcmp(userNameDsp, "") ||
+				!strcmp(userNameDsp, "(null)") ||
+				!strcmp(userNameDsp, NOACCESS) ||
+				!strcmp(userNameDsp, NOBODY))
 			/* It really IS nobody */
-			(void) sprintf(usernameDsp, "%s", "guest");
+			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
 	PrintRecord(tiles, faces, orient, middle, practice);
+	PrintStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
-#endif
-		tiles, faces, middle, movesDsp, messageDsp);
+		, tiles, faces, middle
 #endif
+		);
 }
 
 #ifdef WINVER
@@ -606,16 +614,16 @@ CallbackMlink(Widget w, caddr_t clientData, mlinkCallbackStruct * callData)
 #ifdef HAVE_MOTIF
 			XtManageChild(practiceDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 9); /* menu choice */
-			XtSetValues(mlink, arg, 1);
+			XtVaSetValues(mlink,
+				XtNmenu, 9, NULL); /* menu choice */
 #endif
 			break;
 		case MLINK_RANDOMIZE_QUERY:
 #ifdef HAVE_MOTIF
 			XtManageChild(randomizeDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-			XtSetValues(mlink, arg, 1);
+			XtVaSetValues(mlink,
+				XtNmenu, 5, NULL); /* menu choice */
 #endif
 			break;
 #endif
@@ -668,10 +676,11 @@ CallbackMlink(Widget w, caddr_t clientData, mlinkCallbackStruct * callData)
 				movesDsp = 0;
 			else if (cheat)
 				(void) sprintf(messageDsp,
-					"No cheating %s!!", usernameDsp);
-			else if (HandleSolved(movesDsp, tiles, faces, orient, middle))
+					"No cheating %s!!", userNameDsp);
+			else if (HandleSolved(movesDsp, tiles, faces,
+					orient, middle))
 				(void) sprintf(messageDsp,
-					"Congratulations %s!!", usernameDsp);
+					"Congratulations %s!!", userNameDsp);
 			else
 				(void) strncpy(messageDsp, "Solved!",
 					MESSAGELEN);
@@ -688,9 +697,9 @@ CallbackMlink(Widget w, caddr_t clientData, mlinkCallbackStruct * callData)
 			w->mlink.practice = practice;
 			w->mlink.started = False;
 #else
-			XtSetArg(arg[0], XtNpractice, practice);
-			XtSetArg(arg[1], XtNstart, False);
-			XtSetValues(w, arg, 2);
+			XtVaSetValues(w,
+				XtNpractice, practice,
+				XtNstart, False, NULL);
 #endif
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(practiceSwitch, practice, True);
@@ -699,12 +708,12 @@ CallbackMlink(Widget w, caddr_t clientData, mlinkCallbackStruct * callData)
 		case MLINK_RANDOMIZE:
 			movesDsp = 0;
 #ifdef WINVER
-			w->mlink.practice = practice;
+			w->mlink.practice = False;
 			w->mlink.started = False;
 #else
-			XtSetArg(arg[0], XtNpractice, practice);
-			XtSetArg(arg[1], XtNstart, False);
-			XtSetValues(w, arg, 2);
+			XtVaSetValues(w,
+				XtNpractice, False,
+				XtNstart, False, NULL);
 #endif
 			break;
 		case MLINK_ORIENT:
@@ -714,8 +723,7 @@ CallbackMlink(Widget w, caddr_t clientData, mlinkCallbackStruct * callData)
 #ifdef WINVER
 			w->mlink.orient = orient;
 #else
-			XtSetArg(arg[0], XtNorient, orient);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNorient, orient, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(orientSwitch, orient, True);
 #endif
@@ -728,8 +736,7 @@ CallbackMlink(Widget w, caddr_t clientData, mlinkCallbackStruct * callData)
 #ifdef WINVER
 			w->mlink.middle = middle;
 #else
-			XtSetArg(arg[0], XtNmiddle, middle);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNmiddle, middle, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(middleSwitch, middle, True);
 #endif
@@ -742,8 +749,7 @@ CallbackMlink(Widget w, caddr_t clientData, mlinkCallbackStruct * callData)
 #ifdef WINVER
 			w->mlink.tiles = tiles;
 #else
-			XtSetArg(arg[0], XtNtiles, tiles);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(tile, tiles);
 			if (tiles >= MAXTILES)
@@ -758,8 +764,7 @@ CallbackMlink(Widget w, caddr_t clientData, mlinkCallbackStruct * callData)
 #ifdef WINVER
 			w->mlink.tiles = tiles;
 #else
-			XtSetArg(arg[0], XtNtiles, tiles);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
 			if (tiles > MAXTILES)
 				XtVaSetValues(tile, XmNmaximum, tiles, NULL);
@@ -774,8 +779,7 @@ CallbackMlink(Widget w, caddr_t clientData, mlinkCallbackStruct * callData)
 #ifdef WINVER
 			w->mlink.faces = faces;
 #else
-			XtSetArg(arg[0], XtNfaces, faces);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNfaces, faces, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(face, faces);
 #endif
@@ -788,8 +792,7 @@ CallbackMlink(Widget w, caddr_t clientData, mlinkCallbackStruct * callData)
 #ifdef WINVER
 			w->mlink.faces = faces;
 #else
-			XtSetArg(arg[0], XtNfaces, faces);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNfaces, faces, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(face, faces);
 #endif
@@ -814,8 +817,8 @@ CallbackMlink(Widget w, caddr_t clientData, mlinkCallbackStruct * callData)
 				if (delay < 0)
 					delay = 0;
 				if (delay != oldDelay) {
-					XtSetArg(arg[0], XtNdelay, delay);
-					XtSetValues(w, arg, 1);
+					XtVaSetValues(w,
+						XtNdelay, delay, NULL);
 				}
 				XmScaleSetValue(speed,
 					MAXSPEED + MINSPEED - delay - 1);
@@ -823,17 +826,11 @@ CallbackMlink(Widget w, caddr_t clientData, mlinkCallbackStruct * callData)
 			return;
 #endif
 	}
-#ifdef HAVE_MOTIF
-	PrintState(message, messageDsp);
-	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-#else
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
-#endif
-		tiles, faces, middle, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp
+#ifndef HAVE_MOTIF
+		, tiles, faces, middle
 #endif
+		);
 }
 
 #ifdef WINVER
@@ -858,7 +855,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	PAINTSTRUCT paint;
 	static Boolean mousePressed = False;
 
-	Wnd = widget.core.hWnd = hWnd;
+	widget.core.hWnd = hWnd;
 	if (GetFocus()) {
 		if (!widget.mlink.focus) {
 			widget.core.hDC = GetDC(hWnd);
@@ -1141,24 +1138,7 @@ static void
 Usage(char * programName)
 {
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr,
-		"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n");
-	(void) fprintf(stderr,
-		"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n");
-	(void) fprintf(stderr,
-		"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{border|bd} {color}] [-tile {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-face{0|1|2|3|4|5|6|7} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-tiles {int}] [-faces {int}] [-[no]orient] [-[no]middle]\n");
-	(void) fprintf(stderr,
-		"\t[-[no]install] [-picture {filename}] [-delay msecs] [-[no]sound]\n");
-	(void) fprintf(stderr,
-		"\t[-bumpsound {filename}] [-movesound {filename}]\n");
-	(void) fprintf(stderr,
-		"\t[-base {int}] [-{font|fn} {fontname}] [-username {string}]\n");
+	(void) fprintf(stderr, optionsHelp);
 	exit(1);
 }
 
@@ -1197,12 +1177,15 @@ static XrmOptionDescRec options[] =
 	{(char *) "-delay", (char *) "*mlink.delay", XrmoptionSepArg, NULL},
 	{(char *) "-sound", (char *) "*mlink.sound", XrmoptionNoArg, (char *) "TRUE"},
 	{(char *) "-nosound", (char *) "*mlink.sound", XrmoptionNoArg, (char *) "FALSE"},
-	{(char *) "-bumpsound", (char *) "*mlink.bumpSound", XrmoptionSepArg, NULL},
-	{(char *) "-movesound", (char *) "*mlink.moveSound", XrmoptionSepArg, NULL},
+	{(char *) "-bumpSound", (char *) "*mlink.bumpSound", XrmoptionSepArg, NULL},
+	{(char *) "-moveSound", (char *) "*mlink.moveSound", XrmoptionSepArg, NULL},
 	{(char *) "-base", (char *) "*mlink.base", XrmoptionSepArg, NULL},
 	{(char *) "-fn", (char *) "*mlink.font", XrmoptionSepArg, NULL},
 	{(char *) "-font", (char *) "*mlink.font", XrmoptionSepArg, NULL},
-	{(char *) "-username", (char *) "*mlink.userName", XrmoptionSepArg, NULL}
+	{(char *) "-userName", (char *) "*mlink.userName", XrmoptionSepArg, NULL},
+	{(char *) "-scoreFile", (char *) "*mlink.scoreFile", XrmoptionSepArg, NULL},
+	{(char *) "-scores", (char *) "*mlink.scoreOnly", XrmoptionNoArg, (char *) "TRUE"},
+	{(char *) "-version", (char *) "*mlink.versionOnly", XrmoptionNoArg, (char *) "TRUE"}
 };
 
 #ifdef HAVE_MOTIF
@@ -1211,8 +1194,7 @@ CallbackMlinkPractice(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 9); /* menu choice */
-		XtSetValues(mlink, arg, 1);
+		XtVaSetValues(mlink, XtNmenu, 9, NULL); /* menu choice */
 	}
 }
 
@@ -1221,8 +1203,7 @@ CallbackMlinkRandomize(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-		XtSetValues(mlink, arg, 1);
+		XtVaSetValues(mlink, XtNmenu, 5, NULL); /* menu choice */
 	}
 }
 
@@ -1376,16 +1357,14 @@ fileCB(Widget w, void *value, void *clientData)
 
 	if (val == 2)
 		exit(0);
-	XtSetArg(arg[0], XtNmenu, val);
-	XtSetValues(mlink, arg, 1);
+	XtVaSetValues(mlink, XtNmenu, val, NULL);
 }
 
 static void
 playCB(Widget w, void *value, void *clientData)
 {
 	int val = (int) value;
-	XtSetArg(arg[0], XtNmenu, val + 3); /* GWQ */
-	XtSetValues(mlink, arg, 1);
+	XtVaSetValues(mlink, XtNmenu, val + 3, NULL); /* GWQ */
 }
 
 static Widget
@@ -1519,11 +1498,10 @@ main(int argc, char **argv)
 			RootWindowOfScreen(XtScreen(topLevel)),
 			(char *) mlink_bits,
 			mlink_width, mlink_height);
-	XtSetArg(arg[0], XtNiconPixmap, mlinkIcon);
 #ifdef HAVE_MOTIF
-	/* not XmEXPLICIT */
-	XtSetArg(arg[1], XmNkeyboardFocusPolicy, XmPOINTER);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, mlinkIcon,
+		XmNkeyboardFocusPolicy, XmPOINTER, NULL); /* not XmEXPLICIT */
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
 		xmPanedWindowWidgetClass, topLevel,
 		XmNseparatorOn, False,
@@ -1622,7 +1600,7 @@ main(int argc, char **argv)
 	solveDialog = createHelp(menuBar, (char *) solveHelp,
 		(char *) "Solve");
 	practiceDialog = createQuery(topLevel,
-		(char *) "Are you sure want to toggle the practice mode?",
+		(char *) "Are you sure you want to toggle the practice mode?",
 		(char *) "Practice Query",
 		(XtCallbackProc) CallbackMlinkPractice);
 	randomizeDialog = createQuery(topLevel,
@@ -1760,8 +1738,9 @@ main(int argc, char **argv)
 	mlink = XtCreateManagedWidget("mlink",
 		mlinkWidgetClass, mainPanel, NULL, 0);
 #else
-	XtSetArg(arg[1], XtNinput, True);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, mlinkIcon,
+		XtNinput, True, NULL);
 	mlink = XtCreateManagedWidget("mlink",
 		mlinkWidgetClass, topLevel, NULL, 0);
 #endif
