@@ -25,6 +25,8 @@
 
 /* Methods file for Oct */
 
+#include "file.h"
+#include "rngs.h"
 #include "OctP.h"
 
 #ifdef WINVER
@@ -212,15 +214,18 @@ static XtActionsRec actionsListOct[] =
 static XtResource resourcesOct[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(OctWidget, oct.username),
-	 XtRString, (caddr_t) "nobody"},
+	 XtOffset(OctWidget, oct.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(OctWidget, oct.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(OctWidget, oct.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(OctWidget, oct.background),
 	 XtRString, (caddr_t) XtDefaultBackground},
-	{XtNframeColor, XtCForeground, XtRPixel, sizeof (Pixel),
+	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(OctWidget, oct.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
 	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
@@ -287,6 +292,12 @@ static XtResource resourcesOct[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(OctWidget, oct.cheat),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(OctWidget, oct.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(OctWidget, oct.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(OctWidget, oct.menu),
 	 XtRString, (caddr_t) "-1"},
@@ -363,13 +374,13 @@ loadFont(OctWidget w)
 	if ((w->oct.fontInfo = XLoadQueryFont(display,
 			w->oct.font)) == NULL) {
 		(void) sprintf(buf,
-			"Cannot open %s font.\nAttempting %s font as alternate\n",
+			"Can not open %s font.\nAttempting %s font as alternate\n",
 			w->oct.font, altfontname);
 		DISPLAY_WARNING(buf);
 		if ((w->oct.fontInfo = XLoadQueryFont(display,
 				altfontname)) == NULL) {
 			(void) sprintf(buf,
-				"Cannot open %s alternate font.\nUse the -font option to specify a font to use.\n",
+				"Can not open %s alternate font.\nUse the -font option to specify a font to use.\n",
 				altfontname);
 			DISPLAY_WARNING(buf);
 		}
@@ -565,23 +576,7 @@ static Point triangleUnit[MAXSIDES][4] =
 };
 static Point triangleList[MAXSIDES][4], letterList[MAXSIDES];
 
-void
-intCat(char ** string, const char * var1, const int var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + 21))) {
-        	DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%d", var1, var2);
-}
-
-void
-stringCat(char ** string, const char * var1, const char * var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + strlen(var2) + 1))) {
-        	DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%s", var1, var2);
-}
+static Pixmap dr = 0; /* dummy for future double buffering */
 
 static void
 CheckPieces(OctWidget w)
@@ -719,45 +714,6 @@ Length(OctWidget w, int dir, int h)
 		return (2 * (w->oct.size - h) - 1);
 }
 
-#ifdef WINVER
-static void
-POLYGON(OctWidget w, GC color, GC lineColor, const POINT * poly, int n,
-		Boolean origin)
-{
-	/* CoordModePrevious -> CoordModeOrigin */
-	POINT *temp = NULL;
-	int pt;
-
-	if (!origin) {
-		if (!(temp = (POINT *) malloc(sizeof (POINT) * n))) {
-			DISPLAY_ERROR("Not enough memory, exiting.");
-		}
-		temp[0] = poly[0];
-		for (pt = 1; pt < n; pt++) {
-			temp[pt].x = temp[pt - 1].x + poly[pt].x,
-			temp[pt].y = temp[pt - 1].y + poly[pt].y;
-		}
-	}
-	w->oct.hPen = CreatePen(PS_SOLID, 1, lineColor);
-	w->oct.hOldPen = (HPEN) SelectObject(w->core.hDC, w->oct.hPen);
-	w->oct.hBrush = CreateSolidBrush(color);
-	w->oct.hOldBrush = (HBRUSH) SelectObject(w->core.hDC, w->oct.hBrush);
-	(void) Polygon(w->core.hDC, (origin) ? poly : temp, n);
-	(void) SelectObject(w->core.hDC, w->oct.hOldBrush);
-	(void) DeleteObject(w->oct.hBrush);
-	(void) SelectObject(w->core.hDC, w->oct.hOldPen);
-	(void) DeleteObject(w->oct.hPen);
-	if (!origin) {
-		free(temp);
-	}
-}
-#else
-#define POLYGON(w,c,lc,l,n,o) XFillPolygon(XtDisplay(w), XtWindow(w), c, \
-  l, n, Convex, (o) ? CoordModeOrigin : CoordModePrevious); \
-  XDrawLines(XtDisplay(w), XtWindow(w), lc, \
-  l, (n)+1,(o) ? CoordModeOrigin : CoordModePrevious)
-#endif
-
 static void
 DrawOrientLine(OctWidget w, int orient, int face, int side, int dx, int dy,
 		GC borderGC)
@@ -847,7 +803,7 @@ DrawOrientLine(OctWidget w, int orient, int face, int side, int dx, int dy,
 				free(buf);
 			}
 	}
-	DRAWLINE(w, borderGC, x_1, y_1, x_2, y_2);
+	DRAWLINE(w, dr, borderGC, x_1, y_1, x_2, y_2);
 }
 
 static void
@@ -943,7 +899,7 @@ DrawTriangle(OctWidget w, int face, int position, int offset)
 		faceGC = w->oct.faceGC[w->oct.facetLoc[face][position].face];
 		borderGC = w->oct.borderGC;
 	}
-	POLYGON(w, faceGC, borderGC, triangleList[side], 3, False);
+	POLYGON(w, dr, faceGC, borderGC, triangleList[side], 3, True, False);
 	if (w->oct.mono) {
 		int letterX, letterY;
 		char buf[2];
@@ -964,7 +920,7 @@ DrawTriangle(OctWidget w, int face, int position, int offset)
 		} else {
 			borderGC = w->oct.inverseGC;
 		}
-		DRAWTEXT(w, borderGC, letterX, letterY, buf, 1);
+		DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, 1);
 	}
 	if (w->oct.orient)
 		DrawOrientLine(w, w->oct.facetLoc[face][position].rotation, faceOnView,
@@ -984,7 +940,7 @@ DrawAllPieces(OctWidget w)
 static void
 EraseFrame(const OctWidget w)
 {
-	FILLRECTANGLE(w, w->oct.inverseGC,
+	FILLRECTANGLE(w, dr, w->oct.inverseGC,
 		0, 0, w->core.width, w->core.height);
 }
 
@@ -999,43 +955,43 @@ DrawFrame(OctWidget w, Boolean focus)
 	starty = 1 + w->oct.puzzleOffset.y;
 	lengthx = w->oct.viewLength - w->oct.delta + w->oct.puzzleOffset.x;
 	lengthy = w->oct.viewLength - w->oct.delta + w->oct.puzzleOffset.y;
-	DRAWLINE(w, gc, startx, starty, lengthx, starty);
-	DRAWLINE(w, gc, startx, starty, startx, lengthy);
-	DRAWLINE(w, gc, startx, lengthy, lengthx, starty);
-	DRAWLINE(w, gc, startx, starty, lengthx, lengthy);
+	DRAWLINE(w, dr, gc, startx, starty, lengthx, starty);
+	DRAWLINE(w, dr, gc, startx, starty, startx, lengthy);
+	DRAWLINE(w, dr, gc, startx, lengthy, lengthx, starty);
+	DRAWLINE(w, dr, gc, startx, starty, lengthx, lengthy);
 	if (w->oct.vertical) {
 		longlength = 2 * w->oct.viewLength - 2 * w->oct.delta - 1 +
 			w->oct.puzzleOffset.y;
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			startx, lengthy, startx, longlength);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			lengthx, lengthy, lengthx, longlength);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			startx, longlength, lengthx, longlength);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			startx, longlength, lengthx, lengthy);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			startx, lengthy, lengthx, longlength);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			lengthx, starty, lengthx, lengthy);
-		DRAWLINE(w, w->oct.frameGC,
+		DRAWLINE(w, dr, w->oct.frameGC,
 			0, lengthy, (int) w->core.width, lengthy);
 	} else {
 		longlength = 2 * w->oct.viewLength - 2 * w->oct.delta - 1 +
 			w->oct.puzzleOffset.x;
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			lengthx, starty, longlength, starty);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			lengthx, lengthy, longlength, lengthy);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			longlength, starty, longlength, lengthy);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			longlength, starty, lengthx, lengthy);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			lengthx, starty, longlength, lengthy);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			startx, lengthy, lengthx, lengthy);
-		DRAWLINE(w, w->oct.frameGC,
+		DRAWLINE(w, dr, w->oct.frameGC,
 			lengthx, 0, lengthx, (int) w->core.height);
 	}
 }
@@ -1639,13 +1595,13 @@ ResetPieces(OctWidget w)
 	w->oct.sizeSize = w->oct.size * w->oct.size;
 	for (face = 0; face < MAXFACES; face++) {
 		if (w->oct.facetLoc[face])
-			(void) free((void *) w->oct.facetLoc[face]);
+			free(w->oct.facetLoc[face]);
 		if (!(w->oct.facetLoc[face] = (OctLoc *)
 				malloc(sizeof (OctLoc) * w->oct.sizeSize))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 		if (startLoc[face])
-			(void) free((void *) startLoc[face]);
+			free(startLoc[face]);
 		if (!(startLoc[face] = (OctLoc *)
 				malloc(sizeof (OctLoc) * w->oct.sizeSize))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
@@ -1653,14 +1609,14 @@ ResetPieces(OctWidget w)
 	}
 	for (orient = 0; orient < MAXORIENT / 2; orient++) {
 		if (w->oct.rowLoc[orient])
-			(void) free((void *) w->oct.rowLoc[orient]);
+			free(w->oct.rowLoc[orient]);
 		if (!(w->oct.rowLoc[orient] = (OctLoc *)
 				malloc(sizeof (OctLoc) * (2 * w->oct.size - 1)))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
 	if (w->oct.faceLoc)
-		(void) free((void *) w->oct.faceLoc);
+		free(w->oct.faceLoc);
 	if (!(w->oct.faceLoc = (OctLoc *)
 			malloc(sizeof (OctLoc) * w->oct.sizeSize))) {
 		DISPLAY_ERROR("Not enough memory, exiting.");
@@ -2109,11 +2065,14 @@ SetValuesOct(OctWidget w)
 			szBuf, sizeof (szBuf), INIFILE);
 		w->oct.faceChar[face] = szBuf[0];
 	}
-	(void) GetPrivateProfileString(SECTION, "name", "Guest",
+	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
 		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->oct.username, szBuf);
-		w->oct.username[80] = 0;
-
+	(void) strcpy(w->oct.userName, szBuf);
+		w->oct.userName[80] = 0;
+	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
+		szBuf, sizeof (szBuf), INIFILE);
+	(void) strcpy(w->oct.scoreFile, szBuf);
+		w->oct.scoreFile[80] = 0;
 }
 
 void
