@@ -37,6 +37,7 @@
 #ifndef WINVER
 #define XtNselectCallback ((char *) "selectCallback")
 #define XtNuserName ((char *) "userName")
+#define XtNscoreFile ((char *) "scoreFile")
 #define XtNmono ((char *) "mono")
 #define XtNreverse ((char *) "reverse")
 #define XtNsize ((char *) "size")
@@ -57,7 +58,10 @@
 #define XtNfaceColor5 ((char *) "faceColor5")
 #define XtNfaceColor6 ((char *) "faceColor6")
 #define XtNfaceColor7 ((char *) "faceColor7")
+#define XtNscoreOnly ((char *) "scoreOnly")
+#define XtNversionOnly ((char *) "versionOnly")
 #define XtCUserName ((char *) "UserName")
+#define XtCScoreFile ((char *) "ScoreFile")
 #define XtCMono ((char *) "Mono")
 #define XtCReverse ((char *) "Reverse")
 #define XtCSize ((char *) "Size")
@@ -100,23 +104,6 @@ typedef struct {
 #define OCT_COMPUTED 12
 #define OCT_UNDO 13
 
-#ifdef WINVER
-#ifdef UNIXDELIM
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#else
-#define CURRENTDELIM ".\\"
-#define FINALDELIM "\\"
-#endif
-#else
-#ifdef VMS
-#define CURRENTDELIM "[]"
-#define FINALDELIM ""
-#else
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#endif
-#endif
 #define MINFACETS 1
 #define PERIOD3 3
 #define PERIOD4 4
@@ -136,8 +123,5 @@ typedef struct {
 
 typedef struct _OctRec *OctWidget;
 
-extern void intCat(char ** string, const char * var1, const int var2);
-extern void stringCat(char ** string, const char * var1, const char * var2);
-
 #endif /* _XtOct_h */
 /* DON'T ADD STUFF AFTER THIS #endif */
