@@ -32,38 +32,25 @@
   Version 1: 91/06/10 SunView
 */
 
+#include "file.h"
 #ifdef WINVER
 #include "OctP.h"
 #include "woct.h"
 #define TITLE "woct"
 
 static OctRec widget;
-static HWND Wnd;
 
 #ifndef SCOREPATH
-#define SCOREPATH "c:\\Windows"
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
 #endif
-#define PRINT_MESSAGE(b) (void) MessageBox(Wnd, (LPCSTR) b, "Warning", MB_OK);
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
 #define SET_STARTED(w,b) w->oct.started = b
 #else
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
-#ifdef VMS
-#include <unixlib.h>
-#define getlogin() cuserid(NULL)
-#else
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif
-#if HAVE_FCNTL_H
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#endif
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
+#include "xwin.h"
 #include <X11/Shell.h>
 #include <X11/cursorfont.h>
 #ifdef HAVE_MOTIF
@@ -85,7 +72,7 @@ static HWND Wnd;
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
-#define SET_STARTED(w,b) XtSetArg(arg[0], XtNstart, b); XtSetValues(w, arg, 1)
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
 #include "Oct.h"
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
@@ -93,28 +80,35 @@ static HWND Wnd;
 #endif
 #include "icons/oct.xbm"
 #ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
 #define SCOREPATH "/var/games/xpuzzles"
 #endif
 #endif
+#endif
 
-#ifdef HAVE_MOTIF
+#ifndef WINVER
 static const char aboutHelp[] = {
-	"Version 7.1.3\n"
+	"Oct Version 7.1.5\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
 	"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
+
 static const char optionsHelp[] = {
-	"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]] "
-	"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"[-{foreground|fg} {color}] [-{background|bg} {color}] "
-	"[-{border|bd} {color}] [-face{0|1|2|3|4|5|6|7} {color}]\n"
-	"[-{size {int} | sticky}] [-{mode {int} | both}] "
-	"[-[no]orient] [-[no]practice] [-{font|fn} {fontname}]\n"
-	"[-username {string}]\n"
+	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+	"\t[-{border|bd} {color}] [-face{0|1|2|3|4|5|6|7} {color}]\n"
+	"\t[-{size {int} | sticky}] [-{mode {int} | both}]\n"
+	"\t[-[no]orient] [-[no]practice] [-{font|fn} {fontname}]\n"
+	"\t[-userName {string}] [-scoreFile {filename}] [-scores]\n"
+	"\t[-version]\n"
 };
 #endif
+
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
 	"The original puzzle has 9 triangles per face (size = 3) "
@@ -137,21 +131,27 @@ static const char descriptionHelp[] = {
 	"simulate one with variant turning (period 4 turning and "
 	"sticky mode).\n"
 };
+
 static const char featuresHelp[] = {
 	"Press \"mouse-left\" button to move a piece.  Release "
 	"\"mouse-left\" button on a piece on the same face and\n"
 	"in the same row (but not an adjacent piece or the move "
 	"is ambiguous).  The pieces will then turn towards\n"
 	"where the mouse button was released.\n"
+	"\n"
 	"Click \"mouse-center\" button, or press \"P\" or \"p\" "
 	"keys, to toggle the practice mode (in practice mode the\n"
 	"record should say \"practice\").  This is good for learning "
 	"moves and experimenting.\n"
+	"\n"
 	"Click \"mouse-right\" button, or press \"R\" or \"r\" "
 	"keys, to randomize the puzzle (this must be done first\n"
 	"to set a new record).\n"
+	"\n"
 	"Press \"I\" or \"i\" keys to increase the number of \"facets\".\n"
+	"\n"
 	"Press \"D\" or \"d\" keys to decrease the number of \"facets\".\n"
+	"\n"
 	"Press \"O\" or \"o\" keys to toggle the orient mode.  One "
 	"has to orient the faces in orient mode, besides\n"
 	"getting all the faces to be the same color.  To do this "
@@ -160,8 +160,10 @@ static const char featuresHelp[] = {
 	"\"facets\", if at all (i.e. those \"cubies\" not on a\n"
 	"corner or edge).  This does add complexity so there are "
 	"2 sets of records.\n"
+	"\n"
 	"Press \"3\", \"4\", \"B\", or \"b\" keys (not the keypad 3, 4) "
 	"to change modes to Period 3, Period 4, or Both.\n"
+	"\n"
 	"Press \"Y\" or \"y\" keys to toggle sticky mode (increase/decrease "
 	"is disabled here if sticky mode is on).\n"
 	"\"Sticky\" and \"Period 3\" turning allows only the faces to "
@@ -172,13 +174,22 @@ static const char featuresHelp[] = {
 	"did not exist.\n"
 	"Beware, the \"Sticky\" mode is a hack and much could be done "
 	"to improve its look.\n"
+	"\n"
 	"Press \"S\" or \"s\" keys reserved for the auto-solver "
 	"(not implemented).\n"
+	"\n"
 	"Press \"U\" or \"u\" keys to undo a move.\n"
+	"\n"
 	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+	"\n"
 	"Press \"W\" or \"w\" keys to save a puzzle.\n"
+	"\n"
+	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+	"\n"
 	"Press \"Esc\" key to hide program.\n"
+	"\n"
 	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+	"\n"
 	"Use the key pad, \"R\" keys, or arrow keys to move without "
 	"mouse clicks.\n"
 	"Key pad is defined for Oct as:\n"
@@ -188,6 +199,7 @@ static const char featuresHelp[] = {
 	"4<5>6  Left, Clockwise, Right\n"
 	"  v\n"
 	"1 2 3  Lower Left, Down\n"
+	"\n"
 	"Use the shift keys to access \"Period 4\" turns from "
 	"\"Both\" mode, otherwise it assumes \"Period 3\" turning.\n"
 	"Points turn in \"Period 4\" and faces turn in \"Period 3\".\n"
@@ -195,6 +207,7 @@ static const char featuresHelp[] = {
 	"arrow keys to move the whole octahedron.  This is not\n"
 	"recorded as a turn.\n"
 };
+
 static const char referencesHelp[] = {
 	"Beyond Rubik's Cube: spheres, pyramids, dodecahedrons and "
 	"God knows what else by Douglas R. Hofstadter,\n"
@@ -202,6 +215,7 @@ static const char referencesHelp[] = {
 	"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow.\n"
 };
 #endif
+
 static const char solveHelp[] = {
 	"Auto-solver: sorry, not implemented.\n"
 };
@@ -211,7 +225,7 @@ static const char solveHelp[] = {
 #endif
 
 #define MAXFACETS 6
-#define NEVER -1
+#define NEVER (-1)
 #define FILENAMELEN 1024
 #define USERNAMELEN 120
 #define MESSAGELEN (USERNAMELEN+64)
@@ -231,8 +245,8 @@ static char recordDsp[MESSAGELEN] = "NOT RECORDED";
 static int oldSize;
 
 #ifdef HAVE_MOTIF
-static Widget moves, record, message, modes[MAXMODES], orientSwitch,
-	stickySwitch, practiceSwitch, facets;
+static Widget moves, record, message, modes[MAXMODES], orientSwitch;
+static Widget stickySwitch, practiceSwitch, facets;
 static char buff[21];
 static const char *modeString[] =
 {
@@ -241,20 +255,21 @@ static const char *modeString[] =
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
+static Arg arg[3];
 #else
 static char titleDsp[TITLELEN] = "";
 #endif
+static char scoreFileName[FILENAMELEN] = SCOREFILE;
+static char fileName[FILENAMELEN];
 #ifdef WINVER
 #define MAXPROGNAME 80
 static char progDsp[MAXPROGNAME] = TITLE;
-static char usernameDsp[USERNAMELEN] = "Guest";
+static char userNameDsp[USERNAMELEN] = "Guest";
 #else
 static Pixmap octIcon = None;
 static Widget topLevel, oct;
-static Arg arg[5];
 static char *progDsp;
-static char usernameDsp[USERNAMELEN] = "";
-#endif
+static char userNameDsp[USERNAMELEN] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -265,35 +280,26 @@ PrintState(Widget w, char *msg)
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
 		XtError("PrintState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
-	XtSetArg(arg[0], XmNlabelString, xmstr);
-	XtSetValues(w, arg, 1);
+	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
-#else
-static void
-PrintState(
-#ifndef WINVER
-Widget w,
 #endif
-int mode, int size, Boolean sticky, int moves, char *msg)
-{
-	char ss[10], mb[10];
 
-	if (sticky)
-		(void) strcpy(ss, "sticky");
-	else
-		(void) sprintf(ss, "%d", size);
-	if (mode == BOTH)
-		(void) strcpy(mb, "both");
-	else
-		(void) sprintf(mb, "%d", mode);
-	(void) sprintf(titleDsp, "%s.%s: %s@ (%d/%s) - %s",
-		progDsp, mb, ss, moves, recordDsp, msg);
-#ifdef WINVER
-	SetWindowText(Wnd, (LPSTR) titleDsp);
-#else
-	XtSetArg(arg[0], XtNtitle, titleDsp);
-	XtSetValues(w, arg, 1);
-#endif
+static void
+PrintRecords(void)
+{
+	int i, mode, orient;
+
+	(void) printf("                 OCT  HALL OF FAME\n\n");
+	(void) printf("MODE ORIENT FACET USER            MOVES\n");
+	for (mode = 0; mode < MAXMODES; mode++)
+		for (orient = 0; orient < 2; orient++)
+			for (i = 0; i <= MAXFACETS - MINFACETS + 1; i++) {
+				if (octRecord[mode][orient][i].score > 0)
+					(void) printf("%4d%7d%6d %-12s%9d\n",
+						mode + 3, orient, i + 1, 
+						octRecord[mode][orient][i].name,
+						octRecord[mode][orient][i].score);
+			}
 }
 #endif
 
@@ -316,21 +322,21 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, n, mode, orient;
-	char username[USERNAMELEN];
+	char userName[USERNAMELEN];
 	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *fname, *lname;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
+	stringCat(&buf1, CURRENTDELIM, scoreFileName);
 	lname = buf1;
 	stringCat(&buf1, SCOREPATH, FINALDELIM);
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "r")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "r")) == NULL) {
+	(void) strncpy(fileName, lname, USERNAMELEN);
+	if ((fp = fopen(fileName, "r")) == NULL) {
+		(void) strncpy(fileName, fname, USERNAMELEN);
+		/* Try installed directory. */
+		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
@@ -360,12 +366,12 @@ ReadRecords(void)
 	for (mode = 0; mode < MAXMODES; mode++)
 		for (orient = 0; orient < 2; orient++)
 			for (i = 0; i <= MAXFACETS - MINFACETS + 1; i++) {
-				(void) fscanf(fp, "%d %s\n", &n, username);
+				(void) fscanf(fp, "%d %s\n", &n, userName);
 				if (n <= octRecord[mode][orient][i].score ||
-				    octRecord[mode][orient][i].score <= NEVER) {
+						octRecord[mode][orient][i].score <= NEVER) {
 					octRecord[mode][orient][i].score = n;
 					(void) strncpy(octRecord[mode][orient][i].name,
-						username, USERNAMELEN);
+						userName, USERNAMELEN);
 				}
 			}
 	(void) fclose(fp);
@@ -376,61 +382,31 @@ WriteRecords(void)
 {
 	FILE *fp;
 	int i, mode, orient;
-	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *buf1 = NULL;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
-	lname = buf1;
-	stringCat(&buf1, SCOREPATH, FINALDELIM);
-	stringCat(&buf2, buf1, SCOREFILE);
-	free(buf1);
-	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "w")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "w")) == NULL) {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, " or ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-			free(lname);
-			free(fname);
-			return;
-		}
-/* Probably annoying */
-#if 0
-		else {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, ", falling back to ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-		}
-#endif
+	if ((fp = fopen(fileName, "w")) == NULL) {
+		stringCat(&buf1, "Can not write to ", fileName);
+		PRINT_MESSAGE(buf1);
+		free(buf1);
+		return;
 	}
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockfile[FILENAMELEN];
+		char lockFile[FILENAMELEN];
 
-		(void) strncpy(lockfile, name, FILENAMELEN - 6);
-		(void) strcat(lockfile, ".lock");
-		while (((lfd = open(lockfile, O_CREAT | O_EXCL, 0644)) < 0) &&
+		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strcat(lockFile, ".lock");
+		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
 			(void) sleep(1);
 		if (lfd < 0) {
 #if 1
 			(void) fprintf(stderr,
-			  "Lock file exists... guessing its an old one.\n");
+				"Lock file exists... guessing its an old one.\n");
 #else
 			(void) fprintf(stderr,
-			  "Lock file exists... score not recorded - sorry.\n");
+				"Lock file exists... score not recorded - sorry.\n");
 			return;
 #endif
 		}
@@ -446,26 +422,25 @@ WriteRecords(void)
 		}
 #if HAVE_FCNTL_H
 		(void) close(lfd);
-		(void) unlink(lockfile);
+		(void) unlink(lockFile);
 #endif
 		(void) fclose(fp);
 	}
-	free(lname);
-	free(fname);
 }
 
 static void
-PrintRecord(int size, int mode, Boolean orient, Boolean sticky, Boolean practice)
+PrintRecord(int size, int mode,
+		Boolean orient, Boolean sticky, Boolean practice)
 {
 	int i = mode - PERIOD3;
 	int j = (orient) ? 1 : 0;
 	int k = (sticky) ? MAXFACETS - MINFACETS + 1 : size - MINFACETS;
 
-	if (practice)
+	if (practice) {
 		(void) strncpy(recordDsp, "practice", MESSAGELEN);
-	else if (!sticky && size > MAXFACETS)
+	} else if (!sticky && size > MAXFACETS) {
 		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
-	else if (octRecord[i][j][k].score <= NEVER) {
+	} else if (octRecord[i][j][k].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
 		(void) sprintf(recordDsp, "%d %s",
@@ -476,6 +451,38 @@ PrintRecord(int size, int mode, Boolean orient, Boolean sticky, Boolean practice
 #endif
 }
 
+static void
+PrintStatus(char *msg, int nMoves
+#ifndef HAVE_MOTIF
+		, int mode, int size, Boolean sticky
+#endif
+		)
+{
+#ifdef HAVE_MOTIF
+	PrintState(message, msg);
+	(void) sprintf(buff, "%d", nMoves);
+	PrintState(moves, buff);
+#else
+	char ss[10], mb[10];
+
+	if (sticky)
+		(void) strcpy(ss, "sticky");
+	else
+		(void) sprintf(ss, "%d", size);
+	if (mode == BOTH)
+		(void) strcpy(mb, "both");
+	else
+		(void) sprintf(mb, "%d", mode);
+	(void) sprintf(titleDsp, "%s.%s: %s@ (%d/%s) - %s",
+		progDsp, mb, ss, nMoves, recordDsp, msg);
+#ifdef WINVER
+	SetWindowText(widget.core.hWnd, (LPSTR) titleDsp);
+#else
+	XtVaSetValues(XtParent(oct), XtNtitle, titleDsp, NULL);
+#endif
+#endif
+}
+
 static Boolean
 HandleSolved(int counter, int size, int mode, Boolean orient, Boolean sticky)
 {
@@ -483,16 +490,18 @@ HandleSolved(int counter, int size, int mode, Boolean orient, Boolean sticky)
 	int j = (orient) ? 1 : 0;
 	int k = (sticky) ? MAXFACETS - MINFACETS + 1 : size - MINFACETS;
 
-	if ((sticky || size <= MAXFACETS) && (counter < octRecord[i][j][k].score ||
-	    octRecord[i][j][k].score <= NEVER)) {
+	if ((sticky || size <= MAXFACETS) &&
+			(counter < octRecord[i][j][k].score ||
+	    		octRecord[i][j][k].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		octRecord[i][j][k].score = counter;
-		(void) strncpy(octRecord[i][j][k].name, usernameDsp, USERNAMELEN);
-		if ((size < 2 && mode != PERIOD4) || (size < 4 && mode == PERIOD4) ||
-		    (orient && (counter < octRecord[i][!j][k].score ||
-		    octRecord[i][!j][k].score <= NEVER))) {
+		(void) strncpy(octRecord[i][j][k].name, userNameDsp, USERNAMELEN);
+		if ((size < 2 && mode != PERIOD4) ||
+				(size < 4 && mode == PERIOD4) || (orient &&
+				(counter < octRecord[i][!j][k].score ||
+				octRecord[i][!j][k].score <= NEVER))) {
 			octRecord[i][!j][k].score = counter;
-			(void) strncpy(octRecord[i][!j][k].name, usernameDsp,
+			(void) strncpy(octRecord[i][!j][k].name, userNameDsp,
 				USERNAMELEN);
 		}
 		WriteRecords();
@@ -513,7 +522,7 @@ Widget w
 {
 	int size, mode;
 	Boolean orient, sticky, practice;
-	char *username;
+	char *userName, *scoreFile;
 
 #ifdef WINVER
 	InitializeOct(w, brush);
@@ -523,15 +532,35 @@ Widget w
 	orient = w->oct.orient;
 	sticky = w->oct.sticky;
 	practice = w->oct.practice;
-	username = w->oct.username;
+	userName = w->oct.userName;
+	scoreFile = w->oct.scoreFile;
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
 #else
+	Boolean scoreOnly, versionOnly;
+
 	XtVaGetValues(w,
-		XtNuserName, &username,
+		XtNuserName, &userName,
+		XtNscoreFile, &scoreFile,
 		XtNsize, &size,
 		XtNmode, &mode,
 		XtNorient, &orient,
 		XtNsticky, &sticky,
-		XtNpractice, &practice, NULL);
+		XtNpractice, &practice,
+		XtNscoreOnly, &scoreOnly,
+		XtNversionOnly, &versionOnly, NULL);
+	if (versionOnly) {
+		(void) printf(aboutHelp);
+		exit(0);
+	}
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+	if (scoreOnly) {
+		InitRecords();
+		ReadRecords();
+		PrintRecords();
+		exit(0);
+	}
 #ifdef HAVE_MOTIF
 	if (size > MAXFACETS)
 		XtVaSetValues(facets, XmNmaximum, size, NULL);
@@ -546,32 +575,30 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(usernameDsp, username, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #endif
-	if (!strcmp(username, "") || !strcmp(username, "(null)") ||
-	    !strcmp(username, NOACCESS) || !strcmp(username, NOBODY)) {
+	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
+			!strcmp(userName, NOACCESS) ||
+			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(usernameDsp, username, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		/* The NOACCESS is not necessary, but it may stop silliness. */
-		(void) sprintf(usernameDsp, "%s", getlogin());
-		if (!strcmp(usernameDsp, "") ||
-				!strcmp(usernameDsp, "(null)") ||
-				!strcmp(usernameDsp, NOACCESS) ||
-				!strcmp(usernameDsp, NOBODY))
+		(void) sprintf(userNameDsp, "%s", getlogin());
+		if (!strcmp(userNameDsp, "") ||
+				!strcmp(userNameDsp, "(null)") ||
+				!strcmp(userNameDsp, NOACCESS) ||
+				!strcmp(userNameDsp, NOBODY))
 			/* It really IS nobody */
-			(void) sprintf(usernameDsp, "%s", "guest");
+			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
 	PrintRecord(size, mode, orient, sticky, practice);
 	oldSize = size;
+	PrintStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
-#endif
-		mode, size, sticky, movesDsp, messageDsp);
+		, mode, size, sticky
 #endif
+		);
 }
 
 #ifdef WINVER
@@ -622,16 +649,15 @@ CallbackOct(Widget w, caddr_t clientData, octCallbackStruct * callData)
 #ifdef HAVE_MOTIF
 			XtManageChild(practiceDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 11); /* menu choice */
-			XtSetValues(oct, arg, 1);
+			XtVaSetValues(oct,
+				XtNmenu, 11, NULL); /* menu choice */
 #endif
 			break;
 		case OCT_RANDOMIZE_QUERY:
 #ifdef HAVE_MOTIF
 			XtManageChild(randomizeDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-			XtSetValues(oct, arg, 1);
+			XtVaSetValues(oct, XtNmenu, 5, NULL); /* menu choice */
 #endif
 			break;
 #endif
@@ -649,7 +675,8 @@ CallbackOct(Widget w, caddr_t clientData, octCallbackStruct * callData)
 			break;
 		case OCT_RESTORE:
 			if (practice) {
-				(void) strncpy(recordDsp, "practice", MESSAGELEN);
+				(void) strncpy(recordDsp, "practice",
+					MESSAGELEN);
 #ifdef HAVE_MOTIF
 				PrintState(record, recordDsp);
 #endif
@@ -660,7 +687,8 @@ CallbackOct(Widget w, caddr_t clientData, octCallbackStruct * callData)
 			movesDsp = 0;
 			break;
 		case OCT_AMBIGUOUS:
-			(void) strncpy(messageDsp, "Ambiguous move", MESSAGELEN);
+			(void) strncpy(messageDsp, "Ambiguous move",
+				MESSAGELEN);
 			break;
 		case OCT_ILLEGAL:
 			if (practice || start)
@@ -681,12 +709,13 @@ CallbackOct(Widget w, caddr_t clientData, octCallbackStruct * callData)
 				movesDsp = 0;
 			else if (cheat)
 				(void) sprintf(messageDsp,
-					"No cheating %s!!", usernameDsp);
+					"No cheating %s!!", userNameDsp);
 			else if (HandleSolved(movesDsp, size, mode, orient, sticky))
 				(void) sprintf(messageDsp,
-					"Congratulations %s!!", usernameDsp);
+					"Congratulations %s!!", userNameDsp);
 			else
-				(void) strncpy(messageDsp, "Solved!", MESSAGELEN);
+				(void) strncpy(messageDsp, "Solved!",
+					MESSAGELEN);
 			SET_STARTED(w, False);
 			break;
 		case OCT_PRACTICE:
@@ -700,9 +729,9 @@ CallbackOct(Widget w, caddr_t clientData, octCallbackStruct * callData)
 			w->oct.practice = practice;
 			w->oct.started = False;
 #else
-			XtSetArg(arg[0], XtNpractice, practice);
-			XtSetArg(arg[1], XtNstart, False);
-			XtSetValues(w, arg, 2);
+			XtVaSetValues(w,
+				XtNpractice, practice,
+				XtNstart, False, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(practiceSwitch, practice, True);
 #endif
@@ -711,12 +740,12 @@ CallbackOct(Widget w, caddr_t clientData, octCallbackStruct * callData)
 		case OCT_RANDOMIZE:
 			movesDsp = 0;
 #ifdef WINVER
-			w->oct.practice = practice;
+			w->oct.practice = False;
 			w->oct.started = False;
 #else
-			XtSetArg(arg[0], XtNpractice, False);
-			XtSetArg(arg[1], XtNstart, False);
-			XtSetValues(w, arg, 2);
+			XtVaSetValues(w,
+				XtNpractice, False,
+				XtNstart, False, NULL);
 #endif
 			break;
 		case OCT_DEC:
@@ -728,8 +757,7 @@ CallbackOct(Widget w, caddr_t clientData, octCallbackStruct * callData)
 #ifdef WINVER
 				w->oct.size = size;
 #else
-				XtSetArg(arg[0], XtNsize, size);
-				XtSetValues(w, arg, 1);
+				XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
 				XmScaleSetValue(facets, size);
 				if (size >= MAXFACETS)
@@ -745,8 +773,7 @@ CallbackOct(Widget w, caddr_t clientData, octCallbackStruct * callData)
 #ifdef WINVER
 			w->oct.orient = orient;
 #else
-			XtSetArg(arg[0], XtNorient, orient);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNorient, orient, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(orientSwitch, orient, True);
 #endif
@@ -761,8 +788,7 @@ CallbackOct(Widget w, caddr_t clientData, octCallbackStruct * callData)
 #ifdef WINVER
 				w->oct.size = size;
 #else
-				XtSetArg(arg[0], XtNsize, size);
-				XtSetValues(w, arg, 1);
+				XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
 				if (size > MAXFACETS)
 					XtVaSetValues(facets, XmNmaximum, size, NULL);
@@ -780,8 +806,7 @@ CallbackOct(Widget w, caddr_t clientData, octCallbackStruct * callData)
 #ifdef WINVER
 			w->oct.mode = mode;
 #else
-			XtSetArg(arg[0], XtNmode, mode);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNmode, mode, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(modes[mode - PERIOD3], True, True);
 #endif
@@ -799,9 +824,9 @@ CallbackOct(Widget w, caddr_t clientData, octCallbackStruct * callData)
 			w->oct.sticky = sticky;
 			w->oct.size = size;
 #else
-			XtSetArg(arg[0], XtNsticky, sticky);
-			XtSetArg(arg[1], XtNsize, size);
-			XtSetValues(w, arg, 2);
+			XtVaSetValues(w,
+				XtNsticky, sticky,
+				XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(stickySwitch, sticky, True);
 			XmScaleSetValue(facets, size);
@@ -816,17 +841,11 @@ CallbackOct(Widget w, caddr_t clientData, octCallbackStruct * callData)
 			SET_STARTED(w, True);
 			break;
 	}
-#ifdef HAVE_MOTIF
-	PrintState(message, messageDsp);
-	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-#else
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
-#endif
-		mode, size, sticky, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp
+#ifndef HAVE_MOTIF
+		, mode, size, sticky
 #endif
+		);
 }
 
 #ifdef WINVER
@@ -851,7 +870,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	PAINTSTRUCT paint;
 	int shift = 0;
 
-	Wnd = widget.core.hWnd = hWnd;
+	widget.core.hWnd = hWnd;
 	if (GetFocus()) {
 		if (!widget.oct.focus) {
 			widget.core.hDC = GetDC(hWnd);
@@ -1158,20 +1177,7 @@ static void
 Usage(char * programName)
 {
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr,
-		"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n");
-	(void) fprintf(stderr,
-		"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n");
-	(void) fprintf(stderr,
-		"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{border|bd} {color}] [-face{0|1|2|3|4|5|6|7} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{size {int} | sticky}] [-{mode {int} | both}]\n");
-	(void) fprintf(stderr,
-		"\t[-[no]orient] [-[no]practice] [-{font|fn} {fontname}]\n");
-	(void) fprintf(stderr,
-		"\t[-username {string}]\n");
+	(void) fprintf(stderr, optionsHelp);
 	exit(1);
 }
 
@@ -1207,7 +1213,10 @@ static XrmOptionDescRec options[] =
 	{(char *) "-nopractice", (char *) "*oct.practice", XrmoptionNoArg, (char *) "FALSE"},
 	{(char *) "-fn", (char *) "*oct.font", XrmoptionSepArg, NULL},
 	{(char *) "-font", (char *) "*oct.font", XrmoptionSepArg, NULL},
-	{(char *) "-username", (char *) "*oct.userName", XrmoptionSepArg, NULL}
+	{(char *) "-userName", (char *) "*oct.userName", XrmoptionSepArg, NULL},
+	{(char *) "-scoreFile", (char *) "*oct.scoreFile", XrmoptionSepArg, NULL},
+	{(char *) "-scores", (char *) "*oct.scoreOnly", XrmoptionNoArg, (char *) "TRUE"},
+	{(char *) "-version", (char *) "*oct.versionOnly", XrmoptionNoArg, (char *) "TRUE"}
 };
 
 #ifdef HAVE_MOTIF
@@ -1215,8 +1224,7 @@ static void
 CallbackOctPractice(Widget w, XtPointer clientData, XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 11); /* menu choice */
-		XtSetValues(oct, arg, 1);
+		XtVaSetValues(oct, XtNmenu, 11, NULL); /* menu choice */
 	}
 }
 
@@ -1224,8 +1232,7 @@ static void
 CallbackOctRandomize(Widget w, XtPointer clientData, XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-		XtSetValues(oct, arg, 1);
+		XtVaSetValues(oct, XtNmenu, 5, NULL); /* menu choice */
 	}
 }
 static void
@@ -1258,8 +1265,8 @@ FacetSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct * cbs)
 static void
 ModeToggle(Widget w, int mode, XmToggleButtonCallbackStruct * cbs)
 {
-	int         size;
-	Boolean     orient, sticky, practice;
+	int size;
+	Boolean orient, sticky, practice;
 
 	if (cbs->set) {
 		XtVaGetValues(oct,
@@ -1281,8 +1288,8 @@ ModeToggle(Widget w, int mode, XmToggleButtonCallbackStruct * cbs)
 static void
 OrientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct * cbs)
 {
-	int         size, mode;
-	Boolean     orient = cbs->set, sticky, practice;
+	int size, mode;
+	Boolean orient = cbs->set, sticky, practice;
 
 	XtVaGetValues(oct,
 		XtNsize, &size,
@@ -1303,7 +1310,7 @@ static void
 StickyToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct * cbs)
 {
 	int size, mode;
-	Boolean     orient, sticky = cbs->set, practice;
+	Boolean orient, sticky = cbs->set, practice;
 
 	XtVaGetValues(oct,
 		      XtNsize, &size,
@@ -1331,7 +1338,8 @@ StickyToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct * cbs)
 }
 
 static void
-PracticeToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct * cbs)
+PracticeToggle(Widget w, XtPointer clientData,
+		XmToggleButtonCallbackStruct * cbs)
 {
 	int size, mode;
 	Boolean orient, sticky, practice = cbs->set;
@@ -1362,16 +1370,15 @@ fileCB(Widget w, void *value, void *clientData)
 
 	if (val == 2)
 		exit(0);
-	XtSetArg(arg[0], XtNmenu, val);
-	XtSetValues(oct, arg, 1);
+	XtVaSetValues(oct, XtNmenu, val, NULL);
 }
 
 static void
 playCB(Widget w, void *value, void *clientData)
 {
 	int val = (int) value;
-	XtSetArg(arg[0], XtNmenu, val + 3); /* GWQ */
-	XtSetValues(oct, arg, 1);
+
+	XtVaSetValues(oct, XtNmenu, val + 3, NULL); /* GWQ */
 }
 
 static Widget
@@ -1452,7 +1459,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d\n", val);
+			intCat(&buf, "helpCB: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1506,11 +1513,10 @@ main(int argc, char **argv)
 			RootWindowOfScreen(XtScreen(topLevel)),
 			(char *) oct_bits,
 			oct_width, oct_height);
-	XtSetArg(arg[0], XtNiconPixmap, octIcon);
 #ifdef HAVE_MOTIF
-	/* not XmEXPLICIT */
-	XtSetArg(arg[1], XmNkeyboardFocusPolicy, XmPOINTER);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, octIcon,
+		XmNkeyboardFocusPolicy, XmPOINTER, NULL); /* not XmEXPLICIT */
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
 		xmPanedWindowWidgetClass, topLevel,
 		XmNseparatorOn, False,
@@ -1733,8 +1739,9 @@ main(int argc, char **argv)
 	oct = XtCreateManagedWidget("oct",
 		octWidgetClass, mainPanel, NULL, 0);
 #else
-	XtSetArg(arg[1], XtNinput, True);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, octIcon,
+		XtNinput, True, NULL);
 	oct = XtCreateManagedWidget("oct",
 		octWidgetClass, topLevel, NULL, 0);
 #endif
