@@ -25,10 +25,9 @@
 
 /* Methods file for Panex */
 
-#if defined(USE_RPLAY) || defined(USE_NAS) || defined(USE_VMSPLAY) || defined(USE_ESOUND) || defined(WINVER) || defined(DEF_PLAY)
-#define USE_SOUND
-extern void playSound(char * filename);
-#endif
+#include "file.h"
+#include "rngs.h"
+#include "sound.h"
 #include "PanexP.h"
 
 #ifdef WINVER
@@ -146,15 +145,18 @@ static XtActionsRec actionsListPanex[] =
 static XtResource resourcesPanex[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(PanexWidget, panex.username),
-	 XtRString, (caddr_t) "nobody"},
+	 XtOffset(PanexWidget, panex.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(PanexWidget, panex.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(PanexWidget, panex.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(PanexWidget, panex.background),
 	 XtRString, (caddr_t) XtDefaultBackground},
-	{XtNframeColor, XtCForeground, XtRPixel, sizeof (Pixel),
+	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(PanexWidget, panex.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
 	{XtNtileColor, XtCColor, XtRPixel, sizeof (Pixel),
@@ -205,6 +207,12 @@ static XtResource resourcesPanex[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(PanexWidget, panex.cheat),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(PanexWidget, panex.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(PanexWidget, panex.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(PanexWidget, panex.menu),
 	 XtRString, (caddr_t) "-1"},
@@ -255,78 +263,6 @@ PanexClassRec panexClassRec =
 
 WidgetClass panexWidgetClass = (WidgetClass) & panexClassRec;
 
-#ifndef HAVE_USLEEP
-#if !defined( VMS ) || defined( XVMSUTILS ) || ( __VMS_VER >= 70000000 )
-#ifdef USE_XVMSUTILS
-#include <X11/unix_time.h>
-#endif
-#if HAVE_SYS_TIME_H
-#include <sys/time.h>
-#else
-#if HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#endif
-#endif
-#endif
-#if defined(SYSV) || defined(SVR4)
-#ifdef LESS_THAN_AIX3_2
-#include <sys/poll.h>
-#else /* !LESS_THAN_AIX3_2 */
-#include <poll.h>
-#endif /* !LESS_THAN_AIX3_2 */
-#endif /* defined(SYSV) || defined(SVR4) */
-
-/* not static in case usleep found in system include */
-int
-usleep(unsigned int usec)
-{
-#if (defined (SYSV) || defined(SVR4)) && !defined(__hpux)
-#if defined(HAVE_NANOSLEEP)
-	{
-		struct timespec rqt;
-
-		rqt.tv_nsec = 1000 * (usec % (unsigned int) 1000000);
-		rqt.tv_sec = usec / (unsigned int) 1000000;
-		return nanosleep(&rqt, (struct timespec *) NULL);
-	}
-#else
-	(void) poll(
-#if defined(__cplusplus) || defined(c_plusplus)
-		(pollfd *) /* guess */
-#else
-		(void *)
-#endif
-		0, (int) 0, (usec / 1000));	/* ms resolution */
-#endif
-#else
-#ifdef VMS
-	long timadr[2];
-
-	if (usec != 0) {
-		timadr[0] = -usec * 10;
-		timadr[1] = -1;
-
-		sys$setimr(4, &timadr, 0, 0, 0);
-		sys$waitfr(4);
-	}
-#else
-	struct timeval time_out;
-
-#if 0
-	/* (!defined(AIXV3) && !defined(__hpux)) */
-	extern int select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
-
-#endif
-
-	time_out.tv_usec = usec % (unsigned int) 1000000;
-	time_out.tv_sec = usec / (unsigned int) 1000000;
-	(void) select(0, (void *) 0, (void *) 0, (void *) 0, &time_out);
-#endif
-#endif
-	return 0;
-}
-#endif
-
 void
 SetPanex(PanexWidget w, int reason)
 {
@@ -352,13 +288,13 @@ loadFont(PanexWidget w)
 	if ((w->panex.fontInfo = XLoadQueryFont(display,
 			w->panex.font)) == NULL) {
 		(void) sprintf(buf,
-			"Cannot open %s font.\nAttempting %s font as alternate\n",
+			"Can not open %s font.\nAttempting %s font as alternate\n",
 			w->panex.font, altfontname);
 		DISPLAY_WARNING(buf);
 		if ((w->panex.fontInfo = XLoadQueryFont(display,
 				altfontname)) == NULL) {
 			(void) sprintf(buf,
-				"Cannot open %s alternate font.\nUse the -font option to specify a font to use.\n",
+				"Can not open %s alternate font.\nUse the -font option to specify a font to use.\n",
 				altfontname);
 			DISPLAY_WARNING(buf);
 		}
@@ -402,76 +338,6 @@ static Point trapazoidUnit[5] =
 
 #define MULTDELAY 48
 
-#if (!defined(WINVER) || (WINVER <= 0x030a)) /* if X or WINDOWS 3.1 or less */
-static void
-Sleep(unsigned int cMilliseconds)
-{
-#if (defined(WINVER) && (WINVER <= 0x030a))
-	unsigned long time_out = GetTickCount() + cMilliseconds;
-
-	while (time_out > GetTickCount());
-#else
-	(void) usleep(cMilliseconds * 1000);
-#endif
-}
-#endif
-
-static void
-initTimer(PanexWidget w)
-{
-#ifdef WINVER
-	w->panex.oldTime = GetTickCount();
-#else
-	XFlush(XtDisplay(w));
-	(void) X_GETTIMEOFDAY(&(w->panex.oldTime));
-#endif
-}
-
-static void
-useTimer(PanexWidget w, int delay)
-{
-	int sleepTime;
-#ifdef WINVER
-	long tv = GetTickCount();
-
-	sleepTime = delay - (tv - w->panex.oldTime);
-	w->panex.oldTime = tv;
-	if (sleepTime > 0) {
-		Sleep((unsigned int) sleepTime);
-	}
-#else
-	struct timeval tv;
-
-	XFlush(XtDisplay(w));
-	(void) X_GETTIMEOFDAY(&tv);
-	sleepTime = delay * 1000 - ((tv.tv_sec - w->panex.oldTime.tv_sec) *
-		1000000 + tv.tv_usec - w->panex.oldTime.tv_usec);
-	w->panex.oldTime.tv_sec = tv.tv_sec;
-	w->panex.oldTime.tv_usec = tv.tv_usec;
-	if (sleepTime > 0) {
-		(void) usleep((unsigned int) sleepTime);
-	}
-#endif
-}
-
-void
-intCat(char ** string, const char * var1, const int var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + 21))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%d", var1, var2);
-}
-
-void
-stringCat(char ** string, const char * var1, const char * var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + strlen(var2) + 1))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%s", var1, var2);
-}
-
 static void
 CheckTiles(PanexWidget w)
 {
@@ -595,47 +461,6 @@ PrintTiles(PanexWidget w)
 }
 #endif
 
-#ifdef WINVER
-static void
-POLYGON(PanexWidget w, Pixmap dr, GC color, GC lineColor,
-		const POINT * poly, int n, Boolean origin)
-{
-	/* CoordModePrevious -> CoordModeOrigin */
-	POINT *temp = NULL;
-	int pt;
-
-	if (!origin) {
-		if (!(temp = (POINT *) malloc(sizeof (POINT) * n))) {
-			DISPLAY_ERROR("Not enough memory, exiting.");
-		}
-		temp[0] = poly[0];
-		for (pt = 1; pt < n; pt++) {
-			temp[pt].x = temp[pt - 1].x + poly[pt].x,
-			temp[pt].y = temp[pt - 1].y + poly[pt].y;
-		}
-	}
-	if (dr)
-		w->panex.hOldBitmap =
-			(HBITMAP) SelectObject(w->panex.memDC, dr);
-	w->panex.hPen = CreatePen(PS_SOLID, 1, lineColor);
-	w->panex.hOldPen = (HPEN) SelectObject(DC(w, dr), w->panex.hPen);
-	w->panex.hBrush = CreateSolidBrush(color);
-	w->panex.hOldBrush = (HBRUSH) SelectObject(DC(w, dr),
-		w->panex.hBrush);
-	(void) Polygon(DC(w, dr), (origin) ? poly : temp, n);
-	(void) SelectObject(DC(w, dr), w->panex.hOldBrush);
-	(void) DeleteObject(w->panex.hBrush);
-	(void) SelectObject(DC(w, dr), w->panex.hOldPen);
-	(void) DeleteObject(w->panex.hPen);
-	if (dr)
-		(void) SelectObject(w->panex.memDC, w->panex.hOldBitmap);
-
-	if (!origin) {
-		free(temp);
-	}
-}
-#endif
-
 static void
 fill3DRect(PanexWidget w, Pixmap dr, GC gc, GC darkerGC, GC brighterGC,
 		int x, int y, int width, int height, Boolean raised)
@@ -722,7 +547,7 @@ DrawPyramid(PanexWidget w, Pixmap dr, int color, int i, int j, int size,
 			pyramidGC = w->panex.pyramidGC[color];
 
 	}
-	POLYGON(w, dr, pyramidGC, pyramidGC, trapazoidList, 4, False);
+	POLYGON(w, dr, pyramidGC, pyramidGC, trapazoidList, 4, True, False);
 	if (w->panex.mono) {
 
 		char buf[2];
@@ -867,15 +692,15 @@ DrawTile(PanexWidget w, int i, int j, Boolean erase, int pressedOffset,
 		return;
 	}
 #ifdef WINVER
-	w->panex.hOldBitmap = (HBITMAP) SelectObject(w->panex.memDC,
+	w->core.hOldBitmap = (HBITMAP) SelectObject(w->core.memDC,
 		w->panex.bufferTiles[pressedOffset]);
 	BitBlt(w->core.hDC,
 		dx, dy,
 		w->panex.tileSize.x, w->panex.tileSize.y,
-		w->panex.memDC,
+		w->core.memDC,
 		sx, sy,
 		SRCCOPY);
-	SelectObject(w->panex.memDC, w->panex.hOldBitmap);
+	SelectObject(w->core.memDC, w->core.hOldBitmap);
 #else
 	XSetGraphicsExposures(XtDisplay(w), w->panex.tileGC, False);
 	XCopyArea(XtDisplay(w),
@@ -979,7 +804,8 @@ AnimateSlide(PanexWidget w, int currentStack, int currentPosition,
 		}
 		if (gapI == 0)
 			gapI++;
-		initTimer(w);
+		FLUSH(w);
+		initTimer(w->panex.oldTime);
 		for (inc = 0; inc < space + gapI; inc += gapI) {
 			if (inc > space) {
 				inc = space;
@@ -1006,25 +832,29 @@ AnimateSlide(PanexWidget w, int currentStack, int currentPosition,
 				DrawSlot(w, currentStack,
 					ix, iy + w->panex.tileSize.y,
 					w->panex.tileSize.x + 1, gapI);
-				useTimer(w, w->panex.delay);
+				FLUSH(w);
+				useTimer(&(w->panex.oldTime), w->panex.delay);
 				break;
 			case RIGHT:
 				DrawSlot(w, currentStack,
 					ix - gapI, iy,
 					gapI, w->panex.tileSize.y + 1);
-				useTimer(w, 3 * w->panex.delay);
+				FLUSH(w);
+				useTimer(&(w->panex.oldTime), 3 * w->panex.delay);
 				break;
 			case BOTTOM:
 				DrawSlot(w, currentStack,
 					ix, iy - gapI,
 					w->panex.tileSize.x + 1, gapI);
-				useTimer(w, w->panex.delay);
+				FLUSH(w);
+				useTimer(&(w->panex.oldTime), w->panex.delay);
 				break;
 			case LEFT:
 				DrawSlot(w, currentStack,
 					ix + w->panex.tileSize.x, iy,
 					gapI + 1, w->panex.tileSize.y + 1);
-				useTimer(w, 3 * w->panex.delay);
+				FLUSH(w);
+				useTimer(&(w->panex.oldTime), 3 * w->panex.delay);
 				break;
 			}
 		}
@@ -1165,9 +995,7 @@ DiscreteMoves(PanexWidget w, int currentStack, int currentPosition,
 	DrawTile(w, currentStack, currentPosition, True, FALSE, 0, 0);
 	VirtualMove(w, currentStack, currentPosition, nextStack, nextPosition);
 	DrawTile(w, nextStack, nextPosition, False, FALSE, 0, 0);
-#ifndef WINVER
-	XFlush(XtDisplay(w));
-#endif
+	FLUSH(w);
 	Sleep((unsigned int) MULTDELAY * w->panex.delay /
 		(w->panex.tiles + MAXSTACKS - 1));
 }
@@ -1690,10 +1518,14 @@ SetValuesPanex(PanexWidget w)
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) strcpy(w->panex.moveSound, szBuf);
 		w->panex.moveSound[80] = 0;
-	(void) GetPrivateProfileString(SECTION, "name", "Guest",
+	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
 		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->panex.username, szBuf);
-	 w->panex.username[80] = 0;
+	(void) strcpy(w->panex.userName, szBuf);
+	 w->panex.userName[80] = 0;
+	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
+		szBuf, sizeof (szBuf), INIFILE);
+	(void) strcpy(w->panex.scoreFile, szBuf);
+	 w->panex.scoreFile[80] = 0;
 }
 
 void
@@ -2029,9 +1861,9 @@ ResizeTiles(PanexWidget w)
 {
 	int sel;
 #ifdef WINVER
-	if (w->panex.memDC == NULL) {
-		w->panex.memDC = CreateCompatibleDC(w->core.hDC);
-		if (w->panex.memDC == NULL) {
+	if (w->core.memDC == NULL) {
+		w->core.memDC = CreateCompatibleDC(w->core.hDC);
+		if (w->core.memDC == NULL) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
@@ -2185,12 +2017,13 @@ Widget renew, XEvent * event, Region region
 	DrawAllTiles(w);
 }
 
+#ifndef WINVER
+static
+#endif
 void
-HidePanex(
-#ifdef WINVER
-const PanexWidget w
-#else
-PanexWidget w, XEvent * event, char **args, int nArgs
+HidePanex(PanexWidget w
+#ifndef WINVER
+, XEvent * event, char **args, int nArgs
 #endif
 )
 {
