@@ -37,6 +37,7 @@
 #ifndef WINVER
 #define XtNselectCallback ((char *) "selectCallback")
 #define XtNuserName ((char *) "userName")
+#define XtNscoreFile ((char *) "scoreFile")
 #define XtNtiles ((char *) "tiles")
 #define XtNmode ((char *) "mode")
 #define XtNmono ((char *) "mono")
@@ -52,7 +53,10 @@
 #define XtNtileBorder ((char *) "tileBorder")
 #define XtNpyramidColor0 ((char *) "pyramidColor0")
 #define XtNpyramidColor1 ((char *) "pyramidColor1")
+#define XtNscoreOnly ((char *) "scoreOnly")
+#define XtNversionOnly ((char *) "versionOnly")
 #define XtCUserName ((char *) "UserName")
+#define XtCScoreFile ((char *) "ScoreFile")
 #define XtCTiles ((char *) "Tiles")
 #define XtCMode ((char *) "Mode")
 #define XtCMono ((char *) "Mono")
@@ -89,23 +93,6 @@ typedef struct {
 #define PANEX_UNDO 6
 #define PANEX_SPEED 7
 
-#ifdef WINVER
-#ifdef UNIXDELIM
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#else
-#define CURRENTDELIM ".\\"
-#define FINALDELIM "\\"
-#endif
-#else
-#ifdef VMS
-#define CURRENTDELIM "[]"
-#define FINALDELIM ""
-#else
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#endif
-#endif
 #define MINTILES 1
 #define DEFAULTTILES 10
 #define HANOI 0
@@ -122,8 +109,5 @@ typedef struct {
 
 typedef struct _PanexRec *PanexWidget;
 
-extern void intCat(char ** string, const char * var1, const int var2);
-extern void stringCat(char ** string, const char * var1, const char * var2);
-
 #endif /* _XtPanex_h */
 /* DON'T ADD STUFF AFTER THIS #endif */
