@@ -28,38 +28,25 @@
   Version 5.3: 96/04/30 Xt/Motif
 */
 
+#include "file.h"
 #ifdef WINVER
 #include "PanexP.h"
 #include "wpanex.h"
 #define TITLE "wpanex"
 
 static PanexRec widget;
-static HWND Wnd;
 
 #ifndef SCOREPATH
-#define SCOREPATH "c:\\Windows"
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
 #endif
-#define PRINT_MESSAGE(b) (void) MessageBox(Wnd, (LPCSTR) b, "Warning", MB_OK);
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
 #define SET_STARTED(w,b) w->panex.started = b
 #else
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
-#ifdef VMS
-#include <unixlib.h>
-#define getlogin() cuserid(NULL)
-#else
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif
-#if HAVE_FCNTL_H
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#endif
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
+#include "xwin.h"
 #include <X11/Shell.h>
 #include <X11/cursorfont.h>
 #ifdef HAVE_MOTIF
@@ -81,7 +68,7 @@ static HWND Wnd;
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
-#define SET_STARTED(w,b) XtSetArg(arg[0], XtNstart, b); XtSetValues(w, arg, 1)
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
 #include "Panex.h"
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
@@ -89,13 +76,17 @@ static HWND Wnd;
 #endif
 #include "icons/panex.xbm"
 #ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
 #define SCOREPATH "/var/games/xpuzzles"
 #endif
 #endif
+#endif
 
-#ifdef HAVE_MOTIF
+#ifndef WINVER
 static const char aboutHelp[] = {
-	"Version 7.1.3\n"
+	"Panex Version 7.1.5\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
@@ -103,15 +94,18 @@ static const char aboutHelp[] = {
 	"I got some help from Rene Jansen <rene.j.jansen@bigfoot.com> "
 	"and Nick Baxter <nickb@baxterweb.com>.\n"
 };
+
 static const char optionsHelp[] = {
-	"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]  "
-	"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"[-{foreground|fg} {color}] [-{background|bg} {color}] "
-	"[-{border|bd} {color}] [-tile {color}] [-pyramid{0|1} {color}]\n"
-	"[-tiles {int}] [-{mode {int}|hanoi|panex}] [-delay msecs] "
-	"[-{font|fn} {fontname}] [-username {string}]\n"
+	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+	"\t[-{border|bd} {color}] [-tile {color}] [-pyramid{0|1} {color}]\n"
+	"\t[-tiles {int}] [-{mode {int}|hanoi|panex}] [-delay msecs]\n"
+	"\t[-{font|fn} {fontname}] [-userName {string}]\n"
+	"\t[-scoreFile {filename}] [-scores] [-version]\n"
 };
 #endif
+
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
 	"The original Panex puzzle is from the Japanese Magic Company "
@@ -126,6 +120,7 @@ static const char descriptionHelp[] = {
 	"Edouard Lucas and temple of Benares of the god Brahma is\n"
 	"also his invention.\n"
 };
+
 static const char featuresHelp[] = {
 	"Press \"mouse-left\" button to move a tile in the top tile "
 	"of a column.  Release \"mouse-left\" button on\n"
@@ -170,6 +165,7 @@ static const char featuresHelp[] = {
 	"Unlike other puzzles in the collection there is no way to "
 	"move pieces without drag and drop.\n"
 };
+
 static const char referencesHelp[] = {
 	"Mark Manasse & Danny Sleator of AT&T Bell Laboratories  "
 	"and Victor K. Wei of Bell Communications Research,\n"
@@ -192,7 +188,7 @@ static const char referencesHelp[] = {
 #endif
 
 #define MAXTILES 10
-#define NEVER -1
+#define NEVER (-1)
 #define FILENAMELEN 1024
 #define USERNAMELEN 120
 #define MESSAGELEN (USERNAMELEN+64)
@@ -222,20 +218,21 @@ static const char *modeString[] =
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget clearDialog;
+static Arg arg[3];
 #else
 static char titleDsp[TITLELEN] = "";
 #endif
+static char scoreFileName[FILENAMELEN] = SCOREFILE;
+static char fileName[FILENAMELEN];
 #ifdef WINVER
 #define MAXPROGNAME 80
 static char progDsp[MAXPROGNAME] = TITLE;
-static char usernameDsp[USERNAMELEN] = "Guest";
+static char userNameDsp[USERNAMELEN] = "Guest";
 #else
 static Pixmap panexIcon = None;
 static Widget topLevel, panex;
-static Arg arg[3];
 static char *progDsp;
-static char usernameDsp[USERNAMELEN] = "";
-#endif
+static char userNameDsp[USERNAMELEN] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -246,25 +243,25 @@ PrintState(Widget w, char *msg)
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
 		XtError("PrintState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
-	XtSetArg(arg[0], XmNlabelString, xmstr);
-	XtSetValues(w, arg, 1);
+	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
-#else
+#endif
+
 static void
-PrintState(
-#ifndef WINVER
-Widget w,
-#endif
-int tiles, int moves, char *msg)
+PrintRecords(void)
 {
-	(void) sprintf(titleDsp, "%s: %d@ (%d/%s) - %s",
-		progDsp, tiles, moves, recordDsp, msg);
-#ifdef WINVER
-	SetWindowText(Wnd, (LPSTR) titleDsp);
-#else
-	XtSetArg(arg[0], XtNtitle, titleDsp);
-	XtSetValues(w, arg, 1);
-#endif
+	int i, mode;
+
+	(void) printf("   HANOI/PANEX  HALL OF FAME\n\n");
+	(void) printf("PANEX TILES USER            MOVES\n");
+	for (mode = 0; mode < MAXMODES; mode++)
+		for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
+			if (panexRecord[mode][i].score > 0)
+				(void) printf("%5d%6d %-12s%9d\n",
+					mode, i + 1,
+					panexRecord[mode][i].name,
+					panexRecord[mode][i].score);
+		}
 }
 #endif
 
@@ -286,21 +283,21 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, mode, n;
-	char username[USERNAMELEN];
+	char userName[USERNAMELEN];
 	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *fname, *lname;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
+	stringCat(&buf1, CURRENTDELIM, scoreFileName);
 	lname = buf1;
 	stringCat(&buf1, SCOREPATH, FINALDELIM);
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "r")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "r")) == NULL) {
+	(void) strncpy(fileName, lname, USERNAMELEN);
+	if ((fp = fopen(fileName, "r")) == NULL) {
+		(void) strncpy(fileName, fname, USERNAMELEN);
+		/* Try installed directory. */
+		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
@@ -329,12 +326,12 @@ ReadRecords(void)
 	free(fname);
 	for (mode = 0; mode < MAXMODES; mode++)
 		for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
-			(void) fscanf(fp, "%d %s\n", &n, username);
+			(void) fscanf(fp, "%d %s\n", &n, userName);
 			if (n <= panexRecord[mode][i].score ||
 			    panexRecord[mode][i].score <= NEVER) {
 				panexRecord[mode][i].score = n;
 				(void) strncpy(panexRecord[mode][i].name,
-					username, USERNAMELEN);
+					userName, USERNAMELEN);
 			}
 		}
 	(void) fclose(fp);
@@ -345,61 +342,31 @@ WriteRecords(void)
 {
 	FILE *fp;
 	int i, mode;
-	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *buf1 = NULL;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
-	lname = buf1;
-	stringCat(&buf1, SCOREPATH, FINALDELIM);
-	stringCat(&buf2, buf1, SCOREFILE);
-	free(buf1);
-	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "w")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "w")) == NULL) {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, " or ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-			free(lname);
-			free(fname);
-			return;
-		}
-/* Probably annoying */
-#if 0
-		else {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, ", falling back to ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-		}
-#endif
+	if ((fp = fopen(fileName, "w")) == NULL) {
+		stringCat(&buf1, "Can not write to ", fileName);
+		PRINT_MESSAGE(buf1);
+		free(buf1);
+		return;
 	}
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockfile[FILENAMELEN];
+		char lockFile[FILENAMELEN];
 
-		(void) strncpy(lockfile, name, FILENAMELEN - 6);
-		(void) strcat(lockfile, ".lock");
-		while (((lfd = open(lockfile, O_CREAT | O_EXCL, 0644)) < 0) &&
+		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strcat(lockFile, ".lock");
+		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
 			(void) sleep(1);
 		if (lfd < 0) {
 #if 1
 			(void) fprintf(stderr,
-			  "Lock file exists... guessing its an old one.\n");
+				"Lock file exists... guessing its an old one.\n");
 #else
 			(void) fprintf(stderr,
-			  "Lock file exists... score not recorded - sorry.\n");
+				"Lock file exists... score not recorded - sorry.\n");
 			return;
 #endif
 		}
@@ -413,12 +380,10 @@ WriteRecords(void)
 		}
 #if HAVE_FCNTL_H
 		(void) close(lfd);
-		(void) unlink(lockfile);
+		(void) unlink(lockFile);
 #endif
 		(void) fclose(fp);
 	}
-	free(lname);
-	free(fname);
 }
 
 static void
@@ -440,16 +405,38 @@ PrintRecord(int tiles, int mode)
 #endif
 }
 
+static void
+PrintStatus(char *msg, int nMoves
+#ifndef HAVE_MOTIF
+		, int tiles
+#endif
+		)
+{
+#ifdef HAVE_MOTIF
+	PrintState(message, msg);
+	(void) sprintf(buff, "%d", nMoves);
+	PrintState(moves, buff);
+#else
+	(void) sprintf(titleDsp, "%s: %d@ (%d/%s) - %s",
+		progDsp, tiles, nMoves, recordDsp, msg);
+#ifdef WINVER
+	SetWindowText(widget.core.hWnd, (LPSTR) titleDsp);
+#else
+	XtVaSetValues(XtParent(panex), XtNtitle, titleDsp, NULL);
+#endif
+#endif
+}
+
 static Boolean
 HandleSolved(int counter, int tiles, int mode)
 {
 	int i = tiles - MINTILES, j = mode - HANOI;
 
 	if (tiles <= MAXTILES && (counter < panexRecord[j][i].score ||
-	    panexRecord[j][i].score <= NEVER)) {
+			panexRecord[j][i].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		panexRecord[j][i].score = counter;
-		(void) strncpy(panexRecord[j][i].name, usernameDsp, USERNAMELEN);
+		(void) strncpy(panexRecord[j][i].name, userNameDsp, USERNAMELEN);
 		WriteRecords();
 		PrintRecord(tiles, mode);
 		return True;
@@ -460,26 +447,46 @@ HandleSolved(int counter, int tiles, int mode)
 static void
 Initialize(
 #ifdef WINVER
-	PanexWidget w, HBRUSH brush
+PanexWidget w, HBRUSH brush
 #else
-	Widget w
+Widget w
 #endif
 )
 {
 	int tiles, mode;
-	char *username;
+	char *userName, *scoreFile;
 
 #ifdef WINVER
 	InitializePanex(w, brush);
 
 	tiles = w->panex.tiles;
 	mode = w->panex.mode;
-	username = w->panex.username;
+	userName = w->panex.userName;
+	scoreFile = w->panex.scoreFile;
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
 #else
+	Boolean scoreOnly, versionOnly;
+
 	XtVaGetValues(w,
-		XtNuserName, &username,
+		XtNuserName, &userName,
+		XtNscoreFile, &scoreFile,
 		XtNtiles, &tiles,
-		XtNmode, &mode, NULL);
+		XtNmode, &mode,
+		XtNscoreOnly, &scoreOnly,
+		XtNversionOnly, &versionOnly, NULL);
+	if (versionOnly) {
+		(void) printf(aboutHelp);
+		exit(0);
+	}
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+	if (scoreOnly) {
+		InitRecords();
+		ReadRecords();
+		PrintRecords();
+		exit(0);
+	}
 #ifdef HAVE_MOTIF
 	{
 		int delay;
@@ -497,32 +504,29 @@ Initialize(
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(usernameDsp, username, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #endif
-	if (!strcmp(username, "") || !strcmp(username, "(null)") ||
-	    !strcmp(username, NOACCESS) || !strcmp(username, NOBODY)) {
-		/* The NOACCESS is not necessary, but it may stop silliness. */
+	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
+			!strcmp(userName, NOACCESS) ||
+			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(usernameDsp, username, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(usernameDsp, "%s", getlogin());
-		if (!strcmp(usernameDsp, "") ||
-				!strcmp(usernameDsp, "(null)") ||
-				!strcmp(usernameDsp, NOACCESS) ||
-				!strcmp(usernameDsp, NOBODY))
+		(void) sprintf(userNameDsp, "%s", getlogin());
+		if (!strcmp(userNameDsp, "") ||
+				!strcmp(userNameDsp, "(null)") ||
+				!strcmp(userNameDsp, NOACCESS) ||
+				!strcmp(userNameDsp, NOBODY))
 			/* It really IS nobody */
-			(void) sprintf(usernameDsp, "%s", "guest");
+			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
 	PrintRecord(tiles, mode);
+	PrintStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
+		, tiles
 #endif
-		tiles, movesDsp, messageDsp);
-#endif
-
+		);
 }
 
 #ifdef WINVER
@@ -565,8 +569,8 @@ CallbackPanex(Widget w, caddr_t clientData, panexCallbackStruct * callData)
 #ifdef HAVE_MOTIF
 			XtManageChild(clearDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 3); /* menu choice */
-			XtSetValues(panex, arg, 1);
+			XtVaSetValues(panex,
+				XtNmenu, 3, NULL); /* menu choice */
 #endif
 			break;
 #endif
@@ -598,10 +602,10 @@ CallbackPanex(Widget w, caddr_t clientData, panexCallbackStruct * callData)
 		case PANEX_SOLVED:
 			if (cheat)
 				(void) sprintf(messageDsp,
-					"No cheating %s!!", usernameDsp);
+					"No cheating %s!!", userNameDsp);
 			else if (HandleSolved(movesDsp, tiles, mode))
 				(void) sprintf(messageDsp,
-					"Congratulations %s!!", usernameDsp);
+					"Congratulations %s!!", userNameDsp);
 			else
 				(void) strncpy(messageDsp, "Solved!",
 					MESSAGELEN);
@@ -614,8 +618,7 @@ CallbackPanex(Widget w, caddr_t clientData, panexCallbackStruct * callData)
 #ifdef WINVER
 			w->panex.tiles = tiles;
 #else
-			XtSetArg(arg[0], XtNtiles, tiles);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(tile, tiles);
 			if (tiles >= MAXTILES)
@@ -630,8 +633,7 @@ CallbackPanex(Widget w, caddr_t clientData, panexCallbackStruct * callData)
 #ifdef WINVER
 			w->panex.tiles = tiles;
 #else
-			XtSetArg(arg[0], XtNtiles, tiles);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
 			if (tiles > MAXTILES)
 				XtVaSetValues(tile, XmNmaximum, tiles, NULL);
@@ -646,8 +648,7 @@ CallbackPanex(Widget w, caddr_t clientData, panexCallbackStruct * callData)
 #ifdef WINVER
 			w->panex.mode = mode;
 #else
-			XtSetArg(arg[0], XtNmode, mode);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNmode, mode, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(modes[mode - HANOI], True,
 				True);
@@ -673,8 +674,8 @@ CallbackPanex(Widget w, caddr_t clientData, panexCallbackStruct * callData)
 				if (delay < 0)
 					delay = 0;
 				if (delay != oldDelay) {
-					XtSetArg(arg[0], XtNdelay, delay);
-					XtSetValues(w, arg, 1);
+					XtVaSetValues(w,
+						XtNdelay, delay, NULL);
 				}
 				XmScaleSetValue(speed,
 					MAXSPEED + MINSPEED - delay - 1);
@@ -682,18 +683,11 @@ CallbackPanex(Widget w, caddr_t clientData, panexCallbackStruct * callData)
 			return;
 #endif
 	}
-#ifdef HAVE_MOTIF
-	PrintState(message, messageDsp);
-	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-#else
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
+	PrintStatus(messageDsp, movesDsp
+#ifndef HAVE_MOTIF
+		, tiles
 #endif
-		tiles, movesDsp, messageDsp);
-#endif
-
+		);
 }
 
 #ifdef WINVER
@@ -718,7 +712,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	PAINTSTRUCT paint;
 	static Boolean mousePress = False;
 
-	Wnd = widget.core.hWnd = hWnd;
+	widget.core.hWnd = hWnd;
 	if (GetFocus()) {
 		if (!widget.panex.focus) {
 			widget.core.hDC = GetDC(hWnd);
@@ -915,20 +909,7 @@ static void
 Usage(char * programName)
 {
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr,
-		"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n");
-	(void) fprintf(stderr,
-		"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n");
-	(void) fprintf(stderr,
-		"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{border|bd} {color}] [-tile {color}] [-pyramid{0|1} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-tiles {int}] [-{mode {int}|hanoi|panex}] [-delay msecs]\n");
-	(void) fprintf(stderr,
-		"\t[-movesound {filename}] [-{font|fn} {fontname}]\n");
-	(void) fprintf(stderr, 
-		"\t[-username {string}]\n");
+	(void) fprintf(stderr, optionsHelp);
 	exit(1);
 }
 
@@ -956,10 +937,13 @@ static XrmOptionDescRec options[] =
 	{(char *) "-delay", (char *) "*panex.delay", XrmoptionSepArg, NULL},
 	{(char *) "-sound", (char *) "*panex.sound", XrmoptionNoArg, (char *) "TRUE"},
 	{(char *) "-nosound", (char *) "*panex.sound", XrmoptionNoArg, (char *) "FALSE"},
-	{(char *) "-movesound", (char *) "*panex.moveSound", XrmoptionSepArg, NULL},
+	{(char *) "-moveSound", (char *) "*panex.moveSound", XrmoptionSepArg, NULL},
 	{(char *) "-fn", (char *) "*panex.font", XrmoptionSepArg, NULL},
 	{(char *) "-font", (char *) "*panex.font", XrmoptionSepArg, NULL},
-	{(char *) "-username", (char *) "*userName", XrmoptionSepArg, NULL}
+	{(char *) "-userName", (char *) "*panex.userName", XrmoptionSepArg, NULL},
+	{(char *) "-scoreFile", (char *) "*panex.scoreFile", XrmoptionSepArg, NULL},
+	{(char *) "-scores", (char *) "*panex.scoreOnly", XrmoptionNoArg, (char *) "TRUE"},
+	{(char *) "-version", (char *) "*panex.versionOnly", XrmoptionNoArg, (char *) "TRUE"}
 };
 
 #ifdef HAVE_MOTIF
@@ -967,8 +951,7 @@ static void
 CallbackPanexClear(Widget w, XtPointer clientData, XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 3); /* menu choice */
-		XtSetValues(panex, arg, 1);
+		XtVaSetValues(panex, XtNmenu, 3, NULL); /* menu choice */
 	}
 }
 
@@ -1031,16 +1014,15 @@ fileCB(Widget w, void *value, void *clientData)
 
 	if (val == 2)
 		exit(0);
-	XtSetArg(arg[0], XtNmenu, val);
-	XtSetValues(panex, arg, 1);
+	XtVaSetValues(panex, XtNmenu, val, NULL);
 }
 
 static void
 playCB(Widget w, void *value, void *clientData)
 {
 	int val = (int) value;
-	XtSetArg(arg[0], XtNmenu, val + 3); /* GWQ */
-	XtSetValues(panex, arg, 1);
+
+	XtVaSetValues(panex, XtNmenu, val + 3, NULL); /* GWQ */
 }
 
 static Widget
@@ -1121,7 +1103,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d\n", val);
+			intCat(&buf, "helpCB: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1175,11 +1157,10 @@ main(int argc, char **argv)
 			RootWindowOfScreen(XtScreen(topLevel)),
 			(char *) panex_bits,
 			panex_width, panex_height);
-	XtSetArg(arg[0], XtNiconPixmap, panexIcon);
 #ifdef HAVE_MOTIF
-	/* not XmEXPLICIT */
-	XtSetArg(arg[1], XmNkeyboardFocusPolicy, XmPOINTER);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, panexIcon,
+		XmNkeyboardFocusPolicy, XmPOINTER, NULL); /* not XmEXPLICIT */
 	panel = XtVaCreateManagedWidget("panel",
 		xmPanedWindowWidgetClass, topLevel,
 		XmNseparatorOn, False,
@@ -1386,8 +1367,9 @@ main(int argc, char **argv)
 	panex = XtCreateManagedWidget("panex",
 		panexWidgetClass, mainPanel, NULL, 0);
 #else
-	XtSetArg(arg[1], XtNinput, True);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, panexIcon,
+		XtNinput, True, NULL);
 	panex = XtCreateManagedWidget("panex",
 		panexWidgetClass, topLevel, NULL, 0);
 #endif
