@@ -25,6 +25,8 @@
 
 /* Methods file for Pyraminx */
 
+#include "file.h"
+#include "rngs.h"
 #include "PyraminxP.h"
 
 #ifdef WINVER
@@ -198,15 +200,18 @@ static XtActionsRec actionsListPyraminx[] =
 static XtResource resourcesPyraminx[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(PyraminxWidget, pyraminx.username),
-	 XtRString, (caddr_t) "nobody"},
+	 XtOffset(PyraminxWidget, pyraminx.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(PyraminxWidget, pyraminx.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(PyraminxWidget, pyraminx.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(PyraminxWidget, pyraminx.background),
 	 XtRString, (caddr_t) XtDefaultBackground},
-	{XtNframeColor, XtCForeground, XtRPixel, sizeof (Pixel),
+	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(PyraminxWidget, pyraminx.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
 	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
@@ -264,6 +269,12 @@ static XtResource resourcesPyraminx[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(PyraminxWidget, pyraminx.cheat),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(PyraminxWidget, pyraminx.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(PyraminxWidget, pyraminx.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(PyraminxWidget, pyraminx.menu),
 	 XtRString, (caddr_t) "-1"},
@@ -315,78 +326,6 @@ PyraminxClassRec pyraminxClassRec =
 
 WidgetClass pyraminxWidgetClass = (WidgetClass) & pyraminxClassRec;
 
-#ifndef HAVE_USLEEP
-#if !defined( VMS ) || defined( XVMSUTILS ) || ( __VMS_VER >= 70000000 )
-#ifdef USE_XVMSUTILS
-#include <X11/unix_time.h>
-#endif
-#if HAVE_SYS_TIME_H
-#include <sys/time.h>
-#else
-#if HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#endif
-#endif
-#endif
-#if defined(SYSV) || defined(SVR4)
-#ifdef LESS_THAN_AIX3_2
-#include <sys/poll.h>
-#else /* !LESS_THAN_AIX3_2 */
-#include <poll.h>
-#endif /* !LESS_THAN_AIX3_2 */
-#endif /* defined(SYSV) || defined(SVR4) */
-
-/* not static in case usleep found in system include */
-int
-usleep(unsigned int usec)
-{
-#if (defined (SYSV) || defined(SVR4)) && !defined(__hpux)
-#if defined(HAVE_NANOSLEEP)
-	{
-		struct timespec rqt;
-
-		rqt.tv_nsec = 1000 * (usec % (unsigned int) 1000000);
-		rqt.tv_sec = usec / (unsigned int) 1000000;
-		return nanosleep(&rqt, NULL);
-	}
-#else
-	(void) poll(
-#if defined(__cplusplus) || defined(c_plusplus)
-		(pollfd *) /* guess */
-#else
-		(void *)
-#endif
-		0, (int) 0, usec / 1000);	/* ms resolution */
-#endif
-#else
-#ifdef VMS
-	long timadr[2];
-
-	if (usec != 0) {
-		timadr[0] = -usec * 10;
-		timadr[1] = -1;
-
-		sys$setimr(4, &timadr, 0, 0, 0);
-		sys$waitfr(4);
-	}
-#else
-	struct timeval time_out;
-
-#if 0
-	/* (!defined(AIXV3) && !defined(__hpux)) */
-	extern int select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
-
-#endif
-
-	time_out.tv_usec = usec % (unsigned int) 1000000;
-	time_out.tv_sec = usec / (unsigned int) 1000000;
-	(void) select(0, (void *) 0, (void *) 0, (void *) 0, &time_out);
-#endif
-#endif
-	return 0;
-}
-#endif
-
 void
 SetPyraminx(PyraminxWidget w, int reason)
 {
@@ -412,13 +351,13 @@ loadFont(PyraminxWidget w)
 	if ((w->pyraminx.fontInfo = XLoadQueryFont(display,
 			w->pyraminx.font)) == NULL) {
 		(void) sprintf(buf,
-			"Cannot open %s font.\nAttempting %s font as alternate\n",
+			"Can not open %s font.\nAttempting %s font as alternate\n",
 			w->pyraminx.font, altfontname);
 		DISPLAY_WARNING(buf);
 		if ((w->pyraminx.fontInfo = XLoadQueryFont(display,
 				altfontname)) == NULL) {
 			(void) sprintf(buf,
-				"Cannot open %s alternate font.\nUse the -font option to specify a font to use.\n",
+				"Can not open %s alternate font.\nUse the -font option to specify a font to use.\n",
 				altfontname);
 			DISPLAY_WARNING(buf);
 		}
@@ -503,37 +442,7 @@ static Point triangleUnit[MAXSIDES][4] =
 static Point triangleList[MAXSIDES][4], letterList[MAXSIDES];
 static Point offsetList[MAXSIDES];
 
-#if (!defined(WINVER) || (WINVER <= 0x030a)) /* if X or WINDOWS 3.1 or less */
-static void
-Sleep(unsigned int cMilliseconds)
-{
-#if (defined(WINVER) && (WINVER <= 0x030a))
-	unsigned long time_out = GetTickCount() + cMilliseconds;
-
-	while (time_out > GetTickCount());
-#else
-	(void) usleep(cMilliseconds * 1000);
-#endif
-}
-#endif
-
-void
-intCat(char ** string, const char * var1, const int var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + 21))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%d", var1, var2);
-}
-
-void
-stringCat(char ** string, const char * var1, const char * var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + strlen(var2) + 1))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%s", var1, var2);
-}
+static Pixmap dr = 0; /* dummy for future double buffering */
 
 static void
 CheckPieces(PyraminxWidget w)
@@ -726,47 +635,6 @@ Length(PyraminxWidget w, int face, int dir, int h)
 		return ((face == UP) ? h : w->pyraminx.size - 1 - h);
 }
 
-#ifdef WINVER
-static void
-POLYGON(PyraminxWidget w, GC color, GC lineColor, const POINT * poly, int n,
-		Boolean origin)
-{
-	/* CoordModePrevious -> CoordModeOrigin */
-	POINT *temp = NULL;
-	int pt;
-
-	if (!origin) {
-		if (!(temp = (POINT *) malloc(sizeof (POINT) * n))) {
-			DISPLAY_ERROR("Not enough memory, exiting.");
-		}
-		temp[0] = poly[0];
-		for (pt = 1; pt < n; pt++) {
-			temp[pt].x = temp[pt - 1].x + poly[pt].x,
-			temp[pt].y = temp[pt - 1].y + poly[pt].y;
-		}
-	}
-	w->pyraminx.hPen = CreatePen(PS_SOLID, 1, lineColor);
-	w->pyraminx.hOldPen = (HPEN) SelectObject(w->core.hDC,
-		w->pyraminx.hPen);
-	w->pyraminx.hBrush = CreateSolidBrush(color);
-	w->pyraminx.hOldBrush = (HBRUSH) SelectObject(w->core.hDC,
-		w->pyraminx.hBrush);
-	(void) Polygon(w->core.hDC, (origin) ? poly : temp, n);
-	(void) SelectObject(w->core.hDC, w->pyraminx.hOldBrush);
-	(void) DeleteObject(w->pyraminx.hBrush);
-	(void) SelectObject(w->core.hDC, w->pyraminx.hOldPen);
-	(void) DeleteObject(w->pyraminx.hPen);
-	if (!origin) {
-		free(temp);
-	}
-}
-#else
-#define POLYGON(w,c,lc,l,n,o) XFillPolygon(XtDisplay(w), XtWindow(w), c, \
-  l, n, Convex, (o) ? CoordModeOrigin : CoordModePrevious); \
-  XDrawLines(XtDisplay(w), XtWindow(w), lc, \
-  l, (n)+1,(o) ? CoordModeOrigin : CoordModePrevious)
-#endif
-
 static void
 DrawOrientLine(PyraminxWidget w, int orient, int dx, int dy, int side,
 		GC borderGC)
@@ -819,7 +687,7 @@ DrawOrientLine(PyraminxWidget w, int orient, int dx, int dy, int side,
 				free(buf);
 			}
 	}
-	DRAWLINE(w, borderGC, x_1, y_1, x_2, y_2);
+	DRAWLINE(w, dr, borderGC, x_1, y_1, x_2, y_2);
 }
 
 static void
@@ -877,7 +745,8 @@ DrawTriangle(PyraminxWidget w, int face, int position, int offset)
 		borderGC = w->pyraminx.borderGC;
 	}
 
-	POLYGON(w, faceGC, borderGC, triangleList[faceOnView], 3, False);
+	POLYGON(w, dr, faceGC, borderGC, triangleList[faceOnView], 3,
+		True, False);
 	dx += -faceOnView;
 	dy += -faceOnView;
 	if (w->pyraminx.mono) {
@@ -900,7 +769,7 @@ DrawTriangle(PyraminxWidget w, int face, int position, int offset)
 		} else {
 			borderGC = w->pyraminx.inverseGC;
 		}
-		DRAWTEXT(w, borderGC, letterX, letterY, buf, 1);
+		DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, 1);
 	}
 	if (w->pyraminx.orient)
 		DrawOrientLine(w, orient, dx, dy, faceOnView, borderGC);
@@ -919,7 +788,7 @@ DrawAllPieces(PyraminxWidget w)
 static void
 EraseFrame(const PyraminxWidget w)
 {
-	FILLRECTANGLE(w, w->pyraminx.inverseGC,
+	FILLRECTANGLE(w, dr, w->pyraminx.inverseGC,
 		0, 0, w->core.width, w->core.height);
 }
 
@@ -935,38 +804,38 @@ DrawFrame(PyraminxWidget w, Boolean focus)
 		w->pyraminx.puzzleOffset.x;
 	lengthy = w->pyraminx.viewLength - w->pyraminx.delta +
 		w->pyraminx.puzzleOffset.y;
-	DRAWLINE(w, gc, startx, starty, lengthx, starty);
-	DRAWLINE(w, gc, startx, starty, startx, lengthy);
-	DRAWLINE(w, gc, startx, lengthy, lengthx, starty);
+	DRAWLINE(w, dr, gc, startx, starty, lengthx, starty);
+	DRAWLINE(w, dr, gc, startx, starty, startx, lengthy);
+	DRAWLINE(w, dr, gc, startx, lengthy, lengthx, starty);
 	if (w->pyraminx.vertical) {
 		longlength = 2 * w->pyraminx.viewLength - 2 * w->pyraminx.delta - 1 +
 			w->pyraminx.puzzleOffset.y;
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			startx, lengthy, startx, longlength);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			lengthx, lengthy, lengthx, longlength);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			startx, longlength, lengthx, longlength);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			startx, longlength, lengthx, lengthy);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			lengthx, starty, lengthx, lengthy);
-		DRAWLINE(w, w->pyraminx.frameGC,
+		DRAWLINE(w, dr, w->pyraminx.frameGC,
 			0, lengthy, (int) w->core.width, lengthy);
 	} else {
 		longlength = 2 * w->pyraminx.viewLength - 2 * w->pyraminx.delta - 1 +
 			w->pyraminx.puzzleOffset.x;
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			lengthx, starty, longlength, starty);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			lengthx, lengthy, longlength, lengthy);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			longlength, starty, longlength, lengthy);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			longlength, starty, lengthx, lengthy);
-		DRAWLINE(w, gc,
+		DRAWLINE(w, dr, gc,
 			startx, lengthy, lengthx, lengthy);
-		DRAWLINE(w, w->pyraminx.frameGC,
+		DRAWLINE(w, dr, w->pyraminx.frameGC,
 			lengthx, 0, lengthx, (int) w->core.height);
 	}
 }
@@ -1749,13 +1618,13 @@ ResetPieces(PyraminxWidget w)
 	w->pyraminx.sizeSize = w->pyraminx.size * w->pyraminx.size;
 	for (face = 0; face < MAXFACES; face++) {
 		if (w->pyraminx.facetLoc[face])
-			(void) free((void *) w->pyraminx.facetLoc[face]);
+			free(w->pyraminx.facetLoc[face]);
 		if (!(w->pyraminx.facetLoc[face] = (PyraminxLoc *)
 				malloc(sizeof (PyraminxLoc) * w->pyraminx.sizeSize))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 		if (startLoc[face])
-			(void) free((void *) startLoc[face]);
+			free(startLoc[face]);
 		if (!(startLoc[face] = (PyraminxLoc *)
 				malloc(sizeof (PyraminxLoc) * w->pyraminx.sizeSize))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
@@ -1764,7 +1633,7 @@ ResetPieces(PyraminxWidget w)
 	for (orient = 0; orient < 3; orient++)
 		for (side = 0; side < MAXSIDES; side++) {
 			if (w->pyraminx.rowLoc[orient][side])
-				(void) free((void *) w->pyraminx.rowLoc[orient][side]);
+				free(w->pyraminx.rowLoc[orient][side]);
 			if (!(w->pyraminx.rowLoc[orient][side] = (PyraminxLoc *)
 					malloc(sizeof (PyraminxLoc) * w->pyraminx.size))) {
 				DISPLAY_ERROR("Not enough memory, exiting.");
@@ -1772,7 +1641,7 @@ ResetPieces(PyraminxWidget w)
 		}
 	for (side = 0; side < MAXSIDES; side++) {
 		if (w->pyraminx.faceLoc)
-			(void) free((void *) w->pyraminx.faceLoc[side]);
+			free(w->pyraminx.faceLoc[side]);
 		if (!(w->pyraminx.faceLoc[side] = (PyraminxLoc *)
 				malloc(sizeof (PyraminxLoc) * w->pyraminx.sizeSize))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
@@ -2200,11 +2069,14 @@ SetValuesPyraminx(PyraminxWidget w)
 			szBuf, sizeof (szBuf), INIFILE);
 		w->pyraminx.faceChar[face] = szBuf[0];
 	}
-	(void) GetPrivateProfileString(SECTION, "name", "Guest",
+	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
 		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->pyraminx.username, szBuf);
-		w->pyraminx.username[80] = 0;
-
+	(void) strcpy(w->pyraminx.userName, szBuf);
+		w->pyraminx.userName[80] = 0;
+	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
+		szBuf, sizeof (szBuf), INIFILE);
+	(void) strcpy(w->pyraminx.scoreFile, szBuf);
+		w->pyraminx.scoreFile[80] = 0;
 }
 
 void
