@@ -37,6 +37,7 @@
 #ifndef WINVER
 #define XtNselectCallback ((char *) "selectCallback")
 #define XtNuserName ((char *) "userName")
+#define XtNscoreFile ((char *) "scoreFile")
 #define XtNmono ((char *) "mono")
 #define XtNreverse ((char *) "reverse")
 #define XtNsize ((char *) "size")
@@ -54,7 +55,10 @@
 #define XtNfaceColor1 ((char *) "faceColor1")
 #define XtNfaceColor2 ((char *) "faceColor2")
 #define XtNfaceColor3 ((char *) "faceColor3")
+#define XtNscoreOnly ((char *) "scoreOnly")
+#define XtNversionOnly ((char *) "versionOnly")
 #define XtCUserName ((char *) "UserName")
+#define XtCScoreFile ((char *) "ScoreFile")
 #define XtCSize ((char *) "Size")
 #define XtCMode ((char *) "Mode")
 #define XtCOrient ((char *) "Orient")
@@ -98,23 +102,6 @@ typedef struct {
 #define PYRAMINX_COMPUTED 12
 #define PYRAMINX_UNDO 13
 
-#ifdef WINVER
-#ifdef UNIXDELIM
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#else
-#define CURRENTDELIM ".\\"
-#define FINALDELIM "\\"
-#endif
-#else
-#ifdef VMS
-#define CURRENTDELIM "[]"
-#define FINALDELIM ""
-#else
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#endif
-#endif
 #define MINFACETS 1
 #define PERIOD2 2
 #define PERIOD3 3
@@ -134,8 +121,5 @@ typedef struct {
 
 typedef struct _PyraminxRec *PyraminxWidget;
 
-extern void intCat(char ** string, const char * var1, const int var2);
-extern void stringCat(char ** string, const char * var1, const char * var2);
-
 #endif /* _XtPyraminx_h */
 /* DON'T ADD STUFF AFTER THIS #endif */
