@@ -32,38 +32,25 @@
   Version 1: 91/03/19 SunView
 */
 
+#include "file.h"
 #ifdef WINVER
 #include "PyraminxP.h"
 #include "wpyraminx.h"
 #define TITLE "wpyraminx"
 
 static PyraminxRec widget;
-static HWND Wnd;
 
 #ifndef SCOREPATH
-#define SCOREPATH "c:\\Windows"
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
 #endif
-#define PRINT_MESSAGE(b) (void) MessageBox(Wnd, (LPCSTR) b, "Warning", MB_OK);
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
 #define SET_STARTED(w,b) w->pyraminx.started = b
 #else
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
-#ifdef VMS
-#include <unixlib.h>
-#define getlogin() cuserid(NULL)
-#else
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif
-#if HAVE_FCNTL_H
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#endif
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
+#include "xwin.h"
 #include <X11/Shell.h>
 #include <X11/cursorfont.h>
 #ifdef HAVE_MOTIF
@@ -85,7 +72,7 @@ static HWND Wnd;
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
-#define SET_STARTED(w,b) XtSetArg(arg[0], XtNstart, b); XtSetValues(w, arg, 1)
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
 #include "Pyraminx.h"
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
@@ -93,28 +80,35 @@ static HWND Wnd;
 #endif
 #include "icons/pyraminx.xbm"
 #ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
 #define SCOREPATH "/var/games/xpuzzles"
 #endif
 #endif
+#endif
 
-#ifdef HAVE_MOTIF
+#ifndef WINVER
 static const char aboutHelp[] = {
-	"Version 7.1.3\n"
+	"Pyraminx Version 7.1.5\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
 	"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
+
 static const char optionsHelp[] = {
-	"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]] "
-	"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"[-{foreground|fg} {color}] [-{background|bg} {color}] "
-	"[-{border|bd} {color}] [-face{0|1|2|3} {color}]\n"
-	"[-{size {int} | sticky}] [-{mode {int} | both}] "
-	"[-[no]orient] [-[no]practice] [-delay msecs]\n"
-	"[-{font|fn} {fontname}] [-username {string}]\n"
+	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+	"\t[-{border|bd} {color}] [-face{0|1|2|3} {color}]\n"
+	"\t[-{size {int} | sticky}] [-{mode {int} | both}]\n"
+	"\t[-[no]orient] [-[no]practice] [-delay msecs]\n"
+	"\t[-{font|fn} {fontname}] [-userName {string}]\n"
+	"\t[-scoreFile {filename}] [-scores] [-version]\n"
 };
 #endif
+
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
 	"The original puzzle has 9 triangles per face (size = 3) "
@@ -147,21 +141,27 @@ static const char descriptionHelp[] = {
 	"is able to simulate one with variant turning (period 2 "
 	"turning and sticky mode).\n"
 };
+
 static const char featuresHelp[] = {
 	"Press \"mouse-left\" button to move a piece.  Release "
 	"\"mouse-left\" button on a piece on the same face and\n"
 	"in the same row (but not an adjacent piece or the move "
 	"is ambiguous).  The pieces will then turn towards\n"
 	"where the mouse button was released.\n"
+	"\n"
 	"Click \"mouse-center\" button, or press \"P\" or \"p\" "
 	"keys, to toggle the practice mode (in practice mode the\n"
 	"record should say \"practice\").  This is good for learning "
 	"moves and experimenting.\n"
+	"\n"
 	"Click \"mouse-right\" button, or press \"R\" or \"r\" "
 	"keys, to randomize the puzzle (this must be done first\n"
 	"to set a new record).\n"
+	"\n"
 	"Press \"I\" or \"i\" keys to increase the number of \"facets\".\n"
+	"\n"
 	"Press \"D\" or \"d\" keys to decrease the number of \"facets\".\n"
+	"\n"
 	"Press \"O\" or \"o\" keys to toggle the orient mode.  One "
 	"has to orient the faces in orient mode, besides\n"
 	"getting all the faces to be the same color.  To do this "
@@ -170,8 +170,10 @@ static const char featuresHelp[] = {
 	"\"facets\", if at all (i.e. those \"cubies\" not on a\n"
 	"corner or edge).  This does add complexity so there are "
 	"2 sets of records.\n"
+	"\n"
 	"Press \"2\", \"3\", \"B\", or \"b\" keys (not the keypad 2, 3) "
 	"to change modes to Period 2, Period 3, or Both.\n"
+	"\n"
 	"Press \"Y\" or \"y\" keys to toggle sticky mode (increase/decrease "
 	"is disabled here if sticky mode is on).\n"
 	"\"Sticky\" and \"Period 2\" turning allows only the edges to "
@@ -182,13 +184,22 @@ static const char featuresHelp[] = {
 	"did not exist.\n"
 	"Beware, the \"Sticky\" mode is a hack and much could be done "
 	"to improve its look.\n"
+	"\n"
 	"Press \"S\" or \"s\" keys to start auto-solver.  Only works on "
 	"1x1x1, 2x2x2, and 3x3x3 pyrmaminxs in Period 3 mode.\n"
+	"\n"
 	"Press \"U\" or \"u\" keys to undo a move.\n"
+	"\n"
 	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+	"\n"
 	"Press \"W\" or \"w\" keys to save a puzzle.\n"
+	"\n"
+	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+	"\n"
 	"Press \"Esc\" key to hide program.\n"
+	"\n"
 	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+	"\n"
 	"Use the key pad, \"R\" keys, or arrow keys to move without "
 	"mouse clicks.\n"
 	"Key pad is defined for Pyraminx as:\n"
@@ -202,10 +213,12 @@ static const char featuresHelp[] = {
 	"\"Both\" mode, otherwise it assumes \"Period 2\" turning.\n"
 	"Faces and points turn in \"Period 3\" and edges (2 points) "
 	"turn in \"Period 2\".\n"
+	"\n"
 	"Use the control key and the left mouse button, keypad, or "
 	"arrow keys to move the whole tetrahedron.  This is not\n"
 	"recorded as a turn.\n"
 };
+
 static const char referencesHelp[] = {
 	"James G. Nourse, The Simple Solutions to Cubic Puzzles, "
 	"Bantam Books, New York, 1981. pp 8-15.\n"
@@ -219,6 +232,7 @@ static const char referencesHelp[] = {
 	"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow.\n"
 };
 #endif
+
 static const char solveHelp[] = {
 	"Auto-solver: sorry, only implemented for size < 4 where "
 	"period = 3.\n"
@@ -229,7 +243,7 @@ static const char solveHelp[] = {
 #endif
 
 #define MAXFACETS 7
-#define NEVER -1
+#define NEVER (-1)
 #define FILENAMELEN 1024
 #define USERNAMELEN 120
 #define MESSAGELEN (USERNAMELEN+64)
@@ -252,8 +266,8 @@ static int oldSize;
 #define MINSPEED 1
 #define MAXSPEED 50
 #define MULTSPEED 20
-static Widget moves, record, message, modes[MAXMODES], orientSwitch,
-	stickySwitch, practiceSwitch, facets, speed;
+static Widget moves, record, message, modes[MAXMODES], orientSwitch;
+static Widget stickySwitch, practiceSwitch, facets, speed;
 static char buff[21];
 static const char *modeString[] =
 {
@@ -262,20 +276,21 @@ static const char *modeString[] =
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
+static Arg arg[3];
 #else
 static char titleDsp[TITLELEN] = "";
 #endif
+static char scoreFileName[FILENAMELEN] = SCOREFILE;
+static char fileName[FILENAMELEN];
 #ifdef WINVER
 #define MAXPROGNAME 80
 static char progDsp[MAXPROGNAME] = TITLE;
-static char usernameDsp[USERNAMELEN] = "Guest";
+static char userNameDsp[USERNAMELEN] = "Guest";
 #else
 static Pixmap pyraminxIcon = None;
 static Widget topLevel, pyraminx;
-static Arg arg[5];
 static char *progDsp;
-static char usernameDsp[USERNAMELEN] = "";
-#endif
+static char userNameDsp[USERNAMELEN] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -286,35 +301,26 @@ PrintState(Widget w, char *msg)
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
 		XtError("PrintState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
-	XtSetArg(arg[0], XmNlabelString, xmstr);
-	XtSetValues(w, arg, 1);
+	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
-#else
-static void
-PrintState(
-#ifndef WINVER
-Widget w,
 #endif
-int mode, int size, Boolean sticky, int moves, char *msg)
-{
-	char ss[10], mb[10];
 
-	if (sticky)
-		(void) strcpy(ss, "sticky");
-	else
-		(void) sprintf(ss, "%d", size);
-	if (mode == BOTH)
-		(void) strcpy(mb, "both");
-	else
-		(void) sprintf(mb, "%d", mode);
-	(void) sprintf(titleDsp, "%s.%s: %s@ (%d/%s) - %s",
-		progDsp, mb, ss, moves, recordDsp, msg);
-#ifdef WINVER
-	SetWindowText(Wnd, (LPSTR) titleDsp);
-#else
-	XtSetArg(arg[0], XtNtitle, titleDsp);
-	XtSetValues(w, arg, 1);
-#endif
+static void
+PrintRecords(void)
+{
+	int i, mode, orient;
+
+	(void) printf("             PYRAMINX  HALL OF FAME\n\n");
+	(void) printf("MODE ORIENT FACET USER            MOVES\n");
+	for (mode = 0; mode < MAXMODES; mode++)
+		for (orient = 0; orient < 2; orient++)
+			for (i = 0; i <= MAXFACETS - MINFACETS + 1; i++) {
+				if (pyraminxRecord[mode][orient][i].score > 0)
+					(void) printf("%4d%7d%6d %-12s%9d\n",
+						mode + 2, orient, i + 1,
+						pyraminxRecord[mode][orient][i].name,
+						pyraminxRecord[mode][orient][i].score);
+			}
 }
 #endif
 
@@ -337,21 +343,21 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, n, mode, orient;
-	char username[USERNAMELEN];
+	char userName[USERNAMELEN];
 	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *fname, *lname;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
+	stringCat(&buf1, CURRENTDELIM, scoreFileName);
 	lname = buf1;
 	stringCat(&buf1, SCOREPATH, FINALDELIM);
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
-        fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "r")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "r")) == NULL) {
+	fname = buf2;
+	(void) strncpy(fileName, lname, USERNAMELEN);
+	if ((fp = fopen(fileName, "r")) == NULL) {
+		(void) strncpy(fileName, fname, USERNAMELEN);
+		/* Try installed directory. */
+		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
@@ -381,12 +387,12 @@ ReadRecords(void)
 	for (mode = 0; mode < MAXMODES; mode++)
 		for (orient = 0; orient < 2; orient++)
 			for (i = 0; i <= MAXFACETS - MINFACETS + 1; i++) {
-				(void) fscanf(fp, "%d %s\n", &n, username);
+				(void) fscanf(fp, "%d %s\n", &n, userName);
 				if (n <= pyraminxRecord[mode][orient][i].score ||
-				    pyraminxRecord[mode][orient][i].score <= NEVER) {
+						pyraminxRecord[mode][orient][i].score <= NEVER) {
 					pyraminxRecord[mode][orient][i].score = n;
 					(void) strncpy(pyraminxRecord[mode][orient][i].name,
-						username, USERNAMELEN);
+						userName, USERNAMELEN);
 				}
 			}
 	(void) fclose(fp);
@@ -397,61 +403,31 @@ WriteRecords(void)
 {
 	FILE *fp;
 	int i, mode, orient;
-	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *buf1 = NULL;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
-	lname = buf1;
-	stringCat(&buf1, SCOREPATH, FINALDELIM);
-	stringCat(&buf2, buf1, SCOREFILE);
-	free(buf1);
-	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "w")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "w")) == NULL) {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, " or ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-			free(lname);
-			free(fname);
-			return;
-		}
-/* Probably annoying */
-#if 0
-		else {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, ", falling back to ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-		}
-#endif
+	if ((fp = fopen(fileName, "w")) == NULL) {
+		stringCat(&buf1, "Can not write to ", fileName);
+		PRINT_MESSAGE(buf1);
+		free(buf1);
+		return;
 	}
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockfile[FILENAMELEN];
+		char lockFile[FILENAMELEN];
 
-		(void) strncpy(lockfile, name, FILENAMELEN - 6);
-		(void) strcat(lockfile, ".lock");
-		while (((lfd = open(lockfile, O_CREAT | O_EXCL, 0644)) < 0) &&
+		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strcat(lockFile, ".lock");
+		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
 			(void) sleep(1);
 		if (lfd < 0) {
 #if 1
 			(void) fprintf(stderr,
-			  "Lock file exists... guessing its an old one.\n");
+				"Lock file exists... guessing its an old one.\n");
 #else
 			(void) fprintf(stderr,
-			  "Lock file exists... score not recorded - sorry.\n");
+				"Lock file exists... score not recorded - sorry.\n");
 			return;
 #endif
 		}
@@ -468,26 +444,25 @@ WriteRecords(void)
 		}
 #if HAVE_FCNTL_H
 		(void) close(lfd);
-		(void) unlink(lockfile);
+		(void) unlink(lockFile);
 #endif
 		(void) fclose(fp);
 	}
-	free(lname);
-	free(fname);
 }
 
 static void
-PrintRecord(int size, int mode, Boolean orient, Boolean sticky, Boolean practice)
+PrintRecord(int size, int mode,
+		Boolean orient, Boolean sticky, Boolean practice)
 {
 	int i = mode - PERIOD2;
 	int j = (orient) ? 1 : 0;
 	int k = (sticky) ? MAXFACETS - MINFACETS + 1 : size - MINFACETS;
 
-	if (practice)
+	if (practice) {
 		(void) strncpy(recordDsp, "practice", MESSAGELEN);
-	else if (!sticky && size > MAXFACETS)
+	} else if (!sticky && size > MAXFACETS) {
 		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
-	else if (pyraminxRecord[i][j][k].score <= NEVER) {
+	} else if (pyraminxRecord[i][j][k].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
 		(void) sprintf(recordDsp, "%d %s",
@@ -499,6 +474,38 @@ PrintRecord(int size, int mode, Boolean orient, Boolean sticky, Boolean practice
 #endif
 }
 
+static void
+PrintStatus(char *msg, int nMoves
+#ifndef HAVE_MOTIF
+		, int mode, int size, Boolean sticky
+#endif
+		)
+{
+#ifdef HAVE_MOTIF
+	PrintState(message, msg);
+	(void) sprintf(buff, "%d", nMoves);
+	PrintState(moves, buff);
+#else
+	char ss[10], mb[10];
+
+	if (sticky)
+		(void) strcpy(ss, "sticky");
+	else
+		(void) sprintf(ss, "%d", size);
+	if (mode == BOTH)
+		(void) strcpy(mb, "both");
+	else
+		(void) sprintf(mb, "%d", mode);
+	(void) sprintf(titleDsp, "%s.%s: %s@ (%d/%s) - %s",
+		progDsp, mb, ss, nMoves, recordDsp, msg);
+#ifdef WINVER
+	SetWindowText(widget.core.hWnd, (LPSTR) titleDsp);
+#else
+	XtVaSetValues(XtParent(pyraminx), XtNtitle, titleDsp, NULL);
+#endif
+#endif
+}
+
 static Boolean
 HandleSolved(int counter, int size, int mode, Boolean orient, Boolean sticky)
 {
@@ -507,22 +514,22 @@ HandleSolved(int counter, int size, int mode, Boolean orient, Boolean sticky)
 	int k = (sticky) ? MAXFACETS - MINFACETS + 1 : size - MINFACETS;
 
 	if ((sticky || size <= MAXFACETS) &&
-	    (counter < pyraminxRecord[i][j][k].score ||
-	    pyraminxRecord[i][j][k].score <= NEVER)) {
+			(counter < pyraminxRecord[i][j][k].score ||
+			pyraminxRecord[i][j][k].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		pyraminxRecord[i][j][k].score = counter;
-		(void) strncpy(pyraminxRecord[i][j][k].name, usernameDsp,
+		(void) strncpy(pyraminxRecord[i][j][k].name, userNameDsp,
 			USERNAMELEN);
 		if (size < 4 || mode == PERIOD2 || (orient &&
 			       (counter < pyraminxRecord[i][!j][k].score ||
 			       pyraminxRecord[i][!j][k].score <= NEVER))) {
 			pyraminxRecord[i][!j][k].score = counter;
-			(void) strncpy(pyraminxRecord[i][!j][k].name, usernameDsp,
+			(void) strncpy(pyraminxRecord[i][!j][k].name, userNameDsp,
 				USERNAMELEN);
 		}
 		WriteRecords();
 		PrintRecord(size, mode, orient, sticky, False);
-		return TRUE;
+		return True;
 	}
 	return False;
 }
@@ -538,7 +545,7 @@ Widget w
 {
 	int size, mode;
 	Boolean orient, sticky, practice;
-	char *username;
+	char *userName, *scoreFile;
 
 #ifdef WINVER
 	InitializePyraminx(w, brush);
@@ -548,18 +555,35 @@ Widget w
 	orient = w->pyraminx.orient;
 	sticky = w->pyraminx.sticky;
 	practice = w->pyraminx.practice;
-	username = w->pyraminx.username;
+	userName = w->pyraminx.userName;
+	scoreFile = w->pyraminx.scoreFile;
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
 #else
-	int delay;
+	Boolean scoreOnly, versionOnly;
 
 	XtVaGetValues(w,
-		XtNuserName, &username,
+		XtNuserName, &userName,
+		XtNscoreFile, &scoreFile,
 		XtNsize, &size,
 		XtNmode, &mode,
 		XtNorient, &orient,
 		XtNsticky, &sticky,
 		XtNpractice, &practice,
-		XtNdelay, &delay, NULL);
+		XtNscoreOnly, &scoreOnly,
+		XtNversionOnly, &versionOnly, NULL);
+	if (versionOnly) {
+		(void) printf(aboutHelp);
+		exit(0);
+	}
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+	if (scoreOnly) {
+		InitRecords();
+		ReadRecords();
+		PrintRecords();
+		exit(0);
+	}
 #ifdef HAVE_MOTIF
 	if (size > MAXFACETS)
 		XtVaSetValues(facets, XmNmaximum, size, NULL);
@@ -568,39 +592,43 @@ Widget w
 	XmToggleButtonSetState(orientSwitch, orient, True);
 	XmToggleButtonSetState(stickySwitch, sticky, True);
 	XmToggleButtonSetState(practiceSwitch, practice, True);
-	XmScaleSetValue(speed, MAXSPEED + MINSPEED - delay / MULTSPEED - 1);
+	{
+		int delay;
+
+		XtVaGetValues(w, XtNdelay, &delay, NULL);
+		XmScaleSetValue(speed,
+			MAXSPEED + MINSPEED - delay / MULTSPEED - 1);
+	}
 #endif
 #endif
 	SET_STARTED(w, False);
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(usernameDsp, username, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #endif
-	if (!strcmp(username, "") || !strcmp(username, "(null)") ||
-	    !strcmp(username, NOACCESS) || !strcmp(username, NOBODY)) {
+	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
+			!strcmp(userName, NOACCESS) ||
+			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(usernameDsp, username, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		/* The NOACCESS is not necessary, but it may stop silliness. */
-		(void) sprintf(usernameDsp, "%s", getlogin());
-		if (!strcmp(usernameDsp, "") ||
-				!strcmp(usernameDsp, "(null)") ||
-				!strcmp(usernameDsp, NOACCESS) ||
-				!strcmp(usernameDsp, NOBODY))
+		(void) sprintf(userNameDsp, "%s", getlogin());
+		if (!strcmp(userNameDsp, "") ||
+				!strcmp(userNameDsp, "(null)") ||
+				!strcmp(userNameDsp, NOACCESS) ||
+				!strcmp(userNameDsp, NOBODY))
 			/* It really IS nobody */
-			(void) sprintf(usernameDsp, "%s", "guest");
+			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
 	PrintRecord(size, mode, orient, sticky, practice);
 	oldSize = size;
+	PrintStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
-#endif
-		mode, size, sticky, movesDsp, messageDsp);
+		, mode, size, sticky
 #endif
+		);
 }
 
 #ifdef WINVER
@@ -652,16 +680,16 @@ CallbackPyraminx(Widget w, caddr_t clientData,
 #ifdef HAVE_MOTIF
 			XtManageChild(practiceDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 11); /* menu choice */
-			XtSetValues(pyraminx, arg, 1);
+			XtVaSetValues(pyraminx,
+				XtNmenu, 11, NULL); /* menu choice */
 #endif
 			break;
 		case PYRAMINX_RANDOMIZE_QUERY:
 #ifdef HAVE_MOTIF
 			XtManageChild(randomizeDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-			XtSetValues(pyraminx, arg, 1);
+			XtVaSetValues(pyraminx,
+				XtNmenu, 5, NULL); /* menu choice */
 #endif
 			break;
 #endif
@@ -679,7 +707,8 @@ CallbackPyraminx(Widget w, caddr_t clientData,
 			break;
 		case PYRAMINX_RESTORE:
 			if (practice) {
-				(void) strncpy(recordDsp, "practice", MESSAGELEN);
+				(void) strncpy(recordDsp, "practice",
+					MESSAGELEN);
 #ifdef HAVE_MOTIF
 				PrintState(record, recordDsp);
 #endif
@@ -690,7 +719,8 @@ CallbackPyraminx(Widget w, caddr_t clientData,
 			movesDsp = 0;
 			break;
 		case PYRAMINX_AMBIGUOUS:
-			(void) strncpy(messageDsp, "Ambiguous move", MESSAGELEN);
+			(void) strncpy(messageDsp, "Ambiguous move",
+				MESSAGELEN);
 			break;
 		case PYRAMINX_ILLEGAL:
 			if (practice || start)
@@ -711,12 +741,13 @@ CallbackPyraminx(Widget w, caddr_t clientData,
 				movesDsp = 0;
 			else if (cheat)
 				(void) sprintf(messageDsp,
-					"No cheating %s!!", usernameDsp);
+					"No cheating %s!!", userNameDsp);
 			else if (HandleSolved(movesDsp, size, mode, orient, sticky))
 				(void) sprintf(messageDsp,
-					"Congratulations %s!!", usernameDsp);
+					"Congratulations %s!!", userNameDsp);
 			else
-				(void) strncpy(messageDsp, "Solved!", MESSAGELEN);
+				(void) strncpy(messageDsp, "Solved!",
+					MESSAGELEN);
 			SET_STARTED(w, False);
 			break;
 		case PYRAMINX_PRACTICE:
@@ -730,9 +761,9 @@ CallbackPyraminx(Widget w, caddr_t clientData,
 			w->pyraminx.practice = practice;
 			w->pyraminx.started = False;
 #else
-			XtSetArg(arg[0], XtNpractice, practice);
-			XtSetArg(arg[1], XtNstart, False);
-			XtSetValues(w, arg, 2);
+			XtVaSetValues(w,
+				XtNpractice, practice,
+				XtNstart, False, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(practiceSwitch, practice, True);
 #endif
@@ -741,12 +772,12 @@ CallbackPyraminx(Widget w, caddr_t clientData,
 		case PYRAMINX_RANDOMIZE:
 			movesDsp = 0;
 #ifdef WINVER
-			w->pyraminx.practice = practice;
+			w->pyraminx.practice = False;
 			w->pyraminx.started = False;
 #else
-			XtSetArg(arg[0], XtNpractice, False);
-			XtSetArg(arg[1], XtNstart, False);
-			XtSetValues(w, arg, 2);
+			XtVaSetValues(w,
+				XtNpractice, False,
+				XtNstart, False, NULL);
 #endif
 			break;
 		case PYRAMINX_DEC:
@@ -758,8 +789,7 @@ CallbackPyraminx(Widget w, caddr_t clientData,
 #ifdef WINVER
 				w->pyraminx.size = size;
 #else
-				XtSetArg(arg[0], XtNsize, size);
-				XtSetValues(w, arg, 1);
+				XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
 				XmScaleSetValue(facets, size);
 				if (size >= MAXFACETS)
@@ -775,8 +805,7 @@ CallbackPyraminx(Widget w, caddr_t clientData,
 #ifdef WINVER
 			w->pyraminx.orient = orient;
 #else
-			XtSetArg(arg[0], XtNorient, orient);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNorient, orient, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(orientSwitch, orient, True);
 #endif
@@ -791,8 +820,7 @@ CallbackPyraminx(Widget w, caddr_t clientData,
 #ifdef WINVER
 				w->pyraminx.size = size;
 #else
-				XtSetArg(arg[0], XtNsize, size);
-				XtSetValues(w, arg, 1);
+				XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
 				if (size > MAXFACETS)
 					XtVaSetValues(facets, XmNmaximum, size, NULL);
@@ -810,8 +838,7 @@ CallbackPyraminx(Widget w, caddr_t clientData,
 #ifdef WINVER
 			w->pyraminx.mode = mode;
 #else
-			XtSetArg(arg[0], XtNmode, mode);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNmode, mode, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(modes[mode - PERIOD2], True, True);
 #endif
@@ -829,9 +856,9 @@ CallbackPyraminx(Widget w, caddr_t clientData,
 			w->pyraminx.sticky = sticky;
 			w->pyraminx.size = size;
 #else
-			XtSetArg(arg[0], XtNsticky, sticky);
-			XtSetArg(arg[1], XtNsize, size);
-			XtSetValues(w, arg, 2);
+			XtVaSetValues(w,
+				XtNsticky, sticky,
+				XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(stickySwitch, sticky, True);
 			XmScaleSetValue(facets, size);
@@ -846,17 +873,11 @@ CallbackPyraminx(Widget w, caddr_t clientData,
 			SET_STARTED(w, True);
 			break;
 	}
-#ifdef HAVE_MOTIF
-	PrintState(message, messageDsp);
-	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-#else
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
-#endif
-		mode, size, sticky, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp
+#ifndef HAVE_MOTIF
+		, mode, size, sticky
 #endif
+		);
 }
 
 #ifdef WINVER
@@ -881,7 +902,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	PAINTSTRUCT paint;
 	int shift = 0;
 
-	Wnd = widget.core.hWnd = hWnd;
+	widget.core.hWnd = hWnd;
 	if (GetFocus()) {
 		if (!widget.pyraminx.focus) {
 			widget.core.hDC = GetDC(hWnd);
@@ -1181,20 +1202,7 @@ static void
 Usage(char * programName)
 {
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr,
-		"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n");
-	(void) fprintf(stderr,
-		"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n");
-	(void) fprintf(stderr,
-		"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{border|bd} {color}] [-face{0|1|2|3} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{size {int} | sticky}] [-{mode {int} | both}]\n");
-	(void) fprintf(stderr,
-		"\t[-[no]orient] [-[no]practice] [-delay msecs]\n");
-	(void) fprintf(stderr,
-		"\t[-{font|fn} {fontname}] [-username {string}]\n");
+	(void) fprintf(stderr, optionsHelp);
 	exit(1);
 }
 
@@ -1227,7 +1235,10 @@ static XrmOptionDescRec options[] =
 	{(char *) "-delay", (char *) "*pyraminx.delay", XrmoptionSepArg, NULL},
 	{(char *) "-fn", (char *) "*pyraminx.font", XrmoptionSepArg, NULL},
 	{(char *) "-font", (char *) "*pyraminx.font", XrmoptionSepArg, NULL},
-	{(char *) "-username", (char *) "*pyraminx.userName", XrmoptionSepArg, NULL}
+	{(char *) "-userName", (char *) "*pyraminx.userName", XrmoptionSepArg, NULL},
+	{(char *) "-scoreFile", (char *) "*pyraminx.scoreFile", XrmoptionSepArg, NULL},
+	{(char *) "-scores", (char *) "*pyraminx.scoreOnly", XrmoptionNoArg, (char *) "TRUE"},
+	{(char *) "-version", (char *) "*pyraminx.versionOnly", XrmoptionNoArg, (char *) "TRUE"}
 };
 
 #ifdef HAVE_MOTIF
@@ -1235,8 +1246,7 @@ static void
 CallbackPyraminxPractice(Widget w, XtPointer clientData, XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 11); /* menu choice */
-		XtSetValues(pyraminx, arg, 1);
+		XtVaSetValues(pyraminx, XtNmenu, 11, NULL); /* menu choice */
 	}
 }
 
@@ -1244,8 +1254,7 @@ static void
 CallbackPyraminxRandomize(Widget w, XtPointer clientData, XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-		XtSetValues(pyraminx, arg, 1);
+		XtVaSetValues(pyraminx, XtNmenu, 5, NULL); /* menu choice */
 	}
 }
 static void
@@ -1351,9 +1360,10 @@ StickyToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct * cbs)
 }
 
 static void
-PracticeToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct * cbs)
+PracticeToggle(Widget w, XtPointer clientData,
+		XmToggleButtonCallbackStruct * cbs)
 {
-	int  size, mode;
+	int size, mode;
 	Boolean orient, sticky, practice = cbs->set;
 
 	XtVaSetValues(pyraminx,
@@ -1394,16 +1404,15 @@ fileCB(Widget w, void *value, void *clientData)
 
 	if (val == 2)
 		exit(0);
-	XtSetArg(arg[0], XtNmenu, val);
-	XtSetValues(pyraminx, arg, 1);
+	XtVaSetValues(pyraminx, XtNmenu, val, NULL);
 }
 
 static void
 playCB(Widget w, void *value, void *clientData)
 {
 	int val = (int) value;
-	XtSetArg(arg[0], XtNmenu, val + 3); /* GWQ */
-	XtSetValues(pyraminx, arg, 1);
+
+	XtVaSetValues(pyraminx, XtNmenu, val + 3, NULL); /* GWQ */
 }
 
 static Widget
@@ -1484,13 +1493,14 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d\n", val);
+			intCat(&buf, "helpCB: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
 	}
 }
 #endif
+
 int
 main(int argc, char **argv)
 {
@@ -1537,11 +1547,10 @@ main(int argc, char **argv)
 			RootWindowOfScreen(XtScreen(topLevel)),
 			(char *) pyraminx_bits,
 			pyraminx_width, pyraminx_height);
-	XtSetArg(arg[0], XtNiconPixmap, pyraminxIcon);
 #ifdef HAVE_MOTIF
-	/* not XmEXPLICIT */
-	XtSetArg(arg[1], XmNkeyboardFocusPolicy, XmPOINTER);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, pyraminxIcon,
+		XmNkeyboardFocusPolicy, XmPOINTER, NULL); /* not XmEXPLICIT */
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
 		xmPanedWindowWidgetClass, topLevel,
 		XmNseparatorOn, False,
@@ -1776,8 +1785,9 @@ main(int argc, char **argv)
 	pyraminx = XtCreateManagedWidget("pyraminx",
 		pyraminxWidgetClass, mainPanel, NULL, 0);
 #else
-	XtSetArg(arg[1], XtNinput, True);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, pyraminxIcon,
+		XtNinput, True, NULL);
 	pyraminx = XtCreateManagedWidget("pyraminx",
 		pyraminxWidgetClass, topLevel, NULL, 0);
 #endif
