@@ -25,6 +25,8 @@
 
 /* Methods file for Rubik */
 
+#include "file.h"
+#include "rngs.h"
 #include "RubikP.h"
 #include "Rubik2dP.h"
 #include "Rubik3dP.h"
@@ -111,78 +113,6 @@ RubikClassRec rubikClassRec =
 
 WidgetClass rubikWidgetClass = (WidgetClass) & rubikClassRec;
 
-#ifndef HAVE_USLEEP
-#if !defined( VMS ) || defined( XVMSUTILS ) ||  ( __VMS_VER >= 70000000 )
-#ifdef USE_XVMSUTILS
-#include <X11/unix_time.h>
-#endif
-#if HAVE_SYS_TIME_H
-#include <sys/time.h>
-#else
-#if HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#endif
-#endif
-#endif
-#if defined(SYSV) || defined(SVR4)
-#ifdef LESS_THAN_AIX3_2
-#include <sys/poll.h>
-#else /* !LESS_THAN_AIX3_2 */
-#include <poll.h>
-#endif /* !LESS_THAN_AIX3_2 */
-#endif /* defined(SYSV) || defined(SVR4) */
-
-/* not static in case usleep found in system include */
-int
-usleep(unsigned int usec)
-{
-#if (defined (SYSV) || defined(SVR4)) && !defined(__hpux)
-#if defined(HAVE_NANOSLEEP)
-	{
-		struct timespec rqt;
-
-		rqt.tv_nsec = 1000 * (usec % (unsigned int) 1000000);
-		rqt.tv_sec = usec / (unsigned int) 1000000;
-		return nanosleep(&rqt, NULL);
-	}
-#else
-	(void) poll(
-#if defined(__cplusplus) || defined(c_plusplus)
-		(pollfd *) /* guess */
-#else
-		(void *)
-#endif
-		0, (int) 0, usec / 1000);	/* ms resolution */
-#endif
-#else
-#ifdef VMS
-	long        timadr[2];
-
-	if (usec != 0) {
-		timadr[0] = -usec * 10;
-		timadr[1] = -1;
-
-		sys$setimr(4, &timadr, 0, 0, 0);
-		sys$waitfr(4);
-	}
-#else
-	struct timeval time_out;
-
-#if 0
-	/* (!defined(AIXV3) && !defined(__hpux)) */
-	extern int  select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
-
-#endif
-
-	time_out.tv_usec = usec % (unsigned int) 1000000;
-	time_out.tv_sec = usec / (unsigned int) 1000000;
-	(void) select(0, (void *) 0, (void *) 0, (void *) 0, &time_out);
-#endif
-#endif
-	return 0;
-}
-#endif
-
 void
 SetRubik(RubikWidget w, int reason)
 {
@@ -223,13 +153,13 @@ loadFont(RubikWidget w)
 	if ((w->rubik.fontInfo = XLoadQueryFont(display,
 			w->rubik.font)) == NULL) {
 		(void) sprintf(buf,
-			"Cannot open %s font.\nAttempting %s font as alternate\n",
+			"Can not open %s font.\nAttempting %s font as alternate\n",
 			w->rubik.font, altfontname);
 		DISPLAY_WARNING(buf);
 		if ((w->rubik.fontInfo = XLoadQueryFont(display,
 				altfontname)) == NULL) {
 			(void) sprintf(buf,
-				"Cannot open %s alternate font.\nUse the -font option to specify a font to use.\n",
+				"Can not open %s alternate font.\nUse the -font option to specify a font to use.\n",
 				altfontname);
 			DISPLAY_WARNING(buf);
 		}
@@ -294,38 +224,6 @@ static int  rowToRotate[MAXFACES][MAXORIENT] =
 	{3, 0, 1, 4}
 };
 
-#if (!defined(WINVER) || (WINVER <= 0x030a)) /* if X or WINDOWS 3.1 or less */
-void
-Sleep(unsigned int cMilliseconds)
-{
-#if (defined(WINVER) && (WINVER <= 0x030a))
-	unsigned long time_out = GetTickCount() + cMilliseconds;
-
-	while (time_out > GetTickCount());
-#else
-	(void) usleep(cMilliseconds * 1000);
-#endif
-}
-#endif
-
-void
-intCat(char ** string, const char * var1, const int var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + 21))) {
-        	DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%d", var1, var2);
-}
-
-void
-stringCat(char ** string, const char * var1, const char * var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + strlen(var2) + 1))) {
-        	DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%s", var1, var2);
-}
-
 static void
 CheckPieces(RubikWidget w)
 {
@@ -499,69 +397,6 @@ PrintRow(RubikWidget w, int orient, int size)
 
 #endif
 
-#ifdef WINVER
-void
-POLYGON(RubikWidget w, GC color, GC lineColor, const POINT * poly, int n,
-		Boolean origin)
-{
-	/* CoordModePrevious -> CoordModeOrigin */
-	POINT      *temp = NULL;
-	int         pt;
-
-	if (!origin) {
-		if (!(temp = (POINT *) malloc(sizeof (POINT) * n))) {
-			DISPLAY_ERROR("Not enough memory, exiting.");
-		}
-		temp[0] = poly[0];
-		for (pt = 1; pt < n; pt++) {
-			temp[pt].x = temp[pt - 1].x + poly[pt].x,
-			temp[pt].y = temp[pt - 1].y + poly[pt].y;
-		}
-	}
-	w->rubik.hPen = CreatePen(PS_SOLID, 1, lineColor);
-	w->rubik.hOldPen = (HPEN) SelectObject(w->core.hDC, w->rubik.hPen);
-	w->rubik.hBrush = CreateSolidBrush(color);
-	w->rubik.hOldBrush = (HBRUSH) SelectObject(w->core.hDC,
-		w->rubik.hBrush);
-	(void) Polygon(w->core.hDC, (origin) ? poly : temp, n);
-	(void) SelectObject(w->core.hDC, w->rubik.hOldBrush);
-	(void) DeleteObject(w->rubik.hBrush);
-	(void) SelectObject(w->core.hDC, w->rubik.hOldPen);
-        (void) DeleteObject(w->rubik.hPen);
-	if (!origin) {
-		free(temp);
-	}
-}
-
-void
-POLYLINE(RubikWidget w, GC color, const POINT * poly, int n,
-		Boolean origin)
-{
-	/* CoordModePrevious -> CoordModeOrigin */
-	POINT      *temp = NULL;
-	int         pt;
-
-	if (!origin) {
-		if (!(temp = (POINT *) malloc(sizeof (POINT) * n))) {
-			DISPLAY_ERROR("Not enough memory, exiting.");
-		}
-		temp[0] = poly[0];
-		for (pt = 1; pt < n; pt++) {
-			temp[pt].x = temp[pt - 1].x + poly[pt].x,
-			temp[pt].y = temp[pt - 1].y + poly[pt].y;
-		}
-	}
-	w->rubik.hPen = CreatePen(PS_SOLID, 1, color);
-	w->rubik.hOldPen = (HPEN) SelectObject(w->core.hDC, w->rubik.hPen);
-	(void) Polyline(w->core.hDC, (origin) ? poly : temp, n);
-	(void) SelectObject(w->core.hDC, w->rubik.hOldPen);
-        (void) DeleteObject(w->rubik.hPen);
-	if (!origin) {
-		free(temp);
-	}
-}
-#endif
-
 static void
 DrawSquare(const RubikWidget w, const int face, const int position, const int offset)
 {
@@ -641,7 +476,7 @@ RotateFace(RubikWidget w, int face, int direction)
 		DrawSquare(w, face, position, FALSE);
 	}
 	if (faceLoc != NULL)
-		(void) free((void *) faceLoc);
+		free(faceLoc);
 }
 
 /* Yeah this is big and ugly */
@@ -1005,13 +840,13 @@ ResetPieces(RubikWidget w)
 	for (face = 0; face < MAXFACES; face++) {
 		sizeOfFace = sizeFace(w, face);
 		if (w->rubik.cubeLoc[face])
-			(void) free((void *) w->rubik.cubeLoc[face]);
+			free(w->rubik.cubeLoc[face]);
 		if (!(w->rubik.cubeLoc[face] = (RubikLoc *)
 		      malloc(sizeof (RubikLoc) * sizeOfFace))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 		if (startLoc[face])
-			(void) free((void *) startLoc[face]);
+			free(startLoc[face]);
 		if (!(startLoc[face] = (RubikLoc *)
 		      malloc(sizeof (RubikLoc) * sizeOfFace))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
@@ -1023,7 +858,7 @@ ResetPieces(RubikWidget w)
 	}
 	for (orient = 0; orient < MAXORIENT; orient++) {
 		if (w->rubik.rowLoc[orient])
-			(void) free((void *) w->rubik.rowLoc[orient]);
+			free(w->rubik.rowLoc[orient]);
 		if (!(w->rubik.rowLoc[orient] = (RubikLoc *)
 		      malloc(sizeof (RubikLoc) * MAXMAXSIZE))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
@@ -1362,11 +1197,14 @@ SetValuesRubik(RubikWidget w)
 			szBuf, sizeof (szBuf), INIFILE);
 		w->rubik.faceChar[face] = szBuf[0];
 	}
-	(void) GetPrivateProfileString(SECTION, "name", "Guest",
+	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
 		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->rubik.username, szBuf);
-		w->rubik.username[80] = 0;
-
+	(void) strcpy(w->rubik.userName, szBuf);
+		w->rubik.userName[80] = 0;
+	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
+		szBuf, sizeof (szBuf), INIFILE);
+	(void) strcpy(w->rubik.scoreFile, szBuf);
+		w->rubik.scoreFile[80] = 0;
 }
 
 void
@@ -1393,7 +1231,7 @@ SizeRubik(RubikWidget w)
 }
 
 void
-ExposeRubik(const RubikWidget w)
+ExposeRubik(RubikWidget w)
 {
 	if (w->rubik.dim == 2)
 		ExposeRubik2D((Rubik2DWidget) w);
