@@ -37,6 +37,7 @@
 #ifndef WINVER
 #define XtNselectCallback ((char *) "selectCallback")
 #define XtNuserName ((char *) "userName")
+#define XtNscoreFile ((char *) "scoreFile")
 #define XtNsizex ((char *) "sizex")
 #define XtNsizey ((char *) "sizey")
 #define XtNsizez ((char *) "sizez")
@@ -61,7 +62,10 @@
 #define XtNfaceColor3 ((char *) "faceColor3")
 #define XtNfaceColor4 ((char *) "faceColor4")
 #define XtNfaceColor5 ((char *) "faceColor5")
+#define XtNscoreOnly ((char *) "scoreOnly")
+#define XtNversionOnly ((char *) "versionOnly")
 #define XtCUserName ((char *) "UserName")
+#define XtCScoreFile ((char *) "ScoreFile")
 #define XtCSizeX ((char *) "SizeX")
 #define XtCSizeY ((char *) "SizeY")
 #define XtCSizeZ ((char *) "SizeZ")
@@ -114,23 +118,6 @@ typedef struct {
 #define RUBIK_INCZ 13
 #define RUBIK_DIM 14
 
-#ifdef WINVER
-#ifdef UNIXDELIM
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#else
-#define CURRENTDELIM ".\\"
-#define FINALDELIM "\\"
-#endif
-#else
-#ifdef VMS
-#define CURRENTDELIM "[]"
-#define FINALDELIM ""
-#else
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#endif
-#endif
 #define MAXORIENT 4
 #define MAXFACES 6
 #define MINFACETS 1
@@ -146,8 +133,5 @@ typedef struct {
 
 typedef struct _RubikRec *RubikWidget;
 
-extern void intCat(char ** string, const char * var1, const int var2);
-extern void stringCat(char ** string, const char * var1, const char * var2);
-
 #endif /* _XtRubik_h */
 /* DON'T ADD STUFF AFTER THIS #endif */
