@@ -135,15 +135,18 @@ static XtActionsRec actionsListRubik2D[] =
 static XtResource resourcesRubik2D[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(RubikWidget, rubik.username),
-	 XtRString, (caddr_t) "nobody"},
+	 XtOffset(RubikWidget, rubik.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(RubikWidget, rubik.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.background),
 	 XtRString, (caddr_t) XtDefaultBackground},
-	{XtNframeColor, XtCForeground, XtRPixel, sizeof (Pixel),
+	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
 	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
@@ -221,6 +224,12 @@ static XtResource resourcesRubik2D[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(RubikWidget, rubik.cheat),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(RubikWidget, rubik.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(RubikWidget, rubik.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(RubikWidget, rubik.menu),
 	 XtRString, (caddr_t) "-1"},
@@ -290,6 +299,8 @@ static int  planeToCube[MAXRECT] =
 static int  cubeToPlane[MAXFACES] =
 {1, 3, 4, 5, 7, 10};
 
+static Pixmap dr = 0; /* dummy for future double buffering */
+
 static void
 FacePosition(Rubik2DWidget w, int faceX, int faceY,
 	     int *viewLengthx, int *viewLengthy)
@@ -319,28 +330,28 @@ DrawOrientLine(Rubik2DWidget w, int orient, int dx, int dy, GC borderGC)
 {
 	switch (orient) {
 		case TOP:
-			DRAWLINE(w, borderGC,
+			DRAWLINE(w, dr, borderGC,
 				  dx + w->rubik2d.cubeLength / 2,
 				  dy,
 				  dx + w->rubik2d.cubeLength / 2,
 				  dy + w->rubik.orientLineLength);
 			return;
 		case RIGHT:
-			DRAWLINE(w, borderGC,
+			DRAWLINE(w, dr, borderGC,
 				  dx + w->rubik2d.cubeLength,
 				  dy + w->rubik2d.cubeLength / 2,
 				  dx + w->rubik2d.cubeLength - w->rubik.orientLineLength - 1,
 				  dy + w->rubik2d.cubeLength / 2);
 			return;
 		case BOTTOM:
-			DRAWLINE(w, borderGC,
+			DRAWLINE(w, dr, borderGC,
 				  dx + w->rubik2d.cubeLength / 2,
 				  dy + w->rubik2d.cubeLength,
 				  dx + w->rubik2d.cubeLength / 2,
 				  dy + w->rubik2d.cubeLength - w->rubik.orientLineLength - 1);
 			return;
 		case LEFT:
-			DRAWLINE(w, borderGC,
+			DRAWLINE(w, dr, borderGC,
 				  dx,
 				  dy + w->rubik2d.cubeLength / 2,
 				  dx + w->rubik.orientLineLength,
@@ -397,7 +408,7 @@ DrawSquare2D(Rubik2DWidget w, int face, int position, int offset)
 		faceGC = w->rubik.faceGC[(int) w->rubik.cubeLoc[face][position].face];
 		borderGC = w->rubik.borderGC;
 	}
-	FILLRECTANGLE2(w, faceGC, borderGC,
+	FILLRECTANGLE2(w, dr, faceGC, borderGC,
 		dx, dy, w->rubik2d.cubeLength, w->rubik2d.cubeLength);
 	if (w->rubik.mono) {
 		int         letterX, letterY;
@@ -421,7 +432,7 @@ DrawSquare2D(Rubik2DWidget w, int face, int position, int offset)
 		} else {
 			borderGC = w->rubik.inverseGC;
 		}
-		DRAWTEXT(w, borderGC, letterX, letterY, buf, 1);
+		DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, 1);
 	}
 	if (w->rubik.orient)
 		DrawOrientLine(w, orient, dx, dy, borderGC);
@@ -447,32 +458,32 @@ DrawFrame2D(Rubik2DWidget w, Boolean focus)
 			tempLength.y += w->rubik2d.viewLengthz;
 		}
 	}
-	DRAWLINE(w, gc, pos[1].x, pos[0].y, pos[2].x, pos[0].y);
-	DRAWLINE(w, gc, pos[3].x, pos[1].y, pos[3].x, pos[2].y);
-	DRAWLINE(w, gc, pos[1].x, pos[3].y, pos[2].x, pos[3].y);
-	DRAWLINE(w, gc, pos[0].x, pos[1].y, pos[0].x, pos[2].y);
+	DRAWLINE(w, dr, gc, pos[1].x, pos[0].y, pos[2].x, pos[0].y);
+	DRAWLINE(w, dr, gc, pos[3].x, pos[1].y, pos[3].x, pos[2].y);
+	DRAWLINE(w, dr, gc, pos[1].x, pos[3].y, pos[2].x, pos[3].y);
+	DRAWLINE(w, dr, gc, pos[0].x, pos[1].y, pos[0].x, pos[2].y);
 	letters.x = (pos[0].x + pos[1].x) / 2 - w->rubik.delta;
 	letters.y = (pos[0].y + pos[1].y) / 2;
-	DRAWTEXT(w, w->rubik.borderGC,
+	DRAWTEXT(w, dr, w->rubik.borderGC,
 		(int) (letters.x + 5 * w->rubik.letterOffset.x),
 		(int) (letters.y + w->rubik.letterOffset.y), "Front", 5);
 	letters.x = (pos[2].x + pos[3].x) / 2 - w->rubik.delta;
 	letters.y = (pos[2].y + pos[3].y) / 2;
-	DRAWTEXT(w, w->rubik.borderGC,
+	DRAWTEXT(w, dr, w->rubik.borderGC,
 		 (int) (letters.x + 4 * w->rubik.letterOffset.x),
 		 (int) (letters.y + w->rubik.letterOffset.y), "Back", 4);
 	if (w->rubik.vertical) {
-		DRAWLINE(w, gc, pos[1].x, pos[0].y, pos[1].x, pos[4].y);
-		DRAWLINE(w, gc, pos[2].x, pos[0].y, pos[2].x, pos[4].y);
-		DRAWLINE(w, gc, pos[0].x, pos[1].y, pos[3].x, pos[1].y);
-		DRAWLINE(w, gc, pos[0].x, pos[2].y, pos[3].x, pos[2].y);
-		DRAWLINE(w, gc, pos[1].x, pos[4].y, pos[2].x, pos[4].y);
+		DRAWLINE(w, dr, gc, pos[1].x, pos[0].y, pos[1].x, pos[4].y);
+		DRAWLINE(w, dr, gc, pos[2].x, pos[0].y, pos[2].x, pos[4].y);
+		DRAWLINE(w, dr, gc, pos[0].x, pos[1].y, pos[3].x, pos[1].y);
+		DRAWLINE(w, dr, gc, pos[0].x, pos[2].y, pos[3].x, pos[2].y);
+		DRAWLINE(w, dr, gc, pos[1].x, pos[4].y, pos[2].x, pos[4].y);
 	} else {
-		DRAWLINE(w, gc, pos[0].x, pos[1].y, pos[4].x, pos[1].y);
-		DRAWLINE(w, gc, pos[0].x, pos[2].y, pos[4].x, pos[2].y);
-		DRAWLINE(w, gc, pos[1].x, pos[0].y, pos[1].x, pos[3].y);
-		DRAWLINE(w, gc, pos[2].x, pos[0].y, pos[2].x, pos[3].y);
-		DRAWLINE(w, gc, pos[4].x, pos[1].y, pos[4].x, pos[2].y);
+		DRAWLINE(w, dr, gc, pos[0].x, pos[1].y, pos[4].x, pos[1].y);
+		DRAWLINE(w, dr, gc, pos[0].x, pos[2].y, pos[4].x, pos[2].y);
+		DRAWLINE(w, dr, gc, pos[1].x, pos[0].y, pos[1].x, pos[3].y);
+		DRAWLINE(w, dr, gc, pos[2].x, pos[0].y, pos[2].x, pos[3].y);
+		DRAWLINE(w, dr, gc, pos[4].x, pos[1].y, pos[4].x, pos[2].y);
 	}
 }
 
@@ -691,7 +702,7 @@ Widget renew, XEvent * event, Region region
 	if (!w->core.visible)
 		return;
 #endif
-	FILLRECTANGLE(w, w->rubik.inverseGC,
+	FILLRECTANGLE(w, dr, w->rubik.inverseGC,
 		0, 0, w->core.width, w->core.height);
 	DrawFrame2D(w, w->rubik.focus);
 	DrawAllPieces((RubikWidget) w);
