@@ -37,9 +37,9 @@ typedef struct _Rubik2DClassPart {
 } Rubik2DClassPart;
 
 typedef struct _Rubik2DClassRec {
-	CoreClassPart core_class;
-	RubikClassPart rubik_class;
-	Rubik2DClassPart rubik2d_class;
+	CoreClassPart coreClass;
+	RubikClassPart rubikClass;
+	Rubik2DClassPart rubik2dClass;
 } Rubik2DClassRec;
 
 extern Rubik2DClassRec rubik2dClassRec;
