@@ -151,15 +151,18 @@ static XtActionsRec actionsListRubik3D[] =
 static XtResource resourcesRubik3D[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(RubikWidget, rubik.username),
-	 XtRString, (caddr_t) "nobody"},
+	 XtOffset(RubikWidget, rubik.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(RubikWidget, rubik.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.background),
 	 XtRString, (caddr_t) XtDefaultBackground},
-	{XtNframeColor, XtCForeground, XtRPixel, sizeof (Pixel),
+	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
 	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
@@ -237,6 +240,12 @@ static XtResource resourcesRubik3D[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(RubikWidget, rubik.cheat),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(RubikWidget, rubik.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(RubikWidget, rubik.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(RubikWidget, rubik.menu),
 	 XtRString, (caddr_t) "-1"},
@@ -306,6 +315,8 @@ static RowNext rotateToRow[MAXFACES] =	/* CW to min face */
 	{0, LEFT, TOP}
 };
 
+static Pixmap dr = 0; /* dummy for future double buffering */
+
 static void
 CubeOffset3D(Rubik3DWidget w, int face, int x, int y, int *dx, int *dy)
 {
@@ -557,8 +568,8 @@ DrawSquare3D(Rubik3DWidget w, int face, int position, int offset)
 		faceGC = w->rubik.faceGC[(int) w->rubik.cubeLoc[face][position].face];
 		borderGC = w->rubik.borderGC;
 	}
-	POLYGON((RubikWidget) w, faceGC, borderGC,
-		cubeLoc3D[face], MAXORIENT, False);
+	POLYGON((RubikWidget) w, dr, faceGC, borderGC,
+		cubeLoc3D[face], MAXORIENT, True, False);
 	if (w->rubik.mono) {
 		int         letterX, letterY;
 		char        buf[2];
@@ -579,11 +590,11 @@ DrawSquare3D(Rubik3DWidget w, int face, int position, int offset)
 		} else {
 			borderGC = w->rubik.inverseGC;
 		}
-		DRAWTEXT(w, borderGC,
+		DRAWTEXT(w, dr, borderGC,
 			    letterX, letterY, buf, 1);
 	}
 	if (w->rubik.orient) {
-		DRAWLINE(w, borderGC,
+		DRAWLINE(w, dr, borderGC,
 			  dx + orient3DList[face][(int) w->rubik.cubeLoc[face][position].rotation][0].x,
 			  dy + orient3DList[face][(int) w->rubik.cubeLoc[face][position].rotation][0].y,
 			  dx + orient3DList[face][(int) w->rubik.cubeLoc[face][position].rotation][1].x,
@@ -600,31 +611,32 @@ DrawFrame3D(Rubik3DWidget w, Boolean focus)
 	dx = w->rubik3d.viewSize.x + w->rubik.puzzleOffset.x;
 	dy = w->rubik3d.viewSize.y + w->rubik.puzzleOffset.y;
 	if (w->rubik.vertical) {
-		DRAWLINE(w, w->rubik.frameGC,
+		DRAWLINE(w, dr, w->rubik.frameGC,
 			  0, dy, dx + w->rubik.puzzleOffset.x + 1, dy);
-		DRAWTEXT(w, w->rubik.borderGC,
+		DRAWTEXT(w, dr, w->rubik.borderGC,
 			    (int) (2 * w->rubik.delta),
 			(int) (3 * w->rubik.delta + w->rubik.letterOffset.y),
 			    "Front", 5);
-		DRAWTEXT(w, w->rubik.borderGC, (int)
+		DRAWTEXT(w, dr, w->rubik.borderGC, (int)
 			    (-4 * w->rubik.delta + 2 * 6 * w->rubik.letterOffset.x + w->core.width),
 			    (int) (-w->rubik.delta - 2 * w->rubik.letterOffset.y + w->core.height),
 			    "Back", 4);
 	} else {
-		DRAWLINE(w, w->rubik.frameGC,
+		DRAWLINE(w, dr, w->rubik.frameGC,
 			  dx, 0, dx, dy + w->rubik.puzzleOffset.y + 1);
-		DRAWTEXT(w, w->rubik.borderGC,
+		DRAWTEXT(w, dr, w->rubik.borderGC,
 			    (int) (2 * w->rubik.delta),
 			(int) (3 * w->rubik.delta + w->rubik.letterOffset.y),
 			    "Front", 5);
-		DRAWTEXT(w, w->rubik.borderGC, (int)
+		DRAWTEXT(w, dr, w->rubik.borderGC, (int)
 			    (-4 * w->rubik.delta + 2 * 6 * w->rubik.letterOffset.x + w->core.width),
 			    (int) (-w->rubik.delta - 2 * w->rubik.letterOffset.y + w->core.height),
 			    "Back", 4);
 	}
-	for (face = 0; face < MAXFACES; face++)
-		POLYLINE((RubikWidget) w, gc,
+	for (face = 0; face < MAXFACES; face++) {
+		POLYLINE((RubikWidget) w, dr, gc,
 			faceLoc3D[face], MAXORIENT, False);
+	}
 }
 
 static void
@@ -1272,7 +1284,7 @@ Widget renew, XEvent * event, Region region
 	if (!w->core.visible)
 		return;
 #endif
-	FILLRECTANGLE(w, w->rubik.inverseGC,
+	FILLRECTANGLE(w, dr, w->rubik.inverseGC,
 		0, 0, w->core.width, w->core.height);
 	DrawFrame3D(w, w->rubik.focus);
 	DrawAllPieces((RubikWidget) w);
