@@ -37,9 +37,9 @@ typedef struct _Rubik3DClassPart {
 } Rubik3DClassPart;
 
 typedef struct _Rubik3DClassRec {
-	CoreClassPart core_class;
-	RubikClassPart rubik_class;
-	Rubik3DClassPart rubik3d_class;
+	CoreClassPart coreClass;
+	RubikClassPart rubikClass;
+	Rubik3DClassPart rubik3dClass;
 } Rubik3DClassRec;
 
 extern Rubik3DClassRec rubik3dClassRec;
@@ -61,6 +61,11 @@ extern Rubik3DClassRec rubik3dClassRec;
 #define DIVIDE(a) ((int)((double)a*2.0/SQRT_3))
 
 typedef struct _Rubik3DPart {
+#if 1
+#ifdef WINVER
+	int         dummy[2]; /* There is some corruption, so this is needed */
+#endif
+#endif
 	Point       viewMiddle;
 	Point       faceSize, viewSize;
 	Point       cubeSizex, cubeSizey, cubeSizez;
