@@ -288,15 +288,18 @@ static XtActionsRec actionsListRubikGL[] =
 static XtResource resourcesRubikGL[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(RubikWidget, rubik.username),
-	 XtRString, (caddr_t) "nobody"},
+	 XtOffset(RubikWidget, rubik.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(RubikWidget, rubik.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.background),
 	 XtRString, (caddr_t) XtDefaultBackground},
-	{XtNframeColor, XtCForeground, XtRPixel, sizeof (Pixel),
+	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
 	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
@@ -374,6 +377,12 @@ static XtResource resourcesRubikGL[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(RubikWidget, rubik.cheat),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(RubikWidget, rubik.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(RubikWidget, rubik.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(RubikWidget, rubik.menu),
 	 XtRString, (caddr_t) "-1"},
@@ -1984,6 +1993,9 @@ InitializeRubikGL(Widget request, Widget renew)
 		w->rubik.delay + 1 : MAXTURNINC);
 	(void) initGL(w);
 	ResizeRubikGL(w);
+	w->rubikGL.movement.face = NO_FACE;
+	w->rubikGL.movement.position = NO_POSITION;
+	w->rubikGL.movement.direction = NO_DEPTH;
 }
 
 static void
