@@ -39,9 +39,9 @@ typedef struct _RubikGLClassPart {
 } RubikGLClassPart;
 
 typedef struct _RubikGLClassRec {
-	CoreClassPart core_class;
-	RubikClassPart rubik_class;
-	RubikGLClassPart rubikGL_class;
+	CoreClassPart coreClass;
+	RubikClassPart rubikClass;
+	RubikGLClassPart rubikGLClass;
 } RubikGLClassRec;
 
 extern RubikGLClassRec rubikGLClassRec;
