@@ -25,6 +25,8 @@
 
 /* Methods file for Skewb */
 
+#include "file.h"
+#include "rngs.h"
 #include "SkewbP.h"
 #include "Skewb2dP.h"
 #include "Skewb3dP.h"
@@ -111,78 +113,6 @@ SkewbClassRec skewbClassRec =
 
 WidgetClass skewbWidgetClass = (WidgetClass) & skewbClassRec;
 
-#ifndef HAVE_USLEEP
-#if !defined( VMS ) || defined( XVMSUTILS ) ||  ( __VMS_VER >= 70000000 )
-#ifdef USE_XVMSUTILS
-#include <X11/unix_time.h>
-#endif
-#if HAVE_SYS_TIME_H
-#include <sys/time.h>
-#else
-#if HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#endif
-#endif
-#endif
-#if defined(SYSV) || defined(SVR4)
-#ifdef LESS_THAN_AIX3_2
-#include <sys/poll.h>
-#else /* !LESS_THAN_AIX3_2 */
-#include <poll.h>
-#endif /* !LESS_THAN_AIX3_2 */
-#endif /* defined(SYSV) || defined(SVR4) */
-
-/* not static in case usleep found in system include */
-int
-usleep(unsigned int usec)
-{
-#if (defined (SYSV) || defined(SVR4)) && !defined(__hpux)
-#if defined(HAVE_NANOSLEEP)
-	{
-		struct timespec rqt;
-
-		rqt.tv_nsec = 1000 * (usec % (unsigned int) 1000000);
-		rqt.tv_sec = usec / (unsigned int) 1000000;
-		return nanosleep(&rqt, NULL);
-	}
-#else
-	(void) poll(
-#if defined(__cplusplus) || defined(c_plusplus)
-		(pollfd *) /* guess */
-#else
-		(void *)
-#endif
-		0, (int) 0, usec / 1000);	/* ms resolution */
-#endif
-#else
-#ifdef VMS
-	long        timadr[2];
-
-	if (usec != 0) {
-		timadr[0] = -usec * 10;
-		timadr[1] = -1;
-
-		sys$setimr(4, &timadr, 0, 0, 0);
-		sys$waitfr(4);
-	}
-#else
-	struct timeval time_out;
-
-#if 0
-	/* (!defined(AIXV3) && !defined(__hpux)) */
-	extern int  select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
-
-#endif
-
-	time_out.tv_usec = usec % (unsigned int) 1000000;
-	time_out.tv_sec = usec / (unsigned int) 1000000;
-	(void) select(0, (void *) 0, (void *) 0, (void *) 0, &time_out);
-#endif
-#endif
-	return 0;
-}
-#endif
-
 void
 SetSkewb(SkewbWidget w, int reason)
 {
@@ -220,13 +150,13 @@ loadFont(SkewbWidget w)
 	if ((w->skewb.fontInfo = XLoadQueryFont(display,
 			w->skewb.font)) == NULL) {
 		(void) sprintf(buf,
-			"Cannot open %s font.\nAttempting %s font as alternate\n",
+			"Can not open %s font.\nAttempting %s font as alternate\n",
 			w->skewb.font, altfontname);
 		DISPLAY_WARNING(buf);
 		if ((w->skewb.fontInfo = XLoadQueryFont(display,
 				altfontname)) == NULL) {
 			(void) sprintf(buf,
-				"Cannot open %s alternate font.\nUse the -font option to specify a font to use.\n",
+				"Can not open %s alternate font.\nUse the -font option to specify a font to use.\n",
 				altfontname);
 			DISPLAY_WARNING(buf);
 		}
@@ -549,38 +479,6 @@ static SkewbLocPos orthToDiag[MAXFACES][MAXORIENT][MAXORIENT] =
 	}
 };
 
-#if (!defined(WINVER) || (WINVER <= 0x030a)) /* if X or WINDOWS 3.1 or less */
-static void
-Sleep(unsigned int cMilliseconds)
-{
-#if (defined(WINVER) && (WINVER <= 0x030a))
-	unsigned long time_out = GetTickCount() + cMilliseconds;
-
-	while (time_out > GetTickCount());
-#else
-	(void) usleep(cMilliseconds * 1000);
-#endif
-}
-#endif
-
-void
-intCat(char ** string, const char * var1, const int var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + 21))) {
-        	DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%d", var1, var2);
-}
-
-void
-stringCat(char ** string, const char * var1, const char * var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + strlen(var2) + 1))) {
-        	DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%s", var1, var2);
-}
-
 Boolean
 CheckSolved(SkewbWidget w)
 {
@@ -619,69 +517,6 @@ PrintCube(SkewbWidget w)
 
 #endif
 
-#ifdef WINVER
-void
-POLYGON(SkewbWidget w, GC color, GC lineColor, const POINT * poly, int n,
-		Boolean origin)
-{
-	/* CoordModePrevious -> CoordModeOrigin */
-	POINT      *temp = NULL;
-	int         pt;
-
-	if (!origin) {
-		if (!(temp = (POINT *) malloc(sizeof (POINT) * n))) {
-			DISPLAY_ERROR("Not enough memory, exiting.");
-		}
-		temp[0] = poly[0];
-		for (pt = 1; pt < n; pt++) {
-			temp[pt].x = temp[pt - 1].x + poly[pt].x,
-			temp[pt].y = temp[pt - 1].y + poly[pt].y;
-		}
-	}
-	w->skewb.hPen = CreatePen(PS_SOLID, 1, lineColor);
-	w->skewb.hOldPen = (HPEN) SelectObject(w->core.hDC, w->skewb.hPen);
-	w->skewb.hBrush = CreateSolidBrush(color);
-	w->skewb.hOldBrush = (HBRUSH) SelectObject(w->core.hDC,
-		w->skewb.hBrush);
-	(void) Polygon(w->core.hDC, (origin) ? poly : temp, n);
-	(void) SelectObject(w->core.hDC, w->skewb.hOldBrush);
-	(void) DeleteObject(w->skewb.hBrush);
-	(void) SelectObject(w->core.hDC, w->skewb.hOldPen);
-        (void) DeleteObject(w->skewb.hPen);
-	if (!origin) {
-		free(temp);
-	}
-}
-
-void
-POLYLINE(SkewbWidget w, GC color, const POINT * poly, int n,
-		Boolean origin)
-{
-	/* CoordModePrevious -> CoordModeOrigin */
-	POINT      *temp = NULL;
-	int         pt;
-
-	if (!origin) {
-		if (!(temp = (POINT *) malloc(sizeof (POINT) * n))) {
-			DISPLAY_ERROR("Not enough memory, exiting.");
-		}
-		temp[0] = poly[0];
-		for (pt = 1; pt < n; pt++) {
-			temp[pt].x = temp[pt - 1].x + poly[pt].x,
-			temp[pt].y = temp[pt - 1].y + poly[pt].y;
-		}
-	}
-	w->skewb.hPen = CreatePen(PS_SOLID, 1, color);
-	w->skewb.hOldPen = (HPEN) SelectObject(w->core.hDC, w->skewb.hPen);
-	(void) Polygon(w->core.hDC, (origin) ? poly : temp, n);
-	(void) SelectObject(w->core.hDC, w->skewb.hOldPen);
-        (void) DeleteObject(w->skewb.hPen);
-	if (!origin) {
-		free(temp);
-	}
-}
-#endif
-
 static void
 DrawDiamond(SkewbWidget w, int face, int offset)
 {
@@ -1306,11 +1141,14 @@ SetValuesSkewb(SkewbWidget w)
 			szBuf, sizeof (szBuf), INIFILE);
 		w->skewb.faceChar[face] = szBuf[0];
 	}
-	(void) GetPrivateProfileString(SECTION, "name", "Guest",
+	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
 		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->skewb.username, szBuf);
-		w->skewb.username[80] = 0;
-
+	(void) strcpy(w->skewb.userName, szBuf);
+		w->skewb.userName[80] = 0;
+	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
+		szBuf, sizeof (szBuf), INIFILE);
+	(void) strcpy(w->skewb.scoreFile, szBuf);
+		w->skewb.scoreFile[80] = 0;
 }
 
 void
@@ -1470,8 +1308,8 @@ SetValuesSkewb(Widget current, Widget request, Widget renew)
 		SetAllColors(w);
 		redraw = True;
 	} else if (w->skewb.background != c->skewb.background ||
-		w->skewb.foreground != c->skewb.foreground ||
-		setColors) {
+			w->skewb.foreground != c->skewb.foreground ||
+			setColors) {
 		SetAllColors(w);
 		redraw = True;
 	}
@@ -1636,9 +1474,7 @@ SelectSkewb(SkewbWidget w
 		if (w->skewb.currentPosition == MAXORIENT) {
 			if (control || alt || w->skewb.practice || !CheckSolved(w)) {
 				DrawDiamond(w, w->skewb.currentFace, TRUE);
-#ifndef WINVER
-				XFlush(XtDisplay(w));
-#endif
+				FLUSH(w);
 				Sleep(100);
 				DrawDiamond(w, w->skewb.currentFace, FALSE);
 				w->skewb.currentFace = SKEWB_IGNORE;
