@@ -37,6 +37,7 @@
 #ifndef WINVER
 #define XtNselectCallback ((char *) "selectCallback")
 #define XtNuserName ((char *) "userName")
+#define XtNscoreFile ((char *) "scoreFile")
 #define XtNorient ((char *) "orient")
 #define XtNmono ((char *) "mono")
 #define XtNreverse ((char *) "reverse")
@@ -56,7 +57,10 @@
 #define XtNfaceColor3 ((char *) "faceColor3")
 #define XtNfaceColor4 ((char *) "faceColor4")
 #define XtNfaceColor5 ((char *) "faceColor5")
+#define XtNscoreOnly ((char *) "scoreOnly")
+#define XtNversionOnly ((char *) "versionOnly")
 #define XtCUserName ((char *) "UserName")
+#define XtCScoreFile ((char *) "ScoreFile")
 #define XtCOrient ((char *) "Orient")
 #define XtCMono ((char *) "Mono")
 #define XtCReverse ((char *) "Reverse")
@@ -99,23 +103,6 @@ typedef struct {
 #define SKEWB_UNDO 9
 #define SKEWB_DIM 10
 
-#ifdef WINVER
-#ifdef UNIXDELIM
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#else
-#define CURRENTDELIM ".\\"
-#define FINALDELIM "\\"
-#endif
-#else
-#ifdef VMS
-#define CURRENTDELIM "[]"
-#define FINALDELIM ""
-#else
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#endif
-#endif
 #define MAXFACES 6
 #define DEFAULTORIENT FALSE
 #define DEFAULTPRACTICE FALSE
@@ -128,8 +115,5 @@ typedef struct {
 
 typedef struct _SkewbRec *SkewbWidget;
 
-extern void intCat(char ** string, const char * var1, const int var2);
-extern void stringCat(char ** string, const char * var1, const char * var2);
-
 #endif /* _XtSkewb_h */
 /* DON'T ADD STUFF AFTER THIS #endif */
