@@ -141,15 +141,18 @@ static XtActionsRec actionsListSkewb2D[] =
 static XtResource resourcesSkewb2D[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(SkewbWidget, skewb.username),
-	 XtRString, (caddr_t) "nobody"},
+	 XtOffset(SkewbWidget, skewb.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(SkewbWidget, skewb.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.background),
 	 XtRString, (caddr_t) XtDefaultBackground},
-	{XtNframeColor, XtCForeground, XtRPixel, sizeof (Pixel),
+	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
 	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
@@ -209,6 +212,12 @@ static XtResource resourcesSkewb2D[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(SkewbWidget, skewb.cheat),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(SkewbWidget, skewb.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(SkewbWidget, skewb.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
          XtOffset(SkewbWidget, skewb.menu),
          XtRString, (caddr_t) "-1"},
@@ -314,6 +323,8 @@ static Point letterUnit[MAXCUBES] =
 static Point diamondList[MAXORIENT + 1], triangleList[MAXORIENT][4];
 static Point letterList[MAXCUBES], offsetList[MAXCUBES];
 
+static Pixmap dr = 0; /* dummy for future double buffering */
+
 static void
 DrawOrientLine(Skewb2DWidget w, int cube, int orient, int dx, int dy,
 		GC borderGC)
@@ -323,14 +334,14 @@ DrawOrientLine(Skewb2DWidget w, int cube, int orient, int dx, int dy,
 	if (cube == MAXORIENT) {
 		switch (orient) {
 			case TR:
-				DRAWLINE(w, borderGC,
+				DRAWLINE(w, dr, borderGC,
 				       dx + w->skewb2d.diamondLength / 2 - 2,
 					  dy + w->skewb.delta - 2,
 				       dx + w->skewb2d.diamondLength / 2 - 2,
 					  dy + w->skewb.delta + w->skewb.orientLineLength);
 				return;
 			case BR:
-				DRAWLINE(w, borderGC,
+				DRAWLINE(w, dr, borderGC,
 					  dx + w->skewb2d.diamondLength - 7,
 				       dy + w->skewb2d.diamondLength / 2 - 2,
 					  dx + w->skewb2d.diamondLength -
@@ -338,7 +349,7 @@ DrawOrientLine(Skewb2DWidget w, int cube, int orient, int dx, int dy,
 				      dy + w->skewb2d.diamondLength / 2 - 2);
 				return;
 			case BL:
-				DRAWLINE(w, borderGC,
+				DRAWLINE(w, dr, borderGC,
 				       dx + w->skewb2d.diamondLength / 2 - 2,
 					  dy + w->skewb2d.diamondLength - 7,
 				       dx + w->skewb2d.diamondLength / 2 - 2,
@@ -346,7 +357,7 @@ DrawOrientLine(Skewb2DWidget w, int cube, int orient, int dx, int dy,
 					  w->skewb.orientLineLength - 7);
 				return;
 			case TL:
-				DRAWLINE(w, borderGC,
+				DRAWLINE(w, dr, borderGC,
 					  dx + w->skewb.delta - 2,
 				       dy + w->skewb2d.diamondLength / 2 - 2,
 					  dx + w->skewb.delta + w->skewb.orientLineLength,
@@ -361,28 +372,28 @@ DrawOrientLine(Skewb2DWidget w, int cube, int orient, int dx, int dy,
 	} else {	/* cube != MAXORIENT */
 		switch (orient) {
 			case TR:
-				DRAWLINE(w, borderGC,
+				DRAWLINE(w, dr, borderGC,
 					  dx,
 					  dy - w->skewb.delta,
 					  dx,
 					  dy - w->skewb.delta - w->skewb.orientLineLength / 2);
 				return;
 			case BR:
-				DRAWLINE(w, borderGC,
+				DRAWLINE(w, dr, borderGC,
 					  dx + w->skewb.delta,
 					  dy,
 					  dx + w->skewb.delta + w->skewb.orientLineLength / 2,
 					  dy);
 				return;
 			case BL:
-				DRAWLINE(w, borderGC,
+				DRAWLINE(w, dr, borderGC,
 					  dx,
 					  dy + w->skewb.delta,
 					  dx,
 					  dy + w->skewb.delta + w->skewb.orientLineLength / 2);
 				return;
 			case TL:
-				DRAWLINE(w, borderGC,
+				DRAWLINE(w, dr, borderGC,
 					  dx - w->skewb.delta,
 					  dy,
 					  dx - w->skewb.delta - w->skewb.orientLineLength / 2,
@@ -431,8 +442,8 @@ DrawDiamond2D(Skewb2DWidget w, int face, int offset)
 		faceGC = w->skewb.faceGC[(int) w->skewb.cubeLoc[face][MAXORIENT].face];
 		borderGC = w->skewb.borderGC;
 	}
-	POLYGON((SkewbWidget) w, faceGC, borderGC,
-		diamondList, 4, False);
+	POLYGON((SkewbWidget) w, dr, faceGC, borderGC,
+		diamondList, 4, True, False);
 	if (w->skewb.mono) {
 		int         letterX, letterY;
 		char        buf[2];
@@ -453,7 +464,7 @@ DrawDiamond2D(Skewb2DWidget w, int face, int offset)
 		} else {
 			borderGC = w->skewb.inverseGC;
 		}
-		DRAWTEXT(w, borderGC,
+		DRAWTEXT(w, dr, borderGC,
 			    letterX, letterY, buf, 1);
 	}
 	if (w->skewb.orient)
@@ -498,8 +509,8 @@ DrawTriangle2D(Skewb2DWidget w, int face, int position, int offset)
 		faceGC = w->skewb.faceGC[(int) w->skewb.cubeLoc[face][position].face];
 		borderGC = w->skewb.borderGC;
 	}
-	POLYGON((SkewbWidget) w, faceGC, borderGC,
-		triangleList[newCorner], 3, False);
+	POLYGON((SkewbWidget) w, dr, faceGC, borderGC,
+		triangleList[newCorner], 3, True, False);
 	if (w->skewb.mono) {
 		char        buf[2];
 
@@ -517,7 +528,7 @@ DrawTriangle2D(Skewb2DWidget w, int face, int position, int offset)
 		} else {
 			borderGC = w->skewb.inverseGC;
 		}
-		DRAWTEXT(w, borderGC, letterX, letterY, buf, 1);
+		DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, 1);
 	}
 	if (w->skewb.orient)
 		DrawOrientLine(w, newCorner, orient,
@@ -537,32 +548,32 @@ DrawFrame2D(Skewb2DWidget w, Boolean focus)
 		pos[i].x = i * w->skewb2d.viewLength + w->skewb.puzzleOffset.x;
 		pos[i].y = i * w->skewb2d.viewLength + w->skewb.puzzleOffset.y;
 	}
-	DRAWLINE(w, gc, pos[1].x, pos[0].y, pos[2].x, pos[0].y);
-	DRAWLINE(w, gc, pos[3].x, pos[1].y, pos[3].x, pos[2].y);
-	DRAWLINE(w, gc, pos[1].x, pos[3].y, pos[2].x, pos[3].y);
-	DRAWLINE(w, gc, pos[0].x, pos[1].y, pos[0].x, pos[2].y);
+	DRAWLINE(w, dr, gc, pos[1].x, pos[0].y, pos[2].x, pos[0].y);
+	DRAWLINE(w, dr, gc, pos[3].x, pos[1].y, pos[3].x, pos[2].y);
+	DRAWLINE(w, dr, gc, pos[1].x, pos[3].y, pos[2].x, pos[3].y);
+	DRAWLINE(w, dr, gc, pos[0].x, pos[1].y, pos[0].x, pos[2].y);
 	letters.x = pos[0].x + w->skewb2d.viewLength / 2 - w->skewb.delta;
 	letters.y = pos[0].y + w->skewb2d.viewLength / 2;
-	DRAWTEXT(w, w->skewb.borderGC,
+	DRAWTEXT(w, dr, w->skewb.borderGC,
 		    (int) (letters.x + 5 * w->skewb.letterOffset.x),
 		    (int) (letters.y + w->skewb.letterOffset.y), "Front", 5);
 	letters.x = pos[2].x + w->skewb2d.viewLength / 2 - w->skewb.delta;
 	letters.y = pos[2].y + w->skewb2d.viewLength / 2;
-	DRAWTEXT(w, w->skewb.borderGC,
+	DRAWTEXT(w, dr, w->skewb.borderGC,
 		    (int) (letters.x + 4 * w->skewb.letterOffset.x),
 		    (int) (letters.y + w->skewb.letterOffset.y), "Back", 4);
 	if (w->skewb.vertical) {
-		DRAWLINE(w, gc, pos[1].x, pos[0].y, pos[1].x, pos[4].y);
-		DRAWLINE(w, gc, pos[2].x, pos[0].y, pos[2].x, pos[4].y);
-		DRAWLINE(w, gc, pos[0].x, pos[1].y, pos[3].x, pos[1].y);
-		DRAWLINE(w, gc, pos[0].x, pos[2].y, pos[3].x, pos[2].y);
-		DRAWLINE(w, gc, pos[1].x, pos[4].y, pos[2].x, pos[4].y);
+		DRAWLINE(w, dr, gc, pos[1].x, pos[0].y, pos[1].x, pos[4].y);
+		DRAWLINE(w, dr, gc, pos[2].x, pos[0].y, pos[2].x, pos[4].y);
+		DRAWLINE(w, dr, gc, pos[0].x, pos[1].y, pos[3].x, pos[1].y);
+		DRAWLINE(w, dr, gc, pos[0].x, pos[2].y, pos[3].x, pos[2].y);
+		DRAWLINE(w, dr, gc, pos[1].x, pos[4].y, pos[2].x, pos[4].y);
 	} else {
-		DRAWLINE(w, gc, pos[0].x, pos[1].y, pos[4].x, pos[1].y);
-		DRAWLINE(w, gc, pos[0].x, pos[2].y, pos[4].x, pos[2].y);
-		DRAWLINE(w, gc, pos[1].x, pos[0].y, pos[1].x, pos[3].y);
-		DRAWLINE(w, gc, pos[2].x, pos[0].y, pos[2].x, pos[3].y);
-		DRAWLINE(w, gc, pos[4].x, pos[1].y, pos[4].x, pos[2].y);
+		DRAWLINE(w, dr, gc, pos[0].x, pos[1].y, pos[4].x, pos[1].y);
+		DRAWLINE(w, dr, gc, pos[0].x, pos[2].y, pos[4].x, pos[2].y);
+		DRAWLINE(w, dr, gc, pos[1].x, pos[0].y, pos[1].x, pos[3].y);
+		DRAWLINE(w, dr, gc, pos[2].x, pos[0].y, pos[2].x, pos[3].y);
+		DRAWLINE(w, dr, gc, pos[4].x, pos[1].y, pos[4].x, pos[2].y);
 	}
 }
 
@@ -799,7 +810,7 @@ Widget renew, XEvent * event, Region region
 	if (!w->core.visible)
 		return;
 #endif
-	FILLRECTANGLE(w, w->skewb.inverseGC,
+	FILLRECTANGLE(w, dr, w->skewb.inverseGC,
 		0, 0, w->core.width, w->core.height);
 	DrawFrame2D(w, w->skewb.focus);
 	DrawAllPieces((SkewbWidget) w);
