@@ -141,15 +141,18 @@ static XtActionsRec actionsListSkewb3D[] =
 static XtResource resourcesSkewb3D[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(SkewbWidget, skewb.username),
-	 XtRString, (caddr_t) "nobody"},
+	 XtOffset(SkewbWidget, skewb.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(SkewbWidget, skewb.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.background),
 	 XtRString, (caddr_t) XtDefaultBackground},
-	{XtNframeColor, XtCForeground, XtRPixel, sizeof (Pixel),
+	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
 	{XtNpieceBorder, XtCColor, XtRPixel, sizeof (Pixel),
@@ -209,7 +212,12 @@ static XtResource resourcesSkewb3D[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(SkewbWidget, skewb.cheat),
 	 XtRString, (caddr_t) "FALSE"},
-	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(SkewbWidget, skewb.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(SkewbWidget, skewb.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},{XtNmenu, XtCMenu, XtRInt, sizeof (int),
          XtOffset(SkewbWidget, skewb.menu),
          XtRString, (caddr_t) "-1"},
 	{XtNselectCallback, XtCCallback, XtRCallback, sizeof (caddr_t),
@@ -272,6 +280,8 @@ static Point letter3DList[MAXFACES][MAXCUBES];
 static Point orientDiamond[MAXFACES][MAXORIENT][2];
 static Point orientTriangle[MAXFACES][MAXORIENT][2];
 
+static Pixmap dr = 0; /* dummy for future double buffering */
+
 static void
 DiamondOffset3D(Skewb3DWidget w, int face, int *dx, int *dy)
 {
@@ -441,8 +451,8 @@ DrawTriangle3D(Skewb3DWidget w, int face, int position, int offset)
 		faceGC = w->skewb.faceGC[(int) w->skewb.cubeLoc[face][position].face];
 		borderGC = w->skewb.borderGC;
 	}
-	POLYGON((SkewbWidget) w, faceGC, borderGC,
-		triangleLoc3D[face][side], 3, False);
+	POLYGON((SkewbWidget) w, dr, faceGC, borderGC,
+		triangleLoc3D[face][side], 3, True, False);
 	if (w->skewb.mono) {
 		char        buf[2];
 
@@ -460,12 +470,12 @@ DrawTriangle3D(Skewb3DWidget w, int face, int position, int offset)
 		} else {
 			borderGC = w->skewb.inverseGC;
 		}
-		DRAWTEXT(w, borderGC,
+		DRAWTEXT(w, dr, borderGC,
 			    letterX + w->skewb.letterOffset.x, letterY + w->skewb.letterOffset.y,
 			    buf, 1);
 	}
 	if (w->skewb.orient) {
-		DRAWLINE(w, borderGC,
+		DRAWLINE(w, dr, borderGC,
 			  letterX +
 			  orientTriangle[face][w->skewb.cubeLoc[face][position].rotation][0].x,
 			  letterY +
@@ -497,8 +507,8 @@ DrawDiamond3D(Skewb3DWidget w, int face, int offset)
 		faceGC = w->skewb.faceGC[(int) w->skewb.cubeLoc[face][MAXORIENT].face];
 		borderGC = w->skewb.borderGC;
 	}
-	POLYGON((SkewbWidget) w, faceGC, borderGC,
-		diamondLoc3D[face], 4, False);
+	POLYGON((SkewbWidget) w, dr, faceGC, borderGC,
+		diamondLoc3D[face], 4, True, False);
 	if (w->skewb.mono) {
 		int         letterX, letterY;
 		char        buf[2];
@@ -519,11 +529,11 @@ DrawDiamond3D(Skewb3DWidget w, int face, int offset)
 		} else {
 			borderGC = w->skewb.inverseGC;
 		}
-		DRAWTEXT(w, borderGC,
+		DRAWTEXT(w, dr, borderGC,
 			    letterX, letterY, buf, 1);
 	}
 	if (w->skewb.orient) {
-		DRAWLINE(w, borderGC,
+		DRAWLINE(w, dr, borderGC,
 			  dx +
 			  orientDiamond[face][w->skewb.cubeLoc[face][MAXORIENT].rotation][0].x,
 			  dy +
@@ -544,31 +554,32 @@ DrawFrame3D(Skewb3DWidget w, Boolean focus)
 	dx = w->skewb3d.viewSize.x + w->skewb.puzzleOffset.x;
 	dy = w->skewb3d.viewSize.y + w->skewb.puzzleOffset.y;
 	if (w->skewb.vertical) {
-		DRAWLINE(w, w->skewb.frameGC,
+		DRAWLINE(w, dr, w->skewb.frameGC,
 			  0, dy, dx + w->skewb.puzzleOffset.x + 1, dy);
-		DRAWTEXT(w, w->skewb.borderGC,
+		DRAWTEXT(w, dr, w->skewb.borderGC,
 			    (int) (2 * w->skewb.delta),
 			(int) (3 * w->skewb.delta + w->skewb.letterOffset.y),
 			    "Front", 5);
-		DRAWTEXT(w, w->skewb.borderGC, (int)
+		DRAWTEXT(w, dr, w->skewb.borderGC, (int)
 			    (-4 * w->skewb.delta + 2 * 6 * w->skewb.letterOffset.x + w->core.width),
 			    (int) (-w->skewb.delta - 2 * w->skewb.letterOffset.y + w->core.height),
 			    "Back", 4);
 	} else {
-		DRAWLINE(w, w->skewb.frameGC,
+		DRAWLINE(w, dr, w->skewb.frameGC,
 			  dx, 0, dx, dy + w->skewb.puzzleOffset.y + 1);
-		DRAWTEXT(w, w->skewb.borderGC,
+		DRAWTEXT(w, dr, w->skewb.borderGC,
 			    (int) (2 * w->skewb.delta),
 			(int) (3 * w->skewb.delta + w->skewb.letterOffset.y),
 			    "Front", 5);
-		DRAWTEXT(w, w->skewb.borderGC, (int)
+		DRAWTEXT(w, dr, w->skewb.borderGC, (int)
 			    (-4 * w->skewb.delta + 2 * 6 * w->skewb.letterOffset.x + w->core.width),
 			    (int) (-w->skewb.delta - 2 * w->skewb.letterOffset.y + w->core.height),
 			    "Back", 4);
 	}
-	for (face = 0; face < MAXFACES; face++)
-		POLYLINE((SkewbWidget) w, gc,
+	for (face = 0; face < MAXFACES; face++) {
+		POLYLINE((SkewbWidget) w, dr, gc,
 			faceLoc3D[face], MAXORIENT, False);
+	}
 }
 
 static void
@@ -1113,7 +1124,7 @@ Widget renew, XEvent * event, Region region
 	if (!w->core.visible)
 		return;
 #endif
-	FILLRECTANGLE(w, w->skewb.inverseGC,
+	FILLRECTANGLE(w, dr, w->skewb.inverseGC,
 		0, 0, w->core.width, w->core.height);
 	DrawFrame3D(w, w->skewb.focus) ;
 	DrawAllPieces((SkewbWidget) w);
