@@ -39,9 +39,9 @@ typedef struct _SkewbGLClassPart {
 } SkewbGLClassPart;
 
 typedef struct _SkewbGLClassRec {
-	CoreClassPart core_class;
-	SkewbClassPart skewb_class;
-	SkewbGLClassPart skewbGL_class;
+	CoreClassPart coreClass;
+	SkewbClassPart skewbClass;
+	SkewbGLClassPart skewbGLClass;
 } SkewbGLClassRec;
 
 extern SkewbGLClassRec skewbGLClassRec;
