@@ -32,38 +32,25 @@
   Version 1: 91/03/19 SunView
 */
 
+#include "file.h"
 #ifdef WINVER
 #include "SkewbP.h"
 #include "wskewb.h"
 #define TITLE "wskewb"
 
 static SkewbRec widget;
-static HWND Wnd;
 
 #ifndef SCOREPATH
-#define SCOREPATH "c:\\Windows"
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
 #endif
-#define PRINT_MESSAGE(b) (void) MessageBox(Wnd, (LPCSTR) b, "Warning", MB_OK);
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
 #define SET_STARTED(w,b) w->skewb.started = b
 #else
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
-#ifdef VMS
-#include <unixlib.h>
-#define getlogin() cuserid(NULL)
-#else
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif
-#if HAVE_FCNTL_H
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#endif
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
+#include "xwin.h"
 #include <X11/Shell.h>
 #include <X11/cursorfont.h>
 #ifdef HAVE_MOTIF
@@ -83,7 +70,7 @@ static HWND Wnd;
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
-#define SET_STARTED(w,b) XtSetArg(arg[0], XtNstart, b); XtSetValues(w, arg, 1)
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
 #include "Skewb.h"
 #include "Skewb2d.h"
 #include "Skewb3d.h"
@@ -96,27 +83,34 @@ static HWND Wnd;
 #endif
 #include "icons/skewb.xbm"
 #ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
 #define SCOREPATH "/var/games/xpuzzles"
 #endif
 #endif
+#endif
 
-#ifdef HAVE_MOTIF
+#ifndef WINVER
 static const char aboutHelp[] = {
-	"Version 7.1.3\n"
+	"Skewb Version 7.1.5\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
 	"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
+
 static const char optionsHelp[] = {
-	"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]] "
-	"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"[-{foreground|fg} {color}] [-{background|bg} {color}] "
-	"[-{border|bd} {color}] [-face{0|1|2|3|4|5} {color}] \n"
-	"[-[no]orient] [-[no]practice] [-{font|fn} {fontname}] "
-	"[-username {string}]\n"
+	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+	"\t[-{border|bd} {color}] [-face{0|1|2|3|4|5} {color}] \n"
+	"\t[-[no]orient] [-[no]practice] [-{font|fn} {fontname}]\n"
+	"\t[-userName {string}] [-scoreFile {filename}] [-scores]\n"
+	"\t[-version]\n"
 };
 #endif
+
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
 	"The original puzzle has each face cut by a diamond, so "
@@ -142,18 +136,22 @@ static const char descriptionHelp[] = {
 	"different symbols of 4 each  at the 12 intersection\n"
 	"points.\n"
 };
+
 static const char featuresHelp[] = {
-	"Press  \"mouse-left\"  button  to move a piece.  Release "
-	"\"mouse-left\"  button on a piece  on the same face.\n"
+	"Press \"mouse-left\" button to move a piece.  Release "
+	"\"mouse-left\" button on a piece  on the same face.\n"
 	"(Clicks on diamonds are ignored).  The pieces will then "
 	"turn towards where the mouse button was released.\n"
+	"\n"
 	"Click \"mouse-center\" button, or press \"P\" or \"p\" "
-	"keys, to toggle  the practice mode (in practice mode the\n"
-	"record should say \"practice\").  This is good for learning "
-	"moves and experimenting.\n"
+	"keys, to toggle the practice mode  (in practice mode the\n"
+	"the record should say \"practice\").  This is good for "
+	"learning moves and experimenting.\n"
+	"\n"
 	"Click \"mouse-right\" button,  or press \"R\" or \"r\" "
 	"keys,  to randomize the puzzle  (this must be done first\n"
 	"to set a new record).\n"
+	"\n"
 	"Press \"O\" or \"o\" keys to toggle  the orient mode.  One "
 	"has  to orient the faces  in orient mode,  besides\n"
 	"getting  all the faces to be the  same color.  To do this "
@@ -161,13 +159,22 @@ static const char featuresHelp[] = {
 	"same direction,  this only matters with  center diamond "
 	"piece.  This does add complexity  so there are 2\n"
 	"sets of records.\n"
+	"\n"
 	"\"S\" or \"s\" keys reserved for the auto-solver "
 	"(not implemented).\n"
+	"\n"
 	"Press \"U\" or \"u\" keys to undo a move.\n"
+	"\n"
 	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+	"\n"
 	"Press \"W\" or \"w\" keys to save a puzzle.\n"
+	"\n"
+	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+	"\n"
 	"Press \"Esc\" key to hide program.\n"
+	"\n"
 	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+	"\n"
 	"Use the key pad, \"R\" keys, or arrow keys to move without "
 	"mouse clicks.\n"
 	"Key pad is defined for Skewb2d as:\n"
@@ -196,10 +203,12 @@ static const char featuresHelp[] = {
 	"differently depending on which side of the cube your mouse "
 	"is pointing at.  One thing that stays the\n"
 	"same is \"5\" is Clockwise and \"/\" is Counterclockwise.\n"
+	"\n"
 	"Use the control key and the left mouse button, keypad, or "
-	"arrow keys to move the whole cube.  This is\n"
+	"arrow keys  to move the whole cube.  This is\n"
 	"not recorded as a turn.\n"
 };
+
 static const char referencesHelp[] = {
 	"Beyond Rubik's Cube: spheres, pyramids, dodecahedrons and "
 	"God knows what else by Douglas\n"
@@ -208,6 +217,7 @@ static const char referencesHelp[] = {
 	"Magic Cubes 1996 Catalog of Dr. Christoph Bandelow.\n"
 };
 #endif
+
 static const char solveHelp[] = {
 	"Auto-solver: sorry, not implemented.\n"
 };
@@ -216,7 +226,7 @@ static const char solveHelp[] = {
 #define SCOREFILE "skewb.scores"
 #endif
 
-#define NEVER -1
+#define NEVER (-1)
 #define FILENAMELEN 1024
 #define USERNAMELEN 120
 #define MESSAGELEN (USERNAMELEN+64)
@@ -236,10 +246,12 @@ static char recordDsp[MESSAGELEN] = "NOT RECORDED";
 #ifndef HAVE_MOTIF
 static char titleDsp[TITLELEN] = "";
 #endif
+static char scoreFileName[FILENAMELEN] = SCOREFILE;
+static char fileName[FILENAMELEN];
 #ifdef WINVER
 #define MAXPROGNAME 80
 static char progDsp[MAXPROGNAME] = TITLE;
-static char usernameDsp[USERNAMELEN] = "Guest";
+static char userNameDsp[USERNAMELEN] = "Guest";
 #else
 #ifdef HAVE_MOTIF
 static Widget moves, record, message, orientSwitch, practiceSwitch;
@@ -247,10 +259,11 @@ static char buff[21];
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
+static Arg arg[3];
 #else
-Widget shell;
+static Widget shell;
 #ifdef HAVE_OPENGL
-Widget shellGL;
+static Widget shellGL;
 #endif
 #endif
 static Pixmap skewbIcon = None;
@@ -258,110 +271,36 @@ static Widget topLevel, skewb2d, skewb3d;
 #ifdef HAVE_OPENGL
 static Widget skewbGL;
 #endif
-static Arg arg[4];
 static char *progDsp;
-static char usernameDsp[USERNAMELEN] = "";
-
-/* There's probably a better way to assure that they are the same but I don't
-   know it off hand. */
-static void
-MakeEquivalent(String * username, Boolean * orient, Boolean * practice)
-{
-	Boolean mono, reverse;
-	Pixel foreground, background, pieceBorder;
-	String faceColor[MAXFACES];
-
-	XtVaGetValues(skewb2d,
-		XtNuserName, username,
-		XtNorient, orient,
-		XtNpractice, practice,
-		XtNmono, &mono,
-		XtNreverse, &reverse,
-		XtNforeground, &foreground,
-		XtNbackground, &background,
-		XtNpieceBorder, &pieceBorder,
-		XtNfaceColor0, &(faceColor[0]),
-		XtNfaceColor1, &(faceColor[1]),
-		XtNfaceColor2, &(faceColor[2]),
-		XtNfaceColor3, &(faceColor[3]),
-		XtNfaceColor4, &(faceColor[4]),
-		XtNfaceColor5, &(faceColor[5]), NULL);
-	XtVaSetValues(skewb2d,
-		XtNdirection, SKEWB_IGNORE,
-		XtNstart, False, NULL);
-	XtVaSetValues(skewb3d,
-		XtNuserName, *username,
-		XtNorient, *orient,
-		XtNmono, mono,
-		XtNreverse, reverse,
-		XtNdirection, SKEWB_IGNORE,
-		XtNpractice, *practice,
-		XtNstart, False,
-		XtNforeground, foreground,
-		XtNbackground, background,
-		XtNpieceBorder, pieceBorder,
-		XtNfaceColor0, faceColor[0],
-		XtNfaceColor1, faceColor[1],
-		XtNfaceColor2, faceColor[2],
-		XtNfaceColor3, faceColor[3],
-		XtNfaceColor4, faceColor[4],
-		XtNfaceColor5, faceColor[5], NULL);
-#ifdef HAVE_OPENGL
-	XtVaSetValues(skewbGL,
-		XtNuserName, *username,
-		XtNorient, *orient,
-		XtNmono, mono,
-		XtNreverse, reverse,
-		XtNdirection, SKEWB_IGNORE,
-		XtNpractice, *practice,
-		XtNstart, False,
-		XtNforeground, foreground,
-		XtNbackground, background,
-		XtNpieceBorder, pieceBorder,
-		XtNfaceColor0, faceColor[0],
-		XtNfaceColor1, faceColor[1],
-		XtNfaceColor2, faceColor[2],
-		XtNfaceColor3, faceColor[3],
-		XtNfaceColor4, faceColor[4],
-		XtNfaceColor5, faceColor[5], NULL);
-#endif
-}
-#endif
+static char userNameDsp[USERNAMELEN] = "";
 
 #ifdef HAVE_MOTIF
 static void
 PrintState(Widget w, char *msg)
 {
-	XmString    xmstr;
+	XmString xmstr;
 
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
 		XtError("PrintState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
-	XtSetArg(arg[0], XmNlabelString, xmstr);
-	XtSetValues(w, arg, 1);
+	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
-#else
+#endif
+
 static void
-PrintState(
-#ifndef WINVER
-Widget w,
-#endif
-int dim, int moves, char *msg)
+PrintRecords(void)
 {
-#ifdef HAVE_OPENGL
-	if (dim == 4)
-		(void) sprintf(titleDsp, "%sGL: (%d/%s) - %s",
-			progDsp, moves, recordDsp, msg);
-	else
-#endif
-		(void) sprintf(titleDsp, "%s%dd: (%d/%s) - %s",
-			progDsp, dim, moves, recordDsp, msg);
-#ifdef WINVER
-	SetWindowText(Wnd, (LPSTR) titleDsp);
-#else
-	XtSetArg(arg[0], XtNtitle, titleDsp);
-	XtSetValues(w, arg, 1);
-#endif
+	int orient;
+
+	(void) printf("    SKEWB  HALL OF FAME\n\n");
+	(void) printf("ORIENT USER            MOVES\n");
+	for (orient = 0; orient < 2; orient++) {
+		if (skewbRecord[orient].score > 0)
+			(void) printf("%6d %-12s%9d\n",
+				orient,
+				skewbRecord[orient].name,
+				skewbRecord[orient].score);
+	}
 }
 #endif
 
@@ -381,21 +320,21 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int n, orient;
-	char username[USERNAMELEN];
+	char userName[USERNAMELEN];
 	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *fname, *lname;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
+	stringCat(&buf1, CURRENTDELIM, scoreFileName);
 	lname = buf1;
 	stringCat(&buf1, SCOREPATH, FINALDELIM);
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "r")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "r")) == NULL) {
+	(void) strncpy(fileName, lname, USERNAMELEN);
+	if ((fp = fopen(fileName, "r")) == NULL) {
+		(void) strncpy(fileName, fname, USERNAMELEN);
+		/* Try installed directory. */
+		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
@@ -423,11 +362,11 @@ ReadRecords(void)
 	free(lname);
 	free(fname);
 	for (orient = 0; orient < 2; orient++) {
-		(void) fscanf(fp, "%d %s\n", &n, username);
+		(void) fscanf(fp, "%d %s\n", &n, userName);
 		if (n <= skewbRecord[orient].score ||
 		    skewbRecord[orient].score <= NEVER) {
 			skewbRecord[orient].score = n;
-			(void) strncpy(skewbRecord[orient].name, username,
+			(void) strncpy(skewbRecord[orient].name, userName,
 				USERNAMELEN);
 		}
 	}
@@ -439,61 +378,31 @@ WriteRecords(void)
 {
 	FILE *fp;
 	int orient;
-	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *buf1 = NULL;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
-	lname = buf1;
-	stringCat(&buf1, SCOREPATH, FINALDELIM);
-	stringCat(&buf2, buf1, SCOREFILE);
-	free(buf1);
-	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "w")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "w")) == NULL) {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, " or ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-			free(lname);
-			free(fname);
-			return;
-		}
-/* Probably annoying */
-#if 0
-		else {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, ", falling back to ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-		}
-#endif
+	if ((fp = fopen(fileName, "w")) == NULL) {
+		stringCat(&buf1, "Can not write to ", fileName);
+		PRINT_MESSAGE(buf1);
+		free(buf1);
+		return;
 	}
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockfile[FILENAMELEN];
+		char lockFile[FILENAMELEN];
 
-		(void) strncpy(lockfile, name, FILENAMELEN - 6);
-		(void) strcat(lockfile, ".lock");
-		while (((lfd = open(lockfile, O_CREAT | O_EXCL, 0644)) < 0) &&
+		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strcat(lockFile, ".lock");
+		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
 			(void) sleep(1);
 		if (lfd < 0) {
 #if 1
 			(void) fprintf(stderr,
-			  "Lock file exists... guessing its an old one.\n");
+				"Lock file exists... guessing its an old one.\n");
 #else
 			(void) fprintf(stderr,
-			  "Lock file exists... score not recorded - sorry.\n");
+				"Lock file exists... score not recorded - sorry.\n");
 			return;
 #endif
 		}
@@ -503,12 +412,10 @@ WriteRecords(void)
 			skewbRecord[orient].score, skewbRecord[orient].name);
 #if HAVE_FCNTL_H
 		(void) close(lfd);
-		(void) unlink(lockfile);
+		(void) unlink(lockFile);
 #endif
 		(void) fclose(fp);
 	}
-	free(lname);
-	free(fname);
 }
 
 static void
@@ -516,9 +423,9 @@ PrintRecord(Boolean orient, Boolean practice)
 {
 	int i = (orient) ? 1 : 0;
 
-	if (practice)
+	if (practice) {
 		(void) strncpy(recordDsp, "practice", MESSAGELEN);
-	else if (skewbRecord[i].score <= NEVER) {
+	} else if (skewbRecord[i].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
 		(void) sprintf(recordDsp, "%d %s",
@@ -529,6 +436,124 @@ PrintRecord(Boolean orient, Boolean practice)
 #endif
 }
 
+#ifndef WINVER
+/* There's probably a better way to assure that they are the same but I don't
+   know it off hand. */
+static void
+MakeEquivalent(String *userName, String *scoreFile,
+		Boolean *orient, Boolean *practice)
+{
+	Boolean mono, reverse;
+	Boolean scoreOnly, versionOnly;
+	Pixel foreground, background, pieceBorder;
+	String faceColor[MAXFACES];
+
+	XtVaGetValues(skewb2d,
+		XtNuserName, userName,
+		XtNscoreFile, scoreFile,
+		XtNorient, orient,
+		XtNpractice, practice,
+		XtNmono, &mono,
+		XtNreverse, &reverse,
+		XtNforeground, &foreground,
+		XtNbackground, &background,
+		XtNpieceBorder, &pieceBorder,
+		XtNfaceColor0, &(faceColor[0]),
+		XtNfaceColor1, &(faceColor[1]),
+		XtNfaceColor2, &(faceColor[2]),
+		XtNfaceColor3, &(faceColor[3]),
+		XtNfaceColor4, &(faceColor[4]),
+		XtNfaceColor5, &(faceColor[5]),
+		XtNscoreOnly, &scoreOnly,
+		XtNversionOnly, &versionOnly, NULL);
+	if (versionOnly) {
+		(void) printf(aboutHelp);
+		exit(0);
+	}
+	if (strcmp(*scoreFile, ""))
+		(void) strncpy(scoreFileName, *scoreFile, FILENAMELEN);
+	if (scoreOnly) {
+		InitRecords();
+		ReadRecords();
+		PrintRecords();
+		exit(0);
+	}
+	XtVaSetValues(skewb2d,
+		XtNdirection, SKEWB_IGNORE,
+		XtNstart, False, NULL);
+	XtVaSetValues(skewb3d,
+		XtNuserName, *userName,
+		XtNorient, *orient,
+		XtNmono, mono,
+		XtNreverse, reverse,
+		XtNdirection, SKEWB_IGNORE,
+		XtNpractice, *practice,
+		XtNstart, False,
+		XtNforeground, foreground,
+		XtNbackground, background,
+		XtNpieceBorder, pieceBorder,
+		XtNfaceColor0, faceColor[0],
+		XtNfaceColor1, faceColor[1],
+		XtNfaceColor2, faceColor[2],
+		XtNfaceColor3, faceColor[3],
+		XtNfaceColor4, faceColor[4],
+		XtNfaceColor5, faceColor[5], NULL);
+#ifdef HAVE_OPENGL
+	XtVaSetValues(skewbGL,
+		XtNuserName, *userName,
+		XtNorient, *orient,
+		XtNmono, mono,
+		XtNreverse, reverse,
+		XtNdirection, SKEWB_IGNORE,
+		XtNpractice, *practice,
+		XtNstart, False,
+		XtNforeground, foreground,
+		XtNbackground, background,
+		XtNpieceBorder, pieceBorder,
+		XtNfaceColor0, faceColor[0],
+		XtNfaceColor1, faceColor[1],
+		XtNfaceColor2, faceColor[2],
+		XtNfaceColor3, faceColor[3],
+		XtNfaceColor4, faceColor[4],
+		XtNfaceColor5, faceColor[5], NULL);
+#endif
+}
+#endif
+
+static void
+PrintStatus(char *msg, int nMoves
+#ifndef HAVE_MOTIF
+		, int dim
+#endif
+		)
+{
+#ifdef HAVE_MOTIF
+	PrintState(message, msg);
+	(void) sprintf(buff, "%d", nMoves);
+	PrintState(moves, buff);
+#else
+#ifdef HAVE_OPENGL
+	if (dim == 4)
+		(void) sprintf(titleDsp, "%sGL: (%d/%s) - %s",
+			progDsp, nMoves, recordDsp, msg);
+	else
+#endif
+		(void) sprintf(titleDsp, "%s%dd: (%d/%s) - %s",
+			progDsp, dim, nMoves, recordDsp, msg);
+#ifdef WINVER
+	SetWindowText(widget.core.hWnd, (LPSTR) titleDsp);
+#else
+#ifdef HAVE_OPENGL
+	if (dim == 4)
+		XtVaSetValues(XtParent(skewbGL), XtNtitle, titleDsp, NULL);
+	else
+#endif
+	XtVaSetValues(XtParent((dim == 2) ? skewb2d : skewb3d),
+		XtNtitle, titleDsp, NULL);
+#endif
+#endif
+}
+
 static Boolean
 HandleSolved(int counter, Boolean orient)
 {
@@ -537,11 +562,11 @@ HandleSolved(int counter, Boolean orient)
 	if (counter < skewbRecord[i].score || skewbRecord[i].score <= NEVER) {
 		ReadRecords();	/* Maybe its been updated by another */
 		skewbRecord[i].score = counter;
-		(void) strncpy(skewbRecord[i].name, usernameDsp, USERNAMELEN);
+		(void) strncpy(skewbRecord[i].name, userNameDsp, USERNAMELEN);
 		if (orient && (counter < skewbRecord[!i].score ||
 				skewbRecord[!i].score <= NEVER)) {
 			skewbRecord[!i].score = counter;
-			(void) strncpy(skewbRecord[!i].name, usernameDsp,
+			(void) strncpy(skewbRecord[!i].name, userNameDsp,
 				USERNAMELEN);
 		}
 		WriteRecords();
@@ -561,7 +586,7 @@ void
 )
 {
 	Boolean orient, practice;
-	char *username;
+	char *userName, *scoreFile;
 #ifdef WINVER
 	int dim;
 
@@ -569,11 +594,14 @@ void
 
 	orient = w->skewb.orient;
 	practice = w->skewb.practice;
-	username = w->skewb.username;
+	userName = w->skewb.userName;
+	scoreFile = w->skewb.scoreFile;
 	dim = w->skewb.dim;
 	SET_STARTED(w, False);
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
 #else
-	MakeEquivalent(&username, &orient, &practice);
+	MakeEquivalent(&userName, &scoreFile, &orient, &practice);
 #ifdef HAVE_MOTIF
 	XmToggleButtonSetState(orientSwitch, orient, True);
 	XmToggleButtonSetState(practiceSwitch, practice, True);
@@ -582,32 +610,34 @@ void
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(usernameDsp, username, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #endif
-	if (!strcmp(username, "") || !strcmp(username, "(null)") ||
-	    !strcmp(username, NOACCESS) || !strcmp(username, NOBODY)) {
+	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
+			!strcmp(userName, NOACCESS) ||
+			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(usernameDsp, username, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		/* The NOACCESS is not necessary, but it may stop silliness. */
-		(void) sprintf(usernameDsp, "%s", getlogin());
-		if (!strcmp(usernameDsp, "") ||
-				!strcmp(usernameDsp, "(null)") ||
-				!strcmp(usernameDsp, NOACCESS) ||
-				!strcmp(usernameDsp, NOBODY))
+		(void) sprintf(userNameDsp, "%s", getlogin());
+		if (!strcmp(userNameDsp, "") ||
+				!strcmp(userNameDsp, "(null)") ||
+				!strcmp(userNameDsp, NOACCESS) ||
+				!strcmp(userNameDsp, NOBODY))
 			/* It really IS nobody */
-			(void) sprintf(usernameDsp, "%s", NOBODY);
+			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
 	PrintRecord(orient, practice);
 #ifdef WINVER
-	PrintState(dim, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp, dim);
 #else
-#ifndef HAVE_MOTIF
-	PrintState(XtParent(skewb2d), 2, movesDsp, messageDsp);
-	PrintState(XtParent(skewb3d), 3, movesDsp, messageDsp);
+#ifdef HAVE_MOTIF
+	PrintStatus(messageDsp, movesDsp);
+#else
+	PrintStatus(messageDsp, movesDsp, 2);
+	PrintStatus(messageDsp, movesDsp, 3);
 #ifdef HAVE_OPENGL
-	PrintState(XtParent(skewbGL), 4, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp, 4);
 #endif
 #endif
 #endif
@@ -713,16 +743,16 @@ CallbackSkewb(Widget w, caddr_t clientData, skewbCallbackStruct * callData)
 #ifdef HAVE_MOTIF
 			XtManageChild(practiceDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 8); /* menu choice */
-			XtSetValues(skewb2d, arg, 1);
+			XtVaSetValues(skewb2d,
+				XtNmenu, 8, NULL); /* menu choice */
 #endif
 			break;
 		case SKEWB_RANDOMIZE_QUERY:
 #ifdef HAVE_MOTIF
 			XtManageChild(randomizeDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-			XtSetValues(skewb2d, arg, 1);
+			XtVaSetValues(skewb2d,
+				XtNmenu, 5, NULL); /* menu choice */
 #endif
 			break;
 #endif
@@ -740,30 +770,35 @@ CallbackSkewb(Widget w, caddr_t clientData, skewbCallbackStruct * callData)
 			break;
 		case SKEWB_RESTORE:
 			if (practice) {
-				(void) strncpy(recordDsp, "practice", MESSAGELEN);
+				(void) strncpy(recordDsp, "practice",
+					MESSAGELEN);
 #ifdef HAVE_MOTIF
 				PrintState(record, recordDsp);
 #endif
 			}
 			movesDsp = 0;
 #ifndef WINVER
-			XtSetArg(arg[0], XtNdirection, SKEWB_RESTORE);
 #ifdef HAVE_OPENGL
-			XtSetValues(otherw2, arg, 1);
+			XtVaSetValues(otherw2,
+				XtNdirection, SKEWB_RESTORE, NULL);
 #endif
-			XtSetValues(otherw1, arg, 1);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(otherw1,
+				XtNdirection, SKEWB_RESTORE, NULL);
+			XtVaSetValues(w,
+				XtNdirection, SKEWB_RESTORE, NULL);
 #endif
 			break;
 		case SKEWB_CLEAR:
 			movesDsp = 0;
 #ifndef WINVER
-			XtSetArg(arg[0], XtNdirection, SKEWB_CLEAR);
 #ifdef HAVE_OPENGL
-			XtSetValues(otherw2, arg, 1);
+			XtVaSetValues(otherw2,
+				XtNdirection, SKEWB_CLEAR, NULL);
 #endif
-			XtSetValues(otherw1, arg, 1);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(otherw1,
+				XtNdirection, SKEWB_CLEAR, NULL);
+			XtVaSetValues(w,
+				XtNdirection, SKEWB_CLEAR, NULL);
 #endif
 			break;
 		case SKEWB_RESET:
@@ -780,24 +815,31 @@ CallbackSkewb(Widget w, caddr_t clientData, skewbCallbackStruct * callData)
 #ifndef WINVER
 		case SKEWB_MOVED:
 			movesDsp++;
-			XtSetArg(arg[0], XtNstart, True);
-			XtSetArg(arg[1], XtNface, callData->face);
-			XtSetArg(arg[2], XtNpos, callData->position);
-			XtSetArg(arg[3], XtNdirection, callData->direction);
 #ifdef HAVE_OPENGL
-			XtSetValues(otherw2, arg, 4);
+			XtVaSetValues(otherw2,
+				XtNstart, True,
+				XtNface, callData->face,
+				XtNpos, callData->position,
+				XtNdirection, callData->direction, NULL);
 #endif
-			XtSetValues(otherw1, arg, 4);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(otherw1,
+				XtNstart, True,
+				XtNface, callData->face,
+				XtNpos, callData->position,
+				XtNdirection, callData->direction, NULL);
+			SET_STARTED(w, True);
 			break;
 		case SKEWB_CONTROL:
-			XtSetArg(arg[0], XtNface, callData->face);
-			XtSetArg(arg[1], XtNpos, callData->position);
-			XtSetArg(arg[2], XtNdirection, callData->direction);
 #ifdef HAVE_OPENGL
-			XtSetValues(otherw2, arg, 3);
+			XtVaSetValues(otherw2,
+				XtNface, callData->face,
+				XtNpos, callData->position,
+				XtNdirection, callData->direction, NULL);
 #endif
-			XtSetValues(otherw1, arg, 3);
+			XtVaSetValues(otherw1,
+				XtNface, callData->face,
+				XtNpos, callData->position,
+				XtNdirection, callData->direction, NULL);
 			return;
 #endif
 		case SKEWB_SOLVED:
@@ -805,22 +847,21 @@ CallbackSkewb(Widget w, caddr_t clientData, skewbCallbackStruct * callData)
 				movesDsp = 0;
 			else if (cheat)
 				(void) sprintf(messageDsp,
-					"No cheating %s!!", usernameDsp);
+					"No cheating %s!!", userNameDsp);
 			else if (HandleSolved(movesDsp, orient))
 				(void) sprintf(messageDsp,
-					"Congratulations %s!!", usernameDsp);
+					"Congratulations %s!!", userNameDsp);
 			else
 				(void) strncpy(messageDsp, "Solved!",
 					MESSAGELEN);
 #ifdef WINVER
 			SET_STARTED(w, False);
 #else
-			XtSetArg(arg[0], XtNstart, False);
-			XtSetValues(w, arg, 1);
+			SET_STARTED(w, False);
 #ifdef HAVE_OPENGL
-			XtSetValues(otherw2, arg, 1);
+			SET_STARTED(otherw2, False);
 #endif
-			XtSetValues(otherw1, arg, 1);
+			SET_STARTED(otherw1, False);
 #endif
 			break;
 		case SKEWB_PRACTICE:
@@ -835,13 +876,17 @@ CallbackSkewb(Widget w, caddr_t clientData, skewbCallbackStruct * callData)
 			w->skewb.started = False;
 #else
 
-			XtSetArg(arg[0], XtNpractice, practice);
-			XtSetArg(arg[1], XtNstart, False);
-			XtSetValues(w, arg, 2);
+			XtVaSetValues(w,
+				XtNpractice, practice,
+				XtNstart, False, NULL);
 #ifdef HAVE_OPENGL
-			XtSetValues(otherw2, arg, 2);
+			XtVaSetValues(otherw2,
+				XtNpractice, practice,
+				XtNstart, False, NULL);
 #endif
-			XtSetValues(otherw1, arg, 2);
+			XtVaSetValues(otherw1,
+				XtNpractice, practice,
+				XtNstart, False, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(practiceSwitch, practice, True);
 #endif
@@ -850,16 +895,20 @@ CallbackSkewb(Widget w, caddr_t clientData, skewbCallbackStruct * callData)
 		case SKEWB_RANDOMIZE:
 			movesDsp = 0;
 #ifdef WINVER
-			w->skewb.practice = practice;
+			w->skewb.practice = False;
 			w->skewb.started = False;
 #else
-			XtSetArg(arg[0], XtNpractice, False);
-			XtSetArg(arg[1], XtNstart, False);
-			XtSetValues(w, arg, 2);
+			XtVaSetValues(w,
+				XtNpractice, False,
+				XtNstart, False, NULL);
 #ifdef HAVE_OPENGL
-			XtSetValues(otherw2, arg, 2);
+			XtVaSetValues(otherw2,
+				XtNpractice, False,
+				XtNstart, False, NULL);
 #endif
-			XtSetValues(otherw1, arg, 2);
+			XtVaSetValues(otherw1,
+				XtNpractice, False,
+				XtNstart, False, NULL);
 #endif
 			break;
 		case SKEWB_ORIENT:
@@ -869,12 +918,14 @@ CallbackSkewb(Widget w, caddr_t clientData, skewbCallbackStruct * callData)
 #ifdef WINVER
 			w->skewb.orient = orient;
 #else
-			XtSetArg(arg[0], XtNorient, orient);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w,
+				XtNorient, orient, NULL);
 #ifdef HAVE_OPENGL
-			XtSetValues(otherw2, arg, 1);
+			XtVaSetValues(otherw2,
+				XtNorient, orient, NULL);
 #endif
-			XtSetValues(otherw1, arg, 1);
+			XtVaSetValues(otherw1,
+				XtNorient, orient, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(orientSwitch, orient, True);
 #endif
@@ -884,26 +935,29 @@ CallbackSkewb(Widget w, caddr_t clientData, skewbCallbackStruct * callData)
 #ifdef WINVER
 			SET_STARTED(w, False);
 #else
-			XtSetArg(arg[0], XtNstart, False);
-			XtSetValues(w, arg, 1);
+			SET_STARTED(w, False);
 #ifdef HAVE_OPENGL
-			XtSetValues(otherw2, arg, 1);
+			SET_STARTED(otherw2, False);
 #endif
-			XtSetValues(otherw1, arg, 1);
+			SET_STARTED(otherw1, False);
 #endif
 			break;
 #ifndef WINVER
 		case SKEWB_UNDO:
 			movesDsp--;
-			XtSetArg(arg[0], XtNstart, True);
-			XtSetArg(arg[1], XtNface, callData->face);
-			XtSetArg(arg[2], XtNpos, callData->position);
-			XtSetArg(arg[3], XtNdirection, callData->direction);
 #ifdef HAVE_OPENGL
-			XtSetValues(otherw2, arg, 4);
+			XtVaSetValues(otherw2,
+				XtNstart, True,
+				XtNface, callData->face,
+				XtNpos, callData->position,
+				XtNdirection, callData->direction, NULL);
 #endif
-			XtSetValues(otherw1, arg, 4);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(otherw1,
+				XtNstart, True,
+				XtNface, callData->face,
+				XtNpos, callData->position,
+				XtNdirection, callData->direction, NULL);
+			SET_STARTED(w, True);
 			break;
 #endif
 #ifdef WINVER
@@ -921,17 +975,15 @@ CallbackSkewb(Widget w, caddr_t clientData, skewbCallbackStruct * callData)
 
 	}
 #ifdef WINVER
-	PrintState(dim, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp, dim);
 #else
 #ifdef HAVE_MOTIF
-	PrintState(message, messageDsp);
-	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
+	PrintStatus(messageDsp, movesDsp);
 #else
-	PrintState(XtParent(w), dim, movesDsp, messageDsp);
-	PrintState(XtParent(otherw1), otherdim1, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp, dim);
+	PrintStatus(messageDsp, movesDsp, otherdim1);
 #ifdef HAVE_OPENGL
-	PrintState(XtParent(otherw2), otherdim2, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp, otherdim2);
 #endif
 #endif
 #endif
@@ -963,7 +1015,7 @@ SetSkewbMove(SkewbWidget w, int reason, int face, int position, int direction)
 			SET_STARTED(w, True);
 			break;
 	}
-	PrintState(dim, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp, dim);
 }
 
 static LRESULT CALLBACK
@@ -986,7 +1038,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	HBRUSH brush = (HBRUSH) NULL;
 	PAINTSTRUCT paint;
 
-	Wnd = widget.core.hWnd = hWnd;
+	widget.core.hWnd = hWnd;
 	if (GetFocus()) {
 		if (!widget.skewb.focus) {
 			widget.core.hDC = GetDC(hWnd);
@@ -1252,18 +1304,7 @@ static void
 Usage(char * programName)
 {
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr,
-		"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n");
-	(void) fprintf(stderr,
-		"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n");
-	(void) fprintf(stderr,
-		"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{border|bd} {color}] [-face{0|1|2|3|4|5} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-[no]orient] [-[no]practice] [-{font|fn} {fontname}]\n");
-	(void) fprintf(stderr,
-		"\t[-username {string}]\n");
+	(void) fprintf(stderr, optionsHelp);
 	exit(1);
 }
 
@@ -1293,7 +1334,10 @@ static XrmOptionDescRec options[] =
 	{(char *) "-nopractice", (char *) "*skewb.practice", XrmoptionNoArg, (char *) "FALSE"},
 	{(char *) "-fn", (char *) "*skewb.font", XrmoptionSepArg, NULL},
 	{(char *) "-font", (char *) "*skewb.font", XrmoptionSepArg, NULL},
-	{(char *) "-username", (char *) "*skewb.userName", XrmoptionSepArg, NULL}
+	{(char *) "-userName", (char *) "*skewb.userName", XrmoptionSepArg, NULL},
+	{(char *) "-scoreFile", (char *) "*skewb.scoreFile", XrmoptionSepArg, NULL},
+	{(char *) "-scores", (char *) "*skewb.scoreOnly", XrmoptionNoArg, (char *) "TRUE"},
+	{(char *) "-version", (char *) "*skewb.versionOnly", XrmoptionNoArg, (char *) "TRUE"}
 };
 
 #ifdef HAVE_MOTIF
@@ -1301,8 +1345,7 @@ static void
 CallbackSkewbPractice(Widget w, XtPointer clientData, XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 8); /* menu choice */
-		XtSetValues(skewb2d, arg, 1);
+		XtVaSetValues(skewb2d, XtNmenu, 8, NULL); /* menu choice */
 	}
 }
 
@@ -1310,8 +1353,7 @@ static void
 CallbackSkewbRandomize(Widget w, XtPointer clientData, XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-		XtSetValues(skewb2d, arg, 1);
+		XtVaSetValues(skewb2d, XtNmenu, 5, NULL); /* menu choice */
 	}
 }
 
@@ -1374,16 +1416,15 @@ fileCB(Widget w, void *value, void *clientData)
 
 	if (val == 2)
 		exit(0);
-	XtSetArg(arg[0], XtNmenu, val);
-	XtSetValues(skewb2d, arg, 1);
+	XtVaSetValues(skewb2d, XtNmenu, val, NULL);
 }
 
 static void
 playCB(Widget w, void *value, void *clientData)
 {
 	int val = (int) value;
-	XtSetArg(arg[0], XtNmenu, val + 3); /* GWQ */
-	XtSetValues(skewb2d, arg, 1);
+
+	XtVaSetValues(skewb2d, XtNmenu, val + 3, NULL); /* GWQ */
 }
 
 static Widget
@@ -1464,7 +1505,7 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d\n", val);
+			intCat(&buf, "helpCB: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1515,11 +1556,10 @@ main(int argc, char **argv)
 			RootWindowOfScreen(XtScreen(topLevel)),
 			(char *) skewb_bits,
 			skewb_width, skewb_height);
-	XtSetArg(arg[0], XtNiconPixmap, skewbIcon);
-	/* not XmEXPLICIT */
 #ifdef HAVE_MOTIF
-	XtSetArg(arg[1], XmNkeyboardFocusPolicy, XmPOINTER);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, skewbIcon,
+		XmNkeyboardFocusPolicy, XmPOINTER, NULL); /* not XmEXPLICIT */
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
 		xmPanedWindowWidgetClass, topLevel,
 		XmNseparatorOn, False,
@@ -1711,15 +1751,20 @@ main(int argc, char **argv)
 		XtNheight, 200, NULL);
 #endif
 #else
-	XtSetArg(arg[1], XtNinput, True);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, skewbIcon,
+		XtNinput, True, NULL);
 	shell = XtCreateApplicationShell(argv[0],
 		topLevelShellWidgetClass, NULL, 0);
-	XtSetValues(shell, arg, 2);
+	XtVaSetValues(shell,
+		XtNiconPixmap, skewbIcon,
+		XtNinput, True, NULL);
 #ifdef HAVE_OPENGL
 	shellGL = XtCreateApplicationShell(argv[0],
 		topLevelShellWidgetClass, NULL, 0);
-	XtSetValues(shellGL, arg, 2);
+	XtVaSetValues(shellGL,
+		XtNiconPixmap, skewbIcon,
+		XtNinput, True, NULL);
 #endif
 	skewb2d = XtCreateManagedWidget("skewb",
 		skewb2dWidgetClass, topLevel, NULL, 0);
