@@ -25,6 +25,8 @@
 
 /* Methods file for Threed */
 
+#include "file.h"
+#include "sound.h"
 #include "ThreedP.h"
 
 #ifdef WINVER
@@ -42,7 +44,7 @@
 #endif
 
 #ifndef DATAFILE
-#define DATAFILE "/usr/games/threed.dat"
+#define DATAFILE "threed.dat"
 #endif
 
 static void InitializeThreeD(Widget request, Widget renew);
@@ -272,6 +274,9 @@ static XtResource resourcesThreeD[] = {
 	{XtNreverse, XtCReverse, XtRBoolean, sizeof (Boolean),
 	 XtOffset(ThreeDWidget, threed.reverse),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(ThreeDWidget, threed.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNselectCallback, XtCCallback, XtRCallback, sizeof (caddr_t),
 	 XtOffset(ThreeDWidget, threed.select), XtRCallback, NULL}
 };
@@ -337,24 +342,6 @@ SetThreeD(ThreeDWidget w, int reason)
 static Object3D *OBJ;
 #endif
 
-void
-intCat(char ** string, const char * var1, const int var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + 21))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%d", var1, var2);
-}
-
-static void
-stringCat(char ** string, const char * var1, const char * var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + strlen(var2) + 1))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%s", var1, var2);
-}
-
 static void
 CheckGraphicsThreeD(ThreeDWidget w)
 {
@@ -426,7 +413,10 @@ CheckGraphicsThreeD(ThreeDWidget w)
 		w->threed.angle.psi = (NUM_DEGREES +
 			w->threed.angle.psi) % NUM_DEGREES;
 	}
-	if (w->threed.object < 0 || w->threed.object >= w->threed.numObjects) {
+	if (w->threed.numObjects == 0) {
+		DISPLAY_WARNING("No objects");
+	} else if (w->threed.object < 0 ||
+			w->threed.object >= w->threed.numObjects) {
 		w->threed.object = 0;
 		intCat(&buf1, "Object type number out of bounds, use 0..",
 			w->threed.numObjects - 1);
@@ -477,88 +467,6 @@ CompareObject(const void *elem1, const void *elem2)
 }
 #endif
 
-#ifdef WINVER
-static void
-POLYGON(ThreeDWidget w, Pixmap dr, GC color, GC lineColor,
-		const POINT * poly, int n, Boolean convex, Boolean origin)
-{
-	/* CoordModePrevious -> CoordModeOrigin */
-	Point *temp = NULL;
-	int pt;
-
-	if (!origin) {
-		/* This has a cost in speed... here for compatibility with X.
-		   This is not really used, if it were, it should not
-		   be dynamically allocated. */
-		if (!(temp = (Point *) malloc(sizeof (Point) * n))) {
-			DISPLAY_ERROR("Not enough memory, exiting.");
-		}
-		temp[0] = poly[0];
-		for (pt = 1; pt < n; pt++) {
-			temp[pt].x = temp[pt - 1].x + poly[pt].x,
-			temp[pt].y = temp[pt - 1].y + poly[pt].y;
-		}
-	}
-	if (dr)
-		w->threed.hOldBitmap =
-			(HBITMAP) SelectObject(w->threed.memDC, dr);
-	w->threed.hPen = CreatePen(PS_SOLID, 1, lineColor);
-	w->threed.hOldPen = (HPEN) SelectObject(DC(w, dr),
-		w->threed.hPen);
-	w->threed.hBrush = CreateSolidBrush(color);
-	w->threed.hOldBrush = (HBRUSH) SelectObject(DC(w, dr),
-		w->threed.hBrush);
-	(void) Polygon(DC(w,dr), (origin) ? poly : temp, n);
-	(void) SelectObject(DC(w,dr), w->threed.hOldBrush);
-	(void) DeleteObject(w->threed.hBrush);
-	(void) SelectObject(DC(w,dr), w->threed.hOldPen);
-	(void) DeleteObject(w->threed.hPen);
-	if (dr)
-		(void) SelectObject(w->threed.memDC,
-			w->threed.hOldBitmap);
-	if (!origin) {
-		free(temp);
-	}
-}
-
-static void
-POLYLINE(ThreeDWidget w, Pixmap dr, GC color, const Point * poly, int n,
-		Boolean origin)
-{
-	/* CoordModePrevious -> CoordModeOrigin */
-	Point *temp = NULL;
-	int pt;
-
-	if (!origin) {
-		/* This has a cost in speed... here for compatibility with X.
-		   This is not really used, if it were, it should not
-		   be dynamically allocated. */
-		if (!(temp = (Point *) malloc(sizeof (Point) * n))) {
-			DISPLAY_ERROR("Not enough memory, exiting.");
-		}
-		temp[0] = poly[0];
-		for (pt = 1; pt < n; pt++) {
-			temp[pt].x = temp[pt - 1].x + poly[pt].x,
-			temp[pt].y = temp[pt - 1].y + poly[pt].y;
-		}
-	}
-	if (dr)
-		w->threed.hOldBitmap =
-			(HBITMAP) SelectObject(w->threed.memDC, dr);
-	w->threed.hPen = CreatePen(PS_SOLID, 1, color);
-	w->threed.hOldPen = (HPEN) SelectObject(DC(w,dr), w->threed.hPen);
-	(void) Polyline(DC(w,dr), (origin) ? poly : temp, n);
-	(void) SelectObject(DC(w,dr), w->threed.hOldPen);
-	(void) DeleteObject(w->threed.hPen);
-	if (dr)
-		(void) SelectObject(w->threed.memDC,
-			w->threed.hOldBitmap);
-	if (!origin) {
-		free(temp);
-	}
-}
-#endif
-
 #define EPSILON 0.000001
 #define ASPECTRATIO 1.0
 #define viewDistance ((w->core.width + w->core.height) / 2)
@@ -569,6 +477,8 @@ RealizeObject(ThreeDWidget w, Object3D *obj)
 	int vert, surf;
 	double z;
 
+	if (w->threed.numObjects == 0)
+		return;
 	rotateObject(obj, &(w->threed.deltaAngle));
 	w->threed.deltaAngle.theta = 0;
 	w->threed.deltaAngle.phi = 0;
@@ -590,7 +500,7 @@ RealizeObject(ThreeDWidget w, Object3D *obj)
 		vertex->screen.x = (int) (w->threed.center.x +
 			vertex->eye.x *
 			viewDistance / vertex->eye.z);
-		obj->vertex[vert].screen.y = (int) (w->threed.center.y -
+		vertex->screen.y = (int) (w->threed.center.y -
 			ASPECTRATIO * vertex->eye.y *
 			viewDistance / vertex->eye.z);
 #ifdef DEBUG
@@ -708,15 +618,15 @@ static void
 CopyFromBuffer(ThreeDWidget w)
 {
 #ifdef WINVER
-	w->threed.hOldBitmap = (HBITMAP) SelectObject(w->threed.memDC,
+	w->core.hOldBitmap = (HBITMAP) SelectObject(w->core.memDC,
 		w->threed.bufferObjects[0]);
 	BitBlt(w->core.hDC,
 		0, 0, /* dest */
 		w->core.width, w->core.height,
-		w->threed.memDC,
+		w->core.memDC,
 		0, 0, /* src */
 		SRCCOPY);
-	SelectObject(w->threed.memDC, w->threed.hOldBitmap);
+	(void) SelectObject(w->core.memDC, w->core.hOldBitmap);
 #else
 	XSetGraphicsExposures(XtDisplay(w), w->threed.graphicsGC, False);
 	XCopyArea(XtDisplay(w), w->threed.bufferObjects[0], XtWindow(w),
@@ -1106,14 +1016,31 @@ ReadThreeD(ThreeDWidget w)
 {
 	FILE *fp;
 	char buffer[MAXLINE];
+	char *buf1 = NULL, *buf2 = NULL;
+	char *fname, *lname, *name;
 
-	if ((fp = fopen(DATAFILE, "r")) == NULL) {
-		char *buf1;
-
-		stringCat(&buf1, "Can not read ", DATAFILE);
-		XtWarning(buf1);
-		free(buf1);
-		return;
+	stringCat(&buf1, CURRENTDELIM, DATAFILE);
+	lname = buf1;
+	stringCat(&buf1, DATAPATH, FINALDELIM);
+	stringCat(&buf2, buf1, DATAFILE);
+	free(buf1);
+	fname = buf2;
+	/* Try current directory first. */
+	name = lname;
+	if ((fp = fopen(name, "r")) == NULL) {
+		name = fname;
+		if ((fp = fopen(name, "r")) == NULL) {
+			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf2, buf1, " or ");
+			free(buf1);
+			stringCat(&buf1, buf2, fname);
+			free(buf2);
+			DISPLAY_WARNING(buf1);
+			free(buf1);
+			free(lname);
+			free(fname);
+			return;
+		}
 	}
 	readCommon(w, fp, buffer);
 	(void) fclose(fp);
@@ -1127,6 +1054,8 @@ SetValuesThreeD(Widget current, Widget request, Widget renew)
 	XtGCMask valueMask;
 	Boolean redraw = FALSE;
 
+	if (w->threed.numObjects == 0)
+		return False;
 	CheckGraphicsThreeD(w);
 	if (w->threed.foreground != c->threed.foreground) {
 		valueMask = GCForeground | GCBackground;
@@ -1258,9 +1187,9 @@ RepaintGraphicsThreeD(ThreeDWidget w)
 	int sel;
 
 #ifdef WINVER
-	if (w->threed.memDC == NULL) {
-		w->threed.memDC = CreateCompatibleDC(w->core.hDC);
-		if (w->threed.memDC == NULL) {
+	if (w->core.memDC == NULL) {
+		w->core.memDC = CreateCompatibleDC(w->core.hDC);
+		if (w->core.memDC == NULL) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
@@ -1275,6 +1204,8 @@ RepaintGraphicsThreeD(ThreeDWidget w)
 		w->threed.oldColormap = xgwa.colormap;
 	}
 #endif
+	if (w->threed.numObjects == 0)
+		return;
 	for (sel = 0; sel < 2; sel++) {
 #ifdef WINVER
 		if (w->threed.bufferObjects[sel] != NULL) {
@@ -1373,13 +1304,15 @@ Widget request, Widget renew
 	createTrigTables();
 	ReadThreeD(w);
 	CheckGraphicsThreeD(w);
-	w->threed.name = w->threed.objects[w->threed.object].name;
-	if (!(w->threed.list = (char **) calloc((unsigned int)
-			w->threed.numObjects, sizeof (char **)))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
+	if (w->threed.numObjects > 0) {
+		w->threed.name = w->threed.objects[w->threed.object].name;
+		if (!(w->threed.list = (char **) calloc((unsigned int)
+				w->threed.numObjects, sizeof (char **)))) {
+			DISPLAY_ERROR("Not enough memory, exiting.");
+		}
+		for (i = 0; i < w->threed.numObjects; i++)
+			w->threed.list[i] = w->threed.objects[i].name;
 	}
-	for (i = 0; i < w->threed.numObjects; i++)
-		w->threed.list[i] = w->threed.objects[i].name;
 	w->threed.deltaAngle.theta = w->threed.angle.theta;
 	w->threed.deltaAngle.phi = w->threed.angle.phi;
 	w->threed.deltaAngle.psi = w->threed.angle.psi;
