@@ -32,9 +32,9 @@
   Version 1: 93/03/01 MS Windows by Thomas W. Olsen "The C Users Journal"
 */
 
-#ifdef HAVE_MOTIF
+#ifndef WINVER
 static const char aboutHelp[] = {
-	"Version 7.1.3\n"
+	"Threed Version 7.1.5\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
@@ -42,41 +42,50 @@ static const char aboutHelp[] = {
 	"Originally written by Thomas W. Olsen "
 	"in the \"The C Users Journal\".\n"
 };
+
 static const char optionsHelp[] = {
-	"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]] "
-	"[-display [{host}]:[{vs}]][-fg {color}] [-bg {color}]\n"
-	"[-[no]surface] [-object {int}] [-x {int}] [-y {int}] [-z {int}] "
-	"[-theta {int}] [-phi {int}] [psi {int}] [-white {color}]\n"
-	"[-[lt|dk]gray {color}] [-black {color}] [-another {color}]\n"
+	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+	"\t[-display [{host}]:[{vs}]][-fg {color}] [-bg {color}]\n"
+	"\t[-[no]surface] [-object {int}] [-x {int}] [-y {int}] [-z {int}]\n"
+	"\t[-theta {int}] [-phi {int}] [psi {int}] [-white {color}]\n"
+	"\t[-[lt|dk]gray {color}] [-black {color}] [-another {color}]\n"
+	"\t[-version]\n"
 };
 #endif
+
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
 	"A simple 3D viewer."
 };
+
 static const char featuresHelp[] = {
-	"Press \"i\" keys to move object in.\n"
-	"Press \"o\" keys to move object out.\n"
+	"Press \"L\" or \"l\" keys to move object left.\n"
+	"Press \"R\" or \"r\" keys to move object right.\n"
+	"Press \"U\" or \"u\" keys to move object up.\n"
+	"Press \"D\" or \"d\" keys to move object down.\n"
+	"Press \"I\" or \"i\" keys to move object in.\n"
+	"Press \"O\" or \"o\" keys to move object out.\n"
 	"Press \"S\" or \"s\" keys to change surface.\n"
 	"Press \"B\" or \"b\" keys to change object.\n"
 	"Press \"Esc\" key to hide program.\n"
 	"Press \"Q\", \"fBq\", or \"CTRL-C\" keys kill program.\n"
 	"Use the key pad, \"R\" keys, or arrow keys to rotate object.\n"
 	"Key pad is defined for Threed as:\n"
-	"  /     Out\n"
+	"  /     Counterclockwise\n"
 	"  8     Up\n"
 	"  ^\n"
-	"4<5>6   Left, In, Right\n"
+	"4<5>6   Left, Clockwise, Right\n"
 	"  v\n"
 	"  2     Down\n"
-	"I figured there was other 3D viewers out there.  "
-        "Well, this one is real simple, it only uses basic\n"
-        "drawing routines, so it might be useful to someone "
-	"out there.  If you have any improvements to make,\n"
-	"let me know.\n"
+	"I debated releasing this, since it needs some work."
+	"Also, I figured there was other 3D viewers out there.\n"
+        "Well, this one is real simple, it only uses the X"
+        "libs, so it might be useful to someone out there\n"
+	"If you have any improvements to make, let me know.\n"
 	"In the sample data, Cubes and F16 are big, so the "
 	"polyhedrons are scaled up to them in the data file.\n"
 };
+
 static const char referencesHelp[] = {
 	"Original code by\n"
 	"Thomas W. Olsen \"The C Users Journal\".\n"
@@ -92,10 +101,8 @@ static const char referencesHelp[] = {
 #define TITLE "wthreed"
 
 static ThreeDRec widget;
-static HWND Wnd;
 
-#define PRINT_MESSAGE(b) (void) MessageBox(Wnd, (LPCSTR) b, "Warning", MB_OK);
-#define SET_STARTED(w,b) w->triangles.started = b
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
 
 static void
 Initialize(ThreeDWidget w, HBRUSH brush)
@@ -153,7 +160,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	int vPos, hPos;
 	static Boolean mousePressed = False;
 
-	Wnd = widget.core.hWnd = hWnd;
+	widget.core.hWnd = hWnd;
 	switch (message) {
 		case WM_CREATE:
 			Initialize(&widget, brush);
@@ -564,9 +571,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 
 #else
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <X11/Intrinsic.h>
+#include "xwin.h"
 #include <X11/Shell.h>
 #include <X11/StringDefs.h>
 #include <X11/cursorfont.h>
@@ -585,7 +590,6 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
-#define SET_STARTED(w,b) XtSetArg(arg[0], XtNstart, b); XtSetValues(w, arg, 1)
 #include "Threed.h"
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
@@ -604,30 +608,19 @@ static Widget xDist, yDist, zDist, thetaAng, phiAng, psiAng;
 static Widget surfaceSwitch, objectList;
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
+static Arg arg[3];
+static char *progDsp;
 #else
-static char titleDsp[TITLELEN]="";
+static char titleDsp[TITLELEN] = "";
 #endif
 static Pixmap threedIcon = None;
 static Widget topLevel, threed;
-static Arg arg[3];
-static char *progDsp;
 
 static void
 Usage(char * programName)
 {
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr,
-		"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n");
-	(void) fprintf(stderr,
-		"\t[-display [{host}]:[{vs}]][-fg {color}] [-bg {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-[no]surface] [-object {int}] [-x {int}] [-y {int}]\n");
-	(void) fprintf(stderr,
-		"\t[-z {int}] [-theta {int}] [-phi {int}] [-psi {int}]\n");
-	(void) fprintf(stderr,
-		"\t[-white {color}] [-[lt|dk]gray {color}] [-black {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-another {color}]\n");
+	(void) fprintf(stderr, optionsHelp);
 	exit(1);
 }
 
@@ -652,6 +645,7 @@ static XrmOptionDescRec options[] = {
 	{(char *) "-dkgray", (char *) "*threed.dkgrayBrush", XrmoptionSepArg, NULL},
 	{(char *) "-black", (char *) "*threed.blackBrush", XrmoptionSepArg, NULL},
 	{(char *) "-another", (char *) "*threed.anotherBrush", XrmoptionSepArg, NULL},
+	{(char *) "-version", (char *) "*threed.versionOnly", XrmoptionNoArg, (char *) "TRUE"}
 };
 
 #ifndef HAVE_MOTIF
@@ -663,8 +657,7 @@ static void PrintState(Widget w, char *name, Boolean surface, int object,
 		object, (surface) ? "surface" : "wire",
 		distance.x, distance.y, distance.z,
 		angle.theta, angle.phi, angle.psi);
-	XtSetArg(arg[0], XtNtitle, titleDsp);
-	XtSetValues(w, arg, 1);
+	XtVaSetValues(w, XtNtitle, titleDsp, NULL);
 }
 #endif
 
@@ -674,6 +667,7 @@ static void Initialize(Widget w)
 	IntAngle3D angle;
 	int object;
 	Boolean surface;
+	Boolean versionOnly;
 	char *name;
 #ifndef HAVE_MOTIF
 	char **list;
@@ -694,7 +688,11 @@ static void Initialize(Widget w)
 		XtNobjectNumber, &number,
 		XtNobjectList, &list,
 #endif
-		NULL);
+		XtNversionOnly, &versionOnly, NULL);
+	if (versionOnly) {
+		(void) printf(aboutHelp);
+		exit(0);
+	}
 #ifdef HAVE_MOTIF
 	XmScaleSetValue(xDist, distance.x);
 	XmScaleSetValue(yDist, distance.y);
@@ -704,7 +702,7 @@ static void Initialize(Widget w)
 	XmScaleSetValue(psiAng, angle.psi);
 	XmToggleButtonSetState(surfaceSwitch, surface, True);
 #else
-	PrintState(XtParent(w), name, surface, object, distance, theta, phi);
+	PrintState(XtParent(w), name, surface, object, distance, angle);
 	(void) printf("Objects:\n");
 	for (i = 0; i < number; i++)
 		(void) printf("\t%s\n", list[i]);
@@ -755,16 +753,14 @@ static void CallbackThreeD(Widget w, caddr_t clientData,
 			break;
 		case THREED_SURFACE:
 			surface = !surface;
-			XtSetArg(arg[0], XtNsurface, surface);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNsurface, surface, NULL);
 #ifdef HAVE_MOTIF
 			XmToggleButtonSetState(surfaceSwitch, surface, True);
 #endif
 			break;
 		case THREED_OBJECT:
 			object = (object + 1) % numObjects;
-			XtSetArg(arg[0], XtNobject, object);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNobject, object, NULL);
 			XtVaGetValues(w,
 				XtNobjectName, &name,
 				NULL);
@@ -782,8 +778,7 @@ static void CallbackThreeD(Widget w, caddr_t clientData,
 	XmScaleSetValue(phiAng, angle.phi);
 	XmScaleSetValue(psiAng, angle.psi);
 #else
-	PrintState(XtParent(w), name, surface, object,
-		x, y, z, theta, phi, psi);
+	PrintState(XtParent(w), name, surface, object, distance, angle);
 #endif
 }
 
@@ -1047,9 +1042,9 @@ int main(int argc, char **argv)
 	XmString fileString, quitString;
 	char **list;
 	int object, number;
-#endif
 
 	progDsp = argv[0];
+#endif
 	topLevel = XtInitialize(argv[0], "Threed",
 		options, XtNumber(options), &argc, argv);
 	if (argc != 1)
@@ -1079,11 +1074,10 @@ int main(int argc, char **argv)
 			RootWindowOfScreen(XtScreen(topLevel)),
 			(char *) threed_bits,
 			threed_width, threed_height);
-	XtSetArg(arg[0], XtNiconPixmap, threedIcon);
 #ifdef HAVE_MOTIF
-	/* not XmEXPLICIT */
-	XtSetArg(arg[1], XmNkeyboardFocusPolicy, XmPOINTER);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, threedIcon,
+		XmNkeyboardFocusPolicy, XmPOINTER, NULL); /* not XmEXPLICIT */
 	panel = XtVaCreateManagedWidget("panel",
 		xmPanedWindowWidgetClass, topLevel,
 		XmNseparatorOn, False,
@@ -1236,8 +1230,9 @@ int main(int argc, char **argv)
 	XtAddCallback(surfaceSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) SurfaceToggle, (XtPointer) NULL);
 #else
-	XtSetArg(arg[1], XtNinput, True);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, threedIcon,
+		XtNinput, True, NULL);
 	threed = XtCreateManagedWidget("threed",
 		threedWidgetClass, topLevel,
 		NULL, 0);
