@@ -25,10 +25,9 @@
 
 /* Methods file for Triangles */
 
-#if defined(USE_RPLAY) || defined(USE_NAS) || defined(USE_VMSPLAY) || defined(USE_ESOUND) || defined(WINVER) || defined(DEF_PLAY)
-#define USE_SOUND
-extern void playSound(char * filename);
-#endif
+#include "file.h"
+#include "rngs.h"
+#include "sound.h"
 #include "TrianglesP.h"
 
 #ifndef PICTURE
@@ -181,8 +180,11 @@ static XtActionsRec actionsListTriangles[] =
 static XtResource resourcesTriangles[] =
 {
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
-	 XtOffset(TrianglesWidget, triangles.username),
-	 XtRString, (caddr_t) "guest"},
+	 XtOffset(TrianglesWidget, triangles.userName),
+	 XtRString, (caddr_t) ""},
+	{XtNscoreFile, XtCScoreFile, XtRString, sizeof (String),
+	 XtOffset(TrianglesWidget, triangles.scoreFile),
+	 XtRString, (caddr_t) ""},
 	{XtNforeground, XtCForeground, XtRPixel, sizeof (Pixel),
 	 XtOffset(TrianglesWidget, triangles.foreground),
 	 XtRString, (caddr_t) XtDefaultForeground},
@@ -240,6 +242,12 @@ static XtResource resourcesTriangles[] =
 	{XtNcheat, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(TrianglesWidget, triangles.cheat),
 	 XtRString, (caddr_t) "FALSE"},
+	{XtNscoreOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(TrianglesWidget, triangles.scoreOnly),
+	 XtRString, (caddr_t) "FALSE"},
+	{XtNversionOnly, XtCBoolean, XtRBoolean, sizeof (Boolean),
+	 XtOffset(TrianglesWidget, triangles.versionOnly),
+	 XtRString, (caddr_t) "FALSE"},
 	{XtNmenu, XtCMenu, XtRInt, sizeof (int),
 	 XtOffset(TrianglesWidget, triangles.menu),
 	 XtRString, (caddr_t) "-1"},
@@ -291,78 +299,6 @@ TrianglesClassRec trianglesClassRec =
 
 WidgetClass trianglesWidgetClass = (WidgetClass) & trianglesClassRec;
 
-#ifndef HAVE_USLEEP
-#if !defined( VMS ) || defined( XVMSUTILS ) || ( __VMS_VER >= 70000000 )
-#ifdef USE_XVMSUTILS
-#include <X11/unix_time.h>
-#endif
-#if HAVE_SYS_TIME_H
-#include <sys/time.h>
-#else
-#if HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#endif
-#endif
-#endif
-#if defined(SYSV) || defined(SVR4)
-#ifdef LESS_THAN_AIX3_2
-#include <sys/poll.h>
-#else /* !LESS_THAN_AIX3_2 */
-#include <poll.h>
-#endif /* !LESS_THAN_AIX3_2 */
-#endif /* defined(SYSV) || defined(SVR4) */
-
-/* not static in case usleep found in system include */
-int
-usleep(unsigned int usec)
-{
-#if (defined (SYSV) || defined(SVR4)) && !defined(__hpux)
-#if defined(HAVE_NANOSLEEP)
-	{
-		struct timespec rqt;
-
-		rqt.tv_nsec = 1000 * (usec % (unsigned int) 1000000);
-		rqt.tv_sec = usec / (unsigned int) 1000000;
-		return nanosleep(&rqt, NULL);
-	}
-#else
-	(void) poll(
-#if defined(__cplusplus) || defined(c_plusplus)
-		(pollfd *) /* guess */
-#else
-		(void *)
-#endif
-		0, (int) 0, usec / 1000);	/* ms resolution */
-#endif
-#else
-#ifdef VMS
-	long timadr[2];
-
-	if (usec != 0) {
-		timadr[0] = -usec * 10;
-		timadr[1] = -1;
-
-		sys$setimr(4, &timadr, 0, 0, 0);
-		sys$waitfr(4);
-	}
-#else
-	struct timeval time_out;
-
-#if 0
-	/* (!defined(AIXV3) && !defined(__hpux)) */
-	extern int select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
-
-#endif
-
-	time_out.tv_usec = usec % (unsigned int) 1000000;
-	time_out.tv_sec = usec / (unsigned int) 1000000;
-	(void) select(0, (void *) 0, (void *) 0, (void *) 0, &time_out);
-#endif
-#endif
-	return 0;
-}
-#endif
-
 void
 SetTriangles(TrianglesWidget w, int reason)
 {
@@ -388,13 +324,13 @@ loadFont(TrianglesWidget w)
 	if ((w->triangles.fontInfo = XLoadQueryFont(display,
 			w->triangles.font)) == NULL) {
 		(void) sprintf(buf,
-			"Cannot open %s font.\nAttempting %s font as alternate\n",
+			"Can not open %s font.\nAttempting %s font as alternate\n",
 			w->triangles.font, altfontname);
 		DISPLAY_WARNING(buf);
 		if ((w->triangles.fontInfo = XLoadQueryFont(display,
 				altfontname)) == NULL) {
 			(void) sprintf(buf,
-				"Cannot open %s alternate font.\nUse the -font option to specify a font to use.\n",
+				"Can not open %s alternate font.\nUse the -font option to specify a font to use.\n",
 				altfontname);
 			DISPLAY_WARNING(buf);
 		}
@@ -455,38 +391,6 @@ static Point rhombusUnit[ROWTYPES][ROWTYPES + 2] =
 static Point rhombusList[ROWTYPES][ROWTYPES + 2];
 #endif
 
-#if (!defined(WINVER) || (WINVER <= 0x030a)) /* if X or WINDOWS 3.1 or less */
-static void
-Sleep(unsigned int cMilliseconds)
-{
-#if (defined(WINVER) && (WINVER <= 0x030a))
-	unsigned long time_out = GetTickCount() + cMilliseconds;
-
-	while (time_out > GetTickCount());
-#else
-	(void) usleep(cMilliseconds * 1000);
-#endif
-}
-#endif
-
-void
-intCat(char ** string, const char * var1, const int var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + 21))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%d", var1, var2);
-}
-
-void
-stringCat(char ** string, const char * var1, const char * var2)
-{
-	if (!(*string = (char *) malloc(strlen(var1) + strlen(var2) + 1))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	(void) sprintf(*string, "%s%s", var1, var2);
-}
-
 static void
 CheckTiles(TrianglesWidget w)
 {
@@ -733,83 +637,6 @@ int2String(TrianglesWidget w, char *buf, int number, int base, Boolean capital)
 	return last;
 }
 
-#ifdef WINVER
-static void
-POLYGON(TrianglesWidget w, Pixmap dr, GC color, GC lineColor,
-		const POINT * poly, int n, Boolean origin)
-{
-	/* CoordModePrevious -> CoordModeOrigin */
-	POINT *temp = NULL;
-	int pt;
-
-	if (!origin) {
-		if (!(temp = (POINT *) malloc(sizeof (POINT) * n))) {
-			DISPLAY_ERROR("Not enough memory, exiting.");
-		}
-		temp[0] = poly[0];
-		for (pt = 1; pt < n; pt++) {
-			temp[pt].x = temp[pt - 1].x + poly[pt].x,
-			temp[pt].y = temp[pt - 1].y + poly[pt].y;
-		}
-	}
-	if (dr)
-		w->triangles.hOldBitmap =
-			(HBITMAP) SelectObject(w->triangles.memDC, dr);
-	w->triangles.hPen = CreatePen(PS_SOLID, 1, lineColor);
-	w->triangles.hOldPen = (HPEN) SelectObject(DC(w, dr),
-		w->triangles.hPen);
-	w->triangles.hBrush = CreateSolidBrush(color);
-	w->triangles.hOldBrush = (HBRUSH) SelectObject(DC(w, dr),
-		w->triangles.hBrush);
-	(void) Polygon(DC(w, dr), (origin) ? poly : temp, n);
-	(void) SelectObject(DC(w, dr), w->triangles.hOldBrush);
-	(void) DeleteObject(w->triangles.hBrush);
-	(void) SelectObject(DC(w, dr), w->triangles.hOldPen);
-	(void) DeleteObject(w->triangles.hPen);
-	if (dr)
-		(void) SelectObject(w->triangles.memDC,
-			w->triangles.hOldBitmap);
-	if (!origin) {
-		free(temp);
-	}
-}
-
-static void
-POLYLINE(TrianglesWidget w, Pixmap dr, GC color, const POINT * poly, int n,
-		Boolean origin)
-{
-	/* CoordModePrevious -> CoordModeOrigin */
-	POINT *temp = NULL;
-	int pt;
-
-	if (!origin) {
-		if (!(temp = (POINT *) malloc(sizeof (POINT) * n))) {
-			DISPLAY_ERROR("Not enough memory, exiting.");
-		}
-		temp[0] = poly[0];
-		for (pt = 1; pt < n; pt++) {
-			temp[pt].x = temp[pt - 1].x + poly[pt].x,
-			temp[pt].y = temp[pt - 1].y + poly[pt].y;
-		}
-	}
-	if (dr)
-		w->triangles.hOldBitmap =
-			(HBITMAP) SelectObject(w->triangles.memDC, dr);
-	w->triangles.hPen = CreatePen(PS_SOLID, 1, color);
-	w->triangles.hOldPen = (HPEN) SelectObject(DC(w, dr),
-		w->triangles.hPen);
-	(void) Polyline(DC(w, dr), (origin) ? poly : temp, n);
-	(void) SelectObject(DC(w, dr), w->triangles.hOldPen);
-	(void) DeleteObject(w->triangles.hPen);
-	if (dr)
-		(void) SelectObject(w->triangles.memDC,
-			w->triangles.hOldBitmap);
-	if (!origin) {
-		free(temp);
-	}
-}
-#endif
-
 static void
 fill3DTriangle(TrianglesWidget w, Pixmap dr, GC gc, GC darkerGC, GC brighterGC,
 	Point * list, Boolean raised, Boolean orient)
@@ -825,7 +652,7 @@ fill3DTriangle(TrianglesWidget w, Pixmap dr, GC gc, GC darkerGC, GC brighterGC,
 	tempList[3].x = tempList[0].x;
 	tempList[3].y = tempList[1].y;
 
-	POLYGON(w, dr, currentGC, currentGC, list, 3, False);
+	POLYGON(w, dr, currentGC, currentGC, list, 3, True, False);
 	currentGC = (raised ^ orient) ? ((raised) ? brighterGC : gc) :
 		darkerGC;
 	DRAWLINE(w, dr, currentGC,
@@ -915,7 +742,7 @@ DrawTile(TrianglesWidget w, int pos, int orient, Boolean blank, Boolean erase,
 	triangleList[orient][0].y = dy;
 	if (blank) {
 		POLYGON(w, *dr, tileGC, borderGC, triangleList[orient], 3,
-			False);
+			True, False);
 	} else {
 		if (pressedOffset != 0) {
 			drawShadow(w, *dr, w->triangles.tileDarkerGC,
@@ -951,23 +778,6 @@ DrawTile(TrianglesWidget w, int pos, int orient, Boolean blank, Boolean erase,
 	}
 }
 
-static void
-DrawAllBufferedTiles(const TrianglesWidget w)
-{
-	int k, side = UP, fin = 1, step = 1;
-
-	for (k = 0; k < w->triangles.sizeSize; k++) {
-		DrawTile(w, k, side, (w->triangles.tileOfPosition[k] <= 0),
-			(w->triangles.tileOfPosition[k] <= 0), FALSE, 0, 0);
-		if (fin == k + 1) {
-			side = UP;
-			step += 2;
-			fin += step;
-		} else
-			side = !side;
-	}
-}
-
 void
 DrawAllTiles(const TrianglesWidget w)
 {
@@ -1160,9 +970,7 @@ AnimateSlide(TrianglesWidget w, int dir, int fast, Boolean logMoves)
 				1, 1);
 		  	/* Erase old slivers */
 		  }
-#ifndef WINVER
-		  XFlush(XtDisplay(w));
-#endif
+		  FLUSH(w);
 		  Sleep((unsigned int) (w->triangles.delay / fast));
 	}
 #else
@@ -1215,9 +1023,7 @@ AnimateSlide(TrianglesWidget w, int dir, int fast, Boolean logMoves)
 				DrawTile(w, rowPos[k],
 					(firstOrient + k) & 1,
 					False, False, FALSE, pixX, pixY);
-#ifndef WINVER
-			XFlush(XtDisplay(w));
-#endif
+			FLUSH(w);
 			if (i % 8 == 0)
 				Sleep((unsigned int) (w->triangles.delay /
 					fast));
@@ -1284,13 +1090,13 @@ ResetTiles(TrianglesWidget w)
 
 	w->triangles.sizeSize = w->triangles.size * w->triangles.size;
 	if (w->triangles.tileOfPosition)
-		(void) free((void *) w->triangles.tileOfPosition);
+		free(w->triangles.tileOfPosition);
 	if (!(w->triangles.tileOfPosition = (int *)
 			malloc(sizeof (int) * w->triangles.sizeSize))) {
 		DISPLAY_ERROR("Not enough memory, exiting.");
 	}
 	if (startPosition)
-		(void) free((void *) startPosition);
+		free(startPosition);
 	if (!(startPosition = (int *)
 			malloc(sizeof (int) * w->triangles.sizeSize))) {
 		DISPLAY_ERROR("Not enough memory, exiting.");
@@ -1359,7 +1165,7 @@ DrawFrame(TrianglesWidget w, Pixmap dr, Boolean focus)
 	tempList[3].x = offsetX;
 	tempList[3].y = offsetY;
 	POLYGON(w, dr, w->triangles.borderGC, w->triangles.borderGC,
-		tempList, 3, True);
+		tempList, 3, True, True);
 	tempList[0].x = sumX - 2;
 	tempList[0].y = offsetY;
 	tempList[1].x = sumX - 2;
@@ -1369,7 +1175,7 @@ DrawFrame(TrianglesWidget w, Pixmap dr, Boolean focus)
 	tempList[3].x = sumX - 2;
 	tempList[3].y = offsetY;
 	POLYGON(w, dr, w->triangles.borderGC, w->triangles.borderGC,
-		tempList, 3, True);
+		tempList, 3, True, True);
 	tempList[0].x = sumX2 - 2;
 	tempList[0].y = offsetY;
 	tempList[1].x = sumX - 2;
@@ -2078,10 +1884,14 @@ SetValuesTriangles(TrianglesWidget w)
 	(void) GetPrivateProfileString(SECTION, "bumpSound", BUMPSOUND,
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) strcpy(w->triangles.bumpSound, szBuf);
-	(void) GetPrivateProfileString(SECTION, "name", "Guest",
+	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
 		szBuf, sizeof (szBuf), INIFILE);
-	(void) strcpy(w->triangles.username, szBuf);
-	 w->triangles.username[80] = 0;
+	(void) strcpy(w->triangles.userName, szBuf);
+	 w->triangles.userName[80] = 0;
+	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
+		szBuf, sizeof (szBuf), INIFILE);
+	(void) strcpy(w->triangles.scoreFile, szBuf);
+	 w->triangles.scoreFile[80] = 0;
 }
 
 void
@@ -2313,8 +2123,8 @@ QuitTriangles(TrianglesWidget w
 		if (w->triangles.bufferTiles != NULL) {
 			DeleteObject(w->triangles.bufferTiles);
 		}
-		DeleteDC(w->triangles.memDC);
-		w->triangles.memDC = NULL;
+		DeleteDC(w->core.memDC);
+		w->core.memDC = NULL;
 	}
 #else
 	Display *display = XtDisplay(w);
@@ -2358,9 +2168,9 @@ ResizeTiles(TrianglesWidget w)
 	int sel;
 
 #ifdef WINVER
-	if (w->triangles.memDC == NULL) {
-		w->triangles.memDC = CreateCompatibleDC(w->core.hDC);
-		if (w->triangles.memDC == NULL) {
+	if (w->core.memDC == NULL) {
+		w->core.memDC = CreateCompatibleDC(w->core.hDC);
+		if (w->core.memDC == NULL) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
@@ -2461,7 +2271,7 @@ ResizeTiles(TrianglesWidget w)
 		}
 #endif
 	if (!(w->triangles.picture && *(w->triangles.picture))) {
-		DrawAllBufferedTiles(w);
+		DrawAllTiles(w);
 	}
 }
 
@@ -2634,9 +2444,7 @@ SelectTriangles(TrianglesWidget w
 			DrawTile(w, w->triangles.currentPosition,
 				w->triangles.currentPositionOrient,
 				rowType == TRIANGLES_SPACE, False, TRUE, 0, 0);
-#ifndef WINVER
-			XFlush(XtDisplay(w));
-#endif
+			FLUSH(w);
 			Sleep(100);
 			DrawTile(w, w->triangles.currentPosition,
 				w->triangles.currentPositionOrient,
