@@ -32,38 +32,25 @@
   Version 1: 91/09/05 SunView
 */
 
+#include "file.h"
 #ifdef WINVER
 #include "TrianglesP.h"
 #include "wtriangles.h"
 #define TITLE "wtriangles"
 
 static TrianglesRec widget;
-static HWND Wnd;
 
 #ifndef SCOREPATH
-#define SCOREPATH "c:\\Windows"
+#ifdef UNIXDELIM
+#define SCOREPATH "c:/WINDOWS"
+#else
+#define SCOREPATH "c:\\WINDOWS"
 #endif
-#define PRINT_MESSAGE(b) (void) MessageBox(Wnd, (LPCSTR) b, "Warning", MB_OK);
+#endif
+#define PRINT_MESSAGE(b) (void) MessageBox(widget.core.hWnd, (LPCSTR) b, "Warning", MB_OK);
 #define SET_STARTED(w,b) w->triangles.started = b
 #else
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
-#ifdef VMS
-#include <unixlib.h>
-#define getlogin() cuserid(NULL)
-#else
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif
-#if HAVE_FCNTL_H
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#endif
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
+#include "xwin.h"
 #include <X11/Shell.h>
 #include <X11/cursorfont.h>
 #ifdef HAVE_MOTIF
@@ -83,7 +70,7 @@ static HWND Wnd;
 #else
 #define PRINT_MESSAGE(b) XtWarning(b)
 #endif
-#define SET_STARTED(w,b) XtSetArg(arg[0], XtNstart, b); XtSetValues(w, arg, 1)
+#define SET_STARTED(w,b) XtVaSetValues(w, XtNstart, b, NULL)
 #include "Triangles.h"
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
@@ -91,28 +78,35 @@ static HWND Wnd;
 #endif
 #include "icons/triangles.xbm"
 #ifndef SCOREPATH
+#ifdef VMS
+#define SCOREPATH "SYS$LOGIN:"
+#else
 #define SCOREPATH "/var/games/xpuzzles"
 #endif
 #endif
+#endif
 
-#ifdef HAVE_MOTIF
+#ifndef WINVER
 static const char aboutHelp[] = {
-	"Version 7.1.3\n"
+	"Triangles Version 7.1.5\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
 	"http://www.tux.org/~bagleyd/puzzles.html\n"
 };
+
 static const char optionsHelp[] = {
-	"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]] "
-	"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"[-{foreground|fg} {color}] [-{background|bg} {color}] "
-	"[-{border|bd} {color}] [-tile {color}] [-size {int}]\n"
-	"[-[no]install] [-picture {filename}] [-delay msecs] "
-	"[-[no]sound] [-bumpsound {filename}] [-base {int}]\n"
-	"[-{font|fn} {fontname}] [-username {string}]\n"
+	"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
+	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+	"\t[-{border|bd} {color}] [-tile {color}] [-size {int}]\n"
+	"\t[-[no]install] [-picture {filename}] [-delay msecs]\n"
+	"\t[-[no]sound] [-bumpSound {filename}] [-base {int}]\n"
+	"\t[-{font|fn} {fontname}] [-userName {string}]\n"
+	"\t[-scoreFile {filename}] [-scores] [-version]\n"
 };
 #endif
+
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
 	"A sliding tile puzzle.  A triangular version of the "
@@ -122,6 +116,7 @@ static const char descriptionHelp[] = {
 	"and 6 triangular-shaped pieces.  This is easier to solve "
 	"than 15 puzzle.\n"
 };
+
 static const char featuresHelp[] = {
 	"Click \"mouse-left\" button to move a tile.  Clicks on "
 	"spaces, or clicks on tiles that are not in line with\n"
@@ -146,6 +141,8 @@ static const char featuresHelp[] = {
 	"\n"
 	"Press \"W\" or \"w\" keys to save a puzzle.\n"
 	"\n"
+	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+	"\n"
 	"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
 	"\n"
 	"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
@@ -165,6 +162,7 @@ static const char featuresHelp[] = {
 	"  v\n"
 	"1   3  Lower Left, Lower Right\n"
 };
+
 static const char referencesHelp[] = {
 	"L. E. Horden, Sliding Piece Puzzles  (Recreations in "
 	"Mathematics Series), Oxford University Press  1986,\n"
@@ -174,6 +172,7 @@ static const char referencesHelp[] = {
 	"Press, Seattle 1987, p 126, 127.\n"
 };
 #endif
+
 static const char solveHelp[] = {
 	"Auto-solver: sorry, not implemented.\n"
 };
@@ -183,7 +182,7 @@ static const char solveHelp[] = {
 #endif
 
 #define MAXTILES 16
-#define NEVER -1
+#define NEVER (-1)
 #define FILENAMELEN 1024
 #define USERNAMELEN 120
 #define MESSAGELEN (USERNAMELEN+64)
@@ -212,20 +211,21 @@ static char buff[21];
 static Widget descriptionDialog, featuresDialog;
 static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, randomizeDialog;
+static Arg arg[3];
 #else
 static char titleDsp[TITLELEN] = "";
 #endif
+static char scoreFileName[FILENAMELEN] = SCOREFILE;
+static char fileName[FILENAMELEN];
 #ifdef WINVER
 #define MAXPROGNAME 80
 static char progDsp[MAXPROGNAME] = TITLE;
-static char usernameDsp[USERNAMELEN] = "Guest";
+static char userNameDsp[USERNAMELEN] = "Guest";
 #else
 static Pixmap trianglesIcon = None;
 static Widget topLevel, triangles;
-static Arg arg[3];
 static char *progDsp;
-static char usernameDsp[USERNAMELEN] = "";
-#endif
+static char userNameDsp[USERNAMELEN] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -236,25 +236,24 @@ PrintState(Widget w, char *msg)
 	if (!XtIsSubclass(w, xmLabelWidgetClass))
 		XtError("PrintState() requires a Label Widget");
 	xmstr = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
-	XtSetArg(arg[0], XmNlabelString, xmstr);
-	XtSetValues(w, arg, 1);
+	XtVaSetValues(w, XmNlabelString, xmstr, NULL);
 }
-#else
+#endif
+
 static void
-PrintState(
-#ifndef WINVER
-Widget w,
-#endif
-int size, int moves, char *msg)
+PrintRecords(void)
 {
-	(void) sprintf(titleDsp, "%s: %d@ (%d/%s) - %s",
-		progDsp, size, moves, recordDsp, msg);
-#ifdef WINVER
-	SetWindowText(Wnd, (LPSTR) titleDsp);
-#else
-	XtSetArg(arg[0], XtNtitle, titleDsp);
-	XtSetValues(w, arg, 1);
-#endif
+	int i;
+
+	(void) printf("TRIANGLES  HALL OF FAME\n\n");
+	(void) printf(" TILES USER            MOVES\n");
+	for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
+		if (trianglesRecord[i].score > 0)
+			(void) printf("%6d %-12s%9d\n",
+				i + 1,
+				trianglesRecord[i].name,
+				trianglesRecord[i].score);
+	}
 }
 #endif
 
@@ -274,21 +273,21 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, n;
-	char username[USERNAMELEN];
+	char userName[USERNAMELEN];
 	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *fname, *lname;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
+	stringCat(&buf1, CURRENTDELIM, scoreFileName);
 	lname = buf1;
 	stringCat(&buf1, SCOREPATH, FINALDELIM);
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "r")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "r")) == NULL) {
+	(void) strncpy(fileName, lname, USERNAMELEN);
+	if ((fp = fopen(fileName, "r")) == NULL) {
+		(void) strncpy(fileName, fname, USERNAMELEN);
+		/* Try installed directory. */
+		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
@@ -316,11 +315,11 @@ ReadRecords(void)
 	free(lname);
 	free(fname);
 	for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
-		(void) fscanf(fp, "%d %s\n", &n, username);
+		(void) fscanf(fp, "%d %s\n", &n, userName);
 		if (n <= trianglesRecord[i].score ||
 				trianglesRecord[i].score <= NEVER) {
 			trianglesRecord[i].score = n;
-			(void) strncpy(trianglesRecord[i].name, username,
+			(void) strncpy(trianglesRecord[i].name, userName,
 				USERNAMELEN);
 		}
 	}
@@ -332,61 +331,31 @@ WriteRecords(void)
 {
 	FILE *fp;
 	int i;
-	char *buf1 = NULL, *buf2 = NULL;
-	char *fname, *lname, *name;
+	char *buf1 = NULL;
 
-	stringCat(&buf1, CURRENTDELIM, SCOREFILE);
-	lname = buf1;
-	stringCat(&buf1, SCOREPATH, FINALDELIM);
-	stringCat(&buf2, buf1, SCOREFILE);
-	free(buf1);
-	fname = buf2;
-	name = fname;
-	if ((fp = fopen(name, "w")) == NULL) {
-		/* Try current directory in case its not installed yet. */
-		name = lname;
-		if ((fp = fopen(name, "w")) == NULL) {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, " or ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-			free(lname);
-			free(fname);
-			return;
-		}
-/* Probably annoying */
-#if 0
-		else {
-			stringCat(&buf1, "Can not write to ", fname);
-			stringCat(&buf2, buf1, ", falling back to ");
-			free(buf1);
-			stringCat(&buf1, buf2, lname);
-			free(buf2);
-			PRINT_MESSAGE(buf1);
-			free(buf1);
-		}
-#endif
+	if ((fp = fopen(fileName, "w")) == NULL) {
+		stringCat(&buf1, "Can not write to ", fileName);
+		PRINT_MESSAGE(buf1);
+		free(buf1);
+		return;
 	}
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockfile[FILENAMELEN];
+		char lockFile[FILENAMELEN];
 
-		(void) strncpy(lockfile, name, FILENAMELEN - 6);
-		(void) strcat(lockfile, ".lock");
-		while (((lfd = open(lockfile, O_CREAT | O_EXCL, 0644)) < 0) &&
+		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strcat(lockFile, ".lock");
+		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
 			(void) sleep(1);
 		if (lfd < 0) {
 #if 1
 			(void) fprintf(stderr,
-			  "Lock file exists... guessing its an old one.\n");
+				"Lock file exists... guessing its an old one.\n");
 #else
 			(void) fprintf(stderr,
-			  "Lock file exists... score not recorded - sorry.\n");
+				"Lock file exists... score not recorded - sorry.\n");
 			return;
 #endif
 		}
@@ -397,12 +366,10 @@ WriteRecords(void)
 				trianglesRecord[i].name);
 #if HAVE_FCNTL_H
 		(void) close(lfd);
-		(void) unlink(lockfile);
+		(void) unlink(lockFile);
 #endif
 		(void) fclose(fp);
 	}
-	free(lname);
-	free(fname);
 }
 
 static void
@@ -423,6 +390,28 @@ PrintRecord(int size)
 #endif
 }
 
+static void
+PrintStatus(char *msg, int nMoves
+#ifndef HAVE_MOTIF
+		, int size
+#endif
+		)
+{
+#ifdef HAVE_MOTIF
+	PrintState(message, msg);
+	(void) sprintf(buff, "%d", nMoves);
+	PrintState(moves, buff);
+#else
+	(void) sprintf(titleDsp, "%s: %d@ (%d/%s) - %s",
+		progDsp, size, nMoves, recordDsp, msg);
+#ifdef WINVER
+	SetWindowText(widget.core.hWnd, (LPSTR) titleDsp);
+#else
+	XtVaSetValues(XtParent(triangles), XtNtitle, titleDsp, NULL);
+#endif
+#endif
+}
+
 static Boolean
 HandleSolved(int counter, int size)
 {
@@ -432,7 +421,7 @@ HandleSolved(int counter, int size)
 			trianglesRecord[i].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		trianglesRecord[i].score = counter;
-		(void) strncpy(trianglesRecord[i].name, usernameDsp,
+		(void) strncpy(trianglesRecord[i].name, userNameDsp,
 			USERNAMELEN);
 		WriteRecords();
 		PrintRecord(size);
@@ -451,18 +440,37 @@ Widget w
 )
 {
 	int size;
-	char *username;
+	char *userName, *scoreFile;
 
 #ifdef WINVER
 	InitializeTriangles(w, brush);
 
 	size = w->triangles.size;
-	username = w->triangles.username;
+	userName = w->triangles.userName;
+	scoreFile = w->triangles.scoreFile;
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
 #else
+	Boolean scoreOnly, versionOnly;
 
 	XtVaGetValues(w,
-		XtNuserName, &username,
-		XtNsize, &size, NULL);
+		XtNuserName, &userName,
+		XtNscoreFile, &scoreFile,
+		XtNsize, &size,
+		XtNscoreOnly, &scoreOnly,
+		XtNversionOnly, &versionOnly, NULL);
+	if (versionOnly) {
+		(void) printf(aboutHelp);
+		exit(0);
+	}
+	if (strcmp(scoreFile, ""))
+		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+	if (scoreOnly) {
+		InitRecords();
+		ReadRecords();
+		PrintRecords();
+		exit(0);
+	}
 #ifdef HAVE_MOTIF
 	if (size > MAXTILES)
 		XtVaSetValues(tile, XmNmaximum, size, NULL);
@@ -481,32 +489,29 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(usernameDsp, username, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #endif
-	if (!strcmp(username, "") || !strcmp(username, "(null)") ||
-			!strcmp(username, NOACCESS) ||
-			!strcmp(username, NOBODY)) {
-		/* The NOACCESS is not necessary, but it may stop silliness. */
+	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
+			!strcmp(userName, NOACCESS) ||
+			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(usernameDsp, username, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USERNAMELEN);
 #else
-		(void) sprintf(usernameDsp, "%s", getlogin());
-		if (!strcmp(usernameDsp, "") ||
-				!strcmp(usernameDsp, "(null)") ||
-				!strcmp(usernameDsp, NOACCESS) ||
-				!strcmp(usernameDsp, NOBODY))
+		(void) sprintf(userNameDsp, "%s", getlogin());
+		if (!strcmp(userNameDsp, "") ||
+				!strcmp(userNameDsp, "(null)") ||
+				!strcmp(userNameDsp, NOACCESS) ||
+				!strcmp(userNameDsp, NOBODY))
 			/* It really IS nobody */
-			(void) sprintf(usernameDsp, "%s", "guest");
+			(void) sprintf(userNameDsp, "%s", "guest");
 #endif
 	}
 	PrintRecord(size);
+	PrintStatus(messageDsp, movesDsp
 #ifndef HAVE_MOTIF
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
-#endif
-		size, movesDsp, messageDsp);
+		, size
 #endif
+		);
 }
 
 #ifdef WINVER
@@ -548,8 +553,8 @@ CallbackTriangles(Widget w, caddr_t clientData,
 #ifdef HAVE_MOTIF
 			XtManageChild(randomizeDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-			XtSetValues(triangles, arg, 1);
+			XtVaSetValues(triangles,
+				XtNmenu, 5, NULL); /* menu choice */
 #endif
 			break;
 #endif
@@ -590,10 +595,10 @@ CallbackTriangles(Widget w, caddr_t clientData,
 		case TRIANGLES_SOLVED:
 			if (cheat)
 				(void) sprintf(messageDsp,
-					"No cheating %s!!", usernameDsp);
+					"No cheating %s!!", userNameDsp);
 			else if (HandleSolved(movesDsp, size))
 				(void) sprintf(messageDsp,
-					"Congratulations %s!!", usernameDsp);
+					"Congratulations %s!!", userNameDsp);
 			else
 				(void) strncpy(messageDsp, "Solved!",
 					MESSAGELEN);
@@ -610,8 +615,7 @@ CallbackTriangles(Widget w, caddr_t clientData,
 #ifdef WINVER
 			w->triangles.size = size;
 #else
-			XtSetArg(arg[0], XtNsize, size);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(tile, size);
 			if (size >= MAXTILES)
@@ -626,8 +630,7 @@ CallbackTriangles(Widget w, caddr_t clientData,
 #ifdef WINVER
 			w->triangles.size = size;
 #else
-			XtSetArg(arg[0], XtNsize, size);
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
 			if (size > MAXTILES)
 				XtVaSetValues(tile, XmNmaximum, size, NULL);
@@ -655,8 +658,8 @@ CallbackTriangles(Widget w, caddr_t clientData,
 				if (delay < 0)
 					delay = 0;
 				if (delay != oldDelay) {
-					XtSetArg(arg[0], XtNdelay, delay);
-					XtSetValues(w, arg, 1);
+					XtVaSetValues(w,
+						XtNdelay, delay, NULL);
 				}
 				XmScaleSetValue(speed,
 					MAXSPEED + MINSPEED - delay - 1);
@@ -664,17 +667,11 @@ CallbackTriangles(Widget w, caddr_t clientData,
 			return;
 #endif
 	}
-#ifdef HAVE_MOTIF
-	PrintState(message, messageDsp);
-	(void) sprintf(buff, "%d", movesDsp);
-	PrintState(moves, buff);
-#else
-	PrintState(
-#ifndef WINVER
-		XtParent(w),
-#endif
-		size, movesDsp, messageDsp);
+	PrintStatus(messageDsp, movesDsp
+#ifndef HAVE_MOTIF
+		, size
 #endif
+		);
 }
 
 #ifdef WINVER
@@ -698,7 +695,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 	HBRUSH brush = (HBRUSH) NULL;
 	PAINTSTRUCT paint;
 
-	Wnd = widget.core.hWnd = hWnd;
+	widget.core.hWnd = hWnd;
 	if (GetFocus()) {
 		if (!widget.triangles.focus) {
 			widget.core.hDC = GetDC(hWnd);
@@ -897,20 +894,7 @@ static void
 Usage(char * programName)
 {
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr,
-		"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n");
-	(void) fprintf(stderr,
-		"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n");
-	(void) fprintf(stderr,
-		"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{border|bd} {color}] [-tile {color}] [-size {int}]\n");
-	(void) fprintf(stderr,
-		"\t[-[no]install] [-picture {filename}] [-delay msecs]\n");
-	(void) fprintf(stderr,
-		"\t[-[no]sound] [-bumpsound {filename}] [-base {int}]\n");
-	(void) fprintf(stderr,
-		"\t[-{font|fn} {fontname}] [-username {string}]\n");
+	(void) fprintf(stderr, optionsHelp);
 	exit(1);
 }
 
@@ -936,11 +920,14 @@ static XrmOptionDescRec options[] =
 	{(char *) "-delay", (char *) "*triangles.delay", XrmoptionSepArg, NULL},
 	{(char *) "-sound", (char *) "*triangles.sound", XrmoptionNoArg, (char *) "TRUE"},
 	{(char *) "-nosound", (char *) "*triangles.sound", XrmoptionNoArg, (char *) "FALSE"},
-	{(char *) "-bumpsound", (char *) "*triangles.bumpSound", XrmoptionSepArg, NULL},
+	{(char *) "-bumpSound", (char *) "*triangles.bumpSound", XrmoptionSepArg, NULL},
 	{(char *) "-base", (char *) "*triangles.base", XrmoptionSepArg, NULL},
 	{(char *) "-fn", (char *) "*triangles.font", XrmoptionSepArg, NULL},
 	{(char *) "-font", (char *) "*triangles.font", XrmoptionSepArg, NULL},
-	{(char *) "-username", (char *) "*triangles.userName", XrmoptionSepArg, NULL}
+	{(char *) "-userName", (char *) "*triangles.userName", XrmoptionSepArg, NULL},
+	{(char *) "-scoreFile", (char *) "*triangles.scoreFile", XrmoptionSepArg, NULL},
+	{(char *) "-scores", (char *) "*triangles.scoreOnly", XrmoptionNoArg, (char *) "TRUE"},
+	{(char *) "-version", (char *) "*triangles.versionOnly", XrmoptionNoArg, (char *) "TRUE"}
 };
 
 #ifdef HAVE_MOTIF
@@ -949,8 +936,7 @@ CallbackTrianglesRandomize(Widget w, XtPointer clientData,
 		XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 5); /* menu choice */
-		XtSetValues(triangles, arg, 1);
+		XtVaSetValues(triangles, XtNmenu, 5, NULL); /* menu choice */
 	}
 }
 
@@ -994,16 +980,15 @@ fileCB(Widget w, void *value, void *clientData)
 
 	if (val == 2)
 		exit(0);
-	XtSetArg(arg[0], XtNmenu, val);
-	XtSetValues(triangles, arg, 1);
+	XtVaSetValues(triangles, XtNmenu, val, NULL);
 }
 
 static void
 playCB(Widget w, void *value, void *clientData)
 {
 	int val = (int) value;
-	XtSetArg(arg[0], XtNmenu, val + 3); /* GWQ */
-	XtSetValues(triangles, arg, 1);
+
+	XtVaSetValues(triangles, XtNmenu, val + 3, NULL); /* GWQ */
 }
 
 static Widget
@@ -1136,11 +1121,10 @@ main(int argc, char **argv)
 			RootWindowOfScreen(XtScreen(topLevel)),
 			(char *) triangles_bits,
 			triangles_width, triangles_height);
-	XtSetArg(arg[0], XtNiconPixmap, trianglesIcon);
 #ifdef HAVE_MOTIF
-	/* not XmEXPLICIT */
-	XtSetArg(arg[1], XmNkeyboardFocusPolicy, XmPOINTER);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, trianglesIcon,
+		XmNkeyboardFocusPolicy, XmPOINTER, NULL); /* not XmEXPLICIT */
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
 		xmPanedWindowWidgetClass, topLevel,
 		XmNseparatorOn, False,
@@ -1336,8 +1320,9 @@ main(int argc, char **argv)
 	triangles = XtCreateManagedWidget("triangles",
 		trianglesWidgetClass, mainPanel, NULL, 0);
 #else
-	XtSetArg(arg[1], XtNinput, True);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, trianglesIcon,
+		XtNinput, True, NULL);
 	triangles = XtCreateManagedWidget("triangles",
 		trianglesWidgetClass, topLevel, NULL, 0);
 #endif
